import { nothing } from "lit";
import SgdsElement from "../../base/sgds-element";
import SgdsCloseButton from "../../internals/CloseButton/sgds-close-button";
import SgdsIcon from "../Icon/sgds-icon";
export type AlertVariant = "info" | "success" | "danger" | "warning" | "neutral";
/**
 * @summary Alerts provide short, timely, and relevant information for your users. It can be a simple text message or customised HTML content with paragraphs, headings and links.
 *
 * @slot default - The alert's main content.
 * @slot icon - An icon to show in the alert. Pass in SVG elements.
 *
 * @event sgds-show - Emitted when the alert appears.
 * @event sgds-hide - Emitted after the alert closes.
 *
 */
export declare class SgdsAlert extends SgdsElement {
    static styles: import("lit").CSSResult[];
    /**@internal */
    static dependencies: {
        "sgds-close-button": typeof SgdsCloseButton;
        "sgds-icon": typeof SgdsIcon;
    };
    /** Controls the appearance of the alert  */
    show: boolean;
    /** Enables a close button that allows the user to dismiss the alert. */
    dismissible: boolean;
    /** The alert's theme variant. */
    variant: AlertVariant;
    /** Controls the alert visual between a lighter outline and a solid darker variant. */
    outlined: boolean;
    /** The title of the alert. Only text is allowed */
    title: string;
    /** Closes the alert  */
    close(): void;
    /**@internal */
    _handleShowChange(): void;
    render(): import("lit-html").TemplateResult | typeof nothing;
}
export default SgdsAlert;
