import { __decorate } from 'tslib';
import { html } from 'lit';
import { property } from 'lit/decorators.js';
import SgdsElement from '../../base/sgds-element.js';
import css_248z from './link.js';

/**
 * @summary Link allows users to click and navigate their way from page to page
 *
 * @slot default - Pass in a single anchor tag here
 */
class SgdsLink extends SgdsElement {
    constructor() {
        super(...arguments);
        /** Determines the size of the link */
        this.size = "md";
        /** when true, sets the active stylings of the link */
        this.variant = "primary";
    }
    _handleSlotChange(e) {
        const anchor = this.querySelector("a");
        if (anchor) {
            if (anchor.hasAttribute("disabled")) {
                anchor.setAttribute("href", "javascript:void(0)");
                anchor.setAttribute("tabindex", "-1");
            }
            else {
                anchor.setAttribute("tabindex", "0");
            }
        }
    }
    render() {
        /** When removing href, link is no longer focusable */
        return html `<slot class="nav-link" @slotchange=${this._handleSlotChange}></slot>`;
    }
}
SgdsLink.styles = [...SgdsElement.styles, css_248z];
__decorate([
    property({ type: String, reflect: true })
], SgdsLink.prototype, "size", void 0);
__decorate([
    property({ type: String, reflect: true })
], SgdsLink.prototype, "variant", void 0);

export { SgdsLink, SgdsLink as default };
//# sourceMappingURL=sgds-link.js.map
