import SgdsElement from "../../base/sgds-element";
/**
 * @summary Switch component is used to toggle on and off or yes or no action.
 *
 * @slot default - The default label of switch on the right side of the switch
 * @slot leftLabel - The label on the left side of the switch
 *
 * @event sgds-change - Emitted when the checked state changes.
 *
 */
export declare class SgdsSwitch extends SgdsElement {
    static styles: import("lit").CSSResult[];
    /** The size of the switch. By default, it is small size */
    size: "sm" | "md" | "lg";
    /** When enabled, icon appears in the switch */
    icon: boolean;
    /**@internal */
    input: HTMLInputElement;
    /** Draws the switch in a checked state. */
    checked: boolean;
    /** Disables the switch (so the user can't check / uncheck it). */
    disabled: boolean;
    /** @internal Gets or sets the default value used to reset this element. The initial value corresponds to the one originally specified in the HTML that created this element. */
    defaultChecked: boolean;
    /** Simulates a click on the switch. */
    click(): void;
    /** Sets focus on the switch. */
    focus(options?: FocusOptions): void;
    /** Removes focus from the switch. */
    blur(): void;
    private _handleChange;
    private _handleKeyDown;
    /** @internal For Id/For pair of the HTML form control and label. */
    private _inputId;
    /** @internal */
    _handleDisabledChange(): void;
    private _leftIconNodes;
    firstUpdated(): void;
    render(): import("lit-html").TemplateResult<1>;
}
export default SgdsSwitch;
