import SgdsElement from "../../base/sgds-element";
export type HeaderPosition = "horizontal" | "vertical" | "both";
/**
 * @summary The use of a table is to organise a collections of data into readable rows
 */
export declare class SgdsTable extends SgdsElement {
    static styles: import("lit").CSSResult[];
    /**
     * Use responsive="sm", responsive="md" , responsive="lg", or responsive="xl" as needed to create responsive tables up to a particular breakpoint. From that breakpoint and up, the table will behave normally and not scroll horizontally. Use reponsive="always" to let table be always responsive
     */
    responsive: "sm" | "md" | "lg" | "xl" | "always";
    /**
     * Populate row header cells using Arrays
     */
    rowHeader: string[];
    /**
     * Populate column header cells using Arrays only when <code>headerPosition="vertical"</code> or <code>headerPosition="both"</code>
     */
    columnHeader: string[];
    /**
     * Populate data cells using Arrays
     */
    tableData: Array<(string | number)[]>;
    /**
     * Defines the placement of headers in the table (horizontal, vertical, or both)
     */
    headerPosition: HeaderPosition;
    /** @internal */
    originalTableData: Array<(string | number)[]>;
    connectedCallback(): void;
    private _renderTable;
    render(): import("lit-html").TemplateResult<1>;
}
export default SgdsTable;
