'use client';
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var tslib = require('tslib');
var lit = require('lit');
var decorators_js = require('lit/decorators.js');
var sgdsElement = require('../../base/sgds-element.cjs.js');
var link = require('./link.cjs.js');

/**
 * @summary Link allows users to click and navigate their way from page to page
 *
 * @slot default - Pass in a single anchor tag here
 */
class SgdsLink extends sgdsElement["default"] {
    constructor() {
        super(...arguments);
        /** Determines the size of the link */
        this.size = "md";
        /** when true, sets the active stylings of the link */
        this.variant = "primary";
    }
    _handleSlotChange(e) {
        const anchor = this.querySelector("a");
        if (anchor) {
            if (anchor.hasAttribute("disabled")) {
                anchor.setAttribute("href", "javascript:void(0)");
                anchor.setAttribute("tabindex", "-1");
            }
            else {
                anchor.setAttribute("tabindex", "0");
            }
        }
    }
    render() {
        /** When removing href, link is no longer focusable */
        return lit.html `<slot class="nav-link" @slotchange=${this._handleSlotChange}></slot>`;
    }
}
SgdsLink.styles = [...sgdsElement["default"].styles, link["default"]];
tslib.__decorate([
    decorators_js.property({ type: String, reflect: true })
], SgdsLink.prototype, "size", void 0);
tslib.__decorate([
    decorators_js.property({ type: String, reflect: true })
], SgdsLink.prototype, "variant", void 0);

exports.SgdsLink = SgdsLink;
exports["default"] = SgdsLink;
//# sourceMappingURL=sgds-link.cjs.js.map
