'use client';
import { __decorate } from 'tslib';
import { html } from 'lit';
import { property } from 'lit/decorators.js';
import { watch } from '../../utils/watch.js';
import SgdsElement from '../../base/sgds-element.js';
import css_248z from './mainnav-item.js';

/**
 * @slot default - slot for SgdsMainnavItem element.
 *
 *  */
class SgdsMainnavItem extends SgdsElement {
    constructor() {
        super(...arguments);
        /** when true, sets the active stylings of .nav-link */
        this.active = false;
        /** Disables the SgdsMainnavItem */
        this.disabled = false;
    }
    _handleDisabled() {
        this.setAttribute("aria-disabled", `${this.disabled}`);
    }
    _handleSlotChange(e) {
        const slot = e.target;
        const assignedElements = slot.assignedElements({ flatten: true });
        const anchorItems = assignedElements.filter(item => item.tagName.toLowerCase() === "a" || item.tagName.toLowerCase() === "sgds-link");
        if (anchorItems.length > 1) {
            console.error("More than one anchor tag is added to sgds-mainnav-item");
            return;
        }
        if (anchorItems.length === 0) {
            const nodes = slot.assignedNodes({ flatten: true });
            nodes.forEach(node => {
                if (node.nodeType === Node.TEXT_NODE) {
                    const hyperlink = document.createElement("a");
                    hyperlink.textContent = node.textContent;
                    node.parentNode.replaceChild(hyperlink, node);
                }
            });
        }
        if (anchorItems.length === 1) {
            const anchor = anchorItems[0];
            if (this.active) {
                anchor.setAttribute("aria-current", "true");
            }
            if (this.disabled) {
                anchor.setAttribute("href", "javascript:void(0)");
                anchor.setAttribute("tabindex", "-1");
            }
        }
    }
    render() {
        return html `<slot @slotchange=${this._handleSlotChange}></slot>`;
    }
}
SgdsMainnavItem.styles = [...SgdsElement.styles, css_248z];
__decorate([
    property({ type: Boolean })
], SgdsMainnavItem.prototype, "active", void 0);
__decorate([
    property({ type: Boolean, reflect: true })
], SgdsMainnavItem.prototype, "disabled", void 0);
__decorate([
    watch("disabled")
], SgdsMainnavItem.prototype, "_handleDisabled", null);

export { SgdsMainnavItem, SgdsMainnavItem as default };
//# sourceMappingURL=sgds-mainnav-item.js.map
