'use client';
import { __decorate } from 'tslib';
import { html } from 'lit';
import { property, queryAssignedElements } from 'lit/decorators.js';
import SgdsElement from '../../base/sgds-element.js';
import { watch } from '../../utils/watch.js';
import css_248z from './sidenav-link.js';

/**
 * @slot default - slot for label of anchor tag.
 */
class SgdsSidenavLink extends SgdsElement {
    constructor() {
        super(...arguments);
        /** when true, sets the active stylings of .nav-link */
        this.active = false;
        /** Disables the SgdsMainnavItem */
        this.disabled = false;
    }
    connectedCallback() {
        super.connectedCallback();
        this.setAttribute("aria-disabled", `${this.disabled}`);
    }
    _handleDisabled() {
        this.setAttribute("aria-disabled", `${this.disabled}`);
        this._anchor[0].setAttribute("aria-disabled", `${this.disabled}`);
        if (!this.disabled) {
            this._anchor[0].removeAttribute("tabindex");
        }
    }
    _handleSlotChange() {
        this._anchor[0].setAttribute("aria-disabled", `${this.disabled}`);
        /** If link is disabled, set tabindex of anchor to -1 */
        if (this.disabled) {
            this._anchor[0].setAttribute("tabindex", "-1");
            this._anchor[0].removeAttribute("href");
            this._anchor[0].setAttribute("role", "link");
        }
    }
    render() {
        return html ` <slot @slotchange=${this._handleSlotChange}></slot> `;
    }
}
SgdsSidenavLink.styles = [...SgdsElement.styles, css_248z];
__decorate([
    property({ type: Boolean, reflect: true })
], SgdsSidenavLink.prototype, "active", void 0);
__decorate([
    property({ type: Boolean, reflect: true })
], SgdsSidenavLink.prototype, "disabled", void 0);
__decorate([
    queryAssignedElements({ flatten: true })
], SgdsSidenavLink.prototype, "_anchor", void 0);
__decorate([
    watch("disabled", { waitUntilFirstUpdate: true })
], SgdsSidenavLink.prototype, "_handleDisabled", null);

export { SgdsSidenavLink, SgdsSidenavLink as default };
//# sourceMappingURL=sgds-sidenav-link.js.map
