'use client';
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const locks = new Set();
/**
 * Prevents body scrolling. Keeps track of which elements requested a lock so multiple levels of locking are possible
 * without premature unlocking.
 */
function lockBodyScrolling(lockingEl) {
    locks.add(lockingEl);
    document.body.classList.add("sl-scroll-lock");
}
/**
 * Unlocks body scrolling. Scrolling will only be unlocked once all elements that requested a lock call this method.
 */
function unlockBodyScrolling(lockingEl) {
    locks.delete(lockingEl);
    if (locks.size === 0) {
        document.body.classList.remove("sl-scroll-lock");
    }
}

exports.lockBodyScrolling = lockBodyScrolling;
exports.unlockBodyScrolling = unlockBodyScrolling;
//# sourceMappingURL=scroll.cjs.js.map
