(function (factory) {
  typeof define === 'function' && define.amd ? define(factory) :
  factory();
})((function () { 'use strict';

  /******************************************************************************
  Copyright (c) Microsoft Corporation.

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
  REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
  AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
  INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
  LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
  OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
  PERFORMANCE OF THIS SOFTWARE.
  ***************************************************************************** */

  function __decorate(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
  }

  typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
    var e = new Error(message);
    return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
  };

  /**
   * @license
   * Copyright 2019 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  const NODE_MODE$1 = false;
  // Allows minifiers to rename references to globalThis
  const global$4 = globalThis;
  /**
   * Whether the current browser supports `adoptedStyleSheets`.
   */
  const supportsAdoptingStyleSheets$1 = global$4.ShadowRoot &&
      (global$4.ShadyCSS === undefined || global$4.ShadyCSS.nativeShadow) &&
      'adoptedStyleSheets' in Document.prototype &&
      'replace' in CSSStyleSheet.prototype;
  const constructionToken$1 = Symbol();
  const cssTagCache$1 = new WeakMap();
  /**
   * A container for a string of CSS text, that may be used to create a CSSStyleSheet.
   *
   * CSSResult is the return value of `css`-tagged template literals and
   * `unsafeCSS()`. In order to ensure that CSSResults are only created via the
   * `css` tag and `unsafeCSS()`, CSSResult cannot be constructed directly.
   */
  class CSSResult$1 {
      constructor(cssText, strings, safeToken) {
          // This property needs to remain unminified.
          this['_$cssResult$'] = true;
          if (safeToken !== constructionToken$1) {
              throw new Error('CSSResult is not constructable. Use `unsafeCSS` or `css` instead.');
          }
          this.cssText = cssText;
          this._strings = strings;
      }
      // This is a getter so that it's lazy. In practice, this means stylesheets
      // are not created until the first element instance is made.
      get styleSheet() {
          // If `supportsAdoptingStyleSheets` is true then we assume CSSStyleSheet is
          // constructable.
          let styleSheet = this._styleSheet;
          const strings = this._strings;
          if (supportsAdoptingStyleSheets$1 && styleSheet === undefined) {
              const cacheable = strings !== undefined && strings.length === 1;
              if (cacheable) {
                  styleSheet = cssTagCache$1.get(strings);
              }
              if (styleSheet === undefined) {
                  (this._styleSheet = styleSheet = new CSSStyleSheet()).replaceSync(this.cssText);
                  if (cacheable) {
                      cssTagCache$1.set(strings, styleSheet);
                  }
              }
          }
          return styleSheet;
      }
      toString() {
          return this.cssText;
      }
  }
  /**
   * Wrap a value for interpolation in a {@linkcode css} tagged template literal.
   *
   * This is unsafe because untrusted CSS text can be used to phone home
   * or exfiltrate data to an attacker controlled site. Take care to only use
   * this with trusted input.
   */
  const unsafeCSS$1 = (value) => new CSSResult$1(typeof value === 'string' ? value : String(value), undefined, constructionToken$1);
  /**
   * Applies the given styles to a `shadowRoot`. When Shadow DOM is
   * available but `adoptedStyleSheets` is not, styles are appended to the
   * `shadowRoot` to [mimic spec behavior](https://wicg.github.io/construct-stylesheets/#using-constructed-stylesheets).
   * Note, when shimming is used, any styles that are subsequently placed into
   * the shadowRoot should be placed *before* any shimmed adopted styles. This
   * will match spec behavior that gives adopted sheets precedence over styles in
   * shadowRoot.
   */
  const adoptStyles$1 = (renderRoot, styles) => {
      if (supportsAdoptingStyleSheets$1) {
          renderRoot.adoptedStyleSheets = styles.map((s) => s instanceof CSSStyleSheet ? s : s.styleSheet);
      }
      else {
          for (const s of styles) {
              const style = document.createElement('style');
              // eslint-disable-next-line @typescript-eslint/no-explicit-any
              const nonce = global$4['litNonce'];
              if (nonce !== undefined) {
                  style.setAttribute('nonce', nonce);
              }
              style.textContent = s.cssText;
              renderRoot.appendChild(style);
          }
      }
  };
  const cssResultFromStyleSheet$1 = (sheet) => {
      let cssText = '';
      for (const rule of sheet.cssRules) {
          cssText += rule.cssText;
      }
      return unsafeCSS$1(cssText);
  };
  const getCompatibleStyle$1 = supportsAdoptingStyleSheets$1 ||
      (NODE_MODE$1 )
      ? (s) => s
      : (s) => s instanceof CSSStyleSheet ? cssResultFromStyleSheet$1(s) : s;

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  // TODO (justinfagnani): Add `hasOwn` here when we ship ES2022
  const { is: is$1, defineProperty: defineProperty$1, getOwnPropertyDescriptor: getOwnPropertyDescriptor$1, getOwnPropertyNames: getOwnPropertyNames$1, getOwnPropertySymbols: getOwnPropertySymbols$1, getPrototypeOf: getPrototypeOf$1, } = Object;
  // Lets a minifier replace globalThis references with a minified name
  const global$3 = globalThis;
  let issueWarning$5;
  const trustedTypes$2 = global$3
      .trustedTypes;
  // Temporary workaround for https://crbug.com/993268
  // Currently, any attribute starting with "on" is considered to be a
  // TrustedScript source. Such boolean attributes must be set to the equivalent
  // trusted emptyScript value.
  const emptyStringForBooleanAttribute$1 = trustedTypes$2
      ? trustedTypes$2.emptyScript
      : '';
  const polyfillSupport$3 = global$3.reactiveElementPolyfillSupportDevMode
      ;
  {
      // Ensure warnings are issued only 1x, even if multiple versions of Lit
      // are loaded.
      const issuedWarnings = (global$3.litIssuedWarnings ??=
          new Set());
      // Issue a warning, if we haven't already.
      issueWarning$5 = (code, warning) => {
          warning += ` See https://lit.dev/msg/${code} for more information.`;
          if (!issuedWarnings.has(warning)) {
              console.warn(warning);
              issuedWarnings.add(warning);
          }
      };
      issueWarning$5('dev-mode', `Lit is in dev mode. Not recommended for production!`);
      // Issue polyfill support warning.
      if (global$3.ShadyDOM?.inUse && polyfillSupport$3 === undefined) {
          issueWarning$5('polyfill-support-missing', `Shadow DOM is being polyfilled via \`ShadyDOM\` but ` +
              `the \`polyfill-support\` module has not been loaded.`);
      }
  }
  /**
   * Useful for visualizing and logging insights into what the Lit template system is doing.
   *
   * Compiled out of prod mode builds.
   */
  const debugLogEvent$2 = (event) => {
          const shouldEmit = global$3
              .emitLitDebugLogEvents;
          if (!shouldEmit) {
              return;
          }
          global$3.dispatchEvent(new CustomEvent('lit-debug', {
              detail: event,
          }));
      }
      ;
  /*
   * When using Closure Compiler, JSCompiler_renameProperty(property, object) is
   * replaced at compile time by the munged name for object[property]. We cannot
   * alias this function, so we have to use a small shim that has the same
   * behavior when not compiling.
   */
  /*@__INLINE__*/
  const JSCompiler_renameProperty$2 = (prop, _obj) => prop;
  const defaultConverter$1 = {
      toAttribute(value, type) {
          switch (type) {
              case Boolean:
                  value = value ? emptyStringForBooleanAttribute$1 : null;
                  break;
              case Object:
              case Array:
                  // if the value is `null` or `undefined` pass this through
                  // to allow removing/no change behavior.
                  value = value == null ? value : JSON.stringify(value);
                  break;
          }
          return value;
      },
      fromAttribute(value, type) {
          let fromValue = value;
          switch (type) {
              case Boolean:
                  fromValue = value !== null;
                  break;
              case Number:
                  fromValue = value === null ? null : Number(value);
                  break;
              case Object:
              case Array:
                  // Do *not* generate exception when invalid JSON is set as elements
                  // don't normally complain on being mis-configured.
                  // TODO(sorvell): Do generate exception in *dev mode*.
                  try {
                      // Assert to adhere to Bazel's "must type assert JSON parse" rule.
                      fromValue = JSON.parse(value);
                  }
                  catch (e) {
                      fromValue = null;
                  }
                  break;
          }
          return fromValue;
      },
  };
  /**
   * Change function that returns true if `value` is different from `oldValue`.
   * This method is used as the default for a property's `hasChanged` function.
   */
  const notEqual$1 = (value, old) => !is$1(value, old);
  const defaultPropertyDeclaration$2 = {
      attribute: true,
      type: String,
      converter: defaultConverter$1,
      reflect: false,
      hasChanged: notEqual$1,
  };
  // Ensure metadata is enabled. TypeScript does not polyfill
  // Symbol.metadata, so we must ensure that it exists.
  Symbol.metadata ??= Symbol('metadata');
  // Map from a class's metadata object to property options
  // Note that we must use nullish-coalescing assignment so that we only use one
  // map even if we load multiple version of this module.
  global$3.litPropertyMetadata ??= new WeakMap();
  /**
   * Base element class which manages element properties and attributes. When
   * properties change, the `update` method is asynchronously called. This method
   * should be supplied by subclasses to render updates as desired.
   * @noInheritDoc
   */
  class ReactiveElement$1
  // In the Node build, this `extends` clause will be substituted with
  // `(globalThis.HTMLElement ?? HTMLElement)`.
  //
  // This way, we will first prefer any global `HTMLElement` polyfill that the
  // user has assigned, and then fall back to the `HTMLElement` shim which has
  // been imported (see note at the top of this file about how this import is
  // generated by Rollup). Note that the `HTMLElement` variable has been
  // shadowed by this import, so it no longer refers to the global.
   extends HTMLElement {
      /**
       * Adds an initializer function to the class that is called during instance
       * construction.
       *
       * This is useful for code that runs against a `ReactiveElement`
       * subclass, such as a decorator, that needs to do work for each
       * instance, such as setting up a `ReactiveController`.
       *
       * ```ts
       * const myDecorator = (target: typeof ReactiveElement, key: string) => {
       *   target.addInitializer((instance: ReactiveElement) => {
       *     // This is run during construction of the element
       *     new MyController(instance);
       *   });
       * }
       * ```
       *
       * Decorating a field will then cause each instance to run an initializer
       * that adds a controller:
       *
       * ```ts
       * class MyElement extends LitElement {
       *   @myDecorator foo;
       * }
       * ```
       *
       * Initializers are stored per-constructor. Adding an initializer to a
       * subclass does not add it to a superclass. Since initializers are run in
       * constructors, initializers will run in order of the class hierarchy,
       * starting with superclasses and progressing to the instance's class.
       *
       * @nocollapse
       */
      static addInitializer(initializer) {
          this.__prepare();
          (this._initializers ??= []).push(initializer);
      }
      /**
       * Returns a list of attributes corresponding to the registered properties.
       * @nocollapse
       * @category attributes
       */
      static get observedAttributes() {
          // Ensure we've created all properties
          this.finalize();
          // this.__attributeToPropertyMap is only undefined after finalize() in
          // ReactiveElement itself. ReactiveElement.observedAttributes is only
          // accessed with ReactiveElement as the receiver when a subclass or mixin
          // calls super.observedAttributes
          return (this.__attributeToPropertyMap && [...this.__attributeToPropertyMap.keys()]);
      }
      /**
       * Creates a property accessor on the element prototype if one does not exist
       * and stores a {@linkcode PropertyDeclaration} for the property with the
       * given options. The property setter calls the property's `hasChanged`
       * property option or uses a strict identity check to determine whether or not
       * to request an update.
       *
       * This method may be overridden to customize properties; however,
       * when doing so, it's important to call `super.createProperty` to ensure
       * the property is setup correctly. This method calls
       * `getPropertyDescriptor` internally to get a descriptor to install.
       * To customize what properties do when they are get or set, override
       * `getPropertyDescriptor`. To customize the options for a property,
       * implement `createProperty` like this:
       *
       * ```ts
       * static createProperty(name, options) {
       *   options = Object.assign(options, {myOption: true});
       *   super.createProperty(name, options);
       * }
       * ```
       *
       * @nocollapse
       * @category properties
       */
      static createProperty(name, options = defaultPropertyDeclaration$2) {
          // If this is a state property, force the attribute to false.
          if (options.state) {
              options.attribute = false;
          }
          this.__prepare();
          this.elementProperties.set(name, options);
          if (!options.noAccessor) {
              const key = // Use Symbol.for in dev mode to make it easier to maintain state
                      // when doing HMR.
                      Symbol.for(`${String(name)} (@property() cache)`)
                  ;
              const descriptor = this.getPropertyDescriptor(name, key, options);
              if (descriptor !== undefined) {
                  defineProperty$1(this.prototype, name, descriptor);
              }
          }
      }
      /**
       * Returns a property descriptor to be defined on the given named property.
       * If no descriptor is returned, the property will not become an accessor.
       * For example,
       *
       * ```ts
       * class MyElement extends LitElement {
       *   static getPropertyDescriptor(name, key, options) {
       *     const defaultDescriptor =
       *         super.getPropertyDescriptor(name, key, options);
       *     const setter = defaultDescriptor.set;
       *     return {
       *       get: defaultDescriptor.get,
       *       set(value) {
       *         setter.call(this, value);
       *         // custom action.
       *       },
       *       configurable: true,
       *       enumerable: true
       *     }
       *   }
       * }
       * ```
       *
       * @nocollapse
       * @category properties
       */
      static getPropertyDescriptor(name, key, options) {
          const { get, set } = getOwnPropertyDescriptor$1(this.prototype, name) ?? {
              get() {
                  return this[key];
              },
              set(v) {
                  this[key] = v;
              },
          };
          if (get == null) {
              if ('value' in (getOwnPropertyDescriptor$1(this.prototype, name) ?? {})) {
                  throw new Error(`Field ${JSON.stringify(String(name))} on ` +
                      `${this.name} was declared as a reactive property ` +
                      `but it's actually declared as a value on the prototype. ` +
                      `Usually this is due to using @property or @state on a method.`);
              }
              issueWarning$5('reactive-property-without-getter', `Field ${JSON.stringify(String(name))} on ` +
                  `${this.name} was declared as a reactive property ` +
                  `but it does not have a getter. This will be an error in a ` +
                  `future version of Lit.`);
          }
          return {
              get() {
                  return get?.call(this);
              },
              set(value) {
                  const oldValue = get?.call(this);
                  set.call(this, value);
                  this.requestUpdate(name, oldValue, options);
              },
              configurable: true,
              enumerable: true,
          };
      }
      /**
       * Returns the property options associated with the given property.
       * These options are defined with a `PropertyDeclaration` via the `properties`
       * object or the `@property` decorator and are registered in
       * `createProperty(...)`.
       *
       * Note, this method should be considered "final" and not overridden. To
       * customize the options for a given property, override
       * {@linkcode createProperty}.
       *
       * @nocollapse
       * @final
       * @category properties
       */
      static getPropertyOptions(name) {
          return this.elementProperties.get(name) ?? defaultPropertyDeclaration$2;
      }
      /**
       * Initializes static own properties of the class used in bookkeeping
       * for element properties, initializers, etc.
       *
       * Can be called multiple times by code that needs to ensure these
       * properties exist before using them.
       *
       * This method ensures the superclass is finalized so that inherited
       * property metadata can be copied down.
       * @nocollapse
       */
      static __prepare() {
          if (this.hasOwnProperty(JSCompiler_renameProperty$2('elementProperties'))) {
              // Already prepared
              return;
          }
          // Finalize any superclasses
          const superCtor = getPrototypeOf$1(this);
          superCtor.finalize();
          // Create own set of initializers for this class if any exist on the
          // superclass and copy them down. Note, for a small perf boost, avoid
          // creating initializers unless needed.
          if (superCtor._initializers !== undefined) {
              this._initializers = [...superCtor._initializers];
          }
          // Initialize elementProperties from the superclass
          this.elementProperties = new Map(superCtor.elementProperties);
      }
      /**
       * Finishes setting up the class so that it's ready to be registered
       * as a custom element and instantiated.
       *
       * This method is called by the ReactiveElement.observedAttributes getter.
       * If you override the observedAttributes getter, you must either call
       * super.observedAttributes to trigger finalization, or call finalize()
       * yourself.
       *
       * @nocollapse
       */
      static finalize() {
          if (this.hasOwnProperty(JSCompiler_renameProperty$2('finalized'))) {
              return;
          }
          this.finalized = true;
          this.__prepare();
          // Create properties from the static properties block:
          if (this.hasOwnProperty(JSCompiler_renameProperty$2('properties'))) {
              const props = this.properties;
              const propKeys = [
                  ...getOwnPropertyNames$1(props),
                  ...getOwnPropertySymbols$1(props),
              ];
              for (const p of propKeys) {
                  this.createProperty(p, props[p]);
              }
          }
          // Create properties from standard decorator metadata:
          const metadata = this[Symbol.metadata];
          if (metadata !== null) {
              const properties = litPropertyMetadata.get(metadata);
              if (properties !== undefined) {
                  for (const [p, options] of properties) {
                      this.elementProperties.set(p, options);
                  }
              }
          }
          // Create the attribute-to-property map
          this.__attributeToPropertyMap = new Map();
          for (const [p, options] of this.elementProperties) {
              const attr = this.__attributeNameForProperty(p, options);
              if (attr !== undefined) {
                  this.__attributeToPropertyMap.set(attr, p);
              }
          }
          this.elementStyles = this.finalizeStyles(this.styles);
          {
              if (this.hasOwnProperty('createProperty')) {
                  issueWarning$5('no-override-create-property', 'Overriding ReactiveElement.createProperty() is deprecated. ' +
                      'The override will not be called with standard decorators');
              }
              if (this.hasOwnProperty('getPropertyDescriptor')) {
                  issueWarning$5('no-override-get-property-descriptor', 'Overriding ReactiveElement.getPropertyDescriptor() is deprecated. ' +
                      'The override will not be called with standard decorators');
              }
          }
      }
      /**
       * Takes the styles the user supplied via the `static styles` property and
       * returns the array of styles to apply to the element.
       * Override this method to integrate into a style management system.
       *
       * Styles are deduplicated preserving the _last_ instance in the list. This
       * is a performance optimization to avoid duplicated styles that can occur
       * especially when composing via subclassing. The last item is kept to try
       * to preserve the cascade order with the assumption that it's most important
       * that last added styles override previous styles.
       *
       * @nocollapse
       * @category styles
       */
      static finalizeStyles(styles) {
          const elementStyles = [];
          if (Array.isArray(styles)) {
              // Dedupe the flattened array in reverse order to preserve the last items.
              // Casting to Array<unknown> works around TS error that
              // appears to come from trying to flatten a type CSSResultArray.
              const set = new Set(styles.flat(Infinity).reverse());
              // Then preserve original order by adding the set items in reverse order.
              for (const s of set) {
                  elementStyles.unshift(getCompatibleStyle$1(s));
              }
          }
          else if (styles !== undefined) {
              elementStyles.push(getCompatibleStyle$1(styles));
          }
          return elementStyles;
      }
      /**
       * Returns the property name for the given attribute `name`.
       * @nocollapse
       */
      static __attributeNameForProperty(name, options) {
          const attribute = options.attribute;
          return attribute === false
              ? undefined
              : typeof attribute === 'string'
                  ? attribute
                  : typeof name === 'string'
                      ? name.toLowerCase()
                      : undefined;
      }
      constructor() {
          super();
          this.__instanceProperties = undefined;
          /**
           * True if there is a pending update as a result of calling `requestUpdate()`.
           * Should only be read.
           * @category updates
           */
          this.isUpdatePending = false;
          /**
           * Is set to `true` after the first update. The element code cannot assume
           * that `renderRoot` exists before the element `hasUpdated`.
           * @category updates
           */
          this.hasUpdated = false;
          /**
           * Name of currently reflecting property
           */
          this.__reflectingProperty = null;
          this.__initialize();
      }
      /**
       * Internal only override point for customizing work done when elements
       * are constructed.
       */
      __initialize() {
          this.__updatePromise = new Promise((res) => (this.enableUpdating = res));
          this._$changedProperties = new Map();
          // This enqueues a microtask that ust run before the first update, so it
          // must be called before requestUpdate()
          this.__saveInstanceProperties();
          // ensures first update will be caught by an early access of
          // `updateComplete`
          this.requestUpdate();
          this.constructor._initializers?.forEach((i) => i(this));
      }
      /**
       * Registers a `ReactiveController` to participate in the element's reactive
       * update cycle. The element automatically calls into any registered
       * controllers during its lifecycle callbacks.
       *
       * If the element is connected when `addController()` is called, the
       * controller's `hostConnected()` callback will be immediately called.
       * @category controllers
       */
      addController(controller) {
          (this.__controllers ??= new Set()).add(controller);
          // If a controller is added after the element has been connected,
          // call hostConnected. Note, re-using existence of `renderRoot` here
          // (which is set in connectedCallback) to avoid the need to track a
          // first connected state.
          if (this.renderRoot !== undefined && this.isConnected) {
              controller.hostConnected?.();
          }
      }
      /**
       * Removes a `ReactiveController` from the element.
       * @category controllers
       */
      removeController(controller) {
          this.__controllers?.delete(controller);
      }
      /**
       * Fixes any properties set on the instance before upgrade time.
       * Otherwise these would shadow the accessor and break these properties.
       * The properties are stored in a Map which is played back after the
       * constructor runs. Note, on very old versions of Safari (<=9) or Chrome
       * (<=41), properties created for native platform properties like (`id` or
       * `name`) may not have default values set in the element constructor. On
       * these browsers native properties appear on instances and therefore their
       * default value will overwrite any element default (e.g. if the element sets
       * this.id = 'id' in the constructor, the 'id' will become '' since this is
       * the native platform default).
       */
      __saveInstanceProperties() {
          const instanceProperties = new Map();
          const elementProperties = this.constructor
              .elementProperties;
          for (const p of elementProperties.keys()) {
              if (this.hasOwnProperty(p)) {
                  instanceProperties.set(p, this[p]);
                  delete this[p];
              }
          }
          if (instanceProperties.size > 0) {
              this.__instanceProperties = instanceProperties;
          }
      }
      /**
       * Returns the node into which the element should render and by default
       * creates and returns an open shadowRoot. Implement to customize where the
       * element's DOM is rendered. For example, to render into the element's
       * childNodes, return `this`.
       *
       * @return Returns a node into which to render.
       * @category rendering
       */
      createRenderRoot() {
          const renderRoot = this.shadowRoot ??
              this.attachShadow(this.constructor.shadowRootOptions);
          adoptStyles$1(renderRoot, this.constructor.elementStyles);
          return renderRoot;
      }
      /**
       * On first connection, creates the element's renderRoot, sets up
       * element styling, and enables updating.
       * @category lifecycle
       */
      connectedCallback() {
          // Create renderRoot before controllers `hostConnected`
          this.renderRoot ??=
              this.createRenderRoot();
          this.enableUpdating(true);
          this.__controllers?.forEach((c) => c.hostConnected?.());
      }
      /**
       * Note, this method should be considered final and not overridden. It is
       * overridden on the element instance with a function that triggers the first
       * update.
       * @category updates
       */
      enableUpdating(_requestedUpdate) { }
      /**
       * Allows for `super.disconnectedCallback()` in extensions while
       * reserving the possibility of making non-breaking feature additions
       * when disconnecting at some point in the future.
       * @category lifecycle
       */
      disconnectedCallback() {
          this.__controllers?.forEach((c) => c.hostDisconnected?.());
      }
      /**
       * Synchronizes property values when attributes change.
       *
       * Specifically, when an attribute is set, the corresponding property is set.
       * You should rarely need to implement this callback. If this method is
       * overridden, `super.attributeChangedCallback(name, _old, value)` must be
       * called.
       *
       * See [using the lifecycle callbacks](https://developer.mozilla.org/en-US/docs/Web/Web_Components/Using_custom_elements#using_the_lifecycle_callbacks)
       * on MDN for more information about the `attributeChangedCallback`.
       * @category attributes
       */
      attributeChangedCallback(name, _old, value) {
          this._$attributeToProperty(name, value);
      }
      __propertyToAttribute(name, value) {
          const elemProperties = this.constructor.elementProperties;
          const options = elemProperties.get(name);
          const attr = this.constructor.__attributeNameForProperty(name, options);
          if (attr !== undefined && options.reflect === true) {
              const converter = options.converter?.toAttribute !==
                  undefined
                  ? options.converter
                  : defaultConverter$1;
              const attrValue = converter.toAttribute(value, options.type);
              if (this.constructor.enabledWarnings.includes('migration') &&
                  attrValue === undefined) {
                  issueWarning$5('undefined-attribute-value', `The attribute value for the ${name} property is ` +
                      `undefined on element ${this.localName}. The attribute will be ` +
                      `removed, but in the previous version of \`ReactiveElement\`, ` +
                      `the attribute would not have changed.`);
              }
              // Track if the property is being reflected to avoid
              // setting the property again via `attributeChangedCallback`. Note:
              // 1. this takes advantage of the fact that the callback is synchronous.
              // 2. will behave incorrectly if multiple attributes are in the reaction
              // stack at time of calling. However, since we process attributes
              // in `update` this should not be possible (or an extreme corner case
              // that we'd like to discover).
              // mark state reflecting
              this.__reflectingProperty = name;
              if (attrValue == null) {
                  this.removeAttribute(attr);
              }
              else {
                  this.setAttribute(attr, attrValue);
              }
              // mark state not reflecting
              this.__reflectingProperty = null;
          }
      }
      /** @internal */
      _$attributeToProperty(name, value) {
          const ctor = this.constructor;
          // Note, hint this as an `AttributeMap` so closure clearly understands
          // the type; it has issues with tracking types through statics
          const propName = ctor.__attributeToPropertyMap.get(name);
          // Use tracking info to avoid reflecting a property value to an attribute
          // if it was just set because the attribute changed.
          if (propName !== undefined && this.__reflectingProperty !== propName) {
              const options = ctor.getPropertyOptions(propName);
              const converter = typeof options.converter === 'function'
                  ? { fromAttribute: options.converter }
                  : options.converter?.fromAttribute !== undefined
                      ? options.converter
                      : defaultConverter$1;
              // mark state reflecting
              this.__reflectingProperty = propName;
              this[propName] = converter.fromAttribute(value, options.type
              // eslint-disable-next-line @typescript-eslint/no-explicit-any
              );
              // mark state not reflecting
              this.__reflectingProperty = null;
          }
      }
      /**
       * Requests an update which is processed asynchronously. This should be called
       * when an element should update based on some state not triggered by setting
       * a reactive property. In this case, pass no arguments. It should also be
       * called when manually implementing a property setter. In this case, pass the
       * property `name` and `oldValue` to ensure that any configured property
       * options are honored.
       *
       * @param name name of requesting property
       * @param oldValue old value of requesting property
       * @param options property options to use instead of the previously
       *     configured options
       * @category updates
       */
      requestUpdate(name, oldValue, options) {
          // If we have a property key, perform property update steps.
          if (name !== undefined) {
              if (name instanceof Event) {
                  issueWarning$5(``, `The requestUpdate() method was called with an Event as the property name. This is probably a mistake caused by binding this.requestUpdate as an event listener. Instead bind a function that will call it with no arguments: () => this.requestUpdate()`);
              }
              options ??= this.constructor.getPropertyOptions(name);
              const hasChanged = options.hasChanged ?? notEqual$1;
              const newValue = this[name];
              if (hasChanged(newValue, oldValue)) {
                  this._$changeProperty(name, oldValue, options);
              }
              else {
                  // Abort the request if the property should not be considered changed.
                  return;
              }
          }
          if (this.isUpdatePending === false) {
              this.__updatePromise = this.__enqueueUpdate();
          }
      }
      /**
       * @internal
       */
      _$changeProperty(name, oldValue, options) {
          // TODO (justinfagnani): Create a benchmark of Map.has() + Map.set(
          // vs just Map.set()
          if (!this._$changedProperties.has(name)) {
              this._$changedProperties.set(name, oldValue);
          }
          // Add to reflecting properties set.
          // Note, it's important that every change has a chance to add the
          // property to `__reflectingProperties`. This ensures setting
          // attribute + property reflects correctly.
          if (options.reflect === true && this.__reflectingProperty !== name) {
              (this.__reflectingProperties ??= new Set()).add(name);
          }
      }
      /**
       * Sets up the element to asynchronously update.
       */
      async __enqueueUpdate() {
          this.isUpdatePending = true;
          try {
              // Ensure any previous update has resolved before updating.
              // This `await` also ensures that property changes are batched.
              await this.__updatePromise;
          }
          catch (e) {
              // Refire any previous errors async so they do not disrupt the update
              // cycle. Errors are refired so developers have a chance to observe
              // them, and this can be done by implementing
              // `window.onunhandledrejection`.
              Promise.reject(e);
          }
          const result = this.scheduleUpdate();
          // If `scheduleUpdate` returns a Promise, we await it. This is done to
          // enable coordinating updates with a scheduler. Note, the result is
          // checked to avoid delaying an additional microtask unless we need to.
          if (result != null) {
              await result;
          }
          return !this.isUpdatePending;
      }
      /**
       * Schedules an element update. You can override this method to change the
       * timing of updates by returning a Promise. The update will await the
       * returned Promise, and you should resolve the Promise to allow the update
       * to proceed. If this method is overridden, `super.scheduleUpdate()`
       * must be called.
       *
       * For instance, to schedule updates to occur just before the next frame:
       *
       * ```ts
       * override protected async scheduleUpdate(): Promise<unknown> {
       *   await new Promise((resolve) => requestAnimationFrame(() => resolve()));
       *   super.scheduleUpdate();
       * }
       * ```
       * @category updates
       */
      scheduleUpdate() {
          const result = this.performUpdate();
          if (this.constructor.enabledWarnings.includes('async-perform-update') &&
              typeof result?.then ===
                  'function') {
              issueWarning$5('async-perform-update', `Element ${this.localName} returned a Promise from performUpdate(). ` +
                  `This behavior is deprecated and will be removed in a future ` +
                  `version of ReactiveElement.`);
          }
          return result;
      }
      /**
       * Performs an element update. Note, if an exception is thrown during the
       * update, `firstUpdated` and `updated` will not be called.
       *
       * Call `performUpdate()` to immediately process a pending update. This should
       * generally not be needed, but it can be done in rare cases when you need to
       * update synchronously.
       *
       * @category updates
       */
      performUpdate() {
          // Abort any update if one is not pending when this is called.
          // This can happen if `performUpdate` is called early to "flush"
          // the update.
          if (!this.isUpdatePending) {
              return;
          }
          debugLogEvent$2?.({ kind: 'update' });
          if (!this.hasUpdated) {
              // Create renderRoot before first update. This occurs in `connectedCallback`
              // but is done here to support out of tree calls to `enableUpdating`/`performUpdate`.
              this.renderRoot ??=
                  this.createRenderRoot();
              {
                  // Produce warning if any reactive properties on the prototype are
                  // shadowed by class fields. Instance fields set before upgrade are
                  // deleted by this point, so any own property is caused by class field
                  // initialization in the constructor.
                  const ctor = this.constructor;
                  const shadowedProperties = [...ctor.elementProperties.keys()].filter((p) => this.hasOwnProperty(p) && p in getPrototypeOf$1(this));
                  if (shadowedProperties.length) {
                      throw new Error(`The following properties on element ${this.localName} will not ` +
                          `trigger updates as expected because they are set using class ` +
                          `fields: ${shadowedProperties.join(', ')}. ` +
                          `Native class fields and some compiled output will overwrite ` +
                          `accessors used for detecting changes. See ` +
                          `https://lit.dev/msg/class-field-shadowing ` +
                          `for more information.`);
                  }
              }
              // Mixin instance properties once, if they exist.
              if (this.__instanceProperties) {
                  // TODO (justinfagnani): should we use the stored value? Could a new value
                  // have been set since we stored the own property value?
                  for (const [p, value] of this.__instanceProperties) {
                      this[p] = value;
                  }
                  this.__instanceProperties = undefined;
              }
              // Trigger initial value reflection and populate the initial
              // changedProperties map, but only for the case of experimental
              // decorators on accessors, which will not have already populated the
              // changedProperties map. We can't know if these accessors had
              // initializers, so we just set them anyway - a difference from
              // experimental decorators on fields and standard decorators on
              // auto-accessors.
              // For context why experimentalDecorators with auto accessors are handled
              // specifically also see:
              // https://github.com/lit/lit/pull/4183#issuecomment-1711959635
              const elementProperties = this.constructor
                  .elementProperties;
              if (elementProperties.size > 0) {
                  for (const [p, options] of elementProperties) {
                      if (options.wrapped === true &&
                          !this._$changedProperties.has(p) &&
                          this[p] !== undefined) {
                          this._$changeProperty(p, this[p], options);
                      }
                  }
              }
          }
          let shouldUpdate = false;
          const changedProperties = this._$changedProperties;
          try {
              shouldUpdate = this.shouldUpdate(changedProperties);
              if (shouldUpdate) {
                  this.willUpdate(changedProperties);
                  this.__controllers?.forEach((c) => c.hostUpdate?.());
                  this.update(changedProperties);
              }
              else {
                  this.__markUpdated();
              }
          }
          catch (e) {
              // Prevent `firstUpdated` and `updated` from running when there's an
              // update exception.
              shouldUpdate = false;
              // Ensure element can accept additional updates after an exception.
              this.__markUpdated();
              throw e;
          }
          // The update is no longer considered pending and further updates are now allowed.
          if (shouldUpdate) {
              this._$didUpdate(changedProperties);
          }
      }
      /**
       * Invoked before `update()` to compute values needed during the update.
       *
       * Implement `willUpdate` to compute property values that depend on other
       * properties and are used in the rest of the update process.
       *
       * ```ts
       * willUpdate(changedProperties) {
       *   // only need to check changed properties for an expensive computation.
       *   if (changedProperties.has('firstName') || changedProperties.has('lastName')) {
       *     this.sha = computeSHA(`${this.firstName} ${this.lastName}`);
       *   }
       * }
       *
       * render() {
       *   return html`SHA: ${this.sha}`;
       * }
       * ```
       *
       * @category updates
       */
      willUpdate(_changedProperties) { }
      // Note, this is an override point for polyfill-support.
      // @internal
      _$didUpdate(changedProperties) {
          this.__controllers?.forEach((c) => c.hostUpdated?.());
          if (!this.hasUpdated) {
              this.hasUpdated = true;
              this.firstUpdated(changedProperties);
          }
          this.updated(changedProperties);
          if (this.isUpdatePending &&
              this.constructor.enabledWarnings.includes('change-in-update')) {
              issueWarning$5('change-in-update', `Element ${this.localName} scheduled an update ` +
                  `(generally because a property was set) ` +
                  `after an update completed, causing a new update to be scheduled. ` +
                  `This is inefficient and should be avoided unless the next update ` +
                  `can only be scheduled as a side effect of the previous update.`);
          }
      }
      __markUpdated() {
          this._$changedProperties = new Map();
          this.isUpdatePending = false;
      }
      /**
       * Returns a Promise that resolves when the element has completed updating.
       * The Promise value is a boolean that is `true` if the element completed the
       * update without triggering another update. The Promise result is `false` if
       * a property was set inside `updated()`. If the Promise is rejected, an
       * exception was thrown during the update.
       *
       * To await additional asynchronous work, override the `getUpdateComplete`
       * method. For example, it is sometimes useful to await a rendered element
       * before fulfilling this Promise. To do this, first await
       * `super.getUpdateComplete()`, then any subsequent state.
       *
       * @return A promise of a boolean that resolves to true if the update completed
       *     without triggering another update.
       * @category updates
       */
      get updateComplete() {
          return this.getUpdateComplete();
      }
      /**
       * Override point for the `updateComplete` promise.
       *
       * It is not safe to override the `updateComplete` getter directly due to a
       * limitation in TypeScript which means it is not possible to call a
       * superclass getter (e.g. `super.updateComplete.then(...)`) when the target
       * language is ES5 (https://github.com/microsoft/TypeScript/issues/338).
       * This method should be overridden instead. For example:
       *
       * ```ts
       * class MyElement extends LitElement {
       *   override async getUpdateComplete() {
       *     const result = await super.getUpdateComplete();
       *     await this._myChild.updateComplete;
       *     return result;
       *   }
       * }
       * ```
       *
       * @return A promise of a boolean that resolves to true if the update completed
       *     without triggering another update.
       * @category updates
       */
      getUpdateComplete() {
          return this.__updatePromise;
      }
      /**
       * Controls whether or not `update()` should be called when the element requests
       * an update. By default, this method always returns `true`, but this can be
       * customized to control when to update.
       *
       * @param _changedProperties Map of changed properties with old values
       * @category updates
       */
      shouldUpdate(_changedProperties) {
          return true;
      }
      /**
       * Updates the element. This method reflects property values to attributes.
       * It can be overridden to render and keep updated element DOM.
       * Setting properties inside this method will *not* trigger
       * another update.
       *
       * @param _changedProperties Map of changed properties with old values
       * @category updates
       */
      update(_changedProperties) {
          // The forEach() expression will only run when when __reflectingProperties is
          // defined, and it returns undefined, setting __reflectingProperties to
          // undefined
          this.__reflectingProperties &&= this.__reflectingProperties.forEach((p) => this.__propertyToAttribute(p, this[p]));
          this.__markUpdated();
      }
      /**
       * Invoked whenever the element is updated. Implement to perform
       * post-updating tasks via DOM APIs, for example, focusing an element.
       *
       * Setting properties inside this method will trigger the element to update
       * again after this update cycle completes.
       *
       * @param _changedProperties Map of changed properties with old values
       * @category updates
       */
      updated(_changedProperties) { }
      /**
       * Invoked when the element is first updated. Implement to perform one time
       * work on the element after update.
       *
       * ```ts
       * firstUpdated() {
       *   this.renderRoot.getElementById('my-text-area').focus();
       * }
       * ```
       *
       * Setting properties inside this method will trigger the element to update
       * again after this update cycle completes.
       *
       * @param _changedProperties Map of changed properties with old values
       * @category updates
       */
      firstUpdated(_changedProperties) { }
  }
  /**
   * Memoized list of all element styles.
   * Created lazily on user subclasses when finalizing the class.
   * @nocollapse
   * @category styles
   */
  ReactiveElement$1.elementStyles = [];
  /**
   * Options used when calling `attachShadow`. Set this property to customize
   * the options for the shadowRoot; for example, to create a closed
   * shadowRoot: `{mode: 'closed'}`.
   *
   * Note, these options are used in `createRenderRoot`. If this method
   * is customized, options should be respected if possible.
   * @nocollapse
   * @category rendering
   */
  ReactiveElement$1.shadowRootOptions = { mode: 'open' };
  // Assigned here to work around a jscompiler bug with static fields
  // when compiling to ES5.
  // https://github.com/google/closure-compiler/issues/3177
  ReactiveElement$1[JSCompiler_renameProperty$2('elementProperties')] = new Map();
  ReactiveElement$1[JSCompiler_renameProperty$2('finalized')] = new Map();
  // Apply polyfills if available
  polyfillSupport$3?.({ ReactiveElement: ReactiveElement$1 });
  // Dev mode warnings...
  {
      // Default warning set.
      ReactiveElement$1.enabledWarnings = [
          'change-in-update',
          'async-perform-update',
      ];
      const ensureOwnWarnings = function (ctor) {
          if (!ctor.hasOwnProperty(JSCompiler_renameProperty$2('enabledWarnings'))) {
              ctor.enabledWarnings = ctor.enabledWarnings.slice();
          }
      };
      ReactiveElement$1.enableWarning = function (warning) {
          ensureOwnWarnings(this);
          if (!this.enabledWarnings.includes(warning)) {
              this.enabledWarnings.push(warning);
          }
      };
      ReactiveElement$1.disableWarning = function (warning) {
          ensureOwnWarnings(this);
          const i = this.enabledWarnings.indexOf(warning);
          if (i >= 0) {
              this.enabledWarnings.splice(i, 1);
          }
      };
  }
  // IMPORTANT: do not change the property name or the assignment expression.
  // This line will be used in regexes to search for ReactiveElement usage.
  (global$3.reactiveElementVersions ??= []).push('2.0.4');
  if (global$3.reactiveElementVersions.length > 1) {
      issueWarning$5('multiple-versions', `Multiple versions of Lit loaded. Loading multiple versions ` +
          `is not recommended.`);
  }

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  // Allows minifiers to rename references to globalThis
  const global$2 = globalThis;
  /**
   * Useful for visualizing and logging insights into what the Lit template system is doing.
   *
   * Compiled out of prod mode builds.
   */
  const debugLogEvent$1 = (event) => {
          const shouldEmit = global$2
              .emitLitDebugLogEvents;
          if (!shouldEmit) {
              return;
          }
          global$2.dispatchEvent(new CustomEvent('lit-debug', {
              detail: event,
          }));
      }
      ;
  // Used for connecting beginRender and endRender events when there are nested
  // renders when errors are thrown preventing an endRender event from being
  // called.
  let debugLogRenderId = 0;
  let issueWarning$4;
  {
      global$2.litIssuedWarnings ??= new Set();
      // Issue a warning, if we haven't already.
      issueWarning$4 = (code, warning) => {
          warning += code
              ? ` See https://lit.dev/msg/${code} for more information.`
              : '';
          if (!global$2.litIssuedWarnings.has(warning)) {
              console.warn(warning);
              global$2.litIssuedWarnings.add(warning);
          }
      };
      issueWarning$4('dev-mode', `Lit is in dev mode. Not recommended for production!`);
  }
  const wrap = global$2.ShadyDOM?.inUse &&
      global$2.ShadyDOM?.noPatch === true
      ? global$2.ShadyDOM.wrap
      : (node) => node;
  const trustedTypes$1 = global$2.trustedTypes;
  /**
   * Our TrustedTypePolicy for HTML which is declared using the html template
   * tag function.
   *
   * That HTML is a developer-authored constant, and is parsed with innerHTML
   * before any untrusted expressions have been mixed in. Therefor it is
   * considered safe by construction.
   */
  const policy = trustedTypes$1
      ? trustedTypes$1.createPolicy('lit-html', {
          createHTML: (s) => s,
      })
      : undefined;
  const identityFunction = (value) => value;
  const noopSanitizer = (_node, _name, _type) => identityFunction;
  /** Sets the global sanitizer factory. */
  const setSanitizer = (newSanitizer) => {
      if (sanitizerFactoryInternal !== noopSanitizer) {
          throw new Error(`Attempted to overwrite existing lit-html security policy.` +
              ` setSanitizeDOMValueFactory should be called at most once.`);
      }
      sanitizerFactoryInternal = newSanitizer;
  };
  /**
   * Only used in internal tests, not a part of the public API.
   */
  const _testOnlyClearSanitizerFactoryDoNotCallOrElse = () => {
      sanitizerFactoryInternal = noopSanitizer;
  };
  const createSanitizer = (node, name, type) => {
      return sanitizerFactoryInternal(node, name, type);
  };
  // Added to an attribute name to mark the attribute as bound so we can find
  // it easily.
  const boundAttributeSuffix = '$lit$';
  // This marker is used in many syntactic positions in HTML, so it must be
  // a valid element name and attribute name. We don't support dynamic names (yet)
  // but this at least ensures that the parse tree is closer to the template
  // intention.
  const marker = `lit$${Math.random().toFixed(9).slice(2)}$`;
  // String used to tell if a comment is a marker comment
  const markerMatch = '?' + marker;
  // Text used to insert a comment marker node. We use processing instruction
  // syntax because it's slightly smaller, but parses as a comment node.
  const nodeMarker = `<${markerMatch}>`;
  const d = document;
  // Creates a dynamic marker. We never have to search for these in the DOM.
  const createMarker = () => d.createComment('');
  const isPrimitive = (value) => value === null || (typeof value != 'object' && typeof value != 'function');
  const isArray = Array.isArray;
  const isIterable = (value) => isArray(value) ||
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      typeof value?.[Symbol.iterator] === 'function';
  const SPACE_CHAR = `[ \t\n\f\r]`;
  const ATTR_VALUE_CHAR = `[^ \t\n\f\r"'\`<>=]`;
  const NAME_CHAR = `[^\\s"'>=/]`;
  // These regexes represent the five parsing states that we care about in the
  // Template's HTML scanner. They match the *end* of the state they're named
  // after.
  // Depending on the match, we transition to a new state. If there's no match,
  // we stay in the same state.
  // Note that the regexes are stateful. We utilize lastIndex and sync it
  // across the multiple regexes used. In addition to the five regexes below
  // we also dynamically create a regex to find the matching end tags for raw
  // text elements.
  /**
   * End of text is: `<` followed by:
   *   (comment start) or (tag) or (dynamic tag binding)
   */
  const textEndRegex = /<(?:(!--|\/[^a-zA-Z])|(\/?[a-zA-Z][^>\s]*)|(\/?$))/g;
  const COMMENT_START = 1;
  const TAG_NAME = 2;
  const DYNAMIC_TAG_NAME = 3;
  const commentEndRegex = /-->/g;
  /**
   * Comments not started with <!--, like </{, can be ended by a single `>`
   */
  const comment2EndRegex = />/g;
  /**
   * The tagEnd regex matches the end of the "inside an opening" tag syntax
   * position. It either matches a `>`, an attribute-like sequence, or the end
   * of the string after a space (attribute-name position ending).
   *
   * See attributes in the HTML spec:
   * https://www.w3.org/TR/html5/syntax.html#elements-attributes
   *
   * " \t\n\f\r" are HTML space characters:
   * https://infra.spec.whatwg.org/#ascii-whitespace
   *
   * So an attribute is:
   *  * The name: any character except a whitespace character, ("), ('), ">",
   *    "=", or "/". Note: this is different from the HTML spec which also excludes control characters.
   *  * Followed by zero or more space characters
   *  * Followed by "="
   *  * Followed by zero or more space characters
   *  * Followed by:
   *    * Any character except space, ('), ("), "<", ">", "=", (`), or
   *    * (") then any non-("), or
   *    * (') then any non-(')
   */
  const tagEndRegex = new RegExp(`>|${SPACE_CHAR}(?:(${NAME_CHAR}+)(${SPACE_CHAR}*=${SPACE_CHAR}*(?:${ATTR_VALUE_CHAR}|("|')|))|$)`, 'g');
  const ENTIRE_MATCH = 0;
  const ATTRIBUTE_NAME = 1;
  const SPACES_AND_EQUALS = 2;
  const QUOTE_CHAR = 3;
  const singleQuoteAttrEndRegex = /'/g;
  const doubleQuoteAttrEndRegex = /"/g;
  /**
   * Matches the raw text elements.
   *
   * Comments are not parsed within raw text elements, so we need to search their
   * text content for marker strings.
   */
  const rawTextElement = /^(?:script|style|textarea|title)$/i;
  /** TemplateResult types */
  const HTML_RESULT$1 = 1;
  const SVG_RESULT$1 = 2;
  const MATHML_RESULT = 3;
  // TemplatePart types
  // IMPORTANT: these must match the values in PartType
  const ATTRIBUTE_PART = 1;
  const CHILD_PART = 2;
  const PROPERTY_PART = 3;
  const BOOLEAN_ATTRIBUTE_PART = 4;
  const EVENT_PART = 5;
  const ELEMENT_PART = 6;
  const COMMENT_PART = 7;
  /**
   * Generates a template literal tag function that returns a TemplateResult with
   * the given result type.
   */
  const tag = (type) => (strings, ...values) => {
      // Warn against templates octal escape sequences
      // We do this here rather than in render so that the warning is closer to the
      // template definition.
      if (strings.some((s) => s === undefined)) {
          console.warn('Some template strings are undefined.\n' +
              'This is probably caused by illegal octal escape sequences.');
      }
      {
          // Import static-html.js results in a circular dependency which g3 doesn't
          // handle. Instead we know that static values must have the field
          // `_$litStatic$`.
          if (values.some((val) => val?.['_$litStatic$'])) {
              issueWarning$4('', `Static values 'literal' or 'unsafeStatic' cannot be used as values to non-static templates.\n` +
                  `Please use the static 'html' tag function. See https://lit.dev/docs/templates/expressions/#static-expressions`);
          }
      }
      return {
          // This property needs to remain unminified.
          ['_$litType$']: type,
          strings,
          values,
      };
  };
  /**
   * Interprets a template literal as an HTML template that can efficiently
   * render to and update a container.
   *
   * ```ts
   * const header = (title: string) => html`<h1>${title}</h1>`;
   * ```
   *
   * The `html` tag returns a description of the DOM to render as a value. It is
   * lazy, meaning no work is done until the template is rendered. When rendering,
   * if a template comes from the same expression as a previously rendered result,
   * it's efficiently updated instead of replaced.
   */
  const html$1 = tag(HTML_RESULT$1);
  /**
   * A sentinel value that signals that a value was handled by a directive and
   * should not be written to the DOM.
   */
  const noChange = Symbol.for('lit-noChange');
  /**
   * A sentinel value that signals a ChildPart to fully clear its content.
   *
   * ```ts
   * const button = html`${
   *  user.isAdmin
   *    ? html`<button>DELETE</button>`
   *    : nothing
   * }`;
   * ```
   *
   * Prefer using `nothing` over other falsy values as it provides a consistent
   * behavior between various expression binding contexts.
   *
   * In child expressions, `undefined`, `null`, `''`, and `nothing` all behave the
   * same and render no nodes. In attribute expressions, `nothing` _removes_ the
   * attribute, while `undefined` and `null` will render an empty string. In
   * property expressions `nothing` becomes `undefined`.
   */
  const nothing = Symbol.for('lit-nothing');
  /**
   * The cache of prepared templates, keyed by the tagged TemplateStringsArray
   * and _not_ accounting for the specific template tag used. This means that
   * template tags cannot be dynamic - they must statically be one of html, svg,
   * or attr. This restriction simplifies the cache lookup, which is on the hot
   * path for rendering.
   */
  const templateCache = new WeakMap();
  const walker = d.createTreeWalker(d, 129 /* NodeFilter.SHOW_{ELEMENT|COMMENT} */);
  let sanitizerFactoryInternal = noopSanitizer;
  function trustFromTemplateString(tsa, stringFromTSA) {
      // A security check to prevent spoofing of Lit template results.
      // In the future, we may be able to replace this with Array.isTemplateObject,
      // though we might need to make that check inside of the html and svg
      // functions, because precompiled templates don't come in as
      // TemplateStringArray objects.
      if (!isArray(tsa) || !tsa.hasOwnProperty('raw')) {
          let message = 'invalid template strings array';
          {
              message = `
          Internal Error: expected template strings to be an array
          with a 'raw' field. Faking a template strings array by
          calling html or svg like an ordinary function is effectively
          the same as calling unsafeHtml and can lead to major security
          issues, e.g. opening your code up to XSS attacks.
          If you're using the html or svg tagged template functions normally
          and still seeing this error, please file a bug at
          https://github.com/lit/lit/issues/new?template=bug_report.md
          and include information about your build tooling, if any.
        `
                  .trim()
                  .replace(/\n */g, '\n');
          }
          throw new Error(message);
      }
      return policy !== undefined
          ? policy.createHTML(stringFromTSA)
          : stringFromTSA;
  }
  /**
   * Returns an HTML string for the given TemplateStringsArray and result type
   * (HTML or SVG), along with the case-sensitive bound attribute names in
   * template order. The HTML contains comment markers denoting the `ChildPart`s
   * and suffixes on bound attributes denoting the `AttributeParts`.
   *
   * @param strings template strings array
   * @param type HTML or SVG
   * @return Array containing `[html, attrNames]` (array returned for terseness,
   *     to avoid object fields since this code is shared with non-minified SSR
   *     code)
   */
  const getTemplateHtml = (strings, type) => {
      // Insert makers into the template HTML to represent the position of
      // bindings. The following code scans the template strings to determine the
      // syntactic position of the bindings. They can be in text position, where
      // we insert an HTML comment, attribute value position, where we insert a
      // sentinel string and re-write the attribute name, or inside a tag where
      // we insert the sentinel string.
      const l = strings.length - 1;
      // Stores the case-sensitive bound attribute names in the order of their
      // parts. ElementParts are also reflected in this array as undefined
      // rather than a string, to disambiguate from attribute bindings.
      const attrNames = [];
      let html = type === SVG_RESULT$1 ? '<svg>' : type === MATHML_RESULT ? '<math>' : '';
      // When we're inside a raw text tag (not it's text content), the regex
      // will still be tagRegex so we can find attributes, but will switch to
      // this regex when the tag ends.
      let rawTextEndRegex;
      // The current parsing state, represented as a reference to one of the
      // regexes
      let regex = textEndRegex;
      for (let i = 0; i < l; i++) {
          const s = strings[i];
          // The index of the end of the last attribute name. When this is
          // positive at end of a string, it means we're in an attribute value
          // position and need to rewrite the attribute name.
          // We also use a special value of -2 to indicate that we encountered
          // the end of a string in attribute name position.
          let attrNameEndIndex = -1;
          let attrName;
          let lastIndex = 0;
          let match;
          // The conditions in this loop handle the current parse state, and the
          // assignments to the `regex` variable are the state transitions.
          while (lastIndex < s.length) {
              // Make sure we start searching from where we previously left off
              regex.lastIndex = lastIndex;
              match = regex.exec(s);
              if (match === null) {
                  break;
              }
              lastIndex = regex.lastIndex;
              if (regex === textEndRegex) {
                  if (match[COMMENT_START] === '!--') {
                      regex = commentEndRegex;
                  }
                  else if (match[COMMENT_START] !== undefined) {
                      // We started a weird comment, like </{
                      regex = comment2EndRegex;
                  }
                  else if (match[TAG_NAME] !== undefined) {
                      if (rawTextElement.test(match[TAG_NAME])) {
                          // Record if we encounter a raw-text element. We'll switch to
                          // this regex at the end of the tag.
                          rawTextEndRegex = new RegExp(`</${match[TAG_NAME]}`, 'g');
                      }
                      regex = tagEndRegex;
                  }
                  else if (match[DYNAMIC_TAG_NAME] !== undefined) {
                      {
                          throw new Error('Bindings in tag names are not supported. Please use static templates instead. ' +
                              'See https://lit.dev/docs/templates/expressions/#static-expressions');
                      }
                  }
              }
              else if (regex === tagEndRegex) {
                  if (match[ENTIRE_MATCH] === '>') {
                      // End of a tag. If we had started a raw-text element, use that
                      // regex
                      regex = rawTextEndRegex ?? textEndRegex;
                      // We may be ending an unquoted attribute value, so make sure we
                      // clear any pending attrNameEndIndex
                      attrNameEndIndex = -1;
                  }
                  else if (match[ATTRIBUTE_NAME] === undefined) {
                      // Attribute name position
                      attrNameEndIndex = -2;
                  }
                  else {
                      attrNameEndIndex = regex.lastIndex - match[SPACES_AND_EQUALS].length;
                      attrName = match[ATTRIBUTE_NAME];
                      regex =
                          match[QUOTE_CHAR] === undefined
                              ? tagEndRegex
                              : match[QUOTE_CHAR] === '"'
                                  ? doubleQuoteAttrEndRegex
                                  : singleQuoteAttrEndRegex;
                  }
              }
              else if (regex === doubleQuoteAttrEndRegex ||
                  regex === singleQuoteAttrEndRegex) {
                  regex = tagEndRegex;
              }
              else if (regex === commentEndRegex || regex === comment2EndRegex) {
                  regex = textEndRegex;
              }
              else {
                  // Not one of the five state regexes, so it must be the dynamically
                  // created raw text regex and we're at the close of that element.
                  regex = tagEndRegex;
                  rawTextEndRegex = undefined;
              }
          }
          {
              // If we have a attrNameEndIndex, which indicates that we should
              // rewrite the attribute name, assert that we're in a valid attribute
              // position - either in a tag, or a quoted attribute value.
              console.assert(attrNameEndIndex === -1 ||
                  regex === tagEndRegex ||
                  regex === singleQuoteAttrEndRegex ||
                  regex === doubleQuoteAttrEndRegex, 'unexpected parse state B');
          }
          // We have four cases:
          //  1. We're in text position, and not in a raw text element
          //     (regex === textEndRegex): insert a comment marker.
          //  2. We have a non-negative attrNameEndIndex which means we need to
          //     rewrite the attribute name to add a bound attribute suffix.
          //  3. We're at the non-first binding in a multi-binding attribute, use a
          //     plain marker.
          //  4. We're somewhere else inside the tag. If we're in attribute name
          //     position (attrNameEndIndex === -2), add a sequential suffix to
          //     generate a unique attribute name.
          // Detect a binding next to self-closing tag end and insert a space to
          // separate the marker from the tag end:
          const end = regex === tagEndRegex && strings[i + 1].startsWith('/>') ? ' ' : '';
          html +=
              regex === textEndRegex
                  ? s + nodeMarker
                  : attrNameEndIndex >= 0
                      ? (attrNames.push(attrName),
                          s.slice(0, attrNameEndIndex) +
                              boundAttributeSuffix +
                              s.slice(attrNameEndIndex)) +
                          marker +
                          end
                      : s + marker + (attrNameEndIndex === -2 ? i : end);
      }
      const htmlResult = html +
          (strings[l] || '<?>') +
          (type === SVG_RESULT$1 ? '</svg>' : type === MATHML_RESULT ? '</math>' : '');
      // Returned as an array for terseness
      return [trustFromTemplateString(strings, htmlResult), attrNames];
  };
  class Template {
      constructor(
      // This property needs to remain unminified.
      { strings, ['_$litType$']: type }, options) {
          this.parts = [];
          let node;
          let nodeIndex = 0;
          let attrNameIndex = 0;
          const partCount = strings.length - 1;
          const parts = this.parts;
          // Create template element
          const [html, attrNames] = getTemplateHtml(strings, type);
          this.el = Template.createElement(html, options);
          walker.currentNode = this.el.content;
          // Re-parent SVG or MathML nodes into template root
          if (type === SVG_RESULT$1 || type === MATHML_RESULT) {
              const wrapper = this.el.content.firstChild;
              wrapper.replaceWith(...wrapper.childNodes);
          }
          // Walk the template to find binding markers and create TemplateParts
          while ((node = walker.nextNode()) !== null && parts.length < partCount) {
              if (node.nodeType === 1) {
                  {
                      const tag = node.localName;
                      // Warn if `textarea` includes an expression and throw if `template`
                      // does since these are not supported. We do this by checking
                      // innerHTML for anything that looks like a marker. This catches
                      // cases like bindings in textarea there markers turn into text nodes.
                      if (/^(?:textarea|template)$/i.test(tag) &&
                          node.innerHTML.includes(marker)) {
                          const m = `Expressions are not supported inside \`${tag}\` ` +
                              `elements. See https://lit.dev/msg/expression-in-${tag} for more ` +
                              `information.`;
                          if (tag === 'template') {
                              throw new Error(m);
                          }
                          else
                              issueWarning$4('', m);
                      }
                  }
                  // TODO (justinfagnani): for attempted dynamic tag names, we don't
                  // increment the bindingIndex, and it'll be off by 1 in the element
                  // and off by two after it.
                  if (node.hasAttributes()) {
                      for (const name of node.getAttributeNames()) {
                          if (name.endsWith(boundAttributeSuffix)) {
                              const realName = attrNames[attrNameIndex++];
                              const value = node.getAttribute(name);
                              const statics = value.split(marker);
                              const m = /([.?@])?(.*)/.exec(realName);
                              parts.push({
                                  type: ATTRIBUTE_PART,
                                  index: nodeIndex,
                                  name: m[2],
                                  strings: statics,
                                  ctor: m[1] === '.'
                                      ? PropertyPart
                                      : m[1] === '?'
                                          ? BooleanAttributePart
                                          : m[1] === '@'
                                              ? EventPart
                                              : AttributePart,
                              });
                              node.removeAttribute(name);
                          }
                          else if (name.startsWith(marker)) {
                              parts.push({
                                  type: ELEMENT_PART,
                                  index: nodeIndex,
                              });
                              node.removeAttribute(name);
                          }
                      }
                  }
                  // TODO (justinfagnani): benchmark the regex against testing for each
                  // of the 3 raw text element names.
                  if (rawTextElement.test(node.tagName)) {
                      // For raw text elements we need to split the text content on
                      // markers, create a Text node for each segment, and create
                      // a TemplatePart for each marker.
                      const strings = node.textContent.split(marker);
                      const lastIndex = strings.length - 1;
                      if (lastIndex > 0) {
                          node.textContent = trustedTypes$1
                              ? trustedTypes$1.emptyScript
                              : '';
                          // Generate a new text node for each literal section
                          // These nodes are also used as the markers for node parts
                          // We can't use empty text nodes as markers because they're
                          // normalized when cloning in IE (could simplify when
                          // IE is no longer supported)
                          for (let i = 0; i < lastIndex; i++) {
                              node.append(strings[i], createMarker());
                              // Walk past the marker node we just added
                              walker.nextNode();
                              parts.push({ type: CHILD_PART, index: ++nodeIndex });
                          }
                          // Note because this marker is added after the walker's current
                          // node, it will be walked to in the outer loop (and ignored), so
                          // we don't need to adjust nodeIndex here
                          node.append(strings[lastIndex], createMarker());
                      }
                  }
              }
              else if (node.nodeType === 8) {
                  const data = node.data;
                  if (data === markerMatch) {
                      parts.push({ type: CHILD_PART, index: nodeIndex });
                  }
                  else {
                      let i = -1;
                      while ((i = node.data.indexOf(marker, i + 1)) !== -1) {
                          // Comment node has a binding marker inside, make an inactive part
                          // The binding won't work, but subsequent bindings will
                          parts.push({ type: COMMENT_PART, index: nodeIndex });
                          // Move to the end of the match
                          i += marker.length - 1;
                      }
                  }
              }
              nodeIndex++;
          }
          {
              // If there was a duplicate attribute on a tag, then when the tag is
              // parsed into an element the attribute gets de-duplicated. We can detect
              // this mismatch if we haven't precisely consumed every attribute name
              // when preparing the template. This works because `attrNames` is built
              // from the template string and `attrNameIndex` comes from processing the
              // resulting DOM.
              if (attrNames.length !== attrNameIndex) {
                  throw new Error(`Detected duplicate attribute bindings. This occurs if your template ` +
                      `has duplicate attributes on an element tag. For example ` +
                      `"<input ?disabled=\${true} ?disabled=\${false}>" contains a ` +
                      `duplicate "disabled" attribute. The error was detected in ` +
                      `the following template: \n` +
                      '`' +
                      strings.join('${...}') +
                      '`');
              }
          }
          // We could set walker.currentNode to another node here to prevent a memory
          // leak, but every time we prepare a template, we immediately render it
          // and re-use the walker in new TemplateInstance._clone().
          debugLogEvent$1 &&
              debugLogEvent$1({
                  kind: 'template prep',
                  template: this,
                  clonableTemplate: this.el,
                  parts: this.parts,
                  strings,
              });
      }
      // Overridden via `litHtmlPolyfillSupport` to provide platform support.
      /** @nocollapse */
      static createElement(html, _options) {
          const el = d.createElement('template');
          el.innerHTML = html;
          return el;
      }
  }
  function resolveDirective(part, value, parent = part, attributeIndex) {
      // Bail early if the value is explicitly noChange. Note, this means any
      // nested directive is still attached and is not run.
      if (value === noChange) {
          return value;
      }
      let currentDirective = attributeIndex !== undefined
          ? parent.__directives?.[attributeIndex]
          : parent.__directive;
      const nextDirectiveConstructor = isPrimitive(value)
          ? undefined
          : // This property needs to remain unminified.
              value['_$litDirective$'];
      if (currentDirective?.constructor !== nextDirectiveConstructor) {
          // This property needs to remain unminified.
          currentDirective?.['_$notifyDirectiveConnectionChanged']?.(false);
          if (nextDirectiveConstructor === undefined) {
              currentDirective = undefined;
          }
          else {
              currentDirective = new nextDirectiveConstructor(part);
              currentDirective._$initialize(part, parent, attributeIndex);
          }
          if (attributeIndex !== undefined) {
              (parent.__directives ??= [])[attributeIndex] =
                  currentDirective;
          }
          else {
              parent.__directive = currentDirective;
          }
      }
      if (currentDirective !== undefined) {
          value = resolveDirective(part, currentDirective._$resolve(part, value.values), currentDirective, attributeIndex);
      }
      return value;
  }
  /**
   * An updateable instance of a Template. Holds references to the Parts used to
   * update the template instance.
   */
  class TemplateInstance {
      constructor(template, parent) {
          this._$parts = [];
          /** @internal */
          this._$disconnectableChildren = undefined;
          this._$template = template;
          this._$parent = parent;
      }
      // Called by ChildPart parentNode getter
      get parentNode() {
          return this._$parent.parentNode;
      }
      // See comment in Disconnectable interface for why this is a getter
      get _$isConnected() {
          return this._$parent._$isConnected;
      }
      // This method is separate from the constructor because we need to return a
      // DocumentFragment and we don't want to hold onto it with an instance field.
      _clone(options) {
          const { el: { content }, parts: parts, } = this._$template;
          const fragment = (options?.creationScope ?? d).importNode(content, true);
          walker.currentNode = fragment;
          let node = walker.nextNode();
          let nodeIndex = 0;
          let partIndex = 0;
          let templatePart = parts[0];
          while (templatePart !== undefined) {
              if (nodeIndex === templatePart.index) {
                  let part;
                  if (templatePart.type === CHILD_PART) {
                      part = new ChildPart(node, node.nextSibling, this, options);
                  }
                  else if (templatePart.type === ATTRIBUTE_PART) {
                      part = new templatePart.ctor(node, templatePart.name, templatePart.strings, this, options);
                  }
                  else if (templatePart.type === ELEMENT_PART) {
                      part = new ElementPart(node, this, options);
                  }
                  this._$parts.push(part);
                  templatePart = parts[++partIndex];
              }
              if (nodeIndex !== templatePart?.index) {
                  node = walker.nextNode();
                  nodeIndex++;
              }
          }
          // We need to set the currentNode away from the cloned tree so that we
          // don't hold onto the tree even if the tree is detached and should be
          // freed.
          walker.currentNode = d;
          return fragment;
      }
      _update(values) {
          let i = 0;
          for (const part of this._$parts) {
              if (part !== undefined) {
                  debugLogEvent$1 &&
                      debugLogEvent$1({
                          kind: 'set part',
                          part,
                          value: values[i],
                          valueIndex: i,
                          values,
                          templateInstance: this,
                      });
                  if (part.strings !== undefined) {
                      part._$setValue(values, part, i);
                      // The number of values the part consumes is part.strings.length - 1
                      // since values are in between template spans. We increment i by 1
                      // later in the loop, so increment it by part.strings.length - 2 here
                      i += part.strings.length - 2;
                  }
                  else {
                      part._$setValue(values[i]);
                  }
              }
              i++;
          }
      }
  }
  class ChildPart {
      // See comment in Disconnectable interface for why this is a getter
      get _$isConnected() {
          // ChildParts that are not at the root should always be created with a
          // parent; only RootChildNode's won't, so they return the local isConnected
          // state
          return this._$parent?._$isConnected ?? this.__isConnected;
      }
      constructor(startNode, endNode, parent, options) {
          this.type = CHILD_PART;
          this._$committedValue = nothing;
          // The following fields will be patched onto ChildParts when required by
          // AsyncDirective
          /** @internal */
          this._$disconnectableChildren = undefined;
          this._$startNode = startNode;
          this._$endNode = endNode;
          this._$parent = parent;
          this.options = options;
          // Note __isConnected is only ever accessed on RootParts (i.e. when there is
          // no _$parent); the value on a non-root-part is "don't care", but checking
          // for parent would be more code
          this.__isConnected = options?.isConnected ?? true;
          {
              // Explicitly initialize for consistent class shape.
              this._textSanitizer = undefined;
          }
      }
      /**
       * The parent node into which the part renders its content.
       *
       * A ChildPart's content consists of a range of adjacent child nodes of
       * `.parentNode`, possibly bordered by 'marker nodes' (`.startNode` and
       * `.endNode`).
       *
       * - If both `.startNode` and `.endNode` are non-null, then the part's content
       * consists of all siblings between `.startNode` and `.endNode`, exclusively.
       *
       * - If `.startNode` is non-null but `.endNode` is null, then the part's
       * content consists of all siblings following `.startNode`, up to and
       * including the last child of `.parentNode`. If `.endNode` is non-null, then
       * `.startNode` will always be non-null.
       *
       * - If both `.endNode` and `.startNode` are null, then the part's content
       * consists of all child nodes of `.parentNode`.
       */
      get parentNode() {
          let parentNode = wrap(this._$startNode).parentNode;
          const parent = this._$parent;
          if (parent !== undefined &&
              parentNode?.nodeType === 11 /* Node.DOCUMENT_FRAGMENT */) {
              // If the parentNode is a DocumentFragment, it may be because the DOM is
              // still in the cloned fragment during initial render; if so, get the real
              // parentNode the part will be committed into by asking the parent.
              parentNode = parent.parentNode;
          }
          return parentNode;
      }
      /**
       * The part's leading marker node, if any. See `.parentNode` for more
       * information.
       */
      get startNode() {
          return this._$startNode;
      }
      /**
       * The part's trailing marker node, if any. See `.parentNode` for more
       * information.
       */
      get endNode() {
          return this._$endNode;
      }
      _$setValue(value, directiveParent = this) {
          if (this.parentNode === null) {
              throw new Error(`This \`ChildPart\` has no \`parentNode\` and therefore cannot accept a value. This likely means the element containing the part was manipulated in an unsupported way outside of Lit's control such that the part's marker nodes were ejected from DOM. For example, setting the element's \`innerHTML\` or \`textContent\` can do this.`);
          }
          value = resolveDirective(this, value, directiveParent);
          if (isPrimitive(value)) {
              // Non-rendering child values. It's important that these do not render
              // empty text nodes to avoid issues with preventing default <slot>
              // fallback content.
              if (value === nothing || value == null || value === '') {
                  if (this._$committedValue !== nothing) {
                      debugLogEvent$1 &&
                          debugLogEvent$1({
                              kind: 'commit nothing to child',
                              start: this._$startNode,
                              end: this._$endNode,
                              parent: this._$parent,
                              options: this.options,
                          });
                      this._$clear();
                  }
                  this._$committedValue = nothing;
              }
              else if (value !== this._$committedValue && value !== noChange) {
                  this._commitText(value);
              }
              // This property needs to remain unminified.
          }
          else if (value['_$litType$'] !== undefined) {
              this._commitTemplateResult(value);
          }
          else if (value.nodeType !== undefined) {
              if (this.options?.host === value) {
                  this._commitText(`[probable mistake: rendered a template's host in itself ` +
                      `(commonly caused by writing \${this} in a template]`);
                  console.warn(`Attempted to render the template host`, value, `inside itself. This is almost always a mistake, and in dev mode `, `we render some warning text. In production however, we'll `, `render it, which will usually result in an error, and sometimes `, `in the element disappearing from the DOM.`);
                  return;
              }
              this._commitNode(value);
          }
          else if (isIterable(value)) {
              this._commitIterable(value);
          }
          else {
              // Fallback, will render the string representation
              this._commitText(value);
          }
      }
      _insert(node) {
          return wrap(wrap(this._$startNode).parentNode).insertBefore(node, this._$endNode);
      }
      _commitNode(value) {
          if (this._$committedValue !== value) {
              this._$clear();
              if (sanitizerFactoryInternal !== noopSanitizer) {
                  const parentNodeName = this._$startNode.parentNode?.nodeName;
                  if (parentNodeName === 'STYLE' || parentNodeName === 'SCRIPT') {
                      let message = 'Forbidden';
                      {
                          if (parentNodeName === 'STYLE') {
                              message =
                                  `Lit does not support binding inside style nodes. ` +
                                      `This is a security risk, as style injection attacks can ` +
                                      `exfiltrate data and spoof UIs. ` +
                                      `Consider instead using css\`...\` literals ` +
                                      `to compose styles, and do dynamic styling with ` +
                                      `css custom properties, ::parts, <slot>s, ` +
                                      `and by mutating the DOM rather than stylesheets.`;
                          }
                          else {
                              message =
                                  `Lit does not support binding inside script nodes. ` +
                                      `This is a security risk, as it could allow arbitrary ` +
                                      `code execution.`;
                          }
                      }
                      throw new Error(message);
                  }
              }
              debugLogEvent$1 &&
                  debugLogEvent$1({
                      kind: 'commit node',
                      start: this._$startNode,
                      parent: this._$parent,
                      value: value,
                      options: this.options,
                  });
              this._$committedValue = this._insert(value);
          }
      }
      _commitText(value) {
          // If the committed value is a primitive it means we called _commitText on
          // the previous render, and we know that this._$startNode.nextSibling is a
          // Text node. We can now just replace the text content (.data) of the node.
          if (this._$committedValue !== nothing &&
              isPrimitive(this._$committedValue)) {
              const node = wrap(this._$startNode).nextSibling;
              {
                  if (this._textSanitizer === undefined) {
                      this._textSanitizer = createSanitizer(node, 'data', 'property');
                  }
                  value = this._textSanitizer(value);
              }
              debugLogEvent$1 &&
                  debugLogEvent$1({
                      kind: 'commit text',
                      node,
                      value,
                      options: this.options,
                  });
              node.data = value;
          }
          else {
              {
                  const textNode = d.createTextNode('');
                  this._commitNode(textNode);
                  // When setting text content, for security purposes it matters a lot
                  // what the parent is. For example, <style> and <script> need to be
                  // handled with care, while <span> does not. So first we need to put a
                  // text node into the document, then we can sanitize its content.
                  if (this._textSanitizer === undefined) {
                      this._textSanitizer = createSanitizer(textNode, 'data', 'property');
                  }
                  value = this._textSanitizer(value);
                  debugLogEvent$1 &&
                      debugLogEvent$1({
                          kind: 'commit text',
                          node: textNode,
                          value,
                          options: this.options,
                      });
                  textNode.data = value;
              }
          }
          this._$committedValue = value;
      }
      _commitTemplateResult(result) {
          // This property needs to remain unminified.
          const { values, ['_$litType$']: type } = result;
          // If $litType$ is a number, result is a plain TemplateResult and we get
          // the template from the template cache. If not, result is a
          // CompiledTemplateResult and _$litType$ is a CompiledTemplate and we need
          // to create the <template> element the first time we see it.
          const template = typeof type === 'number'
              ? this._$getTemplate(result)
              : (type.el === undefined &&
                  (type.el = Template.createElement(trustFromTemplateString(type.h, type.h[0]), this.options)),
                  type);
          if (this._$committedValue?._$template === template) {
              debugLogEvent$1 &&
                  debugLogEvent$1({
                      kind: 'template updating',
                      template,
                      instance: this._$committedValue,
                      parts: this._$committedValue._$parts,
                      options: this.options,
                      values,
                  });
              this._$committedValue._update(values);
          }
          else {
              const instance = new TemplateInstance(template, this);
              const fragment = instance._clone(this.options);
              debugLogEvent$1 &&
                  debugLogEvent$1({
                      kind: 'template instantiated',
                      template,
                      instance,
                      parts: instance._$parts,
                      options: this.options,
                      fragment,
                      values,
                  });
              instance._update(values);
              debugLogEvent$1 &&
                  debugLogEvent$1({
                      kind: 'template instantiated and updated',
                      template,
                      instance,
                      parts: instance._$parts,
                      options: this.options,
                      fragment,
                      values,
                  });
              this._commitNode(fragment);
              this._$committedValue = instance;
          }
      }
      // Overridden via `litHtmlPolyfillSupport` to provide platform support.
      /** @internal */
      _$getTemplate(result) {
          let template = templateCache.get(result.strings);
          if (template === undefined) {
              templateCache.set(result.strings, (template = new Template(result)));
          }
          return template;
      }
      _commitIterable(value) {
          // For an Iterable, we create a new InstancePart per item, then set its
          // value to the item. This is a little bit of overhead for every item in
          // an Iterable, but it lets us recurse easily and efficiently update Arrays
          // of TemplateResults that will be commonly returned from expressions like:
          // array.map((i) => html`${i}`), by reusing existing TemplateInstances.
          // If value is an array, then the previous render was of an
          // iterable and value will contain the ChildParts from the previous
          // render. If value is not an array, clear this part and make a new
          // array for ChildParts.
          if (!isArray(this._$committedValue)) {
              this._$committedValue = [];
              this._$clear();
          }
          // Lets us keep track of how many items we stamped so we can clear leftover
          // items from a previous render
          const itemParts = this._$committedValue;
          let partIndex = 0;
          let itemPart;
          for (const item of value) {
              if (partIndex === itemParts.length) {
                  // If no existing part, create a new one
                  // TODO (justinfagnani): test perf impact of always creating two parts
                  // instead of sharing parts between nodes
                  // https://github.com/lit/lit/issues/1266
                  itemParts.push((itemPart = new ChildPart(this._insert(createMarker()), this._insert(createMarker()), this, this.options)));
              }
              else {
                  // Reuse an existing part
                  itemPart = itemParts[partIndex];
              }
              itemPart._$setValue(item);
              partIndex++;
          }
          if (partIndex < itemParts.length) {
              // itemParts always have end nodes
              this._$clear(itemPart && wrap(itemPart._$endNode).nextSibling, partIndex);
              // Truncate the parts array so _value reflects the current state
              itemParts.length = partIndex;
          }
      }
      /**
       * Removes the nodes contained within this Part from the DOM.
       *
       * @param start Start node to clear from, for clearing a subset of the part's
       *     DOM (used when truncating iterables)
       * @param from  When `start` is specified, the index within the iterable from
       *     which ChildParts are being removed, used for disconnecting directives in
       *     those Parts.
       *
       * @internal
       */
      _$clear(start = wrap(this._$startNode).nextSibling, from) {
          this._$notifyConnectionChanged?.(false, true, from);
          while (start && start !== this._$endNode) {
              const n = wrap(start).nextSibling;
              wrap(start).remove();
              start = n;
          }
      }
      /**
       * Implementation of RootPart's `isConnected`. Note that this method
       * should only be called on `RootPart`s (the `ChildPart` returned from a
       * top-level `render()` call). It has no effect on non-root ChildParts.
       * @param isConnected Whether to set
       * @internal
       */
      setConnected(isConnected) {
          if (this._$parent === undefined) {
              this.__isConnected = isConnected;
              this._$notifyConnectionChanged?.(isConnected);
          }
          else {
              throw new Error('part.setConnected() may only be called on a ' +
                  'RootPart returned from render().');
          }
      }
  }
  class AttributePart {
      get tagName() {
          return this.element.tagName;
      }
      // See comment in Disconnectable interface for why this is a getter
      get _$isConnected() {
          return this._$parent._$isConnected;
      }
      constructor(element, name, strings, parent, options) {
          this.type = ATTRIBUTE_PART;
          /** @internal */
          this._$committedValue = nothing;
          /** @internal */
          this._$disconnectableChildren = undefined;
          this.element = element;
          this.name = name;
          this._$parent = parent;
          this.options = options;
          if (strings.length > 2 || strings[0] !== '' || strings[1] !== '') {
              this._$committedValue = new Array(strings.length - 1).fill(new String());
              this.strings = strings;
          }
          else {
              this._$committedValue = nothing;
          }
          {
              this._sanitizer = undefined;
          }
      }
      /**
       * Sets the value of this part by resolving the value from possibly multiple
       * values and static strings and committing it to the DOM.
       * If this part is single-valued, `this._strings` will be undefined, and the
       * method will be called with a single value argument. If this part is
       * multi-value, `this._strings` will be defined, and the method is called
       * with the value array of the part's owning TemplateInstance, and an offset
       * into the value array from which the values should be read.
       * This method is overloaded this way to eliminate short-lived array slices
       * of the template instance values, and allow a fast-path for single-valued
       * parts.
       *
       * @param value The part value, or an array of values for multi-valued parts
       * @param valueIndex the index to start reading values from. `undefined` for
       *   single-valued parts
       * @param noCommit causes the part to not commit its value to the DOM. Used
       *   in hydration to prime attribute parts with their first-rendered value,
       *   but not set the attribute, and in SSR to no-op the DOM operation and
       *   capture the value for serialization.
       *
       * @internal
       */
      _$setValue(value, directiveParent = this, valueIndex, noCommit) {
          const strings = this.strings;
          // Whether any of the values has changed, for dirty-checking
          let change = false;
          if (strings === undefined) {
              // Single-value binding case
              value = resolveDirective(this, value, directiveParent, 0);
              change =
                  !isPrimitive(value) ||
                      (value !== this._$committedValue && value !== noChange);
              if (change) {
                  this._$committedValue = value;
              }
          }
          else {
              // Interpolation case
              const values = value;
              value = strings[0];
              let i, v;
              for (i = 0; i < strings.length - 1; i++) {
                  v = resolveDirective(this, values[valueIndex + i], directiveParent, i);
                  if (v === noChange) {
                      // If the user-provided value is `noChange`, use the previous value
                      v = this._$committedValue[i];
                  }
                  change ||=
                      !isPrimitive(v) || v !== this._$committedValue[i];
                  if (v === nothing) {
                      value = nothing;
                  }
                  else if (value !== nothing) {
                      value += (v ?? '') + strings[i + 1];
                  }
                  // We always record each value, even if one is `nothing`, for future
                  // change detection.
                  this._$committedValue[i] = v;
              }
          }
          if (change && !noCommit) {
              this._commitValue(value);
          }
      }
      /** @internal */
      _commitValue(value) {
          if (value === nothing) {
              wrap(this.element).removeAttribute(this.name);
          }
          else {
              {
                  if (this._sanitizer === undefined) {
                      this._sanitizer = sanitizerFactoryInternal(this.element, this.name, 'attribute');
                  }
                  value = this._sanitizer(value ?? '');
              }
              debugLogEvent$1 &&
                  debugLogEvent$1({
                      kind: 'commit attribute',
                      element: this.element,
                      name: this.name,
                      value,
                      options: this.options,
                  });
              wrap(this.element).setAttribute(this.name, (value ?? ''));
          }
      }
  }
  class PropertyPart extends AttributePart {
      constructor() {
          super(...arguments);
          this.type = PROPERTY_PART;
      }
      /** @internal */
      _commitValue(value) {
          {
              if (this._sanitizer === undefined) {
                  this._sanitizer = sanitizerFactoryInternal(this.element, this.name, 'property');
              }
              value = this._sanitizer(value);
          }
          debugLogEvent$1 &&
              debugLogEvent$1({
                  kind: 'commit property',
                  element: this.element,
                  name: this.name,
                  value,
                  options: this.options,
              });
          // eslint-disable-next-line @typescript-eslint/no-explicit-any
          this.element[this.name] = value === nothing ? undefined : value;
      }
  }
  class BooleanAttributePart extends AttributePart {
      constructor() {
          super(...arguments);
          this.type = BOOLEAN_ATTRIBUTE_PART;
      }
      /** @internal */
      _commitValue(value) {
          debugLogEvent$1 &&
              debugLogEvent$1({
                  kind: 'commit boolean attribute',
                  element: this.element,
                  name: this.name,
                  value: !!(value && value !== nothing),
                  options: this.options,
              });
          wrap(this.element).toggleAttribute(this.name, !!value && value !== nothing);
      }
  }
  class EventPart extends AttributePart {
      constructor(element, name, strings, parent, options) {
          super(element, name, strings, parent, options);
          this.type = EVENT_PART;
          if (this.strings !== undefined) {
              throw new Error(`A \`<${element.localName}>\` has a \`@${name}=...\` listener with ` +
                  'invalid content. Event listeners in templates must have exactly ' +
                  'one expression and no surrounding text.');
          }
      }
      // EventPart does not use the base _$setValue/_resolveValue implementation
      // since the dirty checking is more complex
      /** @internal */
      _$setValue(newListener, directiveParent = this) {
          newListener =
              resolveDirective(this, newListener, directiveParent, 0) ?? nothing;
          if (newListener === noChange) {
              return;
          }
          const oldListener = this._$committedValue;
          // If the new value is nothing or any options change we have to remove the
          // part as a listener.
          const shouldRemoveListener = (newListener === nothing && oldListener !== nothing) ||
              newListener.capture !==
                  oldListener.capture ||
              newListener.once !==
                  oldListener.once ||
              newListener.passive !==
                  oldListener.passive;
          // If the new value is not nothing and we removed the listener, we have
          // to add the part as a listener.
          const shouldAddListener = newListener !== nothing &&
              (oldListener === nothing || shouldRemoveListener);
          debugLogEvent$1 &&
              debugLogEvent$1({
                  kind: 'commit event listener',
                  element: this.element,
                  name: this.name,
                  value: newListener,
                  options: this.options,
                  removeListener: shouldRemoveListener,
                  addListener: shouldAddListener,
                  oldListener,
              });
          if (shouldRemoveListener) {
              this.element.removeEventListener(this.name, this, oldListener);
          }
          if (shouldAddListener) {
              // Beware: IE11 and Chrome 41 don't like using the listener as the
              // options object. Figure out how to deal w/ this in IE11 - maybe
              // patch addEventListener?
              this.element.addEventListener(this.name, this, newListener);
          }
          this._$committedValue = newListener;
      }
      handleEvent(event) {
          if (typeof this._$committedValue === 'function') {
              this._$committedValue.call(this.options?.host ?? this.element, event);
          }
          else {
              this._$committedValue.handleEvent(event);
          }
      }
  }
  class ElementPart {
      constructor(element, parent, options) {
          this.element = element;
          this.type = ELEMENT_PART;
          /** @internal */
          this._$disconnectableChildren = undefined;
          this._$parent = parent;
          this.options = options;
      }
      // See comment in Disconnectable interface for why this is a getter
      get _$isConnected() {
          return this._$parent._$isConnected;
      }
      _$setValue(value) {
          debugLogEvent$1 &&
              debugLogEvent$1({
                  kind: 'commit to element binding',
                  element: this.element,
                  value,
                  options: this.options,
              });
          resolveDirective(this, value);
      }
  }
  // Apply polyfills if available
  const polyfillSupport$2 = global$2.litHtmlPolyfillSupportDevMode
      ;
  polyfillSupport$2?.(Template, ChildPart);
  // IMPORTANT: do not change the property name or the assignment expression.
  // This line will be used in regexes to search for lit-html usage.
  (global$2.litHtmlVersions ??= []).push('3.2.0');
  if (global$2.litHtmlVersions.length > 1) {
      issueWarning$4('multiple-versions', `Multiple versions of Lit loaded. ` +
          `Loading multiple versions is not recommended.`);
  }
  /**
   * Renders a value, usually a lit-html TemplateResult, to the container.
   *
   * This example renders the text "Hello, Zoe!" inside a paragraph tag, appending
   * it to the container `document.body`.
   *
   * ```js
   * import {html, render} from 'lit';
   *
   * const name = "Zoe";
   * render(html`<p>Hello, ${name}!</p>`, document.body);
   * ```
   *
   * @param value Any [renderable
   *   value](https://lit.dev/docs/templates/expressions/#child-expressions),
   *   typically a {@linkcode TemplateResult} created by evaluating a template tag
   *   like {@linkcode html} or {@linkcode svg}.
   * @param container A DOM container to render to. The first render will append
   *   the rendered value to the container, and subsequent renders will
   *   efficiently update the rendered value if the same result type was
   *   previously rendered there.
   * @param options See {@linkcode RenderOptions} for options documentation.
   * @see
   * {@link https://lit.dev/docs/libraries/standalone-templates/#rendering-lit-html-templates| Rendering Lit HTML Templates}
   */
  const render = (value, container, options) => {
      if (container == null) {
          // Give a clearer error message than
          //     Uncaught TypeError: Cannot read properties of null (reading
          //     '_$litPart$')
          // which reads like an internal Lit error.
          throw new TypeError(`The container to render into may not be ${container}`);
      }
      const renderId = debugLogRenderId++ ;
      const partOwnerNode = options?.renderBefore ?? container;
      // This property needs to remain unminified.
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      let part = partOwnerNode['_$litPart$'];
      debugLogEvent$1 &&
          debugLogEvent$1({
              kind: 'begin render',
              id: renderId,
              value,
              container,
              options,
              part,
          });
      if (part === undefined) {
          const endNode = options?.renderBefore ?? null;
          // This property needs to remain unminified.
          // eslint-disable-next-line @typescript-eslint/no-explicit-any
          partOwnerNode['_$litPart$'] = part = new ChildPart(container.insertBefore(createMarker(), endNode), endNode, undefined, options ?? {});
      }
      part._$setValue(value);
      debugLogEvent$1 &&
          debugLogEvent$1({
              kind: 'end render',
              id: renderId,
              value,
              container,
              options,
              part,
          });
      return part;
  };
  {
      render.setSanitizer = setSanitizer;
      render.createSanitizer = createSanitizer;
      {
          render._testOnlyClearSanitizerFactoryDoNotCallOrElse =
              _testOnlyClearSanitizerFactoryDoNotCallOrElse;
      }
  }

  /**
   * @license
   * Copyright 2019 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  const NODE_MODE = false;
  // Allows minifiers to rename references to globalThis
  const global$1 = globalThis;
  /**
   * Whether the current browser supports `adoptedStyleSheets`.
   */
  const supportsAdoptingStyleSheets = global$1.ShadowRoot &&
      (global$1.ShadyCSS === undefined || global$1.ShadyCSS.nativeShadow) &&
      'adoptedStyleSheets' in Document.prototype &&
      'replace' in CSSStyleSheet.prototype;
  const constructionToken = Symbol();
  const cssTagCache = new WeakMap();
  /**
   * A container for a string of CSS text, that may be used to create a CSSStyleSheet.
   *
   * CSSResult is the return value of `css`-tagged template literals and
   * `unsafeCSS()`. In order to ensure that CSSResults are only created via the
   * `css` tag and `unsafeCSS()`, CSSResult cannot be constructed directly.
   */
  class CSSResult {
      constructor(cssText, strings, safeToken) {
          // This property needs to remain unminified.
          this['_$cssResult$'] = true;
          if (safeToken !== constructionToken) {
              throw new Error('CSSResult is not constructable. Use `unsafeCSS` or `css` instead.');
          }
          this.cssText = cssText;
          this._strings = strings;
      }
      // This is a getter so that it's lazy. In practice, this means stylesheets
      // are not created until the first element instance is made.
      get styleSheet() {
          // If `supportsAdoptingStyleSheets` is true then we assume CSSStyleSheet is
          // constructable.
          let styleSheet = this._styleSheet;
          const strings = this._strings;
          if (supportsAdoptingStyleSheets && styleSheet === undefined) {
              const cacheable = strings !== undefined && strings.length === 1;
              if (cacheable) {
                  styleSheet = cssTagCache.get(strings);
              }
              if (styleSheet === undefined) {
                  (this._styleSheet = styleSheet = new CSSStyleSheet()).replaceSync(this.cssText);
                  if (cacheable) {
                      cssTagCache.set(strings, styleSheet);
                  }
              }
          }
          return styleSheet;
      }
      toString() {
          return this.cssText;
      }
  }
  const textFromCSSResult = (value) => {
      // This property needs to remain unminified.
      if (value['_$cssResult$'] === true) {
          return value.cssText;
      }
      else if (typeof value === 'number') {
          return value;
      }
      else {
          throw new Error(`Value passed to 'css' function must be a 'css' function result: ` +
              `${value}. Use 'unsafeCSS' to pass non-literal values, but take care ` +
              `to ensure page security.`);
      }
  };
  /**
   * Wrap a value for interpolation in a {@linkcode css} tagged template literal.
   *
   * This is unsafe because untrusted CSS text can be used to phone home
   * or exfiltrate data to an attacker controlled site. Take care to only use
   * this with trusted input.
   */
  const unsafeCSS = (value) => new CSSResult(typeof value === 'string' ? value : String(value), undefined, constructionToken);
  /**
   * A template literal tag which can be used with LitElement's
   * {@linkcode LitElement.styles} property to set element styles.
   *
   * For security reasons, only literal string values and number may be used in
   * embedded expressions. To incorporate non-literal values {@linkcode unsafeCSS}
   * may be used inside an expression.
   */
  const css = (strings, ...values) => {
      const cssText = strings.length === 1
          ? strings[0]
          : values.reduce((acc, v, idx) => acc + textFromCSSResult(v) + strings[idx + 1], strings[0]);
      return new CSSResult(cssText, strings, constructionToken);
  };
  /**
   * Applies the given styles to a `shadowRoot`. When Shadow DOM is
   * available but `adoptedStyleSheets` is not, styles are appended to the
   * `shadowRoot` to [mimic spec behavior](https://wicg.github.io/construct-stylesheets/#using-constructed-stylesheets).
   * Note, when shimming is used, any styles that are subsequently placed into
   * the shadowRoot should be placed *before* any shimmed adopted styles. This
   * will match spec behavior that gives adopted sheets precedence over styles in
   * shadowRoot.
   */
  const adoptStyles = (renderRoot, styles) => {
      if (supportsAdoptingStyleSheets) {
          renderRoot.adoptedStyleSheets = styles.map((s) => s instanceof CSSStyleSheet ? s : s.styleSheet);
      }
      else {
          for (const s of styles) {
              const style = document.createElement('style');
              // eslint-disable-next-line @typescript-eslint/no-explicit-any
              const nonce = global$1['litNonce'];
              if (nonce !== undefined) {
                  style.setAttribute('nonce', nonce);
              }
              style.textContent = s.cssText;
              renderRoot.appendChild(style);
          }
      }
  };
  const cssResultFromStyleSheet = (sheet) => {
      let cssText = '';
      for (const rule of sheet.cssRules) {
          cssText += rule.cssText;
      }
      return unsafeCSS(cssText);
  };
  const getCompatibleStyle = supportsAdoptingStyleSheets ||
      (NODE_MODE )
      ? (s) => s
      : (s) => s instanceof CSSStyleSheet ? cssResultFromStyleSheet(s) : s;

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  // TODO (justinfagnani): Add `hasOwn` here when we ship ES2022
  const { is, defineProperty, getOwnPropertyDescriptor, getOwnPropertyNames, getOwnPropertySymbols, getPrototypeOf, } = Object;
  // Lets a minifier replace globalThis references with a minified name
  const global = globalThis;
  let issueWarning$3;
  const trustedTypes = global
      .trustedTypes;
  // Temporary workaround for https://crbug.com/993268
  // Currently, any attribute starting with "on" is considered to be a
  // TrustedScript source. Such boolean attributes must be set to the equivalent
  // trusted emptyScript value.
  const emptyStringForBooleanAttribute = trustedTypes
      ? trustedTypes.emptyScript
      : '';
  const polyfillSupport$1 = global.reactiveElementPolyfillSupportDevMode
      ;
  {
      // Ensure warnings are issued only 1x, even if multiple versions of Lit
      // are loaded.
      const issuedWarnings = (global.litIssuedWarnings ??=
          new Set());
      // Issue a warning, if we haven't already.
      issueWarning$3 = (code, warning) => {
          warning += ` See https://lit.dev/msg/${code} for more information.`;
          if (!issuedWarnings.has(warning)) {
              console.warn(warning);
              issuedWarnings.add(warning);
          }
      };
      issueWarning$3('dev-mode', `Lit is in dev mode. Not recommended for production!`);
      // Issue polyfill support warning.
      if (global.ShadyDOM?.inUse && polyfillSupport$1 === undefined) {
          issueWarning$3('polyfill-support-missing', `Shadow DOM is being polyfilled via \`ShadyDOM\` but ` +
              `the \`polyfill-support\` module has not been loaded.`);
      }
  }
  /**
   * Useful for visualizing and logging insights into what the Lit template system is doing.
   *
   * Compiled out of prod mode builds.
   */
  const debugLogEvent = (event) => {
          const shouldEmit = global
              .emitLitDebugLogEvents;
          if (!shouldEmit) {
              return;
          }
          global.dispatchEvent(new CustomEvent('lit-debug', {
              detail: event,
          }));
      }
      ;
  /*
   * When using Closure Compiler, JSCompiler_renameProperty(property, object) is
   * replaced at compile time by the munged name for object[property]. We cannot
   * alias this function, so we have to use a small shim that has the same
   * behavior when not compiling.
   */
  /*@__INLINE__*/
  const JSCompiler_renameProperty$1 = (prop, _obj) => prop;
  const defaultConverter = {
      toAttribute(value, type) {
          switch (type) {
              case Boolean:
                  value = value ? emptyStringForBooleanAttribute : null;
                  break;
              case Object:
              case Array:
                  // if the value is `null` or `undefined` pass this through
                  // to allow removing/no change behavior.
                  value = value == null ? value : JSON.stringify(value);
                  break;
          }
          return value;
      },
      fromAttribute(value, type) {
          let fromValue = value;
          switch (type) {
              case Boolean:
                  fromValue = value !== null;
                  break;
              case Number:
                  fromValue = value === null ? null : Number(value);
                  break;
              case Object:
              case Array:
                  // Do *not* generate exception when invalid JSON is set as elements
                  // don't normally complain on being mis-configured.
                  // TODO(sorvell): Do generate exception in *dev mode*.
                  try {
                      // Assert to adhere to Bazel's "must type assert JSON parse" rule.
                      fromValue = JSON.parse(value);
                  }
                  catch (e) {
                      fromValue = null;
                  }
                  break;
          }
          return fromValue;
      },
  };
  /**
   * Change function that returns true if `value` is different from `oldValue`.
   * This method is used as the default for a property's `hasChanged` function.
   */
  const notEqual = (value, old) => !is(value, old);
  const defaultPropertyDeclaration$1 = {
      attribute: true,
      type: String,
      converter: defaultConverter,
      reflect: false,
      hasChanged: notEqual,
  };
  // Ensure metadata is enabled. TypeScript does not polyfill
  // Symbol.metadata, so we must ensure that it exists.
  Symbol.metadata ??= Symbol('metadata');
  // Map from a class's metadata object to property options
  // Note that we must use nullish-coalescing assignment so that we only use one
  // map even if we load multiple version of this module.
  global.litPropertyMetadata ??= new WeakMap();
  /**
   * Base element class which manages element properties and attributes. When
   * properties change, the `update` method is asynchronously called. This method
   * should be supplied by subclasses to render updates as desired.
   * @noInheritDoc
   */
  class ReactiveElement
  // In the Node build, this `extends` clause will be substituted with
  // `(globalThis.HTMLElement ?? HTMLElement)`.
  //
  // This way, we will first prefer any global `HTMLElement` polyfill that the
  // user has assigned, and then fall back to the `HTMLElement` shim which has
  // been imported (see note at the top of this file about how this import is
  // generated by Rollup). Note that the `HTMLElement` variable has been
  // shadowed by this import, so it no longer refers to the global.
   extends HTMLElement {
      /**
       * Adds an initializer function to the class that is called during instance
       * construction.
       *
       * This is useful for code that runs against a `ReactiveElement`
       * subclass, such as a decorator, that needs to do work for each
       * instance, such as setting up a `ReactiveController`.
       *
       * ```ts
       * const myDecorator = (target: typeof ReactiveElement, key: string) => {
       *   target.addInitializer((instance: ReactiveElement) => {
       *     // This is run during construction of the element
       *     new MyController(instance);
       *   });
       * }
       * ```
       *
       * Decorating a field will then cause each instance to run an initializer
       * that adds a controller:
       *
       * ```ts
       * class MyElement extends LitElement {
       *   @myDecorator foo;
       * }
       * ```
       *
       * Initializers are stored per-constructor. Adding an initializer to a
       * subclass does not add it to a superclass. Since initializers are run in
       * constructors, initializers will run in order of the class hierarchy,
       * starting with superclasses and progressing to the instance's class.
       *
       * @nocollapse
       */
      static addInitializer(initializer) {
          this.__prepare();
          (this._initializers ??= []).push(initializer);
      }
      /**
       * Returns a list of attributes corresponding to the registered properties.
       * @nocollapse
       * @category attributes
       */
      static get observedAttributes() {
          // Ensure we've created all properties
          this.finalize();
          // this.__attributeToPropertyMap is only undefined after finalize() in
          // ReactiveElement itself. ReactiveElement.observedAttributes is only
          // accessed with ReactiveElement as the receiver when a subclass or mixin
          // calls super.observedAttributes
          return (this.__attributeToPropertyMap && [...this.__attributeToPropertyMap.keys()]);
      }
      /**
       * Creates a property accessor on the element prototype if one does not exist
       * and stores a {@linkcode PropertyDeclaration} for the property with the
       * given options. The property setter calls the property's `hasChanged`
       * property option or uses a strict identity check to determine whether or not
       * to request an update.
       *
       * This method may be overridden to customize properties; however,
       * when doing so, it's important to call `super.createProperty` to ensure
       * the property is setup correctly. This method calls
       * `getPropertyDescriptor` internally to get a descriptor to install.
       * To customize what properties do when they are get or set, override
       * `getPropertyDescriptor`. To customize the options for a property,
       * implement `createProperty` like this:
       *
       * ```ts
       * static createProperty(name, options) {
       *   options = Object.assign(options, {myOption: true});
       *   super.createProperty(name, options);
       * }
       * ```
       *
       * @nocollapse
       * @category properties
       */
      static createProperty(name, options = defaultPropertyDeclaration$1) {
          // If this is a state property, force the attribute to false.
          if (options.state) {
              options.attribute = false;
          }
          this.__prepare();
          this.elementProperties.set(name, options);
          if (!options.noAccessor) {
              const key = // Use Symbol.for in dev mode to make it easier to maintain state
                      // when doing HMR.
                      Symbol.for(`${String(name)} (@property() cache)`)
                  ;
              const descriptor = this.getPropertyDescriptor(name, key, options);
              if (descriptor !== undefined) {
                  defineProperty(this.prototype, name, descriptor);
              }
          }
      }
      /**
       * Returns a property descriptor to be defined on the given named property.
       * If no descriptor is returned, the property will not become an accessor.
       * For example,
       *
       * ```ts
       * class MyElement extends LitElement {
       *   static getPropertyDescriptor(name, key, options) {
       *     const defaultDescriptor =
       *         super.getPropertyDescriptor(name, key, options);
       *     const setter = defaultDescriptor.set;
       *     return {
       *       get: defaultDescriptor.get,
       *       set(value) {
       *         setter.call(this, value);
       *         // custom action.
       *       },
       *       configurable: true,
       *       enumerable: true
       *     }
       *   }
       * }
       * ```
       *
       * @nocollapse
       * @category properties
       */
      static getPropertyDescriptor(name, key, options) {
          const { get, set } = getOwnPropertyDescriptor(this.prototype, name) ?? {
              get() {
                  return this[key];
              },
              set(v) {
                  this[key] = v;
              },
          };
          if (get == null) {
              if ('value' in (getOwnPropertyDescriptor(this.prototype, name) ?? {})) {
                  throw new Error(`Field ${JSON.stringify(String(name))} on ` +
                      `${this.name} was declared as a reactive property ` +
                      `but it's actually declared as a value on the prototype. ` +
                      `Usually this is due to using @property or @state on a method.`);
              }
              issueWarning$3('reactive-property-without-getter', `Field ${JSON.stringify(String(name))} on ` +
                  `${this.name} was declared as a reactive property ` +
                  `but it does not have a getter. This will be an error in a ` +
                  `future version of Lit.`);
          }
          return {
              get() {
                  return get?.call(this);
              },
              set(value) {
                  const oldValue = get?.call(this);
                  set.call(this, value);
                  this.requestUpdate(name, oldValue, options);
              },
              configurable: true,
              enumerable: true,
          };
      }
      /**
       * Returns the property options associated with the given property.
       * These options are defined with a `PropertyDeclaration` via the `properties`
       * object or the `@property` decorator and are registered in
       * `createProperty(...)`.
       *
       * Note, this method should be considered "final" and not overridden. To
       * customize the options for a given property, override
       * {@linkcode createProperty}.
       *
       * @nocollapse
       * @final
       * @category properties
       */
      static getPropertyOptions(name) {
          return this.elementProperties.get(name) ?? defaultPropertyDeclaration$1;
      }
      /**
       * Initializes static own properties of the class used in bookkeeping
       * for element properties, initializers, etc.
       *
       * Can be called multiple times by code that needs to ensure these
       * properties exist before using them.
       *
       * This method ensures the superclass is finalized so that inherited
       * property metadata can be copied down.
       * @nocollapse
       */
      static __prepare() {
          if (this.hasOwnProperty(JSCompiler_renameProperty$1('elementProperties'))) {
              // Already prepared
              return;
          }
          // Finalize any superclasses
          const superCtor = getPrototypeOf(this);
          superCtor.finalize();
          // Create own set of initializers for this class if any exist on the
          // superclass and copy them down. Note, for a small perf boost, avoid
          // creating initializers unless needed.
          if (superCtor._initializers !== undefined) {
              this._initializers = [...superCtor._initializers];
          }
          // Initialize elementProperties from the superclass
          this.elementProperties = new Map(superCtor.elementProperties);
      }
      /**
       * Finishes setting up the class so that it's ready to be registered
       * as a custom element and instantiated.
       *
       * This method is called by the ReactiveElement.observedAttributes getter.
       * If you override the observedAttributes getter, you must either call
       * super.observedAttributes to trigger finalization, or call finalize()
       * yourself.
       *
       * @nocollapse
       */
      static finalize() {
          if (this.hasOwnProperty(JSCompiler_renameProperty$1('finalized'))) {
              return;
          }
          this.finalized = true;
          this.__prepare();
          // Create properties from the static properties block:
          if (this.hasOwnProperty(JSCompiler_renameProperty$1('properties'))) {
              const props = this.properties;
              const propKeys = [
                  ...getOwnPropertyNames(props),
                  ...getOwnPropertySymbols(props),
              ];
              for (const p of propKeys) {
                  this.createProperty(p, props[p]);
              }
          }
          // Create properties from standard decorator metadata:
          const metadata = this[Symbol.metadata];
          if (metadata !== null) {
              const properties = litPropertyMetadata.get(metadata);
              if (properties !== undefined) {
                  for (const [p, options] of properties) {
                      this.elementProperties.set(p, options);
                  }
              }
          }
          // Create the attribute-to-property map
          this.__attributeToPropertyMap = new Map();
          for (const [p, options] of this.elementProperties) {
              const attr = this.__attributeNameForProperty(p, options);
              if (attr !== undefined) {
                  this.__attributeToPropertyMap.set(attr, p);
              }
          }
          this.elementStyles = this.finalizeStyles(this.styles);
          {
              if (this.hasOwnProperty('createProperty')) {
                  issueWarning$3('no-override-create-property', 'Overriding ReactiveElement.createProperty() is deprecated. ' +
                      'The override will not be called with standard decorators');
              }
              if (this.hasOwnProperty('getPropertyDescriptor')) {
                  issueWarning$3('no-override-get-property-descriptor', 'Overriding ReactiveElement.getPropertyDescriptor() is deprecated. ' +
                      'The override will not be called with standard decorators');
              }
          }
      }
      /**
       * Takes the styles the user supplied via the `static styles` property and
       * returns the array of styles to apply to the element.
       * Override this method to integrate into a style management system.
       *
       * Styles are deduplicated preserving the _last_ instance in the list. This
       * is a performance optimization to avoid duplicated styles that can occur
       * especially when composing via subclassing. The last item is kept to try
       * to preserve the cascade order with the assumption that it's most important
       * that last added styles override previous styles.
       *
       * @nocollapse
       * @category styles
       */
      static finalizeStyles(styles) {
          const elementStyles = [];
          if (Array.isArray(styles)) {
              // Dedupe the flattened array in reverse order to preserve the last items.
              // Casting to Array<unknown> works around TS error that
              // appears to come from trying to flatten a type CSSResultArray.
              const set = new Set(styles.flat(Infinity).reverse());
              // Then preserve original order by adding the set items in reverse order.
              for (const s of set) {
                  elementStyles.unshift(getCompatibleStyle(s));
              }
          }
          else if (styles !== undefined) {
              elementStyles.push(getCompatibleStyle(styles));
          }
          return elementStyles;
      }
      /**
       * Returns the property name for the given attribute `name`.
       * @nocollapse
       */
      static __attributeNameForProperty(name, options) {
          const attribute = options.attribute;
          return attribute === false
              ? undefined
              : typeof attribute === 'string'
                  ? attribute
                  : typeof name === 'string'
                      ? name.toLowerCase()
                      : undefined;
      }
      constructor() {
          super();
          this.__instanceProperties = undefined;
          /**
           * True if there is a pending update as a result of calling `requestUpdate()`.
           * Should only be read.
           * @category updates
           */
          this.isUpdatePending = false;
          /**
           * Is set to `true` after the first update. The element code cannot assume
           * that `renderRoot` exists before the element `hasUpdated`.
           * @category updates
           */
          this.hasUpdated = false;
          /**
           * Name of currently reflecting property
           */
          this.__reflectingProperty = null;
          this.__initialize();
      }
      /**
       * Internal only override point for customizing work done when elements
       * are constructed.
       */
      __initialize() {
          this.__updatePromise = new Promise((res) => (this.enableUpdating = res));
          this._$changedProperties = new Map();
          // This enqueues a microtask that ust run before the first update, so it
          // must be called before requestUpdate()
          this.__saveInstanceProperties();
          // ensures first update will be caught by an early access of
          // `updateComplete`
          this.requestUpdate();
          this.constructor._initializers?.forEach((i) => i(this));
      }
      /**
       * Registers a `ReactiveController` to participate in the element's reactive
       * update cycle. The element automatically calls into any registered
       * controllers during its lifecycle callbacks.
       *
       * If the element is connected when `addController()` is called, the
       * controller's `hostConnected()` callback will be immediately called.
       * @category controllers
       */
      addController(controller) {
          (this.__controllers ??= new Set()).add(controller);
          // If a controller is added after the element has been connected,
          // call hostConnected. Note, re-using existence of `renderRoot` here
          // (which is set in connectedCallback) to avoid the need to track a
          // first connected state.
          if (this.renderRoot !== undefined && this.isConnected) {
              controller.hostConnected?.();
          }
      }
      /**
       * Removes a `ReactiveController` from the element.
       * @category controllers
       */
      removeController(controller) {
          this.__controllers?.delete(controller);
      }
      /**
       * Fixes any properties set on the instance before upgrade time.
       * Otherwise these would shadow the accessor and break these properties.
       * The properties are stored in a Map which is played back after the
       * constructor runs. Note, on very old versions of Safari (<=9) or Chrome
       * (<=41), properties created for native platform properties like (`id` or
       * `name`) may not have default values set in the element constructor. On
       * these browsers native properties appear on instances and therefore their
       * default value will overwrite any element default (e.g. if the element sets
       * this.id = 'id' in the constructor, the 'id' will become '' since this is
       * the native platform default).
       */
      __saveInstanceProperties() {
          const instanceProperties = new Map();
          const elementProperties = this.constructor
              .elementProperties;
          for (const p of elementProperties.keys()) {
              if (this.hasOwnProperty(p)) {
                  instanceProperties.set(p, this[p]);
                  delete this[p];
              }
          }
          if (instanceProperties.size > 0) {
              this.__instanceProperties = instanceProperties;
          }
      }
      /**
       * Returns the node into which the element should render and by default
       * creates and returns an open shadowRoot. Implement to customize where the
       * element's DOM is rendered. For example, to render into the element's
       * childNodes, return `this`.
       *
       * @return Returns a node into which to render.
       * @category rendering
       */
      createRenderRoot() {
          const renderRoot = this.shadowRoot ??
              this.attachShadow(this.constructor.shadowRootOptions);
          adoptStyles(renderRoot, this.constructor.elementStyles);
          return renderRoot;
      }
      /**
       * On first connection, creates the element's renderRoot, sets up
       * element styling, and enables updating.
       * @category lifecycle
       */
      connectedCallback() {
          // Create renderRoot before controllers `hostConnected`
          this.renderRoot ??=
              this.createRenderRoot();
          this.enableUpdating(true);
          this.__controllers?.forEach((c) => c.hostConnected?.());
      }
      /**
       * Note, this method should be considered final and not overridden. It is
       * overridden on the element instance with a function that triggers the first
       * update.
       * @category updates
       */
      enableUpdating(_requestedUpdate) { }
      /**
       * Allows for `super.disconnectedCallback()` in extensions while
       * reserving the possibility of making non-breaking feature additions
       * when disconnecting at some point in the future.
       * @category lifecycle
       */
      disconnectedCallback() {
          this.__controllers?.forEach((c) => c.hostDisconnected?.());
      }
      /**
       * Synchronizes property values when attributes change.
       *
       * Specifically, when an attribute is set, the corresponding property is set.
       * You should rarely need to implement this callback. If this method is
       * overridden, `super.attributeChangedCallback(name, _old, value)` must be
       * called.
       *
       * See [using the lifecycle callbacks](https://developer.mozilla.org/en-US/docs/Web/Web_Components/Using_custom_elements#using_the_lifecycle_callbacks)
       * on MDN for more information about the `attributeChangedCallback`.
       * @category attributes
       */
      attributeChangedCallback(name, _old, value) {
          this._$attributeToProperty(name, value);
      }
      __propertyToAttribute(name, value) {
          const elemProperties = this.constructor.elementProperties;
          const options = elemProperties.get(name);
          const attr = this.constructor.__attributeNameForProperty(name, options);
          if (attr !== undefined && options.reflect === true) {
              const converter = options.converter?.toAttribute !==
                  undefined
                  ? options.converter
                  : defaultConverter;
              const attrValue = converter.toAttribute(value, options.type);
              if (this.constructor.enabledWarnings.includes('migration') &&
                  attrValue === undefined) {
                  issueWarning$3('undefined-attribute-value', `The attribute value for the ${name} property is ` +
                      `undefined on element ${this.localName}. The attribute will be ` +
                      `removed, but in the previous version of \`ReactiveElement\`, ` +
                      `the attribute would not have changed.`);
              }
              // Track if the property is being reflected to avoid
              // setting the property again via `attributeChangedCallback`. Note:
              // 1. this takes advantage of the fact that the callback is synchronous.
              // 2. will behave incorrectly if multiple attributes are in the reaction
              // stack at time of calling. However, since we process attributes
              // in `update` this should not be possible (or an extreme corner case
              // that we'd like to discover).
              // mark state reflecting
              this.__reflectingProperty = name;
              if (attrValue == null) {
                  this.removeAttribute(attr);
              }
              else {
                  this.setAttribute(attr, attrValue);
              }
              // mark state not reflecting
              this.__reflectingProperty = null;
          }
      }
      /** @internal */
      _$attributeToProperty(name, value) {
          const ctor = this.constructor;
          // Note, hint this as an `AttributeMap` so closure clearly understands
          // the type; it has issues with tracking types through statics
          const propName = ctor.__attributeToPropertyMap.get(name);
          // Use tracking info to avoid reflecting a property value to an attribute
          // if it was just set because the attribute changed.
          if (propName !== undefined && this.__reflectingProperty !== propName) {
              const options = ctor.getPropertyOptions(propName);
              const converter = typeof options.converter === 'function'
                  ? { fromAttribute: options.converter }
                  : options.converter?.fromAttribute !== undefined
                      ? options.converter
                      : defaultConverter;
              // mark state reflecting
              this.__reflectingProperty = propName;
              this[propName] = converter.fromAttribute(value, options.type
              // eslint-disable-next-line @typescript-eslint/no-explicit-any
              );
              // mark state not reflecting
              this.__reflectingProperty = null;
          }
      }
      /**
       * Requests an update which is processed asynchronously. This should be called
       * when an element should update based on some state not triggered by setting
       * a reactive property. In this case, pass no arguments. It should also be
       * called when manually implementing a property setter. In this case, pass the
       * property `name` and `oldValue` to ensure that any configured property
       * options are honored.
       *
       * @param name name of requesting property
       * @param oldValue old value of requesting property
       * @param options property options to use instead of the previously
       *     configured options
       * @category updates
       */
      requestUpdate(name, oldValue, options) {
          // If we have a property key, perform property update steps.
          if (name !== undefined) {
              if (name instanceof Event) {
                  issueWarning$3(``, `The requestUpdate() method was called with an Event as the property name. This is probably a mistake caused by binding this.requestUpdate as an event listener. Instead bind a function that will call it with no arguments: () => this.requestUpdate()`);
              }
              options ??= this.constructor.getPropertyOptions(name);
              const hasChanged = options.hasChanged ?? notEqual;
              const newValue = this[name];
              if (hasChanged(newValue, oldValue)) {
                  this._$changeProperty(name, oldValue, options);
              }
              else {
                  // Abort the request if the property should not be considered changed.
                  return;
              }
          }
          if (this.isUpdatePending === false) {
              this.__updatePromise = this.__enqueueUpdate();
          }
      }
      /**
       * @internal
       */
      _$changeProperty(name, oldValue, options) {
          // TODO (justinfagnani): Create a benchmark of Map.has() + Map.set(
          // vs just Map.set()
          if (!this._$changedProperties.has(name)) {
              this._$changedProperties.set(name, oldValue);
          }
          // Add to reflecting properties set.
          // Note, it's important that every change has a chance to add the
          // property to `__reflectingProperties`. This ensures setting
          // attribute + property reflects correctly.
          if (options.reflect === true && this.__reflectingProperty !== name) {
              (this.__reflectingProperties ??= new Set()).add(name);
          }
      }
      /**
       * Sets up the element to asynchronously update.
       */
      async __enqueueUpdate() {
          this.isUpdatePending = true;
          try {
              // Ensure any previous update has resolved before updating.
              // This `await` also ensures that property changes are batched.
              await this.__updatePromise;
          }
          catch (e) {
              // Refire any previous errors async so they do not disrupt the update
              // cycle. Errors are refired so developers have a chance to observe
              // them, and this can be done by implementing
              // `window.onunhandledrejection`.
              Promise.reject(e);
          }
          const result = this.scheduleUpdate();
          // If `scheduleUpdate` returns a Promise, we await it. This is done to
          // enable coordinating updates with a scheduler. Note, the result is
          // checked to avoid delaying an additional microtask unless we need to.
          if (result != null) {
              await result;
          }
          return !this.isUpdatePending;
      }
      /**
       * Schedules an element update. You can override this method to change the
       * timing of updates by returning a Promise. The update will await the
       * returned Promise, and you should resolve the Promise to allow the update
       * to proceed. If this method is overridden, `super.scheduleUpdate()`
       * must be called.
       *
       * For instance, to schedule updates to occur just before the next frame:
       *
       * ```ts
       * override protected async scheduleUpdate(): Promise<unknown> {
       *   await new Promise((resolve) => requestAnimationFrame(() => resolve()));
       *   super.scheduleUpdate();
       * }
       * ```
       * @category updates
       */
      scheduleUpdate() {
          const result = this.performUpdate();
          if (this.constructor.enabledWarnings.includes('async-perform-update') &&
              typeof result?.then ===
                  'function') {
              issueWarning$3('async-perform-update', `Element ${this.localName} returned a Promise from performUpdate(). ` +
                  `This behavior is deprecated and will be removed in a future ` +
                  `version of ReactiveElement.`);
          }
          return result;
      }
      /**
       * Performs an element update. Note, if an exception is thrown during the
       * update, `firstUpdated` and `updated` will not be called.
       *
       * Call `performUpdate()` to immediately process a pending update. This should
       * generally not be needed, but it can be done in rare cases when you need to
       * update synchronously.
       *
       * @category updates
       */
      performUpdate() {
          // Abort any update if one is not pending when this is called.
          // This can happen if `performUpdate` is called early to "flush"
          // the update.
          if (!this.isUpdatePending) {
              return;
          }
          debugLogEvent?.({ kind: 'update' });
          if (!this.hasUpdated) {
              // Create renderRoot before first update. This occurs in `connectedCallback`
              // but is done here to support out of tree calls to `enableUpdating`/`performUpdate`.
              this.renderRoot ??=
                  this.createRenderRoot();
              {
                  // Produce warning if any reactive properties on the prototype are
                  // shadowed by class fields. Instance fields set before upgrade are
                  // deleted by this point, so any own property is caused by class field
                  // initialization in the constructor.
                  const ctor = this.constructor;
                  const shadowedProperties = [...ctor.elementProperties.keys()].filter((p) => this.hasOwnProperty(p) && p in getPrototypeOf(this));
                  if (shadowedProperties.length) {
                      throw new Error(`The following properties on element ${this.localName} will not ` +
                          `trigger updates as expected because they are set using class ` +
                          `fields: ${shadowedProperties.join(', ')}. ` +
                          `Native class fields and some compiled output will overwrite ` +
                          `accessors used for detecting changes. See ` +
                          `https://lit.dev/msg/class-field-shadowing ` +
                          `for more information.`);
                  }
              }
              // Mixin instance properties once, if they exist.
              if (this.__instanceProperties) {
                  // TODO (justinfagnani): should we use the stored value? Could a new value
                  // have been set since we stored the own property value?
                  for (const [p, value] of this.__instanceProperties) {
                      this[p] = value;
                  }
                  this.__instanceProperties = undefined;
              }
              // Trigger initial value reflection and populate the initial
              // changedProperties map, but only for the case of experimental
              // decorators on accessors, which will not have already populated the
              // changedProperties map. We can't know if these accessors had
              // initializers, so we just set them anyway - a difference from
              // experimental decorators on fields and standard decorators on
              // auto-accessors.
              // For context why experimentalDecorators with auto accessors are handled
              // specifically also see:
              // https://github.com/lit/lit/pull/4183#issuecomment-1711959635
              const elementProperties = this.constructor
                  .elementProperties;
              if (elementProperties.size > 0) {
                  for (const [p, options] of elementProperties) {
                      if (options.wrapped === true &&
                          !this._$changedProperties.has(p) &&
                          this[p] !== undefined) {
                          this._$changeProperty(p, this[p], options);
                      }
                  }
              }
          }
          let shouldUpdate = false;
          const changedProperties = this._$changedProperties;
          try {
              shouldUpdate = this.shouldUpdate(changedProperties);
              if (shouldUpdate) {
                  this.willUpdate(changedProperties);
                  this.__controllers?.forEach((c) => c.hostUpdate?.());
                  this.update(changedProperties);
              }
              else {
                  this.__markUpdated();
              }
          }
          catch (e) {
              // Prevent `firstUpdated` and `updated` from running when there's an
              // update exception.
              shouldUpdate = false;
              // Ensure element can accept additional updates after an exception.
              this.__markUpdated();
              throw e;
          }
          // The update is no longer considered pending and further updates are now allowed.
          if (shouldUpdate) {
              this._$didUpdate(changedProperties);
          }
      }
      /**
       * Invoked before `update()` to compute values needed during the update.
       *
       * Implement `willUpdate` to compute property values that depend on other
       * properties and are used in the rest of the update process.
       *
       * ```ts
       * willUpdate(changedProperties) {
       *   // only need to check changed properties for an expensive computation.
       *   if (changedProperties.has('firstName') || changedProperties.has('lastName')) {
       *     this.sha = computeSHA(`${this.firstName} ${this.lastName}`);
       *   }
       * }
       *
       * render() {
       *   return html`SHA: ${this.sha}`;
       * }
       * ```
       *
       * @category updates
       */
      willUpdate(_changedProperties) { }
      // Note, this is an override point for polyfill-support.
      // @internal
      _$didUpdate(changedProperties) {
          this.__controllers?.forEach((c) => c.hostUpdated?.());
          if (!this.hasUpdated) {
              this.hasUpdated = true;
              this.firstUpdated(changedProperties);
          }
          this.updated(changedProperties);
          if (this.isUpdatePending &&
              this.constructor.enabledWarnings.includes('change-in-update')) {
              issueWarning$3('change-in-update', `Element ${this.localName} scheduled an update ` +
                  `(generally because a property was set) ` +
                  `after an update completed, causing a new update to be scheduled. ` +
                  `This is inefficient and should be avoided unless the next update ` +
                  `can only be scheduled as a side effect of the previous update.`);
          }
      }
      __markUpdated() {
          this._$changedProperties = new Map();
          this.isUpdatePending = false;
      }
      /**
       * Returns a Promise that resolves when the element has completed updating.
       * The Promise value is a boolean that is `true` if the element completed the
       * update without triggering another update. The Promise result is `false` if
       * a property was set inside `updated()`. If the Promise is rejected, an
       * exception was thrown during the update.
       *
       * To await additional asynchronous work, override the `getUpdateComplete`
       * method. For example, it is sometimes useful to await a rendered element
       * before fulfilling this Promise. To do this, first await
       * `super.getUpdateComplete()`, then any subsequent state.
       *
       * @return A promise of a boolean that resolves to true if the update completed
       *     without triggering another update.
       * @category updates
       */
      get updateComplete() {
          return this.getUpdateComplete();
      }
      /**
       * Override point for the `updateComplete` promise.
       *
       * It is not safe to override the `updateComplete` getter directly due to a
       * limitation in TypeScript which means it is not possible to call a
       * superclass getter (e.g. `super.updateComplete.then(...)`) when the target
       * language is ES5 (https://github.com/microsoft/TypeScript/issues/338).
       * This method should be overridden instead. For example:
       *
       * ```ts
       * class MyElement extends LitElement {
       *   override async getUpdateComplete() {
       *     const result = await super.getUpdateComplete();
       *     await this._myChild.updateComplete;
       *     return result;
       *   }
       * }
       * ```
       *
       * @return A promise of a boolean that resolves to true if the update completed
       *     without triggering another update.
       * @category updates
       */
      getUpdateComplete() {
          return this.__updatePromise;
      }
      /**
       * Controls whether or not `update()` should be called when the element requests
       * an update. By default, this method always returns `true`, but this can be
       * customized to control when to update.
       *
       * @param _changedProperties Map of changed properties with old values
       * @category updates
       */
      shouldUpdate(_changedProperties) {
          return true;
      }
      /**
       * Updates the element. This method reflects property values to attributes.
       * It can be overridden to render and keep updated element DOM.
       * Setting properties inside this method will *not* trigger
       * another update.
       *
       * @param _changedProperties Map of changed properties with old values
       * @category updates
       */
      update(_changedProperties) {
          // The forEach() expression will only run when when __reflectingProperties is
          // defined, and it returns undefined, setting __reflectingProperties to
          // undefined
          this.__reflectingProperties &&= this.__reflectingProperties.forEach((p) => this.__propertyToAttribute(p, this[p]));
          this.__markUpdated();
      }
      /**
       * Invoked whenever the element is updated. Implement to perform
       * post-updating tasks via DOM APIs, for example, focusing an element.
       *
       * Setting properties inside this method will trigger the element to update
       * again after this update cycle completes.
       *
       * @param _changedProperties Map of changed properties with old values
       * @category updates
       */
      updated(_changedProperties) { }
      /**
       * Invoked when the element is first updated. Implement to perform one time
       * work on the element after update.
       *
       * ```ts
       * firstUpdated() {
       *   this.renderRoot.getElementById('my-text-area').focus();
       * }
       * ```
       *
       * Setting properties inside this method will trigger the element to update
       * again after this update cycle completes.
       *
       * @param _changedProperties Map of changed properties with old values
       * @category updates
       */
      firstUpdated(_changedProperties) { }
  }
  /**
   * Memoized list of all element styles.
   * Created lazily on user subclasses when finalizing the class.
   * @nocollapse
   * @category styles
   */
  ReactiveElement.elementStyles = [];
  /**
   * Options used when calling `attachShadow`. Set this property to customize
   * the options for the shadowRoot; for example, to create a closed
   * shadowRoot: `{mode: 'closed'}`.
   *
   * Note, these options are used in `createRenderRoot`. If this method
   * is customized, options should be respected if possible.
   * @nocollapse
   * @category rendering
   */
  ReactiveElement.shadowRootOptions = { mode: 'open' };
  // Assigned here to work around a jscompiler bug with static fields
  // when compiling to ES5.
  // https://github.com/google/closure-compiler/issues/3177
  ReactiveElement[JSCompiler_renameProperty$1('elementProperties')] = new Map();
  ReactiveElement[JSCompiler_renameProperty$1('finalized')] = new Map();
  // Apply polyfills if available
  polyfillSupport$1?.({ ReactiveElement });
  // Dev mode warnings...
  {
      // Default warning set.
      ReactiveElement.enabledWarnings = [
          'change-in-update',
          'async-perform-update',
      ];
      const ensureOwnWarnings = function (ctor) {
          if (!ctor.hasOwnProperty(JSCompiler_renameProperty$1('enabledWarnings'))) {
              ctor.enabledWarnings = ctor.enabledWarnings.slice();
          }
      };
      ReactiveElement.enableWarning = function (warning) {
          ensureOwnWarnings(this);
          if (!this.enabledWarnings.includes(warning)) {
              this.enabledWarnings.push(warning);
          }
      };
      ReactiveElement.disableWarning = function (warning) {
          ensureOwnWarnings(this);
          const i = this.enabledWarnings.indexOf(warning);
          if (i >= 0) {
              this.enabledWarnings.splice(i, 1);
          }
      };
  }
  // IMPORTANT: do not change the property name or the assignment expression.
  // This line will be used in regexes to search for ReactiveElement usage.
  (global.reactiveElementVersions ??= []).push('2.0.4');
  if (global.reactiveElementVersions.length > 1) {
      issueWarning$3('multiple-versions', `Multiple versions of Lit loaded. Loading multiple versions ` +
          `is not recommended.`);
  }

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  /*
   * When using Closure Compiler, JSCompiler_renameProperty(property, object) is
   * replaced at compile time by the munged name for object[property]. We cannot
   * alias this function, so we have to use a small shim that has the same
   * behavior when not compiling.
   */
  /*@__INLINE__*/
  const JSCompiler_renameProperty = (prop, _obj) => prop;
  let issueWarning$2;
  {
      // Ensure warnings are issued only 1x, even if multiple versions of Lit
      // are loaded.
      const issuedWarnings = (globalThis.litIssuedWarnings ??= new Set());
      // Issue a warning, if we haven't already.
      issueWarning$2 = (code, warning) => {
          warning += ` See https://lit.dev/msg/${code} for more information.`;
          if (!issuedWarnings.has(warning)) {
              console.warn(warning);
              issuedWarnings.add(warning);
          }
      };
  }
  /**
   * Base element class that manages element properties and attributes, and
   * renders a lit-html template.
   *
   * To define a component, subclass `LitElement` and implement a
   * `render` method to provide the component's template. Define properties
   * using the {@linkcode LitElement.properties properties} property or the
   * {@linkcode property} decorator.
   */
  class LitElement extends ReactiveElement {
      constructor() {
          super(...arguments);
          /**
           * @category rendering
           */
          this.renderOptions = { host: this };
          this.__childPart = undefined;
      }
      /**
       * @category rendering
       */
      createRenderRoot() {
          const renderRoot = super.createRenderRoot();
          // When adoptedStyleSheets are shimmed, they are inserted into the
          // shadowRoot by createRenderRoot. Adjust the renderBefore node so that
          // any styles in Lit content render before adoptedStyleSheets. This is
          // important so that adoptedStyleSheets have precedence over styles in
          // the shadowRoot.
          this.renderOptions.renderBefore ??= renderRoot.firstChild;
          return renderRoot;
      }
      /**
       * Updates the element. This method reflects property values to attributes
       * and calls `render` to render DOM via lit-html. Setting properties inside
       * this method will *not* trigger another update.
       * @param changedProperties Map of changed properties with old values
       * @category updates
       */
      update(changedProperties) {
          // Setting properties in `render` should not trigger an update. Since
          // updates are allowed after super.update, it's important to call `render`
          // before that.
          const value = this.render();
          if (!this.hasUpdated) {
              this.renderOptions.isConnected = this.isConnected;
          }
          super.update(changedProperties);
          this.__childPart = render(value, this.renderRoot, this.renderOptions);
      }
      /**
       * Invoked when the component is added to the document's DOM.
       *
       * In `connectedCallback()` you should setup tasks that should only occur when
       * the element is connected to the document. The most common of these is
       * adding event listeners to nodes external to the element, like a keydown
       * event handler added to the window.
       *
       * ```ts
       * connectedCallback() {
       *   super.connectedCallback();
       *   addEventListener('keydown', this._handleKeydown);
       * }
       * ```
       *
       * Typically, anything done in `connectedCallback()` should be undone when the
       * element is disconnected, in `disconnectedCallback()`.
       *
       * @category lifecycle
       */
      connectedCallback() {
          super.connectedCallback();
          this.__childPart?.setConnected(true);
      }
      /**
       * Invoked when the component is removed from the document's DOM.
       *
       * This callback is the main signal to the element that it may no longer be
       * used. `disconnectedCallback()` should ensure that nothing is holding a
       * reference to the element (such as event listeners added to nodes external
       * to the element), so that it is free to be garbage collected.
       *
       * ```ts
       * disconnectedCallback() {
       *   super.disconnectedCallback();
       *   window.removeEventListener('keydown', this._handleKeydown);
       * }
       * ```
       *
       * An element may be re-connected after being disconnected.
       *
       * @category lifecycle
       */
      disconnectedCallback() {
          super.disconnectedCallback();
          this.__childPart?.setConnected(false);
      }
      /**
       * Invoked on each update to perform rendering tasks. This method may return
       * any value renderable by lit-html's `ChildPart` - typically a
       * `TemplateResult`. Setting properties inside this method will *not* trigger
       * the element to update.
       * @category rendering
       */
      render() {
          return noChange;
      }
  }
  // This property needs to remain unminified.
  LitElement['_$litElement$'] = true;
  /**
   * Ensure this class is marked as `finalized` as an optimization ensuring
   * it will not needlessly try to `finalize`.
   *
   * Note this property name is a string to prevent breaking Closure JS Compiler
   * optimizations. See @lit/reactive-element for more information.
   */
  LitElement[JSCompiler_renameProperty('finalized')] = true;
  // Install hydration if available
  globalThis.litElementHydrateSupport?.({ LitElement });
  // Apply polyfills if available
  const polyfillSupport = globalThis.litElementPolyfillSupportDevMode
      ;
  polyfillSupport?.({ LitElement });
  // IMPORTANT: do not change the property name or the assignment expression.
  // This line will be used in regexes to search for LitElement usage.
  (globalThis.litElementVersions ??= []).push('4.1.0');
  if (globalThis.litElementVersions.length > 1) {
      issueWarning$2('multiple-versions', `Multiple versions of Lit loaded. Loading multiple versions ` +
          `is not recommended.`);
  }

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  let issueWarning$1;
  {
      // Ensure warnings are issued only 1x, even if multiple versions of Lit
      // are loaded.
      const issuedWarnings = (globalThis.litIssuedWarnings ??= new Set());
      // Issue a warning, if we haven't already.
      issueWarning$1 = (code, warning) => {
          warning += ` See https://lit.dev/msg/${code} for more information.`;
          if (!issuedWarnings.has(warning)) {
              console.warn(warning);
              issuedWarnings.add(warning);
          }
      };
  }
  const legacyProperty = (options, proto, name) => {
      const hasOwnProperty = proto.hasOwnProperty(name);
      proto.constructor.createProperty(name, hasOwnProperty ? { ...options, wrapped: true } : options);
      // For accessors (which have a descriptor on the prototype) we need to
      // return a descriptor, otherwise TypeScript overwrites the descriptor we
      // define in createProperty() with the original descriptor. We don't do this
      // for fields, which don't have a descriptor, because this could overwrite
      // descriptor defined by other decorators.
      return hasOwnProperty
          ? Object.getOwnPropertyDescriptor(proto, name)
          : undefined;
  };
  // This is duplicated from a similar variable in reactive-element.ts, but
  // actually makes sense to have this default defined with the decorator, so
  // that different decorators could have different defaults.
  const defaultPropertyDeclaration = {
      attribute: true,
      type: String,
      converter: defaultConverter$1,
      reflect: false,
      hasChanged: notEqual$1,
  };
  /**
   * Wraps a class accessor or setter so that `requestUpdate()` is called with the
   * property name and old value when the accessor is set.
   */
  const standardProperty = (options = defaultPropertyDeclaration, target, context) => {
      const { kind, metadata } = context;
      if (metadata == null) {
          issueWarning$1('missing-class-metadata', `The class ${target} is missing decorator metadata. This ` +
              `could mean that you're using a compiler that supports decorators ` +
              `but doesn't support decorator metadata, such as TypeScript 5.1. ` +
              `Please update your compiler.`);
      }
      // Store the property options
      let properties = globalThis.litPropertyMetadata.get(metadata);
      if (properties === undefined) {
          globalThis.litPropertyMetadata.set(metadata, (properties = new Map()));
      }
      properties.set(context.name, options);
      if (kind === 'accessor') {
          // Standard decorators cannot dynamically modify the class, so we can't
          // replace a field with accessors. The user must use the new `accessor`
          // keyword instead.
          const { name } = context;
          return {
              set(v) {
                  const oldValue = target.get.call(this);
                  target.set.call(this, v);
                  this.requestUpdate(name, oldValue, options);
              },
              init(v) {
                  if (v !== undefined) {
                      this._$changeProperty(name, undefined, options);
                  }
                  return v;
              },
          };
      }
      else if (kind === 'setter') {
          const { name } = context;
          return function (value) {
              const oldValue = this[name];
              target.call(this, value);
              this.requestUpdate(name, oldValue, options);
          };
      }
      throw new Error(`Unsupported decorator location: ${kind}`);
  };
  /**
   * A class field or accessor decorator which creates a reactive property that
   * reflects a corresponding attribute value. When a decorated property is set
   * the element will update and render. A {@linkcode PropertyDeclaration} may
   * optionally be supplied to configure property features.
   *
   * This decorator should only be used for public fields. As public fields,
   * properties should be considered as primarily settable by element users,
   * either via attribute or the property itself.
   *
   * Generally, properties that are changed by the element should be private or
   * protected fields and should use the {@linkcode state} decorator.
   *
   * However, sometimes element code does need to set a public property. This
   * should typically only be done in response to user interaction, and an event
   * should be fired informing the user; for example, a checkbox sets its
   * `checked` property when clicked and fires a `changed` event. Mutating public
   * properties should typically not be done for non-primitive (object or array)
   * properties. In other cases when an element needs to manage state, a private
   * property decorated via the {@linkcode state} decorator should be used. When
   * needed, state properties can be initialized via public properties to
   * facilitate complex interactions.
   *
   * ```ts
   * class MyElement {
   *   @property({ type: Boolean })
   *   clicked = false;
   * }
   * ```
   * @category Decorator
   * @ExportDecoratedItems
   */
  function property(options) {
      return (protoOrTarget, nameOrContext
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      ) => {
          return (typeof nameOrContext === 'object'
              ? standardProperty(options, protoOrTarget, nameOrContext)
              : legacyProperty(options, protoOrTarget, nameOrContext));
      };
  }

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  /**
   * Declares a private or protected reactive property that still triggers
   * updates to the element when it changes. It does not reflect from the
   * corresponding attribute.
   *
   * Properties declared this way must not be used from HTML or HTML templating
   * systems, they're solely for properties internal to the element. These
   * properties may be renamed by optimization tools like closure compiler.
   * @category Decorator
   */
  function state(options) {
      return property({
          ...options,
          // Add both `state` and `attribute` because we found a third party
          // controller that is keying off of PropertyOptions.state to determine
          // whether a field is a private internal property or not.
          state: true,
          attribute: false,
      });
  }

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  /**
   * Wraps up a few best practices when returning a property descriptor from a
   * decorator.
   *
   * Marks the defined property as configurable, and enumerable, and handles
   * the case where we have a busted Reflect.decorate zombiefill (e.g. in Angular
   * apps).
   *
   * @internal
   */
  const desc = (obj, name, descriptor) => {
      // For backwards compatibility, we keep them configurable and enumerable.
      descriptor.configurable = true;
      descriptor.enumerable = true;
      if (
      // We check for Reflect.decorate each time, in case the zombiefill
      // is applied via lazy loading some Angular code.
      Reflect.decorate &&
          typeof name !== 'object') {
          // If we're called as a legacy decorator, and Reflect.decorate is present
          // then we have no guarantees that the returned descriptor will be
          // defined on the class, so we must apply it directly ourselves.
          Object.defineProperty(obj, name, descriptor);
      }
      return descriptor;
  };

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  let issueWarning;
  {
      // Ensure warnings are issued only 1x, even if multiple versions of Lit
      // are loaded.
      const issuedWarnings = (globalThis.litIssuedWarnings ??= new Set());
      // Issue a warning, if we haven't already.
      issueWarning = (code, warning) => {
          warning += code
              ? ` See https://lit.dev/msg/${code} for more information.`
              : '';
          if (!issuedWarnings.has(warning)) {
              console.warn(warning);
              issuedWarnings.add(warning);
          }
      };
  }
  /**
   * A property decorator that converts a class property into a getter that
   * executes a querySelector on the element's renderRoot.
   *
   * @param selector A DOMString containing one or more selectors to match.
   * @param cache An optional boolean which when true performs the DOM query only
   *     once and caches the result.
   *
   * See: https://developer.mozilla.org/en-US/docs/Web/API/Document/querySelector
   *
   * ```ts
   * class MyElement {
   *   @query('#first')
   *   first: HTMLDivElement;
   *
   *   render() {
   *     return html`
   *       <div id="first"></div>
   *       <div id="second"></div>
   *     `;
   *   }
   * }
   * ```
   * @category Decorator
   */
  function query(selector, cache) {
      return ((protoOrTarget, nameOrContext, descriptor) => {
          const doQuery = (el) => {
              const result = (el.renderRoot?.querySelector(selector) ?? null);
              if (result === null && cache && !el.hasUpdated) {
                  const name = typeof nameOrContext === 'object'
                      ? nameOrContext.name
                      : nameOrContext;
                  issueWarning('', `@query'd field ${JSON.stringify(String(name))} with the 'cache' ` +
                      `flag set for selector '${selector}' has been accessed before ` +
                      `the first update and returned null. This is expected if the ` +
                      `renderRoot tree has not been provided beforehand (e.g. via ` +
                      `Declarative Shadow DOM). Therefore the value hasn't been cached.`);
              }
              // TODO: if we want to allow users to assert that the query will never
              // return null, we need a new option and to throw here if the result
              // is null.
              return result;
          };
          if (cache) {
              // Accessors to wrap from either:
              //   1. The decorator target, in the case of standard decorators
              //   2. The property descriptor, in the case of experimental decorators
              //      on auto-accessors.
              //   3. Functions that access our own cache-key property on the instance,
              //      in the case of experimental decorators on fields.
              const { get, set } = typeof nameOrContext === 'object'
                  ? protoOrTarget
                  : descriptor ??
                      (() => {
                          const key = Symbol(`${String(nameOrContext)} (@query() cache)`)
                              ;
                          return {
                              get() {
                                  return this[key];
                              },
                              set(v) {
                                  this[key] = v;
                              },
                          };
                      })();
              return desc(protoOrTarget, nameOrContext, {
                  get() {
                      let result = get.call(this);
                      if (result === undefined) {
                          result = doQuery(this);
                          if (result !== null || this.hasUpdated) {
                              set.call(this, result);
                          }
                      }
                      return result;
                  },
              });
          }
          else {
              // This object works as the return type for both standard and
              // experimental decorators.
              return desc(protoOrTarget, nameOrContext, {
                  get() {
                      return doQuery(this);
                  },
              });
          }
      });
  }

  /**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  /**
   * A property decorator that converts a class property into a getter that
   * returns the `assignedElements` of the given `slot`. Provides a declarative
   * way to use
   * [`HTMLSlotElement.assignedElements`](https://developer.mozilla.org/en-US/docs/Web/API/HTMLSlotElement/assignedElements).
   *
   * Can be passed an optional {@linkcode QueryAssignedElementsOptions} object.
   *
   * Example usage:
   * ```ts
   * class MyElement {
   *   @queryAssignedElements({ slot: 'list' })
   *   listItems!: Array<HTMLElement>;
   *   @queryAssignedElements()
   *   unnamedSlotEls!: Array<HTMLElement>;
   *
   *   render() {
   *     return html`
   *       <slot name="list"></slot>
   *       <slot></slot>
   *     `;
   *   }
   * }
   * ```
   *
   * Note, the type of this property should be annotated as `Array<HTMLElement>`.
   *
   * @category Decorator
   */
  function queryAssignedElements(options) {
      return ((obj, name) => {
          const { slot, selector } = options ?? {};
          const slotSelector = `slot${slot ? `[name=${slot}]` : ':not([name])'}`;
          return desc(obj, name, {
              get() {
                  const slotEl = this.renderRoot?.querySelector(slotSelector);
                  const elements = slotEl?.assignedElements(options) ?? [];
                  return (selector === undefined
                      ? elements
                      : elements.filter((node) => node.matches(selector)));
              },
          });
      });
  }

  /**
   * @license
   * Copyright 2020 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  window.ShadyDOM?.inUse &&
      window.ShadyDOM?.noPatch === true
      ? window.ShadyDOM.wrap
      : (node) => node;
  /**
   * Tests whether a part has only a single-expression with no strings to
   * interpolate between.
   *
   * Only AttributePart and PropertyPart can have multiple expressions.
   * Multi-expression parts have a `strings` property and single-expression
   * parts do not.
   */
  const isSingleExpression = (part) => part.strings === undefined;

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  const PartType = {
      ATTRIBUTE: 1,
      CHILD: 2,
      PROPERTY: 3,
      BOOLEAN_ATTRIBUTE: 4,
      EVENT: 5,
      ELEMENT: 6,
  };
  /**
   * Creates a user-facing directive function from a Directive class. This
   * function has the same parameters as the directive's render() method.
   */
  const directive = (c) => (...values) => ({
      // This property needs to remain unminified.
      ['_$litDirective$']: c,
      values,
  });
  /**
   * Base class for creating custom directives. Users should extend this class,
   * implement `render` and/or `update`, and then pass their subclass to
   * `directive`.
   */
  class Directive {
      constructor(_partInfo) { }
      // See comment in Disconnectable interface for why this is a getter
      get _$isConnected() {
          return this._$parent._$isConnected;
      }
      /** @internal */
      _$initialize(part, parent, attributeIndex) {
          this.__part = part;
          this._$parent = parent;
          this.__attributeIndex = attributeIndex;
      }
      /** @internal */
      _$resolve(part, props) {
          return this.update(part, props);
      }
      update(_part, props) {
          return this.render(...props);
      }
  }

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  /**
   * Recursively walks down the tree of Parts/TemplateInstances/Directives to set
   * the connected state of directives and run `disconnected`/ `reconnected`
   * callbacks.
   *
   * @return True if there were children to disconnect; false otherwise
   */
  const notifyChildrenConnectedChanged = (parent, isConnected) => {
      const children = parent._$disconnectableChildren;
      if (children === undefined) {
          return false;
      }
      for (const obj of children) {
          // The existence of `_$notifyDirectiveConnectionChanged` is used as a "brand" to
          // disambiguate AsyncDirectives from other DisconnectableChildren
          // (as opposed to using an instanceof check to know when to call it); the
          // redundancy of "Directive" in the API name is to avoid conflicting with
          // `_$notifyConnectionChanged`, which exists `ChildParts` which are also in
          // this list
          // Disconnect Directive (and any nested directives contained within)
          // This property needs to remain unminified.
          obj['_$notifyDirectiveConnectionChanged']?.(isConnected, false);
          // Disconnect Part/TemplateInstance
          notifyChildrenConnectedChanged(obj, isConnected);
      }
      return true;
  };
  /**
   * Removes the given child from its parent list of disconnectable children, and
   * if the parent list becomes empty as a result, removes the parent from its
   * parent, and so forth up the tree when that causes subsequent parent lists to
   * become empty.
   */
  const removeDisconnectableFromParent = (obj) => {
      let parent, children;
      do {
          if ((parent = obj._$parent) === undefined) {
              break;
          }
          children = parent._$disconnectableChildren;
          children.delete(obj);
          obj = parent;
      } while (children?.size === 0);
  };
  const addDisconnectableToParent = (obj) => {
      // Climb the parent tree, creating a sparse tree of children needing
      // disconnection
      for (let parent; (parent = obj._$parent); obj = parent) {
          let children = parent._$disconnectableChildren;
          if (children === undefined) {
              parent._$disconnectableChildren = children = new Set();
          }
          else if (children.has(obj)) {
              // Once we've reached a parent that already contains this child, we
              // can short-circuit
              break;
          }
          children.add(obj);
          installDisconnectAPI(parent);
      }
  };
  /**
   * Changes the parent reference of the ChildPart, and updates the sparse tree of
   * Disconnectable children accordingly.
   *
   * Note, this method will be patched onto ChildPart instances and called from
   * the core code when parts are moved between different parents.
   */
  function reparentDisconnectables(newParent) {
      if (this._$disconnectableChildren !== undefined) {
          removeDisconnectableFromParent(this);
          this._$parent = newParent;
          addDisconnectableToParent(this);
      }
      else {
          this._$parent = newParent;
      }
  }
  /**
   * Sets the connected state on any directives contained within the committed
   * value of this part (i.e. within a TemplateInstance or iterable of
   * ChildParts) and runs their `disconnected`/`reconnected`s, as well as within
   * any directives stored on the ChildPart (when `valueOnly` is false).
   *
   * `isClearingValue` should be passed as `true` on a top-level part that is
   * clearing itself, and not as a result of recursively disconnecting directives
   * as part of a `clear` operation higher up the tree. This both ensures that any
   * directive on this ChildPart that produced a value that caused the clear
   * operation is not disconnected, and also serves as a performance optimization
   * to avoid needless bookkeeping when a subtree is going away; when clearing a
   * subtree, only the top-most part need to remove itself from the parent.
   *
   * `fromPartIndex` is passed only in the case of a partial `_clear` running as a
   * result of truncating an iterable.
   *
   * Note, this method will be patched onto ChildPart instances and called from the
   * core code when parts are cleared or the connection state is changed by the
   * user.
   */
  function notifyChildPartConnectedChanged(isConnected, isClearingValue = false, fromPartIndex = 0) {
      const value = this._$committedValue;
      const children = this._$disconnectableChildren;
      if (children === undefined || children.size === 0) {
          return;
      }
      if (isClearingValue) {
          if (Array.isArray(value)) {
              // Iterable case: Any ChildParts created by the iterable should be
              // disconnected and removed from this ChildPart's disconnectable
              // children (starting at `fromPartIndex` in the case of truncation)
              for (let i = fromPartIndex; i < value.length; i++) {
                  notifyChildrenConnectedChanged(value[i], false);
                  removeDisconnectableFromParent(value[i]);
              }
          }
          else if (value != null) {
              // TemplateInstance case: If the value has disconnectable children (will
              // only be in the case that it is a TemplateInstance), we disconnect it
              // and remove it from this ChildPart's disconnectable children
              notifyChildrenConnectedChanged(value, false);
              removeDisconnectableFromParent(value);
          }
      }
      else {
          notifyChildrenConnectedChanged(this, isConnected);
      }
  }
  /**
   * Patches disconnection API onto ChildParts.
   */
  const installDisconnectAPI = (obj) => {
      if (obj.type == PartType.CHILD) {
          obj._$notifyConnectionChanged ??=
              notifyChildPartConnectedChanged;
          obj._$reparentDisconnectables ??= reparentDisconnectables;
      }
  };
  /**
   * An abstract `Directive` base class whose `disconnected` method will be
   * called when the part containing the directive is cleared as a result of
   * re-rendering, or when the user calls `part.setConnected(false)` on
   * a part that was previously rendered containing the directive (as happens
   * when e.g. a LitElement disconnects from the DOM).
   *
   * If `part.setConnected(true)` is subsequently called on a
   * containing part, the directive's `reconnected` method will be called prior
   * to its next `update`/`render` callbacks. When implementing `disconnected`,
   * `reconnected` should also be implemented to be compatible with reconnection.
   *
   * Note that updates may occur while the directive is disconnected. As such,
   * directives should generally check the `this.isConnected` flag during
   * render/update to determine whether it is safe to subscribe to resources
   * that may prevent garbage collection.
   */
  class AsyncDirective extends Directive {
      constructor() {
          super(...arguments);
          // @internal
          this._$disconnectableChildren = undefined;
      }
      /**
       * Initialize the part with internal fields
       * @param part
       * @param parent
       * @param attributeIndex
       */
      _$initialize(part, parent, attributeIndex) {
          super._$initialize(part, parent, attributeIndex);
          addDisconnectableToParent(this);
          this.isConnected = part._$isConnected;
      }
      // This property needs to remain unminified.
      /**
       * Called from the core code when a directive is going away from a part (in
       * which case `shouldRemoveFromParent` should be true), and from the
       * `setChildrenConnected` helper function when recursively changing the
       * connection state of a tree (in which case `shouldRemoveFromParent` should
       * be false).
       *
       * @param isConnected
       * @param isClearingDirective - True when the directive itself is being
       *     removed; false when the tree is being disconnected
       * @internal
       */
      ['_$notifyDirectiveConnectionChanged'](isConnected, isClearingDirective = true) {
          if (isConnected !== this.isConnected) {
              this.isConnected = isConnected;
              if (isConnected) {
                  this.reconnected?.();
              }
              else {
                  this.disconnected?.();
              }
          }
          if (isClearingDirective) {
              notifyChildrenConnectedChanged(this, isConnected);
              removeDisconnectableFromParent(this);
          }
      }
      /**
       * Sets the value of the directive's Part outside the normal `update`/`render`
       * lifecycle of a directive.
       *
       * This method should not be called synchronously from a directive's `update`
       * or `render`.
       *
       * @param directive The directive to update
       * @param value The value to set
       */
      setValue(value) {
          if (isSingleExpression(this.__part)) {
              this.__part._$setValue(value, this);
          }
          else {
              // this.__attributeIndex will be defined in this case, but
              // assert it in dev mode
              if (this.__attributeIndex === undefined) {
                  throw new Error(`Expected this.__attributeIndex to be a number`);
              }
              const newValues = [...this.__part._$committedValue];
              newValues[this.__attributeIndex] = value;
              this.__part._$setValue(newValues, this, 0);
          }
      }
      /**
       * User callbacks for implementing logic to release any resources/subscriptions
       * that may have been retained by this directive. Since directives may also be
       * re-connected, `reconnected` should also be implemented to restore the
       * working state of the directive prior to the next render.
       */
      disconnected() { }
      reconnected() { }
  }

  /**
   * @license
   * Copyright 2020 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  /**
   * Creates a new Ref object, which is container for a reference to an element.
   */
  const createRef = () => new Ref();
  /**
   * An object that holds a ref value.
   */
  class Ref {
  }
  // When callbacks are used for refs, this map tracks the last value the callback
  // was called with, for ensuring a directive doesn't clear the ref if the ref
  // has already been rendered to a new spot. It is double-keyed on both the
  // context (`options.host`) and the callback, since we auto-bind class methods
  // to `options.host`.
  const lastElementForContextAndCallback = new WeakMap();
  class RefDirective extends AsyncDirective {
      render(_ref) {
          return nothing;
      }
      update(part, [ref]) {
          const refChanged = ref !== this._ref;
          if (refChanged && this._ref !== undefined) {
              // The ref passed to the directive has changed;
              // unset the previous ref's value
              this._updateRefValue(undefined);
          }
          if (refChanged || this._lastElementForRef !== this._element) {
              // We either got a new ref or this is the first render;
              // store the ref/element & update the ref value
              this._ref = ref;
              this._context = part.options?.host;
              this._updateRefValue((this._element = part.element));
          }
          return nothing;
      }
      _updateRefValue(element) {
          if (!this.isConnected) {
              element = undefined;
          }
          if (typeof this._ref === 'function') {
              // If the current ref was called with a previous value, call with
              // `undefined`; We do this to ensure callbacks are called in a consistent
              // way regardless of whether a ref might be moving up in the tree (in
              // which case it would otherwise be called with the new value before the
              // previous one unsets it) and down in the tree (where it would be unset
              // before being set). Note that element lookup is keyed by
              // both the context and the callback, since we allow passing unbound
              // functions that are called on options.host, and we want to treat
              // these as unique "instances" of a function.
              const context = this._context ?? globalThis;
              let lastElementForCallback = lastElementForContextAndCallback.get(context);
              if (lastElementForCallback === undefined) {
                  lastElementForCallback = new WeakMap();
                  lastElementForContextAndCallback.set(context, lastElementForCallback);
              }
              if (lastElementForCallback.get(this._ref) !== undefined) {
                  this._ref.call(this._context, undefined);
              }
              lastElementForCallback.set(this._ref, element);
              // Call the ref with the new element value
              if (element !== undefined) {
                  this._ref.call(this._context, element);
              }
          }
          else {
              this._ref.value = element;
          }
      }
      get _lastElementForRef() {
          return typeof this._ref === 'function'
              ? lastElementForContextAndCallback
                  .get(this._context ?? globalThis)
                  ?.get(this._ref)
              : this._ref?.value;
      }
      disconnected() {
          // Only clear the box if our element is still the one in it (i.e. another
          // directive instance hasn't rendered its element to it before us); that
          // only happens in the event of the directive being cleared (not via manual
          // disconnection)
          if (this._lastElementForRef === this._element) {
              this._updateRefValue(undefined);
          }
      }
      reconnected() {
          // If we were manually disconnected, we can safely put our element back in
          // the box, since no rendering could have occurred to change its state
          this._updateRefValue(this._element);
      }
  }
  /**
   * Sets the value of a Ref object or calls a ref callback with the element it's
   * bound to.
   *
   * A Ref object acts as a container for a reference to an element. A ref
   * callback is a function that takes an element as its only argument.
   *
   * The ref directive sets the value of the Ref object or calls the ref callback
   * during rendering, if the referenced element changed.
   *
   * Note: If a ref callback is rendered to a different element position or is
   * removed in a subsequent render, it will first be called with `undefined`,
   * followed by another call with the new element it was rendered to (if any).
   *
   * ```js
   * // Using Ref object
   * const inputRef = createRef();
   * render(html`<input ${ref(inputRef)}>`, container);
   * inputRef.value.focus();
   *
   * // Using callback
   * const callback = (inputElement) => inputElement.focus();
   * render(html`<input ${ref(callback)}>`, container);
   * ```
   */
  const ref = directive(RefDirective);

  var top = 'top';
  var bottom = 'bottom';
  var right = 'right';
  var left = 'left';
  var auto = 'auto';
  var basePlacements = [top, bottom, right, left];
  var start = 'start';
  var end = 'end';
  var clippingParents = 'clippingParents';
  var viewport = 'viewport';
  var popper = 'popper';
  var reference = 'reference';
  var variationPlacements = /*#__PURE__*/basePlacements.reduce(function (acc, placement) {
    return acc.concat([placement + "-" + start, placement + "-" + end]);
  }, []);
  var placements = /*#__PURE__*/[].concat(basePlacements, [auto]).reduce(function (acc, placement) {
    return acc.concat([placement, placement + "-" + start, placement + "-" + end]);
  }, []); // modifiers that need to read the DOM

  var beforeRead = 'beforeRead';
  var read = 'read';
  var afterRead = 'afterRead'; // pure-logic modifiers

  var beforeMain = 'beforeMain';
  var main = 'main';
  var afterMain = 'afterMain'; // modifier with the purpose to write to the DOM (or write into a framework state)

  var beforeWrite = 'beforeWrite';
  var write = 'write';
  var afterWrite = 'afterWrite';
  var modifierPhases = [beforeRead, read, afterRead, beforeMain, main, afterMain, beforeWrite, write, afterWrite];

  function getNodeName(element) {
    return element ? (element.nodeName || '').toLowerCase() : null;
  }

  function getWindow(node) {
    if (node == null) {
      return window;
    }

    if (node.toString() !== '[object Window]') {
      var ownerDocument = node.ownerDocument;
      return ownerDocument ? ownerDocument.defaultView || window : window;
    }

    return node;
  }

  function isElement$1(node) {
    var OwnElement = getWindow(node).Element;
    return node instanceof OwnElement || node instanceof Element;
  }

  function isHTMLElement(node) {
    var OwnElement = getWindow(node).HTMLElement;
    return node instanceof OwnElement || node instanceof HTMLElement;
  }

  function isShadowRoot(node) {
    // IE 11 has no ShadowRoot
    if (typeof ShadowRoot === 'undefined') {
      return false;
    }

    var OwnElement = getWindow(node).ShadowRoot;
    return node instanceof OwnElement || node instanceof ShadowRoot;
  }

  // and applies them to the HTMLElements such as popper and arrow

  function applyStyles(_ref) {
    var state = _ref.state;
    Object.keys(state.elements).forEach(function (name) {
      var style = state.styles[name] || {};
      var attributes = state.attributes[name] || {};
      var element = state.elements[name]; // arrow is optional + virtual elements

      if (!isHTMLElement(element) || !getNodeName(element)) {
        return;
      } // Flow doesn't support to extend this property, but it's the most
      // effective way to apply styles to an HTMLElement
      // $FlowFixMe[cannot-write]


      Object.assign(element.style, style);
      Object.keys(attributes).forEach(function (name) {
        var value = attributes[name];

        if (value === false) {
          element.removeAttribute(name);
        } else {
          element.setAttribute(name, value === true ? '' : value);
        }
      });
    });
  }

  function effect$2(_ref2) {
    var state = _ref2.state;
    var initialStyles = {
      popper: {
        position: state.options.strategy,
        left: '0',
        top: '0',
        margin: '0'
      },
      arrow: {
        position: 'absolute'
      },
      reference: {}
    };
    Object.assign(state.elements.popper.style, initialStyles.popper);
    state.styles = initialStyles;

    if (state.elements.arrow) {
      Object.assign(state.elements.arrow.style, initialStyles.arrow);
    }

    return function () {
      Object.keys(state.elements).forEach(function (name) {
        var element = state.elements[name];
        var attributes = state.attributes[name] || {};
        var styleProperties = Object.keys(state.styles.hasOwnProperty(name) ? state.styles[name] : initialStyles[name]); // Set all values to an empty string to unset them

        var style = styleProperties.reduce(function (style, property) {
          style[property] = '';
          return style;
        }, {}); // arrow is optional + virtual elements

        if (!isHTMLElement(element) || !getNodeName(element)) {
          return;
        }

        Object.assign(element.style, style);
        Object.keys(attributes).forEach(function (attribute) {
          element.removeAttribute(attribute);
        });
      });
    };
  } // eslint-disable-next-line import/no-unused-modules


  var applyStyles$1 = {
    name: 'applyStyles',
    enabled: true,
    phase: 'write',
    fn: applyStyles,
    effect: effect$2,
    requires: ['computeStyles']
  };

  function getBasePlacement(placement) {
    return placement.split('-')[0];
  }

  var max = Math.max;
  var min = Math.min;
  var round = Math.round;

  function getUAString() {
    var uaData = navigator.userAgentData;

    if (uaData != null && uaData.brands && Array.isArray(uaData.brands)) {
      return uaData.brands.map(function (item) {
        return item.brand + "/" + item.version;
      }).join(' ');
    }

    return navigator.userAgent;
  }

  function isLayoutViewport() {
    return !/^((?!chrome|android).)*safari/i.test(getUAString());
  }

  function getBoundingClientRect(element, includeScale, isFixedStrategy) {
    if (includeScale === void 0) {
      includeScale = false;
    }

    if (isFixedStrategy === void 0) {
      isFixedStrategy = false;
    }

    var clientRect = element.getBoundingClientRect();
    var scaleX = 1;
    var scaleY = 1;

    if (includeScale && isHTMLElement(element)) {
      scaleX = element.offsetWidth > 0 ? round(clientRect.width) / element.offsetWidth || 1 : 1;
      scaleY = element.offsetHeight > 0 ? round(clientRect.height) / element.offsetHeight || 1 : 1;
    }

    var _ref = isElement$1(element) ? getWindow(element) : window,
        visualViewport = _ref.visualViewport;

    var addVisualOffsets = !isLayoutViewport() && isFixedStrategy;
    var x = (clientRect.left + (addVisualOffsets && visualViewport ? visualViewport.offsetLeft : 0)) / scaleX;
    var y = (clientRect.top + (addVisualOffsets && visualViewport ? visualViewport.offsetTop : 0)) / scaleY;
    var width = clientRect.width / scaleX;
    var height = clientRect.height / scaleY;
    return {
      width: width,
      height: height,
      top: y,
      right: x + width,
      bottom: y + height,
      left: x,
      x: x,
      y: y
    };
  }

  // means it doesn't take into account transforms.

  function getLayoutRect(element) {
    var clientRect = getBoundingClientRect(element); // Use the clientRect sizes if it's not been transformed.
    // Fixes https://github.com/popperjs/popper-core/issues/1223

    var width = element.offsetWidth;
    var height = element.offsetHeight;

    if (Math.abs(clientRect.width - width) <= 1) {
      width = clientRect.width;
    }

    if (Math.abs(clientRect.height - height) <= 1) {
      height = clientRect.height;
    }

    return {
      x: element.offsetLeft,
      y: element.offsetTop,
      width: width,
      height: height
    };
  }

  function contains(parent, child) {
    var rootNode = child.getRootNode && child.getRootNode(); // First, attempt with faster native method

    if (parent.contains(child)) {
      return true;
    } // then fallback to custom implementation with Shadow DOM support
    else if (rootNode && isShadowRoot(rootNode)) {
        var next = child;

        do {
          if (next && parent.isSameNode(next)) {
            return true;
          } // $FlowFixMe[prop-missing]: need a better way to handle this...


          next = next.parentNode || next.host;
        } while (next);
      } // Give up, the result is false


    return false;
  }

  function getComputedStyle$1(element) {
    return getWindow(element).getComputedStyle(element);
  }

  function isTableElement(element) {
    return ['table', 'td', 'th'].indexOf(getNodeName(element)) >= 0;
  }

  function getDocumentElement(element) {
    // $FlowFixMe[incompatible-return]: assume body is always available
    return ((isElement$1(element) ? element.ownerDocument : // $FlowFixMe[prop-missing]
    element.document) || window.document).documentElement;
  }

  function getParentNode(element) {
    if (getNodeName(element) === 'html') {
      return element;
    }

    return (// this is a quicker (but less type safe) way to save quite some bytes from the bundle
      // $FlowFixMe[incompatible-return]
      // $FlowFixMe[prop-missing]
      element.assignedSlot || // step into the shadow DOM of the parent of a slotted node
      element.parentNode || ( // DOM Element detected
      isShadowRoot(element) ? element.host : null) || // ShadowRoot detected
      // $FlowFixMe[incompatible-call]: HTMLElement is a Node
      getDocumentElement(element) // fallback

    );
  }

  function getTrueOffsetParent(element) {
    if (!isHTMLElement(element) || // https://github.com/popperjs/popper-core/issues/837
    getComputedStyle$1(element).position === 'fixed') {
      return null;
    }

    return element.offsetParent;
  } // `.offsetParent` reports `null` for fixed elements, while absolute elements
  // return the containing block


  function getContainingBlock(element) {
    var isFirefox = /firefox/i.test(getUAString());
    var isIE = /Trident/i.test(getUAString());

    if (isIE && isHTMLElement(element)) {
      // In IE 9, 10 and 11 fixed elements containing block is always established by the viewport
      var elementCss = getComputedStyle$1(element);

      if (elementCss.position === 'fixed') {
        return null;
      }
    }

    var currentNode = getParentNode(element);

    if (isShadowRoot(currentNode)) {
      currentNode = currentNode.host;
    }

    while (isHTMLElement(currentNode) && ['html', 'body'].indexOf(getNodeName(currentNode)) < 0) {
      var css = getComputedStyle$1(currentNode); // This is non-exhaustive but covers the most common CSS properties that
      // create a containing block.
      // https://developer.mozilla.org/en-US/docs/Web/CSS/Containing_block#identifying_the_containing_block

      if (css.transform !== 'none' || css.perspective !== 'none' || css.contain === 'paint' || ['transform', 'perspective'].indexOf(css.willChange) !== -1 || isFirefox && css.willChange === 'filter' || isFirefox && css.filter && css.filter !== 'none') {
        return currentNode;
      } else {
        currentNode = currentNode.parentNode;
      }
    }

    return null;
  } // Gets the closest ancestor positioned element. Handles some edge cases,
  // such as table ancestors and cross browser bugs.


  function getOffsetParent(element) {
    var window = getWindow(element);
    var offsetParent = getTrueOffsetParent(element);

    while (offsetParent && isTableElement(offsetParent) && getComputedStyle$1(offsetParent).position === 'static') {
      offsetParent = getTrueOffsetParent(offsetParent);
    }

    if (offsetParent && (getNodeName(offsetParent) === 'html' || getNodeName(offsetParent) === 'body' && getComputedStyle$1(offsetParent).position === 'static')) {
      return window;
    }

    return offsetParent || getContainingBlock(element) || window;
  }

  function getMainAxisFromPlacement(placement) {
    return ['top', 'bottom'].indexOf(placement) >= 0 ? 'x' : 'y';
  }

  function within(min$1, value, max$1) {
    return max(min$1, min(value, max$1));
  }
  function withinMaxClamp(min, value, max) {
    var v = within(min, value, max);
    return v > max ? max : v;
  }

  function getFreshSideObject() {
    return {
      top: 0,
      right: 0,
      bottom: 0,
      left: 0
    };
  }

  function mergePaddingObject(paddingObject) {
    return Object.assign({}, getFreshSideObject(), paddingObject);
  }

  function expandToHashMap(value, keys) {
    return keys.reduce(function (hashMap, key) {
      hashMap[key] = value;
      return hashMap;
    }, {});
  }

  var toPaddingObject = function toPaddingObject(padding, state) {
    padding = typeof padding === 'function' ? padding(Object.assign({}, state.rects, {
      placement: state.placement
    })) : padding;
    return mergePaddingObject(typeof padding !== 'number' ? padding : expandToHashMap(padding, basePlacements));
  };

  function arrow(_ref) {
    var _state$modifiersData$;

    var state = _ref.state,
        name = _ref.name,
        options = _ref.options;
    var arrowElement = state.elements.arrow;
    var popperOffsets = state.modifiersData.popperOffsets;
    var basePlacement = getBasePlacement(state.placement);
    var axis = getMainAxisFromPlacement(basePlacement);
    var isVertical = [left, right].indexOf(basePlacement) >= 0;
    var len = isVertical ? 'height' : 'width';

    if (!arrowElement || !popperOffsets) {
      return;
    }

    var paddingObject = toPaddingObject(options.padding, state);
    var arrowRect = getLayoutRect(arrowElement);
    var minProp = axis === 'y' ? top : left;
    var maxProp = axis === 'y' ? bottom : right;
    var endDiff = state.rects.reference[len] + state.rects.reference[axis] - popperOffsets[axis] - state.rects.popper[len];
    var startDiff = popperOffsets[axis] - state.rects.reference[axis];
    var arrowOffsetParent = getOffsetParent(arrowElement);
    var clientSize = arrowOffsetParent ? axis === 'y' ? arrowOffsetParent.clientHeight || 0 : arrowOffsetParent.clientWidth || 0 : 0;
    var centerToReference = endDiff / 2 - startDiff / 2; // Make sure the arrow doesn't overflow the popper if the center point is
    // outside of the popper bounds

    var min = paddingObject[minProp];
    var max = clientSize - arrowRect[len] - paddingObject[maxProp];
    var center = clientSize / 2 - arrowRect[len] / 2 + centerToReference;
    var offset = within(min, center, max); // Prevents breaking syntax highlighting...

    var axisProp = axis;
    state.modifiersData[name] = (_state$modifiersData$ = {}, _state$modifiersData$[axisProp] = offset, _state$modifiersData$.centerOffset = offset - center, _state$modifiersData$);
  }

  function effect$1(_ref2) {
    var state = _ref2.state,
        options = _ref2.options;
    var _options$element = options.element,
        arrowElement = _options$element === void 0 ? '[data-popper-arrow]' : _options$element;

    if (arrowElement == null) {
      return;
    } // CSS selector


    if (typeof arrowElement === 'string') {
      arrowElement = state.elements.popper.querySelector(arrowElement);

      if (!arrowElement) {
        return;
      }
    }

    if (!contains(state.elements.popper, arrowElement)) {
      return;
    }

    state.elements.arrow = arrowElement;
  } // eslint-disable-next-line import/no-unused-modules


  var arrow$1 = {
    name: 'arrow',
    enabled: true,
    phase: 'main',
    fn: arrow,
    effect: effect$1,
    requires: ['popperOffsets'],
    requiresIfExists: ['preventOverflow']
  };

  function getVariation(placement) {
    return placement.split('-')[1];
  }

  var unsetSides = {
    top: 'auto',
    right: 'auto',
    bottom: 'auto',
    left: 'auto'
  }; // Round the offsets to the nearest suitable subpixel based on the DPR.
  // Zooming can change the DPR, but it seems to report a value that will
  // cleanly divide the values into the appropriate subpixels.

  function roundOffsetsByDPR(_ref, win) {
    var x = _ref.x,
        y = _ref.y;
    var dpr = win.devicePixelRatio || 1;
    return {
      x: round(x * dpr) / dpr || 0,
      y: round(y * dpr) / dpr || 0
    };
  }

  function mapToStyles(_ref2) {
    var _Object$assign2;

    var popper = _ref2.popper,
        popperRect = _ref2.popperRect,
        placement = _ref2.placement,
        variation = _ref2.variation,
        offsets = _ref2.offsets,
        position = _ref2.position,
        gpuAcceleration = _ref2.gpuAcceleration,
        adaptive = _ref2.adaptive,
        roundOffsets = _ref2.roundOffsets,
        isFixed = _ref2.isFixed;
    var _offsets$x = offsets.x,
        x = _offsets$x === void 0 ? 0 : _offsets$x,
        _offsets$y = offsets.y,
        y = _offsets$y === void 0 ? 0 : _offsets$y;

    var _ref3 = typeof roundOffsets === 'function' ? roundOffsets({
      x: x,
      y: y
    }) : {
      x: x,
      y: y
    };

    x = _ref3.x;
    y = _ref3.y;
    var hasX = offsets.hasOwnProperty('x');
    var hasY = offsets.hasOwnProperty('y');
    var sideX = left;
    var sideY = top;
    var win = window;

    if (adaptive) {
      var offsetParent = getOffsetParent(popper);
      var heightProp = 'clientHeight';
      var widthProp = 'clientWidth';

      if (offsetParent === getWindow(popper)) {
        offsetParent = getDocumentElement(popper);

        if (getComputedStyle$1(offsetParent).position !== 'static' && position === 'absolute') {
          heightProp = 'scrollHeight';
          widthProp = 'scrollWidth';
        }
      } // $FlowFixMe[incompatible-cast]: force type refinement, we compare offsetParent with window above, but Flow doesn't detect it


      offsetParent = offsetParent;

      if (placement === top || (placement === left || placement === right) && variation === end) {
        sideY = bottom;
        var offsetY = isFixed && offsetParent === win && win.visualViewport ? win.visualViewport.height : // $FlowFixMe[prop-missing]
        offsetParent[heightProp];
        y -= offsetY - popperRect.height;
        y *= gpuAcceleration ? 1 : -1;
      }

      if (placement === left || (placement === top || placement === bottom) && variation === end) {
        sideX = right;
        var offsetX = isFixed && offsetParent === win && win.visualViewport ? win.visualViewport.width : // $FlowFixMe[prop-missing]
        offsetParent[widthProp];
        x -= offsetX - popperRect.width;
        x *= gpuAcceleration ? 1 : -1;
      }
    }

    var commonStyles = Object.assign({
      position: position
    }, adaptive && unsetSides);

    var _ref4 = roundOffsets === true ? roundOffsetsByDPR({
      x: x,
      y: y
    }, getWindow(popper)) : {
      x: x,
      y: y
    };

    x = _ref4.x;
    y = _ref4.y;

    if (gpuAcceleration) {
      var _Object$assign;

      return Object.assign({}, commonStyles, (_Object$assign = {}, _Object$assign[sideY] = hasY ? '0' : '', _Object$assign[sideX] = hasX ? '0' : '', _Object$assign.transform = (win.devicePixelRatio || 1) <= 1 ? "translate(" + x + "px, " + y + "px)" : "translate3d(" + x + "px, " + y + "px, 0)", _Object$assign));
    }

    return Object.assign({}, commonStyles, (_Object$assign2 = {}, _Object$assign2[sideY] = hasY ? y + "px" : '', _Object$assign2[sideX] = hasX ? x + "px" : '', _Object$assign2.transform = '', _Object$assign2));
  }

  function computeStyles(_ref5) {
    var state = _ref5.state,
        options = _ref5.options;
    var _options$gpuAccelerat = options.gpuAcceleration,
        gpuAcceleration = _options$gpuAccelerat === void 0 ? true : _options$gpuAccelerat,
        _options$adaptive = options.adaptive,
        adaptive = _options$adaptive === void 0 ? true : _options$adaptive,
        _options$roundOffsets = options.roundOffsets,
        roundOffsets = _options$roundOffsets === void 0 ? true : _options$roundOffsets;
    var commonStyles = {
      placement: getBasePlacement(state.placement),
      variation: getVariation(state.placement),
      popper: state.elements.popper,
      popperRect: state.rects.popper,
      gpuAcceleration: gpuAcceleration,
      isFixed: state.options.strategy === 'fixed'
    };

    if (state.modifiersData.popperOffsets != null) {
      state.styles.popper = Object.assign({}, state.styles.popper, mapToStyles(Object.assign({}, commonStyles, {
        offsets: state.modifiersData.popperOffsets,
        position: state.options.strategy,
        adaptive: adaptive,
        roundOffsets: roundOffsets
      })));
    }

    if (state.modifiersData.arrow != null) {
      state.styles.arrow = Object.assign({}, state.styles.arrow, mapToStyles(Object.assign({}, commonStyles, {
        offsets: state.modifiersData.arrow,
        position: 'absolute',
        adaptive: false,
        roundOffsets: roundOffsets
      })));
    }

    state.attributes.popper = Object.assign({}, state.attributes.popper, {
      'data-popper-placement': state.placement
    });
  } // eslint-disable-next-line import/no-unused-modules


  var computeStyles$1 = {
    name: 'computeStyles',
    enabled: true,
    phase: 'beforeWrite',
    fn: computeStyles,
    data: {}
  };

  var passive = {
    passive: true
  };

  function effect(_ref) {
    var state = _ref.state,
        instance = _ref.instance,
        options = _ref.options;
    var _options$scroll = options.scroll,
        scroll = _options$scroll === void 0 ? true : _options$scroll,
        _options$resize = options.resize,
        resize = _options$resize === void 0 ? true : _options$resize;
    var window = getWindow(state.elements.popper);
    var scrollParents = [].concat(state.scrollParents.reference, state.scrollParents.popper);

    if (scroll) {
      scrollParents.forEach(function (scrollParent) {
        scrollParent.addEventListener('scroll', instance.update, passive);
      });
    }

    if (resize) {
      window.addEventListener('resize', instance.update, passive);
    }

    return function () {
      if (scroll) {
        scrollParents.forEach(function (scrollParent) {
          scrollParent.removeEventListener('scroll', instance.update, passive);
        });
      }

      if (resize) {
        window.removeEventListener('resize', instance.update, passive);
      }
    };
  } // eslint-disable-next-line import/no-unused-modules


  var eventListeners = {
    name: 'eventListeners',
    enabled: true,
    phase: 'write',
    fn: function fn() {},
    effect: effect,
    data: {}
  };

  var hash$1 = {
    left: 'right',
    right: 'left',
    bottom: 'top',
    top: 'bottom'
  };
  function getOppositePlacement(placement) {
    return placement.replace(/left|right|bottom|top/g, function (matched) {
      return hash$1[matched];
    });
  }

  var hash = {
    start: 'end',
    end: 'start'
  };
  function getOppositeVariationPlacement(placement) {
    return placement.replace(/start|end/g, function (matched) {
      return hash[matched];
    });
  }

  function getWindowScroll(node) {
    var win = getWindow(node);
    var scrollLeft = win.pageXOffset;
    var scrollTop = win.pageYOffset;
    return {
      scrollLeft: scrollLeft,
      scrollTop: scrollTop
    };
  }

  function getWindowScrollBarX(element) {
    // If <html> has a CSS width greater than the viewport, then this will be
    // incorrect for RTL.
    // Popper 1 is broken in this case and never had a bug report so let's assume
    // it's not an issue. I don't think anyone ever specifies width on <html>
    // anyway.
    // Browsers where the left scrollbar doesn't cause an issue report `0` for
    // this (e.g. Edge 2019, IE11, Safari)
    return getBoundingClientRect(getDocumentElement(element)).left + getWindowScroll(element).scrollLeft;
  }

  function getViewportRect(element, strategy) {
    var win = getWindow(element);
    var html = getDocumentElement(element);
    var visualViewport = win.visualViewport;
    var width = html.clientWidth;
    var height = html.clientHeight;
    var x = 0;
    var y = 0;

    if (visualViewport) {
      width = visualViewport.width;
      height = visualViewport.height;
      var layoutViewport = isLayoutViewport();

      if (layoutViewport || !layoutViewport && strategy === 'fixed') {
        x = visualViewport.offsetLeft;
        y = visualViewport.offsetTop;
      }
    }

    return {
      width: width,
      height: height,
      x: x + getWindowScrollBarX(element),
      y: y
    };
  }

  // of the `<html>` and `<body>` rect bounds if horizontally scrollable

  function getDocumentRect(element) {
    var _element$ownerDocumen;

    var html = getDocumentElement(element);
    var winScroll = getWindowScroll(element);
    var body = (_element$ownerDocumen = element.ownerDocument) == null ? void 0 : _element$ownerDocumen.body;
    var width = max(html.scrollWidth, html.clientWidth, body ? body.scrollWidth : 0, body ? body.clientWidth : 0);
    var height = max(html.scrollHeight, html.clientHeight, body ? body.scrollHeight : 0, body ? body.clientHeight : 0);
    var x = -winScroll.scrollLeft + getWindowScrollBarX(element);
    var y = -winScroll.scrollTop;

    if (getComputedStyle$1(body || html).direction === 'rtl') {
      x += max(html.clientWidth, body ? body.clientWidth : 0) - width;
    }

    return {
      width: width,
      height: height,
      x: x,
      y: y
    };
  }

  function isScrollParent(element) {
    // Firefox wants us to check `-x` and `-y` variations as well
    var _getComputedStyle = getComputedStyle$1(element),
        overflow = _getComputedStyle.overflow,
        overflowX = _getComputedStyle.overflowX,
        overflowY = _getComputedStyle.overflowY;

    return /auto|scroll|overlay|hidden/.test(overflow + overflowY + overflowX);
  }

  function getScrollParent(node) {
    if (['html', 'body', '#document'].indexOf(getNodeName(node)) >= 0) {
      // $FlowFixMe[incompatible-return]: assume body is always available
      return node.ownerDocument.body;
    }

    if (isHTMLElement(node) && isScrollParent(node)) {
      return node;
    }

    return getScrollParent(getParentNode(node));
  }

  /*
  given a DOM element, return the list of all scroll parents, up the list of ancesors
  until we get to the top window object. This list is what we attach scroll listeners
  to, because if any of these parent elements scroll, we'll need to re-calculate the
  reference element's position.
  */

  function listScrollParents(element, list) {
    var _element$ownerDocumen;

    if (list === void 0) {
      list = [];
    }

    var scrollParent = getScrollParent(element);
    var isBody = scrollParent === ((_element$ownerDocumen = element.ownerDocument) == null ? void 0 : _element$ownerDocumen.body);
    var win = getWindow(scrollParent);
    var target = isBody ? [win].concat(win.visualViewport || [], isScrollParent(scrollParent) ? scrollParent : []) : scrollParent;
    var updatedList = list.concat(target);
    return isBody ? updatedList : // $FlowFixMe[incompatible-call]: isBody tells us target will be an HTMLElement here
    updatedList.concat(listScrollParents(getParentNode(target)));
  }

  function rectToClientRect(rect) {
    return Object.assign({}, rect, {
      left: rect.x,
      top: rect.y,
      right: rect.x + rect.width,
      bottom: rect.y + rect.height
    });
  }

  function getInnerBoundingClientRect(element, strategy) {
    var rect = getBoundingClientRect(element, false, strategy === 'fixed');
    rect.top = rect.top + element.clientTop;
    rect.left = rect.left + element.clientLeft;
    rect.bottom = rect.top + element.clientHeight;
    rect.right = rect.left + element.clientWidth;
    rect.width = element.clientWidth;
    rect.height = element.clientHeight;
    rect.x = rect.left;
    rect.y = rect.top;
    return rect;
  }

  function getClientRectFromMixedType(element, clippingParent, strategy) {
    return clippingParent === viewport ? rectToClientRect(getViewportRect(element, strategy)) : isElement$1(clippingParent) ? getInnerBoundingClientRect(clippingParent, strategy) : rectToClientRect(getDocumentRect(getDocumentElement(element)));
  } // A "clipping parent" is an overflowable container with the characteristic of
  // clipping (or hiding) overflowing elements with a position different from
  // `initial`


  function getClippingParents(element) {
    var clippingParents = listScrollParents(getParentNode(element));
    var canEscapeClipping = ['absolute', 'fixed'].indexOf(getComputedStyle$1(element).position) >= 0;
    var clipperElement = canEscapeClipping && isHTMLElement(element) ? getOffsetParent(element) : element;

    if (!isElement$1(clipperElement)) {
      return [];
    } // $FlowFixMe[incompatible-return]: https://github.com/facebook/flow/issues/1414


    return clippingParents.filter(function (clippingParent) {
      return isElement$1(clippingParent) && contains(clippingParent, clipperElement) && getNodeName(clippingParent) !== 'body';
    });
  } // Gets the maximum area that the element is visible in due to any number of
  // clipping parents


  function getClippingRect(element, boundary, rootBoundary, strategy) {
    var mainClippingParents = boundary === 'clippingParents' ? getClippingParents(element) : [].concat(boundary);
    var clippingParents = [].concat(mainClippingParents, [rootBoundary]);
    var firstClippingParent = clippingParents[0];
    var clippingRect = clippingParents.reduce(function (accRect, clippingParent) {
      var rect = getClientRectFromMixedType(element, clippingParent, strategy);
      accRect.top = max(rect.top, accRect.top);
      accRect.right = min(rect.right, accRect.right);
      accRect.bottom = min(rect.bottom, accRect.bottom);
      accRect.left = max(rect.left, accRect.left);
      return accRect;
    }, getClientRectFromMixedType(element, firstClippingParent, strategy));
    clippingRect.width = clippingRect.right - clippingRect.left;
    clippingRect.height = clippingRect.bottom - clippingRect.top;
    clippingRect.x = clippingRect.left;
    clippingRect.y = clippingRect.top;
    return clippingRect;
  }

  function computeOffsets(_ref) {
    var reference = _ref.reference,
        element = _ref.element,
        placement = _ref.placement;
    var basePlacement = placement ? getBasePlacement(placement) : null;
    var variation = placement ? getVariation(placement) : null;
    var commonX = reference.x + reference.width / 2 - element.width / 2;
    var commonY = reference.y + reference.height / 2 - element.height / 2;
    var offsets;

    switch (basePlacement) {
      case top:
        offsets = {
          x: commonX,
          y: reference.y - element.height
        };
        break;

      case bottom:
        offsets = {
          x: commonX,
          y: reference.y + reference.height
        };
        break;

      case right:
        offsets = {
          x: reference.x + reference.width,
          y: commonY
        };
        break;

      case left:
        offsets = {
          x: reference.x - element.width,
          y: commonY
        };
        break;

      default:
        offsets = {
          x: reference.x,
          y: reference.y
        };
    }

    var mainAxis = basePlacement ? getMainAxisFromPlacement(basePlacement) : null;

    if (mainAxis != null) {
      var len = mainAxis === 'y' ? 'height' : 'width';

      switch (variation) {
        case start:
          offsets[mainAxis] = offsets[mainAxis] - (reference[len] / 2 - element[len] / 2);
          break;

        case end:
          offsets[mainAxis] = offsets[mainAxis] + (reference[len] / 2 - element[len] / 2);
          break;
      }
    }

    return offsets;
  }

  function detectOverflow(state, options) {
    if (options === void 0) {
      options = {};
    }

    var _options = options,
        _options$placement = _options.placement,
        placement = _options$placement === void 0 ? state.placement : _options$placement,
        _options$strategy = _options.strategy,
        strategy = _options$strategy === void 0 ? state.strategy : _options$strategy,
        _options$boundary = _options.boundary,
        boundary = _options$boundary === void 0 ? clippingParents : _options$boundary,
        _options$rootBoundary = _options.rootBoundary,
        rootBoundary = _options$rootBoundary === void 0 ? viewport : _options$rootBoundary,
        _options$elementConte = _options.elementContext,
        elementContext = _options$elementConte === void 0 ? popper : _options$elementConte,
        _options$altBoundary = _options.altBoundary,
        altBoundary = _options$altBoundary === void 0 ? false : _options$altBoundary,
        _options$padding = _options.padding,
        padding = _options$padding === void 0 ? 0 : _options$padding;
    var paddingObject = mergePaddingObject(typeof padding !== 'number' ? padding : expandToHashMap(padding, basePlacements));
    var altContext = elementContext === popper ? reference : popper;
    var popperRect = state.rects.popper;
    var element = state.elements[altBoundary ? altContext : elementContext];
    var clippingClientRect = getClippingRect(isElement$1(element) ? element : element.contextElement || getDocumentElement(state.elements.popper), boundary, rootBoundary, strategy);
    var referenceClientRect = getBoundingClientRect(state.elements.reference);
    var popperOffsets = computeOffsets({
      reference: referenceClientRect,
      element: popperRect,
      strategy: 'absolute',
      placement: placement
    });
    var popperClientRect = rectToClientRect(Object.assign({}, popperRect, popperOffsets));
    var elementClientRect = elementContext === popper ? popperClientRect : referenceClientRect; // positive = overflowing the clipping rect
    // 0 or negative = within the clipping rect

    var overflowOffsets = {
      top: clippingClientRect.top - elementClientRect.top + paddingObject.top,
      bottom: elementClientRect.bottom - clippingClientRect.bottom + paddingObject.bottom,
      left: clippingClientRect.left - elementClientRect.left + paddingObject.left,
      right: elementClientRect.right - clippingClientRect.right + paddingObject.right
    };
    var offsetData = state.modifiersData.offset; // Offsets can be applied only to the popper element

    if (elementContext === popper && offsetData) {
      var offset = offsetData[placement];
      Object.keys(overflowOffsets).forEach(function (key) {
        var multiply = [right, bottom].indexOf(key) >= 0 ? 1 : -1;
        var axis = [top, bottom].indexOf(key) >= 0 ? 'y' : 'x';
        overflowOffsets[key] += offset[axis] * multiply;
      });
    }

    return overflowOffsets;
  }

  function computeAutoPlacement(state, options) {
    if (options === void 0) {
      options = {};
    }

    var _options = options,
        placement = _options.placement,
        boundary = _options.boundary,
        rootBoundary = _options.rootBoundary,
        padding = _options.padding,
        flipVariations = _options.flipVariations,
        _options$allowedAutoP = _options.allowedAutoPlacements,
        allowedAutoPlacements = _options$allowedAutoP === void 0 ? placements : _options$allowedAutoP;
    var variation = getVariation(placement);
    var placements$1 = variation ? flipVariations ? variationPlacements : variationPlacements.filter(function (placement) {
      return getVariation(placement) === variation;
    }) : basePlacements;
    var allowedPlacements = placements$1.filter(function (placement) {
      return allowedAutoPlacements.indexOf(placement) >= 0;
    });

    if (allowedPlacements.length === 0) {
      allowedPlacements = placements$1;
    } // $FlowFixMe[incompatible-type]: Flow seems to have problems with two array unions...


    var overflows = allowedPlacements.reduce(function (acc, placement) {
      acc[placement] = detectOverflow(state, {
        placement: placement,
        boundary: boundary,
        rootBoundary: rootBoundary,
        padding: padding
      })[getBasePlacement(placement)];
      return acc;
    }, {});
    return Object.keys(overflows).sort(function (a, b) {
      return overflows[a] - overflows[b];
    });
  }

  function getExpandedFallbackPlacements(placement) {
    if (getBasePlacement(placement) === auto) {
      return [];
    }

    var oppositePlacement = getOppositePlacement(placement);
    return [getOppositeVariationPlacement(placement), oppositePlacement, getOppositeVariationPlacement(oppositePlacement)];
  }

  function flip(_ref) {
    var state = _ref.state,
        options = _ref.options,
        name = _ref.name;

    if (state.modifiersData[name]._skip) {
      return;
    }

    var _options$mainAxis = options.mainAxis,
        checkMainAxis = _options$mainAxis === void 0 ? true : _options$mainAxis,
        _options$altAxis = options.altAxis,
        checkAltAxis = _options$altAxis === void 0 ? true : _options$altAxis,
        specifiedFallbackPlacements = options.fallbackPlacements,
        padding = options.padding,
        boundary = options.boundary,
        rootBoundary = options.rootBoundary,
        altBoundary = options.altBoundary,
        _options$flipVariatio = options.flipVariations,
        flipVariations = _options$flipVariatio === void 0 ? true : _options$flipVariatio,
        allowedAutoPlacements = options.allowedAutoPlacements;
    var preferredPlacement = state.options.placement;
    var basePlacement = getBasePlacement(preferredPlacement);
    var isBasePlacement = basePlacement === preferredPlacement;
    var fallbackPlacements = specifiedFallbackPlacements || (isBasePlacement || !flipVariations ? [getOppositePlacement(preferredPlacement)] : getExpandedFallbackPlacements(preferredPlacement));
    var placements = [preferredPlacement].concat(fallbackPlacements).reduce(function (acc, placement) {
      return acc.concat(getBasePlacement(placement) === auto ? computeAutoPlacement(state, {
        placement: placement,
        boundary: boundary,
        rootBoundary: rootBoundary,
        padding: padding,
        flipVariations: flipVariations,
        allowedAutoPlacements: allowedAutoPlacements
      }) : placement);
    }, []);
    var referenceRect = state.rects.reference;
    var popperRect = state.rects.popper;
    var checksMap = new Map();
    var makeFallbackChecks = true;
    var firstFittingPlacement = placements[0];

    for (var i = 0; i < placements.length; i++) {
      var placement = placements[i];

      var _basePlacement = getBasePlacement(placement);

      var isStartVariation = getVariation(placement) === start;
      var isVertical = [top, bottom].indexOf(_basePlacement) >= 0;
      var len = isVertical ? 'width' : 'height';
      var overflow = detectOverflow(state, {
        placement: placement,
        boundary: boundary,
        rootBoundary: rootBoundary,
        altBoundary: altBoundary,
        padding: padding
      });
      var mainVariationSide = isVertical ? isStartVariation ? right : left : isStartVariation ? bottom : top;

      if (referenceRect[len] > popperRect[len]) {
        mainVariationSide = getOppositePlacement(mainVariationSide);
      }

      var altVariationSide = getOppositePlacement(mainVariationSide);
      var checks = [];

      if (checkMainAxis) {
        checks.push(overflow[_basePlacement] <= 0);
      }

      if (checkAltAxis) {
        checks.push(overflow[mainVariationSide] <= 0, overflow[altVariationSide] <= 0);
      }

      if (checks.every(function (check) {
        return check;
      })) {
        firstFittingPlacement = placement;
        makeFallbackChecks = false;
        break;
      }

      checksMap.set(placement, checks);
    }

    if (makeFallbackChecks) {
      // `2` may be desired in some cases – research later
      var numberOfChecks = flipVariations ? 3 : 1;

      var _loop = function _loop(_i) {
        var fittingPlacement = placements.find(function (placement) {
          var checks = checksMap.get(placement);

          if (checks) {
            return checks.slice(0, _i).every(function (check) {
              return check;
            });
          }
        });

        if (fittingPlacement) {
          firstFittingPlacement = fittingPlacement;
          return "break";
        }
      };

      for (var _i = numberOfChecks; _i > 0; _i--) {
        var _ret = _loop(_i);

        if (_ret === "break") break;
      }
    }

    if (state.placement !== firstFittingPlacement) {
      state.modifiersData[name]._skip = true;
      state.placement = firstFittingPlacement;
      state.reset = true;
    }
  } // eslint-disable-next-line import/no-unused-modules


  var flip$1 = {
    name: 'flip',
    enabled: true,
    phase: 'main',
    fn: flip,
    requiresIfExists: ['offset'],
    data: {
      _skip: false
    }
  };

  function getSideOffsets(overflow, rect, preventedOffsets) {
    if (preventedOffsets === void 0) {
      preventedOffsets = {
        x: 0,
        y: 0
      };
    }

    return {
      top: overflow.top - rect.height - preventedOffsets.y,
      right: overflow.right - rect.width + preventedOffsets.x,
      bottom: overflow.bottom - rect.height + preventedOffsets.y,
      left: overflow.left - rect.width - preventedOffsets.x
    };
  }

  function isAnySideFullyClipped(overflow) {
    return [top, right, bottom, left].some(function (side) {
      return overflow[side] >= 0;
    });
  }

  function hide(_ref) {
    var state = _ref.state,
        name = _ref.name;
    var referenceRect = state.rects.reference;
    var popperRect = state.rects.popper;
    var preventedOffsets = state.modifiersData.preventOverflow;
    var referenceOverflow = detectOverflow(state, {
      elementContext: 'reference'
    });
    var popperAltOverflow = detectOverflow(state, {
      altBoundary: true
    });
    var referenceClippingOffsets = getSideOffsets(referenceOverflow, referenceRect);
    var popperEscapeOffsets = getSideOffsets(popperAltOverflow, popperRect, preventedOffsets);
    var isReferenceHidden = isAnySideFullyClipped(referenceClippingOffsets);
    var hasPopperEscaped = isAnySideFullyClipped(popperEscapeOffsets);
    state.modifiersData[name] = {
      referenceClippingOffsets: referenceClippingOffsets,
      popperEscapeOffsets: popperEscapeOffsets,
      isReferenceHidden: isReferenceHidden,
      hasPopperEscaped: hasPopperEscaped
    };
    state.attributes.popper = Object.assign({}, state.attributes.popper, {
      'data-popper-reference-hidden': isReferenceHidden,
      'data-popper-escaped': hasPopperEscaped
    });
  } // eslint-disable-next-line import/no-unused-modules


  var hide$1 = {
    name: 'hide',
    enabled: true,
    phase: 'main',
    requiresIfExists: ['preventOverflow'],
    fn: hide
  };

  function distanceAndSkiddingToXY(placement, rects, offset) {
    var basePlacement = getBasePlacement(placement);
    var invertDistance = [left, top].indexOf(basePlacement) >= 0 ? -1 : 1;

    var _ref = typeof offset === 'function' ? offset(Object.assign({}, rects, {
      placement: placement
    })) : offset,
        skidding = _ref[0],
        distance = _ref[1];

    skidding = skidding || 0;
    distance = (distance || 0) * invertDistance;
    return [left, right].indexOf(basePlacement) >= 0 ? {
      x: distance,
      y: skidding
    } : {
      x: skidding,
      y: distance
    };
  }

  function offset(_ref2) {
    var state = _ref2.state,
        options = _ref2.options,
        name = _ref2.name;
    var _options$offset = options.offset,
        offset = _options$offset === void 0 ? [0, 0] : _options$offset;
    var data = placements.reduce(function (acc, placement) {
      acc[placement] = distanceAndSkiddingToXY(placement, state.rects, offset);
      return acc;
    }, {});
    var _data$state$placement = data[state.placement],
        x = _data$state$placement.x,
        y = _data$state$placement.y;

    if (state.modifiersData.popperOffsets != null) {
      state.modifiersData.popperOffsets.x += x;
      state.modifiersData.popperOffsets.y += y;
    }

    state.modifiersData[name] = data;
  } // eslint-disable-next-line import/no-unused-modules


  var offset$1 = {
    name: 'offset',
    enabled: true,
    phase: 'main',
    requires: ['popperOffsets'],
    fn: offset
  };

  function popperOffsets(_ref) {
    var state = _ref.state,
        name = _ref.name;
    // Offsets are the actual position the popper needs to have to be
    // properly positioned near its reference element
    // This is the most basic placement, and will be adjusted by
    // the modifiers in the next step
    state.modifiersData[name] = computeOffsets({
      reference: state.rects.reference,
      element: state.rects.popper,
      strategy: 'absolute',
      placement: state.placement
    });
  } // eslint-disable-next-line import/no-unused-modules


  var popperOffsets$1 = {
    name: 'popperOffsets',
    enabled: true,
    phase: 'read',
    fn: popperOffsets,
    data: {}
  };

  function getAltAxis(axis) {
    return axis === 'x' ? 'y' : 'x';
  }

  function preventOverflow(_ref) {
    var state = _ref.state,
        options = _ref.options,
        name = _ref.name;
    var _options$mainAxis = options.mainAxis,
        checkMainAxis = _options$mainAxis === void 0 ? true : _options$mainAxis,
        _options$altAxis = options.altAxis,
        checkAltAxis = _options$altAxis === void 0 ? false : _options$altAxis,
        boundary = options.boundary,
        rootBoundary = options.rootBoundary,
        altBoundary = options.altBoundary,
        padding = options.padding,
        _options$tether = options.tether,
        tether = _options$tether === void 0 ? true : _options$tether,
        _options$tetherOffset = options.tetherOffset,
        tetherOffset = _options$tetherOffset === void 0 ? 0 : _options$tetherOffset;
    var overflow = detectOverflow(state, {
      boundary: boundary,
      rootBoundary: rootBoundary,
      padding: padding,
      altBoundary: altBoundary
    });
    var basePlacement = getBasePlacement(state.placement);
    var variation = getVariation(state.placement);
    var isBasePlacement = !variation;
    var mainAxis = getMainAxisFromPlacement(basePlacement);
    var altAxis = getAltAxis(mainAxis);
    var popperOffsets = state.modifiersData.popperOffsets;
    var referenceRect = state.rects.reference;
    var popperRect = state.rects.popper;
    var tetherOffsetValue = typeof tetherOffset === 'function' ? tetherOffset(Object.assign({}, state.rects, {
      placement: state.placement
    })) : tetherOffset;
    var normalizedTetherOffsetValue = typeof tetherOffsetValue === 'number' ? {
      mainAxis: tetherOffsetValue,
      altAxis: tetherOffsetValue
    } : Object.assign({
      mainAxis: 0,
      altAxis: 0
    }, tetherOffsetValue);
    var offsetModifierState = state.modifiersData.offset ? state.modifiersData.offset[state.placement] : null;
    var data = {
      x: 0,
      y: 0
    };

    if (!popperOffsets) {
      return;
    }

    if (checkMainAxis) {
      var _offsetModifierState$;

      var mainSide = mainAxis === 'y' ? top : left;
      var altSide = mainAxis === 'y' ? bottom : right;
      var len = mainAxis === 'y' ? 'height' : 'width';
      var offset = popperOffsets[mainAxis];
      var min$1 = offset + overflow[mainSide];
      var max$1 = offset - overflow[altSide];
      var additive = tether ? -popperRect[len] / 2 : 0;
      var minLen = variation === start ? referenceRect[len] : popperRect[len];
      var maxLen = variation === start ? -popperRect[len] : -referenceRect[len]; // We need to include the arrow in the calculation so the arrow doesn't go
      // outside the reference bounds

      var arrowElement = state.elements.arrow;
      var arrowRect = tether && arrowElement ? getLayoutRect(arrowElement) : {
        width: 0,
        height: 0
      };
      var arrowPaddingObject = state.modifiersData['arrow#persistent'] ? state.modifiersData['arrow#persistent'].padding : getFreshSideObject();
      var arrowPaddingMin = arrowPaddingObject[mainSide];
      var arrowPaddingMax = arrowPaddingObject[altSide]; // If the reference length is smaller than the arrow length, we don't want
      // to include its full size in the calculation. If the reference is small
      // and near the edge of a boundary, the popper can overflow even if the
      // reference is not overflowing as well (e.g. virtual elements with no
      // width or height)

      var arrowLen = within(0, referenceRect[len], arrowRect[len]);
      var minOffset = isBasePlacement ? referenceRect[len] / 2 - additive - arrowLen - arrowPaddingMin - normalizedTetherOffsetValue.mainAxis : minLen - arrowLen - arrowPaddingMin - normalizedTetherOffsetValue.mainAxis;
      var maxOffset = isBasePlacement ? -referenceRect[len] / 2 + additive + arrowLen + arrowPaddingMax + normalizedTetherOffsetValue.mainAxis : maxLen + arrowLen + arrowPaddingMax + normalizedTetherOffsetValue.mainAxis;
      var arrowOffsetParent = state.elements.arrow && getOffsetParent(state.elements.arrow);
      var clientOffset = arrowOffsetParent ? mainAxis === 'y' ? arrowOffsetParent.clientTop || 0 : arrowOffsetParent.clientLeft || 0 : 0;
      var offsetModifierValue = (_offsetModifierState$ = offsetModifierState == null ? void 0 : offsetModifierState[mainAxis]) != null ? _offsetModifierState$ : 0;
      var tetherMin = offset + minOffset - offsetModifierValue - clientOffset;
      var tetherMax = offset + maxOffset - offsetModifierValue;
      var preventedOffset = within(tether ? min(min$1, tetherMin) : min$1, offset, tether ? max(max$1, tetherMax) : max$1);
      popperOffsets[mainAxis] = preventedOffset;
      data[mainAxis] = preventedOffset - offset;
    }

    if (checkAltAxis) {
      var _offsetModifierState$2;

      var _mainSide = mainAxis === 'x' ? top : left;

      var _altSide = mainAxis === 'x' ? bottom : right;

      var _offset = popperOffsets[altAxis];

      var _len = altAxis === 'y' ? 'height' : 'width';

      var _min = _offset + overflow[_mainSide];

      var _max = _offset - overflow[_altSide];

      var isOriginSide = [top, left].indexOf(basePlacement) !== -1;

      var _offsetModifierValue = (_offsetModifierState$2 = offsetModifierState == null ? void 0 : offsetModifierState[altAxis]) != null ? _offsetModifierState$2 : 0;

      var _tetherMin = isOriginSide ? _min : _offset - referenceRect[_len] - popperRect[_len] - _offsetModifierValue + normalizedTetherOffsetValue.altAxis;

      var _tetherMax = isOriginSide ? _offset + referenceRect[_len] + popperRect[_len] - _offsetModifierValue - normalizedTetherOffsetValue.altAxis : _max;

      var _preventedOffset = tether && isOriginSide ? withinMaxClamp(_tetherMin, _offset, _tetherMax) : within(tether ? _tetherMin : _min, _offset, tether ? _tetherMax : _max);

      popperOffsets[altAxis] = _preventedOffset;
      data[altAxis] = _preventedOffset - _offset;
    }

    state.modifiersData[name] = data;
  } // eslint-disable-next-line import/no-unused-modules


  var preventOverflow$1 = {
    name: 'preventOverflow',
    enabled: true,
    phase: 'main',
    fn: preventOverflow,
    requiresIfExists: ['offset']
  };

  function getHTMLElementScroll(element) {
    return {
      scrollLeft: element.scrollLeft,
      scrollTop: element.scrollTop
    };
  }

  function getNodeScroll(node) {
    if (node === getWindow(node) || !isHTMLElement(node)) {
      return getWindowScroll(node);
    } else {
      return getHTMLElementScroll(node);
    }
  }

  function isElementScaled(element) {
    var rect = element.getBoundingClientRect();
    var scaleX = round(rect.width) / element.offsetWidth || 1;
    var scaleY = round(rect.height) / element.offsetHeight || 1;
    return scaleX !== 1 || scaleY !== 1;
  } // Returns the composite rect of an element relative to its offsetParent.
  // Composite means it takes into account transforms as well as layout.


  function getCompositeRect(elementOrVirtualElement, offsetParent, isFixed) {
    if (isFixed === void 0) {
      isFixed = false;
    }

    var isOffsetParentAnElement = isHTMLElement(offsetParent);
    var offsetParentIsScaled = isHTMLElement(offsetParent) && isElementScaled(offsetParent);
    var documentElement = getDocumentElement(offsetParent);
    var rect = getBoundingClientRect(elementOrVirtualElement, offsetParentIsScaled, isFixed);
    var scroll = {
      scrollLeft: 0,
      scrollTop: 0
    };
    var offsets = {
      x: 0,
      y: 0
    };

    if (isOffsetParentAnElement || !isOffsetParentAnElement && !isFixed) {
      if (getNodeName(offsetParent) !== 'body' || // https://github.com/popperjs/popper-core/issues/1078
      isScrollParent(documentElement)) {
        scroll = getNodeScroll(offsetParent);
      }

      if (isHTMLElement(offsetParent)) {
        offsets = getBoundingClientRect(offsetParent, true);
        offsets.x += offsetParent.clientLeft;
        offsets.y += offsetParent.clientTop;
      } else if (documentElement) {
        offsets.x = getWindowScrollBarX(documentElement);
      }
    }

    return {
      x: rect.left + scroll.scrollLeft - offsets.x,
      y: rect.top + scroll.scrollTop - offsets.y,
      width: rect.width,
      height: rect.height
    };
  }

  function order(modifiers) {
    var map = new Map();
    var visited = new Set();
    var result = [];
    modifiers.forEach(function (modifier) {
      map.set(modifier.name, modifier);
    }); // On visiting object, check for its dependencies and visit them recursively

    function sort(modifier) {
      visited.add(modifier.name);
      var requires = [].concat(modifier.requires || [], modifier.requiresIfExists || []);
      requires.forEach(function (dep) {
        if (!visited.has(dep)) {
          var depModifier = map.get(dep);

          if (depModifier) {
            sort(depModifier);
          }
        }
      });
      result.push(modifier);
    }

    modifiers.forEach(function (modifier) {
      if (!visited.has(modifier.name)) {
        // check for visited object
        sort(modifier);
      }
    });
    return result;
  }

  function orderModifiers(modifiers) {
    // order based on dependencies
    var orderedModifiers = order(modifiers); // order based on phase

    return modifierPhases.reduce(function (acc, phase) {
      return acc.concat(orderedModifiers.filter(function (modifier) {
        return modifier.phase === phase;
      }));
    }, []);
  }

  function debounce(fn) {
    var pending;
    return function () {
      if (!pending) {
        pending = new Promise(function (resolve) {
          Promise.resolve().then(function () {
            pending = undefined;
            resolve(fn());
          });
        });
      }

      return pending;
    };
  }

  function mergeByName(modifiers) {
    var merged = modifiers.reduce(function (merged, current) {
      var existing = merged[current.name];
      merged[current.name] = existing ? Object.assign({}, existing, current, {
        options: Object.assign({}, existing.options, current.options),
        data: Object.assign({}, existing.data, current.data)
      }) : current;
      return merged;
    }, {}); // IE11 does not support Object.values

    return Object.keys(merged).map(function (key) {
      return merged[key];
    });
  }

  var DEFAULT_OPTIONS = {
    placement: 'bottom',
    modifiers: [],
    strategy: 'absolute'
  };

  function areValidElements() {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return !args.some(function (element) {
      return !(element && typeof element.getBoundingClientRect === 'function');
    });
  }

  function popperGenerator(generatorOptions) {
    if (generatorOptions === void 0) {
      generatorOptions = {};
    }

    var _generatorOptions = generatorOptions,
        _generatorOptions$def = _generatorOptions.defaultModifiers,
        defaultModifiers = _generatorOptions$def === void 0 ? [] : _generatorOptions$def,
        _generatorOptions$def2 = _generatorOptions.defaultOptions,
        defaultOptions = _generatorOptions$def2 === void 0 ? DEFAULT_OPTIONS : _generatorOptions$def2;
    return function createPopper(reference, popper, options) {
      if (options === void 0) {
        options = defaultOptions;
      }

      var state = {
        placement: 'bottom',
        orderedModifiers: [],
        options: Object.assign({}, DEFAULT_OPTIONS, defaultOptions),
        modifiersData: {},
        elements: {
          reference: reference,
          popper: popper
        },
        attributes: {},
        styles: {}
      };
      var effectCleanupFns = [];
      var isDestroyed = false;
      var instance = {
        state: state,
        setOptions: function setOptions(setOptionsAction) {
          var options = typeof setOptionsAction === 'function' ? setOptionsAction(state.options) : setOptionsAction;
          cleanupModifierEffects();
          state.options = Object.assign({}, defaultOptions, state.options, options);
          state.scrollParents = {
            reference: isElement$1(reference) ? listScrollParents(reference) : reference.contextElement ? listScrollParents(reference.contextElement) : [],
            popper: listScrollParents(popper)
          }; // Orders the modifiers based on their dependencies and `phase`
          // properties

          var orderedModifiers = orderModifiers(mergeByName([].concat(defaultModifiers, state.options.modifiers))); // Strip out disabled modifiers

          state.orderedModifiers = orderedModifiers.filter(function (m) {
            return m.enabled;
          });
          runModifierEffects();
          return instance.update();
        },
        // Sync update – it will always be executed, even if not necessary. This
        // is useful for low frequency updates where sync behavior simplifies the
        // logic.
        // For high frequency updates (e.g. `resize` and `scroll` events), always
        // prefer the async Popper#update method
        forceUpdate: function forceUpdate() {
          if (isDestroyed) {
            return;
          }

          var _state$elements = state.elements,
              reference = _state$elements.reference,
              popper = _state$elements.popper; // Don't proceed if `reference` or `popper` are not valid elements
          // anymore

          if (!areValidElements(reference, popper)) {
            return;
          } // Store the reference and popper rects to be read by modifiers


          state.rects = {
            reference: getCompositeRect(reference, getOffsetParent(popper), state.options.strategy === 'fixed'),
            popper: getLayoutRect(popper)
          }; // Modifiers have the ability to reset the current update cycle. The
          // most common use case for this is the `flip` modifier changing the
          // placement, which then needs to re-run all the modifiers, because the
          // logic was previously ran for the previous placement and is therefore
          // stale/incorrect

          state.reset = false;
          state.placement = state.options.placement; // On each update cycle, the `modifiersData` property for each modifier
          // is filled with the initial data specified by the modifier. This means
          // it doesn't persist and is fresh on each update.
          // To ensure persistent data, use `${name}#persistent`

          state.orderedModifiers.forEach(function (modifier) {
            return state.modifiersData[modifier.name] = Object.assign({}, modifier.data);
          });

          for (var index = 0; index < state.orderedModifiers.length; index++) {
            if (state.reset === true) {
              state.reset = false;
              index = -1;
              continue;
            }

            var _state$orderedModifie = state.orderedModifiers[index],
                fn = _state$orderedModifie.fn,
                _state$orderedModifie2 = _state$orderedModifie.options,
                _options = _state$orderedModifie2 === void 0 ? {} : _state$orderedModifie2,
                name = _state$orderedModifie.name;

            if (typeof fn === 'function') {
              state = fn({
                state: state,
                options: _options,
                name: name,
                instance: instance
              }) || state;
            }
          }
        },
        // Async and optimistically optimized update – it will not be executed if
        // not necessary (debounced to run at most once-per-tick)
        update: debounce(function () {
          return new Promise(function (resolve) {
            instance.forceUpdate();
            resolve(state);
          });
        }),
        destroy: function destroy() {
          cleanupModifierEffects();
          isDestroyed = true;
        }
      };

      if (!areValidElements(reference, popper)) {
        return instance;
      }

      instance.setOptions(options).then(function (state) {
        if (!isDestroyed && options.onFirstUpdate) {
          options.onFirstUpdate(state);
        }
      }); // Modifiers have the ability to execute arbitrary code before the first
      // update cycle runs. They will be executed in the same order as the update
      // cycle. This is useful when a modifier adds some persistent data that
      // other modifiers need to use, but the modifier is run after the dependent
      // one.

      function runModifierEffects() {
        state.orderedModifiers.forEach(function (_ref) {
          var name = _ref.name,
              _ref$options = _ref.options,
              options = _ref$options === void 0 ? {} : _ref$options,
              effect = _ref.effect;

          if (typeof effect === 'function') {
            var cleanupFn = effect({
              state: state,
              name: name,
              instance: instance,
              options: options
            });

            var noopFn = function noopFn() {};

            effectCleanupFns.push(cleanupFn || noopFn);
          }
        });
      }

      function cleanupModifierEffects() {
        effectCleanupFns.forEach(function (fn) {
          return fn();
        });
        effectCleanupFns = [];
      }

      return instance;
    };
  }
  var createPopper$2 = /*#__PURE__*/popperGenerator(); // eslint-disable-next-line import/no-unused-modules

  var defaultModifiers$1 = [eventListeners, popperOffsets$1, computeStyles$1, applyStyles$1];
  var createPopper$1 = /*#__PURE__*/popperGenerator({
    defaultModifiers: defaultModifiers$1
  }); // eslint-disable-next-line import/no-unused-modules

  var defaultModifiers = [eventListeners, popperOffsets$1, computeStyles$1, applyStyles$1, offset$1, flip$1, preventOverflow$1, arrow$1, hide$1];
  var createPopper = /*#__PURE__*/popperGenerator({
    defaultModifiers: defaultModifiers
  }); // eslint-disable-next-line import/no-unused-modules

  var Popper = /*#__PURE__*/Object.freeze({
    __proto__: null,
    popperGenerator: popperGenerator,
    detectOverflow: detectOverflow,
    createPopperBase: createPopper$2,
    createPopper: createPopper,
    createPopperLite: createPopper$1,
    top: top,
    bottom: bottom,
    right: right,
    left: left,
    auto: auto,
    basePlacements: basePlacements,
    start: start,
    end: end,
    clippingParents: clippingParents,
    viewport: viewport,
    popper: popper,
    reference: reference,
    variationPlacements: variationPlacements,
    placements: placements,
    beforeRead: beforeRead,
    read: read,
    afterRead: afterRead,
    beforeMain: beforeMain,
    main: main,
    afterMain: afterMain,
    beforeWrite: beforeWrite,
    write: write,
    afterWrite: afterWrite,
    modifierPhases: modifierPhases,
    applyStyles: applyStyles$1,
    arrow: arrow$1,
    computeStyles: computeStyles$1,
    eventListeners: eventListeners,
    flip: flip$1,
    hide: hide$1,
    offset: offset$1,
    popperOffsets: popperOffsets$1,
    preventOverflow: preventOverflow$1
  });

  /**
   * --------------------------------------------------------------------------
   * Bootstrap dom/data.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */

  /**
   * Constants
   */

  const elementMap = new Map();

  var Data = {
    set(element, key, instance) {
      if (!elementMap.has(element)) {
        elementMap.set(element, new Map());
      }

      const instanceMap = elementMap.get(element);

      // make it clear we only want one instance per element
      // can be removed later when multiple key/instances are fine to be used
      if (!instanceMap.has(key) && instanceMap.size !== 0) {
        // eslint-disable-next-line no-console
        console.error(`Bootstrap doesn't allow more than one instance per element. Bound instance: ${Array.from(instanceMap.keys())[0]}.`);
        return
      }

      instanceMap.set(key, instance);
    },

    get(element, key) {
      if (elementMap.has(element)) {
        return elementMap.get(element).get(key) || null
      }

      return null
    },

    remove(element, key) {
      if (!elementMap.has(element)) {
        return
      }

      const instanceMap = elementMap.get(element);

      instanceMap.delete(key);

      // free up element references if there are no instances left for an element
      if (instanceMap.size === 0) {
        elementMap.delete(element);
      }
    }
  };

  /**
   * --------------------------------------------------------------------------
   * Bootstrap util/index.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */
  const MILLISECONDS_MULTIPLIER = 1000;
  const TRANSITION_END = 'transitionend';

  /**
   * Properly escape IDs selectors to handle weird IDs
   * @param {string} selector
   * @returns {string}
   */
  const parseSelector = selector => {
    if (selector && window.CSS && window.CSS.escape) {
      // document.querySelector needs escaping to handle IDs (html5+) containing for instance /
      selector = selector.replace(/#([^\s"#']+)/g, (match, id) => `#${CSS.escape(id)}`);
    }

    return selector
  };

  // Shout-out Angus Croll (https://goo.gl/pxwQGp)
  const toType = object => {
    if (object === null || object === undefined) {
      return `${object}`
    }

    return Object.prototype.toString.call(object).match(/\s([a-z]+)/i)[1].toLowerCase()
  };

  const getTransitionDurationFromElement = element => {
    if (!element) {
      return 0
    }

    // Get transition-duration of the element
    let { transitionDuration, transitionDelay } = window.getComputedStyle(element);

    const floatTransitionDuration = Number.parseFloat(transitionDuration);
    const floatTransitionDelay = Number.parseFloat(transitionDelay);

    // Return 0 if element or transition duration is not found
    if (!floatTransitionDuration && !floatTransitionDelay) {
      return 0
    }

    // If multiple durations are defined, take the first
    transitionDuration = transitionDuration.split(',')[0];
    transitionDelay = transitionDelay.split(',')[0];

    return (Number.parseFloat(transitionDuration) + Number.parseFloat(transitionDelay)) * MILLISECONDS_MULTIPLIER
  };

  const triggerTransitionEnd = element => {
    element.dispatchEvent(new Event(TRANSITION_END));
  };

  const isElement = object => {
    if (!object || typeof object !== 'object') {
      return false
    }

    if (typeof object.jquery !== 'undefined') {
      object = object[0];
    }

    return typeof object.nodeType !== 'undefined'
  };

  const getElement = object => {
    // it's a jQuery object or a node element
    if (isElement(object)) {
      return object.jquery ? object[0] : object
    }

    if (typeof object === 'string' && object.length > 0) {
      return document.querySelector(parseSelector(object))
    }

    return null
  };

  const isVisible = element => {
    if (!isElement(element) || element.getClientRects().length === 0) {
      return false
    }

    const elementIsVisible = getComputedStyle(element).getPropertyValue('visibility') === 'visible';
    // Handle `details` element as its content may falsie appear visible when it is closed
    const closedDetails = element.closest('details:not([open])');

    if (!closedDetails) {
      return elementIsVisible
    }

    if (closedDetails !== element) {
      const summary = element.closest('summary');
      if (summary && summary.parentNode !== closedDetails) {
        return false
      }

      if (summary === null) {
        return false
      }
    }

    return elementIsVisible
  };

  const isDisabled = element => {
    if (!element || element.nodeType !== Node.ELEMENT_NODE) {
      return true
    }

    if (element.classList.contains('disabled')) {
      return true
    }

    if (typeof element.disabled !== 'undefined') {
      return element.disabled
    }

    return element.hasAttribute('disabled') && element.getAttribute('disabled') !== 'false'
  };

  const noop = () => {};

  const getjQuery = () => {
    if (window.jQuery && !document.body.hasAttribute('data-bs-no-jquery')) {
      return window.jQuery
    }

    return null
  };

  const DOMContentLoadedCallbacks = [];

  const onDOMContentLoaded = callback => {
    if (document.readyState === 'loading') {
      // add listener on the first call when the document is in loading state
      if (!DOMContentLoadedCallbacks.length) {
        document.addEventListener('DOMContentLoaded', () => {
          for (const callback of DOMContentLoadedCallbacks) {
            callback();
          }
        });
      }

      DOMContentLoadedCallbacks.push(callback);
    } else {
      callback();
    }
  };

  const isRTL = () => document.documentElement.dir === 'rtl';

  const defineJQueryPlugin = plugin => {
    onDOMContentLoaded(() => {
      const $ = getjQuery();
      /* istanbul ignore if */
      if ($) {
        const name = plugin.NAME;
        const JQUERY_NO_CONFLICT = $.fn[name];
        $.fn[name] = plugin.jQueryInterface;
        $.fn[name].Constructor = plugin;
        $.fn[name].noConflict = () => {
          $.fn[name] = JQUERY_NO_CONFLICT;
          return plugin.jQueryInterface
        };
      }
    });
  };

  const execute = (possibleCallback, args = [], defaultValue = possibleCallback) => {
    return typeof possibleCallback === 'function' ? possibleCallback(...args) : defaultValue
  };

  const executeAfterTransition = (callback, transitionElement, waitForTransition = true) => {
    if (!waitForTransition) {
      execute(callback);
      return
    }

    const durationPadding = 5;
    const emulatedDuration = getTransitionDurationFromElement(transitionElement) + durationPadding;

    let called = false;

    const handler = ({ target }) => {
      if (target !== transitionElement) {
        return
      }

      called = true;
      transitionElement.removeEventListener(TRANSITION_END, handler);
      execute(callback);
    };

    transitionElement.addEventListener(TRANSITION_END, handler);
    setTimeout(() => {
      if (!called) {
        triggerTransitionEnd(transitionElement);
      }
    }, emulatedDuration);
  };

  /**
   * Return the previous/next element of a list.
   *
   * @param {array} list    The list of elements
   * @param activeElement   The active element
   * @param shouldGetNext   Choose to get next or previous element
   * @param isCycleAllowed
   * @return {Element|elem} The proper element
   */
  const getNextActiveElement = (list, activeElement, shouldGetNext, isCycleAllowed) => {
    const listLength = list.length;
    let index = list.indexOf(activeElement);

    // if the element does not exist in the list return an element
    // depending on the direction and if cycle is allowed
    if (index === -1) {
      return !shouldGetNext && isCycleAllowed ? list[listLength - 1] : list[0]
    }

    index += shouldGetNext ? 1 : -1;

    if (isCycleAllowed) {
      index = (index + listLength) % listLength;
    }

    return list[Math.max(0, Math.min(index, listLength - 1))]
  };

  /**
   * --------------------------------------------------------------------------
   * Bootstrap dom/event-handler.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */

  /**
   * Constants
   */

  const namespaceRegex = /[^.]*(?=\..*)\.|.*/;
  const stripNameRegex = /\..*/;
  const stripUidRegex = /::\d+$/;
  const eventRegistry = {}; // Events storage
  let uidEvent = 1;
  const customEvents = {
    mouseenter: 'mouseover',
    mouseleave: 'mouseout'
  };

  const nativeEvents = new Set([
    'click',
    'dblclick',
    'mouseup',
    'mousedown',
    'contextmenu',
    'mousewheel',
    'DOMMouseScroll',
    'mouseover',
    'mouseout',
    'mousemove',
    'selectstart',
    'selectend',
    'keydown',
    'keypress',
    'keyup',
    'orientationchange',
    'touchstart',
    'touchmove',
    'touchend',
    'touchcancel',
    'pointerdown',
    'pointermove',
    'pointerup',
    'pointerleave',
    'pointercancel',
    'gesturestart',
    'gesturechange',
    'gestureend',
    'focus',
    'blur',
    'change',
    'reset',
    'select',
    'submit',
    'focusin',
    'focusout',
    'load',
    'unload',
    'beforeunload',
    'resize',
    'move',
    'DOMContentLoaded',
    'readystatechange',
    'error',
    'abort',
    'scroll'
  ]);

  /**
   * Private methods
   */

  function makeEventUid(element, uid) {
    return (uid && `${uid}::${uidEvent++}`) || element.uidEvent || uidEvent++
  }

  function getElementEvents(element) {
    const uid = makeEventUid(element);

    element.uidEvent = uid;
    eventRegistry[uid] = eventRegistry[uid] || {};

    return eventRegistry[uid]
  }

  function bootstrapHandler(element, fn) {
    return function handler(event) {
      hydrateObj(event, { delegateTarget: element });

      if (handler.oneOff) {
        EventHandler.off(element, event.type, fn);
      }

      return fn.apply(element, [event])
    }
  }

  function bootstrapDelegationHandler(element, selector, fn) {
    return function handler(event) {
      const domElements = element.querySelectorAll(selector);

      for (let { target } = event; target && target !== this; target = target.parentNode) {
        for (const domElement of domElements) {
          if (domElement !== target) {
            continue
          }

          hydrateObj(event, { delegateTarget: target });

          if (handler.oneOff) {
            EventHandler.off(element, event.type, selector, fn);
          }

          return fn.apply(target, [event])
        }
      }
    }
  }

  function findHandler(events, callable, delegationSelector = null) {
    return Object.values(events)
      .find(event => event.callable === callable && event.delegationSelector === delegationSelector)
  }

  function normalizeParameters(originalTypeEvent, handler, delegationFunction) {
    const isDelegated = typeof handler === 'string';
    // TODO: tooltip passes `false` instead of selector, so we need to check
    const callable = isDelegated ? delegationFunction : (handler || delegationFunction);
    let typeEvent = getTypeEvent(originalTypeEvent);

    if (!nativeEvents.has(typeEvent)) {
      typeEvent = originalTypeEvent;
    }

    return [isDelegated, callable, typeEvent]
  }

  function addHandler(element, originalTypeEvent, handler, delegationFunction, oneOff) {
    if (typeof originalTypeEvent !== 'string' || !element) {
      return
    }

    let [isDelegated, callable, typeEvent] = normalizeParameters(originalTypeEvent, handler, delegationFunction);

    // in case of mouseenter or mouseleave wrap the handler within a function that checks for its DOM position
    // this prevents the handler from being dispatched the same way as mouseover or mouseout does
    if (originalTypeEvent in customEvents) {
      const wrapFunction = fn => {
        return function (event) {
          if (!event.relatedTarget || (event.relatedTarget !== event.delegateTarget && !event.delegateTarget.contains(event.relatedTarget))) {
            return fn.call(this, event)
          }
        }
      };

      callable = wrapFunction(callable);
    }

    const events = getElementEvents(element);
    const handlers = events[typeEvent] || (events[typeEvent] = {});
    const previousFunction = findHandler(handlers, callable, isDelegated ? handler : null);

    if (previousFunction) {
      previousFunction.oneOff = previousFunction.oneOff && oneOff;

      return
    }

    const uid = makeEventUid(callable, originalTypeEvent.replace(namespaceRegex, ''));
    const fn = isDelegated ?
      bootstrapDelegationHandler(element, handler, callable) :
      bootstrapHandler(element, callable);

    fn.delegationSelector = isDelegated ? handler : null;
    fn.callable = callable;
    fn.oneOff = oneOff;
    fn.uidEvent = uid;
    handlers[uid] = fn;

    element.addEventListener(typeEvent, fn, isDelegated);
  }

  function removeHandler(element, events, typeEvent, handler, delegationSelector) {
    const fn = findHandler(events[typeEvent], handler, delegationSelector);

    if (!fn) {
      return
    }

    element.removeEventListener(typeEvent, fn, Boolean(delegationSelector));
    delete events[typeEvent][fn.uidEvent];
  }

  function removeNamespacedHandlers(element, events, typeEvent, namespace) {
    const storeElementEvent = events[typeEvent] || {};

    for (const [handlerKey, event] of Object.entries(storeElementEvent)) {
      if (handlerKey.includes(namespace)) {
        removeHandler(element, events, typeEvent, event.callable, event.delegationSelector);
      }
    }
  }

  function getTypeEvent(event) {
    // allow to get the native events from namespaced events ('click.bs.button' --> 'click')
    event = event.replace(stripNameRegex, '');
    return customEvents[event] || event
  }

  const EventHandler = {
    on(element, event, handler, delegationFunction) {
      addHandler(element, event, handler, delegationFunction, false);
    },

    one(element, event, handler, delegationFunction) {
      addHandler(element, event, handler, delegationFunction, true);
    },

    off(element, originalTypeEvent, handler, delegationFunction) {
      if (typeof originalTypeEvent !== 'string' || !element) {
        return
      }

      const [isDelegated, callable, typeEvent] = normalizeParameters(originalTypeEvent, handler, delegationFunction);
      const inNamespace = typeEvent !== originalTypeEvent;
      const events = getElementEvents(element);
      const storeElementEvent = events[typeEvent] || {};
      const isNamespace = originalTypeEvent.startsWith('.');

      if (typeof callable !== 'undefined') {
        // Simplest case: handler is passed, remove that listener ONLY.
        if (!Object.keys(storeElementEvent).length) {
          return
        }

        removeHandler(element, events, typeEvent, callable, isDelegated ? handler : null);
        return
      }

      if (isNamespace) {
        for (const elementEvent of Object.keys(events)) {
          removeNamespacedHandlers(element, events, elementEvent, originalTypeEvent.slice(1));
        }
      }

      for (const [keyHandlers, event] of Object.entries(storeElementEvent)) {
        const handlerKey = keyHandlers.replace(stripUidRegex, '');

        if (!inNamespace || originalTypeEvent.includes(handlerKey)) {
          removeHandler(element, events, typeEvent, event.callable, event.delegationSelector);
        }
      }
    },

    trigger(element, event, args) {
      if (typeof event !== 'string' || !element) {
        return null
      }

      const $ = getjQuery();
      const typeEvent = getTypeEvent(event);
      const inNamespace = event !== typeEvent;

      let jQueryEvent = null;
      let bubbles = true;
      let nativeDispatch = true;
      let defaultPrevented = false;

      if (inNamespace && $) {
        jQueryEvent = $.Event(event, args);

        $(element).trigger(jQueryEvent);
        bubbles = !jQueryEvent.isPropagationStopped();
        nativeDispatch = !jQueryEvent.isImmediatePropagationStopped();
        defaultPrevented = jQueryEvent.isDefaultPrevented();
      }

      const evt = hydrateObj(new Event(event, { bubbles, cancelable: true }), args);

      if (defaultPrevented) {
        evt.preventDefault();
      }

      if (nativeDispatch) {
        element.dispatchEvent(evt);
      }

      if (evt.defaultPrevented && jQueryEvent) {
        jQueryEvent.preventDefault();
      }

      return evt
    }
  };

  function hydrateObj(obj, meta = {}) {
    for (const [key, value] of Object.entries(meta)) {
      try {
        obj[key] = value;
      } catch {
        Object.defineProperty(obj, key, {
          configurable: true,
          get() {
            return value
          }
        });
      }
    }

    return obj
  }

  /**
   * --------------------------------------------------------------------------
   * Bootstrap dom/manipulator.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */

  function normalizeData(value) {
    if (value === 'true') {
      return true
    }

    if (value === 'false') {
      return false
    }

    if (value === Number(value).toString()) {
      return Number(value)
    }

    if (value === '' || value === 'null') {
      return null
    }

    if (typeof value !== 'string') {
      return value
    }

    try {
      return JSON.parse(decodeURIComponent(value))
    } catch {
      return value
    }
  }

  function normalizeDataKey(key) {
    return key.replace(/[A-Z]/g, chr => `-${chr.toLowerCase()}`)
  }

  const Manipulator = {
    setDataAttribute(element, key, value) {
      element.setAttribute(`data-bs-${normalizeDataKey(key)}`, value);
    },

    removeDataAttribute(element, key) {
      element.removeAttribute(`data-bs-${normalizeDataKey(key)}`);
    },

    getDataAttributes(element) {
      if (!element) {
        return {}
      }

      const attributes = {};
      const bsKeys = Object.keys(element.dataset).filter(key => key.startsWith('bs') && !key.startsWith('bsConfig'));

      for (const key of bsKeys) {
        let pureKey = key.replace(/^bs/, '');
        pureKey = pureKey.charAt(0).toLowerCase() + pureKey.slice(1, pureKey.length);
        attributes[pureKey] = normalizeData(element.dataset[key]);
      }

      return attributes
    },

    getDataAttribute(element, key) {
      return normalizeData(element.getAttribute(`data-bs-${normalizeDataKey(key)}`))
    }
  };

  /**
   * --------------------------------------------------------------------------
   * Bootstrap util/config.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */

  /**
   * Class definition
   */

  class Config {
    // Getters
    static get Default() {
      return {}
    }

    static get DefaultType() {
      return {}
    }

    static get NAME() {
      throw new Error('You have to implement the static method "NAME", for each component!')
    }

    _getConfig(config) {
      config = this._mergeConfigObj(config);
      config = this._configAfterMerge(config);
      this._typeCheckConfig(config);
      return config
    }

    _configAfterMerge(config) {
      return config
    }

    _mergeConfigObj(config, element) {
      const jsonConfig = isElement(element) ? Manipulator.getDataAttribute(element, 'config') : {}; // try to parse

      return {
        ...this.constructor.Default,
        ...(typeof jsonConfig === 'object' ? jsonConfig : {}),
        ...(isElement(element) ? Manipulator.getDataAttributes(element) : {}),
        ...(typeof config === 'object' ? config : {})
      }
    }

    _typeCheckConfig(config, configTypes = this.constructor.DefaultType) {
      for (const [property, expectedTypes] of Object.entries(configTypes)) {
        const value = config[property];
        const valueType = isElement(value) ? 'element' : toType(value);

        if (!new RegExp(expectedTypes).test(valueType)) {
          throw new TypeError(
            `${this.constructor.NAME.toUpperCase()}: Option "${property}" provided type "${valueType}" but expected type "${expectedTypes}".`
          )
        }
      }
    }
  }

  /**
   * --------------------------------------------------------------------------
   * Bootstrap base-component.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */

  /**
   * Constants
   */

  const VERSION = '5.3.3';

  /**
   * Class definition
   */

  class BaseComponent extends Config {
    constructor(element, config) {
      super();

      element = getElement(element);
      if (!element) {
        return
      }

      this._element = element;
      this._config = this._getConfig(config);

      Data.set(this._element, this.constructor.DATA_KEY, this);
    }

    // Public
    dispose() {
      Data.remove(this._element, this.constructor.DATA_KEY);
      EventHandler.off(this._element, this.constructor.EVENT_KEY);

      for (const propertyName of Object.getOwnPropertyNames(this)) {
        this[propertyName] = null;
      }
    }

    _queueCallback(callback, element, isAnimated = true) {
      executeAfterTransition(callback, element, isAnimated);
    }

    _getConfig(config) {
      config = this._mergeConfigObj(config, this._element);
      config = this._configAfterMerge(config);
      this._typeCheckConfig(config);
      return config
    }

    // Static
    static getInstance(element) {
      return Data.get(getElement(element), this.DATA_KEY)
    }

    static getOrCreateInstance(element, config = {}) {
      return this.getInstance(element) || new this(element, typeof config === 'object' ? config : null)
    }

    static get VERSION() {
      return VERSION
    }

    static get DATA_KEY() {
      return `bs.${this.NAME}`
    }

    static get EVENT_KEY() {
      return `.${this.DATA_KEY}`
    }

    static eventName(name) {
      return `${name}${this.EVENT_KEY}`
    }
  }

  /**
   * --------------------------------------------------------------------------
   * Bootstrap dom/selector-engine.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */

  const getSelector = element => {
    let selector = element.getAttribute('data-bs-target');

    if (!selector || selector === '#') {
      let hrefAttribute = element.getAttribute('href');

      // The only valid content that could double as a selector are IDs or classes,
      // so everything starting with `#` or `.`. If a "real" URL is used as the selector,
      // `document.querySelector` will rightfully complain it is invalid.
      // See https://github.com/twbs/bootstrap/issues/32273
      if (!hrefAttribute || (!hrefAttribute.includes('#') && !hrefAttribute.startsWith('.'))) {
        return null
      }

      // Just in case some CMS puts out a full URL with the anchor appended
      if (hrefAttribute.includes('#') && !hrefAttribute.startsWith('#')) {
        hrefAttribute = `#${hrefAttribute.split('#')[1]}`;
      }

      selector = hrefAttribute && hrefAttribute !== '#' ? hrefAttribute.trim() : null;
    }

    return selector ? selector.split(',').map(sel => parseSelector(sel)).join(',') : null
  };

  const SelectorEngine = {
    find(selector, element = document.documentElement) {
      return [].concat(...Element.prototype.querySelectorAll.call(element, selector))
    },

    findOne(selector, element = document.documentElement) {
      return Element.prototype.querySelector.call(element, selector)
    },

    children(element, selector) {
      return [].concat(...element.children).filter(child => child.matches(selector))
    },

    parents(element, selector) {
      const parents = [];
      let ancestor = element.parentNode.closest(selector);

      while (ancestor) {
        parents.push(ancestor);
        ancestor = ancestor.parentNode.closest(selector);
      }

      return parents
    },

    prev(element, selector) {
      let previous = element.previousElementSibling;

      while (previous) {
        if (previous.matches(selector)) {
          return [previous]
        }

        previous = previous.previousElementSibling;
      }

      return []
    },
    // TODO: this is now unused; remove later along with prev()
    next(element, selector) {
      let next = element.nextElementSibling;

      while (next) {
        if (next.matches(selector)) {
          return [next]
        }

        next = next.nextElementSibling;
      }

      return []
    },

    focusableChildren(element) {
      const focusables = [
        'a',
        'button',
        'input',
        'textarea',
        'select',
        'details',
        '[tabindex]',
        '[contenteditable="true"]'
      ].map(selector => `${selector}:not([tabindex^="-"])`).join(',');

      return this.find(focusables, element).filter(el => !isDisabled(el) && isVisible(el))
    },

    getSelectorFromElement(element) {
      const selector = getSelector(element);

      if (selector) {
        return SelectorEngine.findOne(selector) ? selector : null
      }

      return null
    },

    getElementFromSelector(element) {
      const selector = getSelector(element);

      return selector ? SelectorEngine.findOne(selector) : null
    },

    getMultipleElementsFromSelector(element) {
      const selector = getSelector(element);

      return selector ? SelectorEngine.find(selector) : []
    }
  };

  /**
   * --------------------------------------------------------------------------
   * Bootstrap dropdown.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */

  /**
   * Constants
   */

  const NAME = 'dropdown';
  const DATA_KEY = 'bs.dropdown';
  const EVENT_KEY = `.${DATA_KEY}`;
  const DATA_API_KEY = '.data-api';

  const ESCAPE_KEY = 'Escape';
  const TAB_KEY = 'Tab';
  const ARROW_UP_KEY = 'ArrowUp';
  const ARROW_DOWN_KEY = 'ArrowDown';
  const RIGHT_MOUSE_BUTTON = 2; // MouseEvent.button value for the secondary button, usually the right button

  const EVENT_HIDE = `hide${EVENT_KEY}`;
  const EVENT_HIDDEN = `hidden${EVENT_KEY}`;
  const EVENT_SHOW = `show${EVENT_KEY}`;
  const EVENT_SHOWN = `shown${EVENT_KEY}`;
  const EVENT_CLICK_DATA_API = `click${EVENT_KEY}${DATA_API_KEY}`;
  const EVENT_KEYDOWN_DATA_API = `keydown${EVENT_KEY}${DATA_API_KEY}`;
  const EVENT_KEYUP_DATA_API = `keyup${EVENT_KEY}${DATA_API_KEY}`;

  const CLASS_NAME_SHOW = 'show';
  const CLASS_NAME_DROPUP = 'dropup';
  const CLASS_NAME_DROPEND = 'dropend';
  const CLASS_NAME_DROPSTART = 'dropstart';
  const CLASS_NAME_DROPUP_CENTER = 'dropup-center';
  const CLASS_NAME_DROPDOWN_CENTER = 'dropdown-center';

  const SELECTOR_DATA_TOGGLE = '[data-bs-toggle="dropdown"]:not(.disabled):not(:disabled)';
  const SELECTOR_DATA_TOGGLE_SHOWN = `${SELECTOR_DATA_TOGGLE}.${CLASS_NAME_SHOW}`;
  const SELECTOR_MENU = '.dropdown-menu';
  const SELECTOR_NAVBAR = '.navbar';
  const SELECTOR_NAVBAR_NAV = '.navbar-nav';
  const SELECTOR_VISIBLE_ITEMS = '.dropdown-menu .dropdown-item:not(.disabled):not(:disabled)';

  const PLACEMENT_TOP = isRTL() ? 'top-end' : 'top-start';
  const PLACEMENT_TOPEND = isRTL() ? 'top-start' : 'top-end';
  const PLACEMENT_BOTTOM = isRTL() ? 'bottom-end' : 'bottom-start';
  const PLACEMENT_BOTTOMEND = isRTL() ? 'bottom-start' : 'bottom-end';
  const PLACEMENT_RIGHT = isRTL() ? 'left-start' : 'right-start';
  const PLACEMENT_LEFT = isRTL() ? 'right-start' : 'left-start';
  const PLACEMENT_TOPCENTER = 'top';
  const PLACEMENT_BOTTOMCENTER = 'bottom';

  const Default = {
    autoClose: true,
    boundary: 'clippingParents',
    display: 'dynamic',
    offset: [0, 2],
    popperConfig: null,
    reference: 'toggle'
  };

  const DefaultType = {
    autoClose: '(boolean|string)',
    boundary: '(string|element)',
    display: 'string',
    offset: '(array|string|function)',
    popperConfig: '(null|object|function)',
    reference: '(string|element|object)'
  };

  /**
   * Class definition
   */

  class Dropdown extends BaseComponent {
    constructor(element, config) {
      super(element, config);

      this._popper = null;
      this._parent = this._element.parentNode; // dropdown wrapper
      // TODO: v6 revert #37011 & change markup https://getbootstrap.com/docs/5.3/forms/input-group/
      this._menu = SelectorEngine.next(this._element, SELECTOR_MENU)[0] ||
        SelectorEngine.prev(this._element, SELECTOR_MENU)[0] ||
        SelectorEngine.findOne(SELECTOR_MENU, this._parent);
      this._inNavbar = this._detectNavbar();
    }

    // Getters
    static get Default() {
      return Default
    }

    static get DefaultType() {
      return DefaultType
    }

    static get NAME() {
      return NAME
    }

    // Public
    toggle() {
      return this._isShown() ? this.hide() : this.show()
    }

    show() {
      if (isDisabled(this._element) || this._isShown()) {
        return
      }

      const relatedTarget = {
        relatedTarget: this._element
      };

      const showEvent = EventHandler.trigger(this._element, EVENT_SHOW, relatedTarget);

      if (showEvent.defaultPrevented) {
        return
      }

      this._createPopper();

      // If this is a touch-enabled device we add extra
      // empty mouseover listeners to the body's immediate children;
      // only needed because of broken event delegation on iOS
      // https://www.quirksmode.org/blog/archives/2014/02/mouse_event_bub.html
      if ('ontouchstart' in document.documentElement && !this._parent.closest(SELECTOR_NAVBAR_NAV)) {
        for (const element of [].concat(...document.body.children)) {
          EventHandler.on(element, 'mouseover', noop);
        }
      }

      this._element.focus();
      this._element.setAttribute('aria-expanded', true);

      this._menu.classList.add(CLASS_NAME_SHOW);
      this._element.classList.add(CLASS_NAME_SHOW);
      EventHandler.trigger(this._element, EVENT_SHOWN, relatedTarget);
    }

    hide() {
      if (isDisabled(this._element) || !this._isShown()) {
        return
      }

      const relatedTarget = {
        relatedTarget: this._element
      };

      this._completeHide(relatedTarget);
    }

    dispose() {
      if (this._popper) {
        this._popper.destroy();
      }

      super.dispose();
    }

    update() {
      this._inNavbar = this._detectNavbar();
      if (this._popper) {
        this._popper.update();
      }
    }

    // Private
    _completeHide(relatedTarget) {
      const hideEvent = EventHandler.trigger(this._element, EVENT_HIDE, relatedTarget);
      if (hideEvent.defaultPrevented) {
        return
      }

      // If this is a touch-enabled device we remove the extra
      // empty mouseover listeners we added for iOS support
      if ('ontouchstart' in document.documentElement) {
        for (const element of [].concat(...document.body.children)) {
          EventHandler.off(element, 'mouseover', noop);
        }
      }

      if (this._popper) {
        this._popper.destroy();
      }

      this._menu.classList.remove(CLASS_NAME_SHOW);
      this._element.classList.remove(CLASS_NAME_SHOW);
      this._element.setAttribute('aria-expanded', 'false');
      Manipulator.removeDataAttribute(this._menu, 'popper');
      EventHandler.trigger(this._element, EVENT_HIDDEN, relatedTarget);
    }

    _getConfig(config) {
      config = super._getConfig(config);

      if (typeof config.reference === 'object' && !isElement(config.reference) &&
        typeof config.reference.getBoundingClientRect !== 'function'
      ) {
        // Popper virtual elements require a getBoundingClientRect method
        throw new TypeError(`${NAME.toUpperCase()}: Option "reference" provided type "object" without a required "getBoundingClientRect" method.`)
      }

      return config
    }

    _createPopper() {
      if (typeof Popper === 'undefined') {
        throw new TypeError('Bootstrap\'s dropdowns require Popper (https://popper.js.org)')
      }

      let referenceElement = this._element;

      if (this._config.reference === 'parent') {
        referenceElement = this._parent;
      } else if (isElement(this._config.reference)) {
        referenceElement = getElement(this._config.reference);
      } else if (typeof this._config.reference === 'object') {
        referenceElement = this._config.reference;
      }

      const popperConfig = this._getPopperConfig();
      this._popper = createPopper(referenceElement, this._menu, popperConfig);
    }

    _isShown() {
      return this._menu.classList.contains(CLASS_NAME_SHOW)
    }

    _getPlacement() {
      const parentDropdown = this._parent;

      if (parentDropdown.classList.contains(CLASS_NAME_DROPEND)) {
        return PLACEMENT_RIGHT
      }

      if (parentDropdown.classList.contains(CLASS_NAME_DROPSTART)) {
        return PLACEMENT_LEFT
      }

      if (parentDropdown.classList.contains(CLASS_NAME_DROPUP_CENTER)) {
        return PLACEMENT_TOPCENTER
      }

      if (parentDropdown.classList.contains(CLASS_NAME_DROPDOWN_CENTER)) {
        return PLACEMENT_BOTTOMCENTER
      }

      // We need to trim the value because custom properties can also include spaces
      const isEnd = getComputedStyle(this._menu).getPropertyValue('--bs-position').trim() === 'end';

      if (parentDropdown.classList.contains(CLASS_NAME_DROPUP)) {
        return isEnd ? PLACEMENT_TOPEND : PLACEMENT_TOP
      }

      return isEnd ? PLACEMENT_BOTTOMEND : PLACEMENT_BOTTOM
    }

    _detectNavbar() {
      return this._element.closest(SELECTOR_NAVBAR) !== null
    }

    _getOffset() {
      const { offset } = this._config;

      if (typeof offset === 'string') {
        return offset.split(',').map(value => Number.parseInt(value, 10))
      }

      if (typeof offset === 'function') {
        return popperData => offset(popperData, this._element)
      }

      return offset
    }

    _getPopperConfig() {
      const defaultBsPopperConfig = {
        placement: this._getPlacement(),
        modifiers: [{
          name: 'preventOverflow',
          options: {
            boundary: this._config.boundary
          }
        },
        {
          name: 'offset',
          options: {
            offset: this._getOffset()
          }
        }]
      };

      // Disable Popper if we have a static display or Dropdown is in Navbar
      if (this._inNavbar || this._config.display === 'static') {
        Manipulator.setDataAttribute(this._menu, 'popper', 'static'); // TODO: v6 remove
        defaultBsPopperConfig.modifiers = [{
          name: 'applyStyles',
          enabled: false
        }];
      }

      return {
        ...defaultBsPopperConfig,
        ...execute(this._config.popperConfig, [defaultBsPopperConfig])
      }
    }

    _selectMenuItem({ key, target }) {
      const items = SelectorEngine.find(SELECTOR_VISIBLE_ITEMS, this._menu).filter(element => isVisible(element));

      if (!items.length) {
        return
      }

      // if target isn't included in items (e.g. when expanding the dropdown)
      // allow cycling to get the last item in case key equals ARROW_UP_KEY
      getNextActiveElement(items, target, key === ARROW_DOWN_KEY, !items.includes(target)).focus();
    }

    // Static
    static jQueryInterface(config) {
      return this.each(function () {
        const data = Dropdown.getOrCreateInstance(this, config);

        if (typeof config !== 'string') {
          return
        }

        if (typeof data[config] === 'undefined') {
          throw new TypeError(`No method named "${config}"`)
        }

        data[config]();
      })
    }

    static clearMenus(event) {
      if (event.button === RIGHT_MOUSE_BUTTON || (event.type === 'keyup' && event.key !== TAB_KEY)) {
        return
      }

      const openToggles = SelectorEngine.find(SELECTOR_DATA_TOGGLE_SHOWN);

      for (const toggle of openToggles) {
        const context = Dropdown.getInstance(toggle);
        if (!context || context._config.autoClose === false) {
          continue
        }

        const composedPath = event.composedPath();
        const isMenuTarget = composedPath.includes(context._menu);
        if (
          composedPath.includes(context._element) ||
          (context._config.autoClose === 'inside' && !isMenuTarget) ||
          (context._config.autoClose === 'outside' && isMenuTarget)
        ) {
          continue
        }

        // Tab navigation through the dropdown menu or events from contained inputs shouldn't close the menu
        if (context._menu.contains(event.target) && ((event.type === 'keyup' && event.key === TAB_KEY) || /input|select|option|textarea|form/i.test(event.target.tagName))) {
          continue
        }

        const relatedTarget = { relatedTarget: context._element };

        if (event.type === 'click') {
          relatedTarget.clickEvent = event;
        }

        context._completeHide(relatedTarget);
      }
    }

    static dataApiKeydownHandler(event) {
      // If not an UP | DOWN | ESCAPE key => not a dropdown command
      // If input/textarea && if key is other than ESCAPE => not a dropdown command

      const isInput = /input|textarea/i.test(event.target.tagName);
      const isEscapeEvent = event.key === ESCAPE_KEY;
      const isUpOrDownEvent = [ARROW_UP_KEY, ARROW_DOWN_KEY].includes(event.key);

      if (!isUpOrDownEvent && !isEscapeEvent) {
        return
      }

      if (isInput && !isEscapeEvent) {
        return
      }

      event.preventDefault();

      // TODO: v6 revert #37011 & change markup https://getbootstrap.com/docs/5.3/forms/input-group/
      const getToggleButton = this.matches(SELECTOR_DATA_TOGGLE) ?
        this :
        (SelectorEngine.prev(this, SELECTOR_DATA_TOGGLE)[0] ||
          SelectorEngine.next(this, SELECTOR_DATA_TOGGLE)[0] ||
          SelectorEngine.findOne(SELECTOR_DATA_TOGGLE, event.delegateTarget.parentNode));

      const instance = Dropdown.getOrCreateInstance(getToggleButton);

      if (isUpOrDownEvent) {
        event.stopPropagation();
        instance.show();
        instance._selectMenuItem(event);
        return
      }

      if (instance._isShown()) { // else is escape and we check if it is shown
        event.stopPropagation();
        instance.hide();
        getToggleButton.focus();
      }
    }
  }

  /**
   * Data API implementation
   */

  EventHandler.on(document, EVENT_KEYDOWN_DATA_API, SELECTOR_DATA_TOGGLE, Dropdown.dataApiKeydownHandler);
  EventHandler.on(document, EVENT_KEYDOWN_DATA_API, SELECTOR_MENU, Dropdown.dataApiKeydownHandler);
  EventHandler.on(document, EVENT_CLICK_DATA_API, Dropdown.clearMenus);
  EventHandler.on(document, EVENT_KEYUP_DATA_API, Dropdown.clearMenus);
  EventHandler.on(document, EVENT_CLICK_DATA_API, SELECTOR_DATA_TOGGLE, function (event) {
    event.preventDefault();
    Dropdown.getOrCreateInstance(this).toggle();
  });

  /**
   * jQuery
   */

  defineJQueryPlugin(Dropdown);

  /* eslint-disable @typescript-eslint/no-explicit-any */
  const assign = (target, ...args) => Object.assign(target, ...args);
  const keys = (obj) => Object.keys(obj);

  /* eslint-disable @typescript-eslint/no-explicit-any */
  function _isObject(item) {
      return item && typeof item === "object" && item.constructor === Object;
  }
  const mergeDeep = (target, source) => {
      if (_isObject(target) && _isObject(source)) {
          keys(source).forEach(key => {
              if (_isObject(source[key])) {
                  if (!target[key] || !_isObject(target[key])) {
                      target[key] = source[key];
                  }
                  mergeDeep(target[key], source[key]);
              }
              else {
                  assign(target, { [key]: source[key] });
              }
          });
      }
      return target;
  };

  var css_248z$4 = css`:host{-webkit-text-size-adjust:100%;-webkit-tap-highlight-color:rgba(0,0,0,0);color:var(--sgds-body-color-default);font-family:var(--sgds-font-family-brand);font-size:var(--sgds-font-size-2);font-weight:var(--sgds-font-weight-regular);line-height:var(--sgds-line-height-body);margin:0;*,:after,:before{box-sizing:border-box}:disabled{cursor:not-allowed}@media (prefers-reduced-motion:no-preference){:root{scroll-behavior:smooth}}a[target=_blank]{align-items:center;display:flex;gap:var(--sgds-gap-2-xs)}::slotted(a[target=_blank]):after,a[target=_blank]:after{background-color:currentColor;content:"/";display:inline-block;-webkit-mask-image:url("data:image/svg+xml;charset=utf-8,%3Csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' fill='none'%3E%3Cpath fill-rule='evenodd' clip-rule='evenodd' d='M9.274 3.9H9.3a.6.6 0 0 1 0 1.2c-.85 0-1.451 0-1.922.039-.463.038-.745.11-.968.223A2.4 2.4 0 0 0 5.361 6.41c-.113.223-.184.505-.222.968-.039.47-.04 1.072-.04 1.922v5.4c0 .85.001 1.451.04 1.922.038.463.11.745.222.968a2.4 2.4 0 0 0 1.05 1.048c.222.114.504.185.967.223.47.038 1.072.039 1.922.039h5.4c.85 0 1.451 0 1.921-.039.464-.038.746-.11.969-.223a2.4 2.4 0 0 0 1.048-1.048c.113-.223.185-.505.223-.968.038-.47.039-1.072.039-1.922a.6.6 0 1 1 1.2 0v.026c0 .818 0 1.469-.043 1.993-.044.538-.136.996-.35 1.415a3.6 3.6 0 0 1-1.573 1.574c-.42.213-.878.305-1.415.35-.525.042-1.175.042-1.993.042H9.274c-.818 0-1.469 0-1.993-.043-.538-.044-.996-.136-1.415-.35a3.6 3.6 0 0 1-1.574-1.573c-.213-.42-.305-.877-.35-1.415-.042-.524-.042-1.175-.042-1.993V9.274c0-.818 0-1.468.043-1.993.044-.538.136-.996.35-1.415a3.6 3.6 0 0 1 1.573-1.574c.42-.213.877-.305 1.415-.35C7.805 3.9 8.456 3.9 9.274 3.9Zm3.626.6a.6.6 0 0 1 .6-.6h6a.6.6 0 0 1 .6.6v6a.6.6 0 1 1-1.2 0V5.949l-5.976 5.975a.6.6 0 0 1-.848-.848L18.05 5.1H13.5a.6.6 0 0 1-.6-.6Z' fill='%230E0E0E'/%3E%3C/svg%3E");mask-image:url("data:image/svg+xml;charset=utf-8,%3Csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' fill='none'%3E%3Cpath fill-rule='evenodd' clip-rule='evenodd' d='M9.274 3.9H9.3a.6.6 0 0 1 0 1.2c-.85 0-1.451 0-1.922.039-.463.038-.745.11-.968.223A2.4 2.4 0 0 0 5.361 6.41c-.113.223-.184.505-.222.968-.039.47-.04 1.072-.04 1.922v5.4c0 .85.001 1.451.04 1.922.038.463.11.745.222.968a2.4 2.4 0 0 0 1.05 1.048c.222.114.504.185.967.223.47.038 1.072.039 1.922.039h5.4c.85 0 1.451 0 1.921-.039.464-.038.746-.11.969-.223a2.4 2.4 0 0 0 1.048-1.048c.113-.223.185-.505.223-.968.038-.47.039-1.072.039-1.922a.6.6 0 1 1 1.2 0v.026c0 .818 0 1.469-.043 1.993-.044.538-.136.996-.35 1.415a3.6 3.6 0 0 1-1.573 1.574c-.42.213-.878.305-1.415.35-.525.042-1.175.042-1.993.042H9.274c-.818 0-1.469 0-1.993-.043-.538-.044-.996-.136-1.415-.35a3.6 3.6 0 0 1-1.574-1.573c-.213-.42-.305-.877-.35-1.415-.042-.524-.042-1.175-.042-1.993V9.274c0-.818 0-1.468.043-1.993.044-.538.136-.996.35-1.415a3.6 3.6 0 0 1 1.573-1.574c.42-.213.877-.305 1.415-.35C7.805 3.9 8.456 3.9 9.274 3.9Zm3.626.6a.6.6 0 0 1 .6-.6h6a.6.6 0 0 1 .6.6v6a.6.6 0 1 1-1.2 0V5.949l-5.976 5.975a.6.6 0 0 1-.848-.848L18.05 5.1H13.5a.6.6 0 0 1-.6-.6Z' fill='%230E0E0E'/%3E%3C/svg%3E");-webkit-mask-position:center;mask-position:center;-webkit-mask-repeat:no-repeat;mask-repeat:no-repeat;padding:0 .45em}::slotted(svg){vertical-align:middle}}`;

  /**
   * @cssprop --sgds-{stateColor} - State colors in hexadecimal value
   * @cssprop --sgds-{stateColor}-rgb - State colors in rgb value
   * @cssprop --sgds-{stateColor}-{weights} - State colors with different weightage in hexadecimal value
   * @cssprop --sgds-gray-{weights} - State colors with different weightage in hexadecimal value
   * @cssprop --overlay-background-color - The drawer and modal component overlay background color
   * @cssprop --zindex-modal - The drawer and modal component z-index value
   */
  class SgdsElement extends LitElement {
      /** Emits a custom event with more convenient defaults. */
      emit(name, options) {
          const event = new CustomEvent(name, Object.assign({ bubbles: true, cancelable: false, composed: true, detail: {} }, options));
          this.dispatchEvent(event);
          return event;
      }
      static define(name, elementConstructor = this, options = {}) {
          const currentlyRegisteredConstructor = customElements.get(name);
          if (!currentlyRegisteredConstructor) {
              // We try to register as the actual class first. If for some reason that fails, we fall back to anonymous classes.
              // customElements can only have 1 class of the same "object id" per registry, so that is why the try {} catch {} exists.
              // Some tools like Jest Snapshots and if you import the constructor and call `new SgdsButton()` they will fail with
              //   the anonymous class version.
              try {
                  customElements.define(name, elementConstructor, options);
              }
              catch (_err) {
                  customElements.define(name, class extends elementConstructor {
                  }, options);
              }
              return;
          }
          // let newVersion = ' (unknown version)';
          // let existingVersion = newVersion;
          // if ('version' in elementConstructor && elementConstructor.version) {
          //   newVersion = ' v' + elementConstructor.version;
          // }
          // if ('version' in currentlyRegisteredConstructor && currentlyRegisteredConstructor.version) {
          //   existingVersion = ' v' + currentlyRegisteredConstructor.version;
          // }
          // // Need to make sure we're not working with null or empty strings before doing version comparisons.
          // if (newVersion && existingVersion && newVersion === existingVersion) {
          //   // If versions match, we don't need to warn anyone. Carry on.
          //   return;
          // }
          // console.warn(
          //   `Attempted to register <${name}>${newVersion}, but <${name}>${existingVersion} has already been registered.`
          // );
      }
      constructor() {
          super();
          Object.entries(this.constructor.dependencies).forEach(([name, component]) => {
              this.constructor.define(name, component);
          });
      }
  }
  SgdsElement.styles = [css_248z$4];
  /** @internal */
  SgdsElement.dependencies = {};

  function generateId (componentName = "", elementName = "") {
      return `id-${Math.random().toString().substring(2, 6)}-sgds-${componentName}-${elementName}`;
  }

  const ARROW_DOWN$1 = "ArrowDown";
  const ARROW_UP$1 = "ArrowUp";
  const ESC = "Escape";
  /**
   * @event sgds-show - Emitted event when show instance is called
   * @event sgds-after-show - Emitted event when dropdown has been made visible to the user and CSS transitions have completed
   * @event sgds-hide - Emitted event when hide instance is called
   * @event sgds-after-hide - Emitted event when dropdown has hidden to the user and CSS transitions have completed
   */
  class DropdownElement extends SgdsElement {
      constructor() {
          // static styles = SgdsElement.styles;
          super(...arguments);
          /** @internal */
          this.myDropdown = createRef();
          /** @internal */
          this.bsDropdown = null;
          /** @internal Unique id generated for the dropdown menu */
          this.dropdownMenuId = generateId("dropdown-menu", "div");
          /** @internal Controls auto-flipping of menu */
          this.noFlip = false;
          /** @internal When true, aligns right edge of menu with right edge of button */
          this.menuAlignRight = false;
          /** @internal The drop position of menu relative to the toggle button */
          this.drop = "down";
          /**  Additional configuration to pass to Popper.js. See https://popper.js.org/ for config opts */
          this.popperOpts = {};
          /** @internal */
          this.modifierOpt = [];
          /** When true, dropdown menu shows on first load */
          this.menuIsOpen = false;
          /** Controls the close behaviour of dropdown menu. By default menu auto-closes when SgdsDropdownItem or area outside dropdown is clicked */
          this.close = "default";
          /** Disables the dropdown toggle */
          this.disabled = false;
      }
      connectedCallback() {
          super.connectedCallback();
          if (this.close !== "inside") {
              document.addEventListener("click", (event) => this._handleClickOutOfElement(event, this));
          }
      }
      disconnectedCallback() {
          super.disconnectedCallback();
          document.removeEventListener("click", (event) => this._handleClickOutOfElement(event, this));
      }
      firstUpdated() {
          this.bsDropdown = new Dropdown(this.myDropdown.value, {
              // autoClose not working as bootstrap is using attribute data-bs-toggle="dropdown" to configure autoclose. But it doesnt look into this attribute in the shadow dom
              reference: "toggle", // working
              popperConfig: (defaultConfig) => {
                  //working
                  this.dropdownConfig = {
                      placement: "bottom-start",
                      modifiers: !this.noFlip
                          ? this.modifierOpt
                          : [
                              ...this.modifierOpt,
                              {
                                  name: "flip",
                                  options: { fallbackPlacements: [] }
                              }
                          ]
                  };
                  switch (this.drop) {
                      case "up":
                          this.dropdownConfig.placement = this.menuAlignRight ? "top-end" : "top-start";
                          break;
                      case "right":
                          this.dropdownConfig.placement = "right-start";
                          break;
                      case "left":
                          this.dropdownConfig.placement = "left-start";
                          break;
                      case "down":
                          this.dropdownConfig.placement = this.menuAlignRight ? "bottom-end" : "bottom-start";
                          break;
                      default:
                          this.dropdownConfig.placement = undefined;
                          break;
                  }
                  return mergeDeep(defaultConfig, mergeDeep(this.dropdownConfig, this.popperOpts));
              }
          });
          this.myDropdown.value.addEventListener("show.bs.dropdown", () => {
              this.menuIsOpen = true;
              this.emit("sgds-show");
          });
          this.myDropdown.value.addEventListener("shown.bs.dropdown", () => {
              this.menuIsOpen = true;
              this.emit("sgds-after-show");
          });
          this.myDropdown.value.addEventListener("hide.bs.dropdown", () => {
              this.menuIsOpen = false;
              this.emit("sgds-hide");
          });
          this.myDropdown.value.addEventListener("hidden.bs.dropdown", () => {
              this.menuIsOpen = false;
              this.emit("sgds-after-hide");
          });
          this.addEventListener("keydown", this._handleKeyboardMenuEvent);
      }
      /** When invoked, opens the dropdown menu */
      showMenu() {
          this.bsDropdown.show();
      }
      /** When invoked, hides the dropdown menu */
      hideMenu() {
          this.bsDropdown.hide();
      }
      toggleMenu() {
          this.bsDropdown.toggle();
      }
      _handleKeyboardMenuEvent(e) {
          switch (e.key) {
              case ARROW_DOWN$1:
                  e.preventDefault();
                  if (!this.menuIsOpen)
                      return this.showMenu();
                  break;
              case ARROW_UP$1:
                  e.preventDefault();
                  if (!this.menuIsOpen)
                      return this.showMenu();
                  break;
              case ESC:
                  return this.hideMenu();
          }
      }
      _handleClickOutOfElement(e, self) {
          if (!e.composedPath().includes(self)) {
              this.hideMenu();
          }
      }
  }
  __decorate([
      property({ type: Boolean, state: true })
  ], DropdownElement.prototype, "noFlip", void 0);
  __decorate([
      property({ type: Boolean, reflect: true, state: true })
  ], DropdownElement.prototype, "menuAlignRight", void 0);
  __decorate([
      property({ type: String, reflect: true, state: true })
  ], DropdownElement.prototype, "drop", void 0);
  __decorate([
      property({ type: Object })
  ], DropdownElement.prototype, "popperOpts", void 0);
  __decorate([
      state()
  ], DropdownElement.prototype, "dropdownConfig", void 0);
  __decorate([
      property()
  ], DropdownElement.prototype, "modifierOpt", void 0);
  __decorate([
      property({ type: Boolean, reflect: true })
  ], DropdownElement.prototype, "menuIsOpen", void 0);
  __decorate([
      property({ type: Boolean, reflect: true })
  ], DropdownElement.prototype, "disabled", void 0);

  const TAB = "Tab";
  const ARROW_DOWN = "ArrowDown";
  const ARROW_UP = "ArrowUp";
  const ENTER = "Enter";
  /**
   * @event sgds-select - Emitted event when a slot item is selected
   */
  class DropdownListElement extends DropdownElement {
      constructor() {
          super(...arguments);
          /** @internal */
          this.nextDropdownItemNo = 0;
          /** @internal */
          this.prevDropdownItemNo = -1;
      }
      connectedCallback() {
          super.connectedCallback();
          this.addEventListener("sgds-hide", this._resetMenu);
      }
      disconnectedCallback() {
          super.disconnectedCallback();
          this.removeEventListener("sgds-hide", this._resetMenu);
      }
      firstUpdated() {
          super.firstUpdated();
          this.addEventListener("keydown", this._handleKeyboardMenuItemsEvent);
      }
      handleSelectSlot(e) {
          const items = this._getActiveMenuItems();
          const currentItemNo = items.indexOf(e.target);
          this.nextDropdownItemNo = currentItemNo + 1;
          this.prevDropdownItemNo = currentItemNo <= 0 ? items.length - 1 : currentItemNo - 1;
          /** Emitted event from SgdsDropdown element when a slot item is selected */
          const selectedItem = e.target;
          if (!selectedItem.disabled) {
              this.emit("sgds-select");
              this.close !== "outside" && this.bsDropdown.hide();
          }
          else
              return;
      }
      _resetMenu() {
          this.nextDropdownItemNo = 0;
          this.prevDropdownItemNo = -1;
          // reset the tabindex
          const items = this._getMenuItems();
          items.forEach(item => {
              const dropdownItem = item.shadowRoot.querySelector(".dropdown-item");
              dropdownItem.removeAttribute("tabindex");
          });
      }
      _handleKeyboardMenuItemsEvent(e) {
          const menuItems = this._getActiveMenuItems();
          switch (e.key) {
              case ARROW_DOWN:
                  e.preventDefault();
                  if (this.nextDropdownItemNo === menuItems.length) {
                      return this._setMenuItem(0);
                  }
                  else {
                      return this._setMenuItem(this.nextDropdownItemNo > 0 ? this.nextDropdownItemNo : 0);
                  }
              case ARROW_UP:
                  e.preventDefault();
                  if (this.prevDropdownItemNo < 0) {
                      return this._setMenuItem(menuItems.length - 1, false);
                  }
                  else {
                      return this._setMenuItem(this.prevDropdownItemNo, false);
                  }
              case TAB:
                  if (!this.menuIsOpen) {
                      return;
                  }
                  e.preventDefault();
                  if (e.shiftKey) {
                      if (this.prevDropdownItemNo < 0) {
                          return this._setMenuItem(menuItems.length - 1, false);
                      }
                      else {
                          return this._setMenuItem(this.prevDropdownItemNo, false);
                      }
                  }
                  if (this.nextDropdownItemNo === menuItems.length) {
                      return this._setMenuItem(0);
                  }
                  else {
                      return this._setMenuItem(this.nextDropdownItemNo > 0 ? this.nextDropdownItemNo : 0);
                  }
              case ENTER:
                  if (menuItems.includes(e.target)) {
                      return this.handleSelectSlot(e);
                  }
                  break;
          }
      }
      _getMenuItems() {
          var _a;
          // for case when default slot is used e.g. dropdown, mainnavdropdown
          if (this.shadowRoot.querySelector("slot#default")) {
              return (_a = this.shadowRoot.querySelector("slot#default")) === null || _a === void 0 ? void 0 : _a.assignedElements({
                  flatten: true
              });
          }
          // for case when there is no slot e.g. combobox
          if (this.menu.hasChildNodes()) {
              const menuItems = this.menu.children;
              return [...menuItems];
          }
      }
      _getActiveMenuItems() {
          return this._getMenuItems().filter(item => !item.disabled);
      }
      _setMenuItem(currentItemIdx, isArrowDown = true) {
          const items = this._getActiveMenuItems();
          if (items.length === 0)
              return;
          const item = items[currentItemIdx];
          this.nextDropdownItemNo = currentItemIdx + 1;
          this.prevDropdownItemNo = currentItemIdx - 1 < 0 ? items.length - 1 : currentItemIdx - 1;
          let activeItem;
          if (item.disabled) {
              return this._setMenuItem(isArrowDown ? this.nextDropdownItemNo : this.prevDropdownItemNo);
          }
          else
              activeItem = item;
          // focus or blur items depending on active or not
          items.forEach(item => {
              const dropdownItem = item.shadowRoot.querySelector(".dropdown-item");
              dropdownItem.setAttribute("tabindex", item === activeItem ? "0" : "-1");
              item === activeItem && dropdownItem.focus();
          });
      }
  }
  DropdownListElement.styles = DropdownElement.styles;
  __decorate([
      query("ul.dropdown-menu")
  ], DropdownListElement.prototype, "menu", void 0);
  __decorate([
      state()
  ], DropdownListElement.prototype, "nextDropdownItemNo", void 0);
  __decorate([
      state()
  ], DropdownListElement.prototype, "prevDropdownItemNo", void 0);

  // @watch decorator
  //
  // Runs when an observed property changes, e.g. @property or @state, but before the component updates.
  //
  // To wait for an update to complete after a change occurs, use `await this.updateComplete` in the handler. To start
  // watching after the initial update/render, use `{ waitUntilFirstUpdate: true }` or `this.hasUpdated` in the handler.
  //
  // Usage:
  //
  //  @watch('propName')
  //  handlePropChange(oldValue, newValue) {
  //    ...
  //  }
  function watch(propName, options) {
      const resolvedOptions = Object.assign({ waitUntilFirstUpdate: false }, options);
      return (proto, decoratedFnName) => {
          // @ts-expect-error -- update is a protected property
          const { update } = proto;
          if (propName in proto) {
              const propNameKey = propName;
              // @ts-expect-error -- update is a protected property
              proto.update = function (changedProps) {
                  if (changedProps.has(propNameKey)) {
                      const oldValue = changedProps.get(propNameKey);
                      const newValue = this[propNameKey];
                      if (oldValue !== newValue) {
                          if (!resolvedOptions.waitUntilFirstUpdate || this.hasUpdated) {
                              this[decoratedFnName](oldValue, newValue);
                          }
                      }
                  }
                  update.call(this, changedProps);
              };
          }
      };
  }

  var css_248z$3 = css`.dropdown-menu{background-clip:padding-box;background-color:var(--sgds-surface-default);border-radius:var(--sgds-border-radius-md);box-shadow:0 0 1px 0 hsla(0,0%,5%,.12),0 4px 8px 0 hsla(0,0%,5%,.12);color:var(--sgds-color-default);display:none;list-style:none;margin:0;min-width:var(--sgds-dimension-280);overflow-y:auto;padding:var(--sgds-padding-xs) 0;position:absolute;text-align:left;z-index:1000}.dropdown .dropdown-menu{max-height:var(--sgds-dimension-192)}.dropdown-menu.show{display:block}.nav-tabs .dropdown-menu{border-top-left-radius:0;border-top-right-radius:0;margin-top:calc(var(--sgds-nav-tabs-border-width)*-1)}@media (min-width:576px){.navbar-expand-sm .navbar-nav .dropdown-menu{position:absolute}}@media (min-width:768px){.navbar-expand-md .navbar-nav .dropdown-menu{position:absolute}}@media (min-width:992px){.navbar-expand-lg .navbar-nav .dropdown-menu{position:absolute}}@media (min-width:1200px){.navbar-expand-xl .navbar-nav .dropdown-menu{position:absolute}}@media (min-width:1400px){.navbar-expand-xxl .navbar-nav .dropdown-menu{position:absolute}}.navbar-expand .navbar-nav .dropdown-menu{position:absolute}.sgds.navbar .dropdown-menu.megamenu{left:0;right:0;width:100%}.sgds.combobox>.dropdown-menu{min-width:100%}`;

  var css_248z$2 = css`:host{position:relative}.dropdown{display:flex;height:100%}`;

  /**
   * @summary `SgdsDropdown` toggles contextual overlays for displaying lists of links.
   * @slot default - slot for sgds-dropdown-item passed into dropdown's menu
   * @slot toggler - slot for the toggler that triggers the open and closing of menu, typically a button. Only pass in a single element into this slot
   *
   */
  class SgdsDropdown extends DropdownListElement {
      constructor() {
          super();
          /** Controls auto-flipping of menu */
          this.noFlip = false;
          /** When true, aligns right edge of menu with right edge of button */
          this.menuAlignRight = false;
          /** The drop position of menu relative to the toggle button */
          this.drop = "down";
          /**@internal */
          this.modifierOpt = [
              {
                  name: "offset",
                  options: {
                      offset: [0, 8]
                  }
              }
          ];
      }
      _handleCloseMenu() {
          const button = this._toggler[0];
          button.focus();
      }
      _handleClick() {
          if (this.disabled) {
              return;
          }
          this.toggleMenu();
      }
      async connectedCallback() {
          super.connectedCallback();
          this.addEventListener("sgds-hide", this._handleCloseMenu);
      }
      async disconnectedCallback() {
          this.removeEventListener("sgds-hide", this._handleCloseMenu);
      }
      async firstUpdated() {
          super.firstUpdated();
          if (this.menuIsOpen) {
              this.showMenu();
          }
          this._handleDisabled();
      }
      _handleDisabled() {
          const button = this._toggler[0];
          if (this.disabled) {
              button.setAttribute("disabled", "true");
          }
          else {
              button.hasAttribute("disabled") && button.removeAttribute("disabled");
          }
      }
      render() {
          return html$1 `
      <div class="dropdown">
        <div
          class="toggler-container"
          ${ref(this.myDropdown)}
          @click=${this._handleClick}
          aria-expanded="${this.menuIsOpen}"
          aria-haspopup="menu"
        >
          <slot name="toggler"></slot>
        </div>
        <div class="dropdown-menu" role="menu">
          <slot id="default" @click=${this.handleSelectSlot}></slot>
        </div>
      </div>
    `;
      }
  }
  SgdsDropdown.styles = [...DropdownListElement.styles, css_248z$2, css_248z$3];
  __decorate([
      property({ type: Boolean, reflect: true, state: false })
  ], SgdsDropdown.prototype, "noFlip", void 0);
  __decorate([
      property({ type: Boolean, reflect: true, state: false })
  ], SgdsDropdown.prototype, "menuAlignRight", void 0);
  __decorate([
      property({ type: String, reflect: true, state: false })
  ], SgdsDropdown.prototype, "drop", void 0);
  __decorate([
      queryAssignedElements({ slot: "toggler", flatten: true })
  ], SgdsDropdown.prototype, "_toggler", void 0);
  __decorate([
      watch("disabled", { waitUntilFirstUpdate: true })
  ], SgdsDropdown.prototype, "_handleDisabled", null);

  /**
   * @license
   * Copyright 2018 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  class ClassMapDirective extends Directive {
      constructor(partInfo) {
          super(partInfo);
          if (partInfo.type !== PartType.ATTRIBUTE ||
              partInfo.name !== 'class' ||
              partInfo.strings?.length > 2) {
              throw new Error('`classMap()` can only be used in the `class` attribute ' +
                  'and must be the only part in the attribute.');
          }
      }
      render(classInfo) {
          // Add spaces to ensure separation from static classes
          return (' ' +
              Object.keys(classInfo)
                  .filter((key) => classInfo[key])
                  .join(' ') +
              ' ');
      }
      update(part, [classInfo]) {
          // Remember dynamic classes on the first render
          if (this._previousClasses === undefined) {
              this._previousClasses = new Set();
              if (part.strings !== undefined) {
                  this._staticClasses = new Set(part.strings
                      .join(' ')
                      .split(/\s/)
                      .filter((s) => s !== ''));
              }
              for (const name in classInfo) {
                  if (classInfo[name] && !this._staticClasses?.has(name)) {
                      this._previousClasses.add(name);
                  }
              }
              return this.render(classInfo);
          }
          const classList = part.element.classList;
          // Remove old classes that no longer apply
          for (const name of this._previousClasses) {
              if (!(name in classInfo)) {
                  classList.remove(name);
                  this._previousClasses.delete(name);
              }
          }
          // Add or remove classes based on their classMap value
          for (const name in classInfo) {
              // We explicitly want a loose truthy check of `value` because it seems
              // more convenient that '' and 0 are skipped.
              const value = !!classInfo[name];
              if (value !== this._previousClasses.has(name) &&
                  !this._staticClasses?.has(name)) {
                  if (value) {
                      classList.add(name);
                      this._previousClasses.add(name);
                  }
                  else {
                      classList.remove(name);
                      this._previousClasses.delete(name);
                  }
              }
          }
          return noChange;
      }
  }
  /**
   * A directive that applies dynamic CSS classes.
   *
   * This must be used in the `class` attribute and must be the only part used in
   * the attribute. It takes each property in the `classInfo` argument and adds
   * the property name to the element's `classList` if the property value is
   * truthy; if the property value is falsy, the property name is removed from
   * the element's `class`.
   *
   * For example `{foo: bar}` applies the class `foo` if the value of `bar` is
   * truthy.
   *
   * @param classInfo
   */
  const classMap = directive(ClassMapDirective);

  /**
   * @license
   * Copyright 2020 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  /**
   * Prevents JSON injection attacks.
   *
   * The goals of this brand:
   *   1) fast to check
   *   2) code is small on the wire
   *   3) multiple versions of Lit in a single page will all produce mutually
   *      interoperable StaticValues
   *   4) normal JSON.parse (without an unusual reviver) can not produce a
   *      StaticValue
   *
   * Symbols satisfy (1), (2), and (4). We use Symbol.for to satisfy (3), but
   * we don't care about the key, so we break ties via (2) and use the empty
   * string.
   */
  const brand = Symbol.for('');
  /** Safely extracts the string part of a StaticValue. */
  const unwrapStaticValue = (value) => {
      if (value?.r !== brand) {
          return undefined;
      }
      return value?.['_$litStatic$'];
  };
  const stringsCache = new Map();
  /**
   * Wraps a lit-html template tag (`html` or `svg`) to add static value support.
   */
  const withStatic = (coreTag) => (strings, ...values) => {
      const l = values.length;
      let staticValue;
      let dynamicValue;
      const staticStrings = [];
      const dynamicValues = [];
      let i = 0;
      let hasStatics = false;
      let s;
      while (i < l) {
          s = strings[i];
          // Collect any unsafeStatic values, and their following template strings
          // so that we treat a run of template strings and unsafe static values as
          // a single template string.
          while (i < l &&
              ((dynamicValue = values[i]),
                  (staticValue = unwrapStaticValue(dynamicValue))) !== undefined) {
              s += staticValue + strings[++i];
              hasStatics = true;
          }
          // If the last value is static, we don't need to push it.
          if (i !== l) {
              dynamicValues.push(dynamicValue);
          }
          staticStrings.push(s);
          i++;
      }
      // If the last value isn't static (which would have consumed the last
      // string), then we need to add the last string.
      if (i === l) {
          staticStrings.push(strings[l]);
      }
      if (hasStatics) {
          const key = staticStrings.join('$$lit$$');
          strings = stringsCache.get(key);
          if (strings === undefined) {
              // Beware: in general this pattern is unsafe, and doing so may bypass
              // lit's security checks and allow an attacker to execute arbitrary
              // code and inject arbitrary content.
              // eslint-disable-next-line @typescript-eslint/no-explicit-any
              staticStrings.raw = staticStrings;
              stringsCache.set(key, (strings = staticStrings));
          }
          values = dynamicValues;
      }
      return coreTag(strings, ...values);
  };
  /**
   * Interprets a template literal as an HTML template that can efficiently
   * render to and update a container.
   *
   * Includes static value support from `lit-html/static.js`.
   */
  const html = withStatic(html$1);

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  const HTML_RESULT = 1;
  class UnsafeHTMLDirective extends Directive {
      constructor(partInfo) {
          super(partInfo);
          this._value = nothing;
          if (partInfo.type !== PartType.CHILD) {
              throw new Error(`${this.constructor.directiveName}() can only be used in child bindings`);
          }
      }
      render(value) {
          if (value === nothing || value == null) {
              this._templateResult = undefined;
              return (this._value = value);
          }
          if (value === noChange) {
              return value;
          }
          if (typeof value != 'string') {
              throw new Error(`${this.constructor.directiveName}() called with a non-string value`);
          }
          if (value === this._value) {
              return this._templateResult;
          }
          this._value = value;
          const strings = [value];
          // eslint-disable-next-line @typescript-eslint/no-explicit-any
          strings.raw = strings;
          // WARNING: impersonating a TemplateResult like this is extremely
          // dangerous. Third-party directives should not do this.
          return (this._templateResult = {
              // Cast to a known set of integers that satisfy ResultType so that we
              // don't have to export ResultType and possibly encourage this pattern.
              // This property needs to remain unminified.
              ['_$litType$']: this.constructor
                  .resultType,
              strings,
              values: [],
          });
      }
  }
  UnsafeHTMLDirective.directiveName = 'unsafeHTML';
  UnsafeHTMLDirective.resultType = HTML_RESULT;

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  const SVG_RESULT = 2;
  class UnsafeSVGDirective extends UnsafeHTMLDirective {
  }
  UnsafeSVGDirective.directiveName = 'unsafeSVG';
  UnsafeSVGDirective.resultType = SVG_RESULT;
  /**
   * Renders the result as SVG, rather than text.
   *
   * The values `undefined`, `null`, and `nothing`, will all result in no content
   * (empty string) being rendered.
   *
   * Note, this is unsafe to use with any user-provided input that hasn't been
   * sanitized or escaped, as it may lead to cross-site-scripting
   * vulnerabilities.
   */
  const unsafeSVG = directive(UnsafeSVGDirective);

  var css_248z$1 = css`:host{color:inherit;display:inline-flex}:host([size=sm]) svg{height:var(--sgds-icon-size-sm);width:var(--sgds-icon-size-sm)}:host([size=md]) svg{height:var(--sgds-icon-size-md);width:var(--sgds-icon-size-md)}:host([size=xl]) svg{height:var(--sgds-icon-size-xl);width:var(--sgds-icon-size-xl)}:host([size="2-xl"]) svg{height:var(--sgds-icon-size-2-xl);width:var(--sgds-icon-size-2-xl)}:host([size="3-xl"]) svg{height:var(--sgds-icon-size-3-xl);width:var(--sgds-icon-size-3-xl)}svg{display:inline-block;height:var(--sgds-icon-size-lg);width:var(--sgds-icon-size-lg)}`;

  /**
   * @summary Icons offer a form of visual shorthand that we are all familiar with. They can label, inform and aid navigation quickly and effectively in minimal space. Icons must first and foremost communicate meaning. By default, the icon component renders icons from `SgdsIcon` library set
   */
  class SgdsIcon extends SgdsElement {
      constructor() {
          super(...arguments);
          /** Specifies a small, medium or large icon, the size is medium by default. */
          this.size = "lg";
          /** @internal */
          this._svgContent = null;
      }
      async updated(changedProperties) {
          if (changedProperties.has("name")) {
              await this._loadSvg(this.name);
          }
      }
      async _loadSvg(name) {
          if (name) {
              const pascalName = name
                  .split("-")
                  .map(name => String(name).charAt(0).toUpperCase() + String(name).slice(1))
                  .join("");
              try {
                  const iconRegistry$1 = await Promise.resolve().then(function () { return iconRegistry; });
                  const svg = iconRegistry$1[pascalName];
                  if (svg) {
                      this._svgContent = svg;
                  }
                  else {
                      throw new Error("icon `name` not found");
                  }
              }
              catch (error) {
                  console.error(`Unable to load icon: ${name}.`, error);
              }
          }
      }
      render() {
          return html `${unsafeSVG(this._svgContent)}`;
      }
  }
  SgdsIcon.styles = [...SgdsElement.styles, css_248z$1];
  __decorate([
      property({ type: String, reflect: true })
  ], SgdsIcon.prototype, "name", void 0);
  __decorate([
      property({ type: String, reflect: true })
  ], SgdsIcon.prototype, "size", void 0);
  __decorate([
      state()
  ], SgdsIcon.prototype, "_svgContent", void 0);

  var css_248z = css`.dropdown-item{align-items:center;background-color:var(--sgds-bg-transparent);clear:both;color:var(--sgds-color-default);cursor:pointer;display:flex;gap:var(--sgds-gap-sm);padding:var(--sgds-padding-sm) var(--sgds-padding-lg);text-align:inherit;white-space:nowrap}.dropdown-item:not(.nav-link):hover{background-color:var(--sgds-bg-translucent-subtle)}.dropdown-item:not(.nav-link):focus,.dropdown-item:not(.nav-link):focus-visible{background-color:var(--sgds-bg-translucent-subtle);box-shadow:inset var(--sgds-form-box-shadow-focus);outline:0}.dropdown-item:not(.nav-link).active{background-color:var(--sgds-bg-translucent-subtle);color:var(--sgds-primary-color-default);text-decoration:none}.dropdown-item.disabled,.dropdown-item:disabled{opacity:var(--sgds-opacity-50);pointer-events:none}::slotted(*){color:inherit!important;display:flex;gap:var(--sgds-gap-sm);text-decoration:none!important}.nav-link{gap:var(--sgds-gap-xs);padding:var(--sgds-padding-sm) var(--sgds-mainnav-padding-x)}.nav-link:hover{color:var(--sgds-primary-color-default)}.nav-link:focus,.nav-link:focus-visible{outline:0}.nav-link:focus-visible{box-shadow:var(--sgds-box-shadow-focus) inset;color:var(--sgds-primary-color-default)}.nav-link.active{background-color:var(--sgds-bg-translucent-subtle);color:var(--sgds-primary-color-default)}`;

  /**
   * @summary `SgdsDropdownItem` are navigation links built with `HTMLAnchorElement`. It should be used in the default slot of `SgdsDropdown`
   * @slot default - The default slot for SgdsDropdownItem. Pass in a single anchor tag per dropdown item directly for navigation items.
   */
  class SgdsDropdownItem extends SgdsElement {
      constructor() {
          super(...arguments);
          /** when true, sets the active stylings of .nav-link */
          this.active = false;
          /** Disables the SgdsMainnavItem */
          this.disabled = false;
      }
      connectedCallback() {
          super.connectedCallback();
          this.addEventListener("keydown", (e) => {
              if (e.key === "Enter") {
                  this.anchor[0].click();
              }
          });
          this.setAttribute("role", "menuitem");
          this.setAttribute("aria-disabled", `${this.disabled}`);
      }
      render() {
          return html$1 `
      <div
        class="dropdown-item ${classMap({
            disabled: this.disabled,
            active: this.active
        })}"
        tabindex=${this.disabled ? "-1" : "0"}
      >
        <slot></slot>
      </div>
    `;
      }
  }
  SgdsDropdownItem.styles = [css_248z$2, css_248z];
  SgdsDropdownItem.dependencies = {
      "sgds-icon": SgdsIcon
  };
  __decorate([
      queryAssignedElements({ flatten: true })
  ], SgdsDropdownItem.prototype, "anchor", void 0);
  __decorate([
      property({ type: Boolean })
  ], SgdsDropdownItem.prototype, "active", void 0);
  __decorate([
      property({ type: Boolean, reflect: true })
  ], SgdsDropdownItem.prototype, "disabled", void 0);

  /**
   *
   * @param name tagname of custom element
   * @returns boolean
   */
  function register(name, constructor) {
      if (!customElements.get(name)) {
          customElements.define(name, constructor);
      }
  }

  register("sgds-dropdown", SgdsDropdown);
  register("sgds-dropdown-item", SgdsDropdownItem);

  const Archive = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M9.375 12.5c0-.345.28-.625.625-.625h4a.625.625 0 1 1 0 1.25h-4a.625.625 0 0 1-.625-.625Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M4.934 2.875h14.132c.4 0 .691 0 .946.05a2.625 2.625 0 0 1 2.063 2.063c.05.255.05.546.05.946v.132c0 .4 0 .691-.05.946a2.625 2.625 0 0 1-1.95 2.038v6.677c0 .817 0 1.468-.043 1.994-.044.54-.136 1.001-.352 1.425a3.625 3.625 0 0 1-1.584 1.584c-.424.216-.886.308-1.425.352-.526.043-1.177.043-1.994.043H9.273c-.817 0-1.468 0-1.994-.043-.54-.044-1.001-.136-1.425-.352a3.625 3.625 0 0 1-1.584-1.584c-.216-.424-.308-.886-.352-1.425-.043-.526-.043-1.177-.043-1.994V9.05a2.625 2.625 0 0 1-1.95-2.038c-.05-.255-.05-.546-.05-.946v-.132c0-.4 0-.691.05-.946a2.625 2.625 0 0 1 2.063-2.063c.255-.05.546-.05.946-.05Zm.191 6.25V15.7c0 .85 0 1.45.039 1.92.038.461.109.74.22.958.228.447.59.81 1.038 1.038.218.111.497.183.959.22.468.039 1.069.039 1.919.039h5.4c.85 0 1.45 0 1.92-.039.461-.037.74-.109.958-.22.447-.228.81-.59 1.038-1.038.111-.218.183-.497.22-.959.039-.468.039-1.069.039-1.919V9.125H5.125Zm14.31-1.25H4.565a.636.636 0 0 0-.049-.003 1.712 1.712 0 0 1-.284-.023 1.375 1.375 0 0 1-1.08-1.08c-.024-.118-.027-.274-.027-.769s.003-.65.026-.768a1.375 1.375 0 0 1 1.08-1.08c.118-.024.274-.027.769-.027h14c.495 0 .65.003.768.026.546.109.972.535 1.08 1.08.024.118.027.274.027.769s-.003.65-.026.768a1.375 1.375 0 0 1-1.08 1.08 1.61 1.61 0 0 1-.285.024.634.634 0 0 0-.05.003Z" clip-rule="evenodd"/>
</svg>`;
  const ArrowBarDown = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M2.5 3.9a.6.6 0 0 0 0 1.2h19a.6.6 0 1 0 0-1.2h-19Zm10.1 5.6a.6.6 0 1 0-1.2 0v8.552l-3.976-3.976a.6.6 0 1 0-.848.848l5 5a.6.6 0 0 0 .848 0l5-5a.6.6 0 1 0-.848-.848L12.6 18.052V9.5Z"/>
</svg>`;
  const ArrowBarLeft = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M20.1 2.5a.6.6 0 1 0-1.2 0v19a.6.6 0 1 0 1.2 0v-19Zm-5.6 10.1a.6.6 0 1 0 0-1.2H5.948l3.976-3.976a.6.6 0 1 0-.848-.848l-5 5a.6.6 0 0 0 0 .848l5 5a.6.6 0 0 0 .848-.848L5.948 12.6H14.5Z"/>
</svg>`;
  const ArrowBarRight = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M3.9 21.5a.6.6 0 1 0 1.2 0v-19a.6.6 0 1 0-1.2 0v19Zm5.6-10.1a.6.6 0 0 0 0 1.2h8.551l-3.975 3.976a.6.6 0 1 0 .848.848l5-5a.6.6 0 0 0 0-.848l-5-5a.6.6 0 0 0-.848.848L18.05 11.4H9.5Z"/>
</svg>`;
  const ArrowBarUp = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M21.5 20.1a.6.6 0 1 0 0-1.2h-19a.6.6 0 0 0 0 1.2h19Zm-10.1-5.6a.6.6 0 1 0 1.2 0V5.949l3.976 3.975a.6.6 0 0 0 .848-.848l-5-5a.6.6 0 0 0-.848 0l-5 5a.6.6 0 1 0 .848.848L11.4 5.95v8.55Z"/>
</svg>`;
  const ArrowCircleDown = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M11.9 7.575c.345 0 .625.28.625.625v6.091l2.733-2.733a.625.625 0 1 1 .884.884l-3.8 3.8a.625.625 0 0 1-.884 0l-3.8-3.8a.625.625 0 1 1 .884-.884l2.733 2.733V8.2c0-.345.28-.625.625-.625Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M1.775 12c0-5.592 4.533-10.125 10.125-10.125S22.025 6.408 22.025 12 17.492 22.125 11.9 22.125 1.775 17.592 1.775 12ZM11.9 3.125a8.875 8.875 0 1 0 0 17.75 8.875 8.875 0 0 0 0-17.75Z" clip-rule="evenodd"/>
</svg>`;
  const ArrowCircleLeft = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M12.442 7.758a.625.625 0 0 1 0 .884l-2.733 2.733H15.8a.625.625 0 1 1 0 1.25H9.709l2.733 2.733a.625.625 0 1 1-.884.884l-3.8-3.8a.625.625 0 0 1 0-.884l3.8-3.8a.625.625 0 0 1 .884 0Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M1.875 12C1.875 6.408 6.408 1.875 12 1.875S22.125 6.408 22.125 12 17.592 22.125 12 22.125 1.875 17.592 1.875 12ZM12 3.125a8.875 8.875 0 1 0 0 17.75 8.875 8.875 0 0 0 0-17.75Z" clip-rule="evenodd"/>
</svg>`;
  const ArrowCircleRight = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M11.558 8.642a.625.625 0 1 1 .884-.884l3.8 3.8a.625.625 0 0 1 0 .884l-3.8 3.8a.625.625 0 1 1-.884-.884l2.733-2.733H8.2a.625.625 0 1 1 0-1.25h6.091l-2.733-2.733Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M1.875 12C1.875 6.408 6.408 1.875 12 1.875S22.125 6.408 22.125 12 17.592 22.125 12 22.125 1.875 17.592 1.875 12ZM12 3.125a8.875 8.875 0 1 0 0 17.75 8.875 8.875 0 0 0 0-17.75Z" clip-rule="evenodd"/>
</svg>`;
  const ArrowCircleUp = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="m7.758 11.558 3.8-3.8a.625.625 0 0 1 .884 0l3.8 3.8a.625.625 0 1 1-.884.884l-2.733-2.733V15.8a.625.625 0 1 1-1.25 0V9.709l-2.733 2.733a.625.625 0 1 1-.884-.884Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M1.875 12C1.875 6.408 6.408 1.875 12 1.875S22.125 6.408 22.125 12 17.592 22.125 12 22.125 1.875 17.592 1.875 12ZM12 3.125a8.875 8.875 0 1 0 0 17.75 8.875 8.875 0 0 0 0-17.75Z" clip-rule="evenodd"/>
</svg>`;
  const ArrowClockwise = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M10.695 2.396a.6.6 0 0 1 .848 0l1.765 1.765a.6.6 0 0 1 0 .848l-1.765 1.765a.6.6 0 1 1-.848-.848l.811-.812a6.902 6.902 0 1 0 4.555 1.302.6.6 0 1 1 .706-.97 8.102 8.102 0 1 1-5.396-1.525l-.676-.677a.6.6 0 0 1 0-.848Z" clip-rule="evenodd"/>
</svg>`;
  const ArrowDown = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M12 3.4a.6.6 0 0 1 .6.6v14.552l4.976-4.976a.6.6 0 0 1 .848.848l-6 6a.6.6 0 0 1-.848 0l-6-6a.6.6 0 0 1 .848-.848l4.976 4.976V4a.6.6 0 0 1 .6-.6Z" clip-rule="evenodd"/>
</svg>`;
  const ArrowLeft = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M10.424 5.576a.6.6 0 0 1 0 .848L5.448 11.4H20a.6.6 0 1 1 0 1.2H5.448l4.976 4.976a.6.6 0 0 1-.848.848l-6-6a.6.6 0 0 1 0-.848l6-6a.6.6 0 0 1 .848 0Z" clip-rule="evenodd"/>
</svg>`;
  const ArrowRepeat = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M17.708 8.13a6.891 6.891 0 0 0-9.155-2.106 6.89 6.89 0 0 0-3.41 5.251.6.6 0 1 1-1.193-.127 8.09 8.09 0 0 1 4.003-6.163 8.091 8.091 0 0 1 10.72 2.43l.248-.923a.6.6 0 1 1 1.159.31l-.646 2.411a.6.6 0 0 1-.735.425l-2.409-.646a.6.6 0 1 1 .311-1.16l1.107.297Zm1.808 4.061a.6.6 0 0 1 .534.66 8.09 8.09 0 0 1-4.003 6.164 8.091 8.091 0 0 1-10.72-2.43l-.247.922a.6.6 0 1 1-1.16-.31l.646-2.41a.6.6 0 0 1 .735-.425l2.409.646a.6.6 0 1 1-.311 1.159l-1.107-.297a6.891 6.891 0 0 0 9.155 2.106 6.89 6.89 0 0 0 3.41-5.252.6.6 0 0 1 .66-.533Z" clip-rule="evenodd"/>
</svg>`;
  const ArrowRight = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M13.576 5.576a.6.6 0 0 1 .848 0l6 6a.6.6 0 0 1 0 .848l-6 6a.6.6 0 0 1-.848-.848L18.55 12.6H4a.6.6 0 1 1 0-1.2h14.55l-4.975-4.976a.6.6 0 0 1 0-.848Z" clip-rule="evenodd"/>
</svg>`;
  const ArrowSquareDown = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M12 7.597c.345 0 .625.28.625.625v6.047l2.71-2.71a.625.625 0 0 1 .885.883l-3.778 3.778a.625.625 0 0 1-.884 0L7.78 12.442a.625.625 0 1 1 .884-.884l2.711 2.71V8.223c0-.345.28-.625.625-.625Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M8.006 2.875h7.988c.77 0 1.387 0 1.884.04.512.042.953.13 1.359.337.65.332 1.18.86 1.511 1.511.207.406.295.847.336 1.359.041.498.041 1.114.041 1.884v7.988c0 .77 0 1.387-.04 1.884-.042.512-.13.953-.337 1.359a3.46 3.46 0 0 1-1.511 1.511c-.406.207-.847.295-1.358.336-.498.041-1.115.041-1.885.041H8.006c-.77 0-1.386 0-1.884-.04-.512-.042-.953-.13-1.359-.337a3.459 3.459 0 0 1-1.511-1.511c-.207-.406-.295-.847-.336-1.358-.041-.498-.041-1.115-.041-1.885V8.006c0-.77 0-1.386.04-1.884.042-.512.13-.953.337-1.359.332-.65.86-1.18 1.511-1.511.406-.207.847-.295 1.359-.336.498-.041 1.114-.041 1.884-.041ZM6.223 4.162c-.434.035-.692.102-.892.204a2.2 2.2 0 0 0-.965.965c-.102.2-.169.458-.204.892-.037.441-.037 1.007-.037 1.81v7.934c0 .803 0 1.369.037 1.81.035.433.102.692.204.892a2.2 2.2 0 0 0 .965.965c.2.102.458.169.892.204.441.037 1.007.037 1.81.037h7.934c.803 0 1.369 0 1.81-.037.433-.035.692-.102.892-.204a2.2 2.2 0 0 0 .965-.965c.102-.2.169-.459.204-.892.037-.441.037-1.007.037-1.81V8.033c0-.803 0-1.369-.037-1.81-.035-.434-.102-.692-.204-.892a2.208 2.208 0 0 0-.965-.965c-.2-.102-.459-.169-.892-.204-.441-.037-1.007-.037-1.81-.037H8.033c-.803 0-1.369 0-1.81.037Z" clip-rule="evenodd"/>
</svg>`;
  const ArrowSquareLeft = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M12.442 7.78a.625.625 0 0 1 0 .884l-2.71 2.711h6.046a.625.625 0 1 1 0 1.25H9.73l2.71 2.71a.625.625 0 0 1-.883.885L7.78 12.442a.625.625 0 0 1 0-.884l3.778-3.778a.625.625 0 0 1 .884 0Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M8.006 2.875h7.988c.77 0 1.387 0 1.884.04.512.042.953.13 1.359.337.65.332 1.18.86 1.511 1.511.207.406.295.847.336 1.359.041.498.041 1.114.041 1.884v7.988c0 .77 0 1.387-.04 1.884-.042.512-.13.953-.337 1.359a3.46 3.46 0 0 1-1.511 1.511c-.406.207-.847.295-1.358.336-.498.041-1.115.041-1.885.041H8.006c-.77 0-1.386 0-1.884-.04-.512-.042-.953-.13-1.359-.337a3.459 3.459 0 0 1-1.511-1.511c-.207-.406-.295-.847-.336-1.358-.041-.498-.041-1.115-.041-1.885V8.006c0-.77 0-1.386.04-1.884.042-.512.13-.953.337-1.359.332-.65.86-1.18 1.511-1.511.406-.207.847-.295 1.359-.336.498-.041 1.114-.041 1.884-.041ZM6.223 4.162c-.434.035-.692.102-.892.204a2.2 2.2 0 0 0-.965.965c-.102.2-.169.458-.204.892-.037.441-.037 1.007-.037 1.81v7.934c0 .803 0 1.369.037 1.81.035.433.102.692.204.892a2.2 2.2 0 0 0 .965.965c.2.102.458.169.892.204.441.037 1.007.037 1.81.037h7.934c.803 0 1.369 0 1.81-.037.433-.035.692-.102.892-.204a2.2 2.2 0 0 0 .965-.965c.102-.2.169-.459.204-.892.037-.441.037-1.007.037-1.81V8.033c0-.803 0-1.369-.037-1.81-.035-.434-.102-.692-.204-.892a2.208 2.208 0 0 0-.965-.965c-.2-.102-.459-.169-.892-.204-.441-.037-1.007-.037-1.81-.037H8.033c-.803 0-1.369 0-1.81.037Z" clip-rule="evenodd"/>
</svg>`;
  const ArrowSquareRight = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M11.558 7.78a.625.625 0 0 1 .884 0l3.778 3.778a.625.625 0 0 1 0 .884l-3.778 3.778a.625.625 0 1 1-.884-.884l2.71-2.711H8.223a.625.625 0 1 1 0-1.25h6.047l-2.71-2.71a.625.625 0 0 1 0-.885Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M8.006 2.875h7.988c.77 0 1.387 0 1.884.04.512.042.953.13 1.359.337.65.332 1.18.86 1.511 1.511.207.406.295.847.336 1.359.041.498.041 1.114.041 1.884v7.988c0 .77 0 1.387-.04 1.884-.042.512-.13.953-.337 1.359a3.46 3.46 0 0 1-1.511 1.511c-.406.207-.847.295-1.358.336-.498.041-1.115.041-1.885.041H8.006c-.77 0-1.386 0-1.884-.04-.512-.042-.953-.13-1.359-.337a3.459 3.459 0 0 1-1.511-1.511c-.207-.406-.295-.847-.336-1.358-.041-.498-.041-1.115-.041-1.885V8.006c0-.77 0-1.386.04-1.884.042-.512.13-.953.337-1.359.332-.65.86-1.18 1.511-1.511.406-.207.847-.295 1.359-.336.498-.041 1.114-.041 1.884-.041ZM6.223 4.162c-.434.035-.692.102-.892.204a2.2 2.2 0 0 0-.965.965c-.102.2-.169.458-.204.892-.037.441-.037 1.007-.037 1.81v7.934c0 .803 0 1.369.037 1.81.035.433.102.692.204.892a2.2 2.2 0 0 0 .965.965c.2.102.458.169.892.204.441.037 1.007.037 1.81.037h7.934c.803 0 1.369 0 1.81-.037.433-.035.692-.102.892-.204a2.2 2.2 0 0 0 .965-.965c.102-.2.169-.459.204-.892.037-.441.037-1.007.037-1.81V8.033c0-.803 0-1.369-.037-1.81-.035-.434-.102-.692-.204-.892a2.208 2.208 0 0 0-.965-.965c-.2-.102-.459-.169-.892-.204-.441-.037-1.007-.037-1.81-.037H8.033c-.803 0-1.369 0-1.81.037Z" clip-rule="evenodd"/>
</svg>`;
  const ArrowSquareUp = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M11.558 7.78a.625.625 0 0 1 .884 0l3.778 3.778a.625.625 0 1 1-.884.884l-2.711-2.71v6.046a.625.625 0 1 1-1.25 0V9.73l-2.71 2.71a.625.625 0 1 1-.885-.883l3.778-3.778Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M8.006 2.875h7.988c.77 0 1.387 0 1.884.04.512.042.953.13 1.359.337.65.332 1.18.86 1.511 1.511.207.406.295.847.336 1.359.041.498.041 1.114.041 1.884v7.988c0 .77 0 1.387-.04 1.884-.042.512-.13.953-.337 1.359a3.46 3.46 0 0 1-1.511 1.511c-.406.207-.847.295-1.358.336-.498.041-1.115.041-1.885.041H8.006c-.77 0-1.386 0-1.884-.04-.512-.042-.953-.13-1.359-.337a3.459 3.459 0 0 1-1.511-1.511c-.207-.406-.295-.847-.336-1.358-.041-.498-.041-1.115-.041-1.885V8.006c0-.77 0-1.386.04-1.884.042-.512.13-.953.337-1.359.332-.65.86-1.18 1.511-1.511.406-.207.847-.295 1.359-.336.498-.041 1.114-.041 1.884-.041ZM6.223 4.162c-.434.035-.692.102-.892.204a2.2 2.2 0 0 0-.965.965c-.102.2-.169.458-.204.892-.037.441-.037 1.007-.037 1.81v7.934c0 .803 0 1.369.037 1.81.035.433.102.692.204.892a2.2 2.2 0 0 0 .965.965c.2.102.458.169.892.204.441.037 1.007.037 1.81.037h7.934c.803 0 1.369 0 1.81-.037.433-.035.692-.102.892-.204a2.2 2.2 0 0 0 .965-.965c.102-.2.169-.459.204-.892.037-.441.037-1.007.037-1.81V8.033c0-.803 0-1.369-.037-1.81-.035-.434-.102-.692-.204-.892a2.208 2.208 0 0 0-.965-.965c-.2-.102-.459-.169-.892-.204-.441-.037-1.007-.037-1.81-.037H8.033c-.803 0-1.369 0-1.81.037Z" clip-rule="evenodd"/>
</svg>`;
  const ArrowUp = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M11.576 3.576a.6.6 0 0 1 .848 0l6 6a.6.6 0 0 1-.848.848L12.6 5.45V20a.6.6 0 1 1-1.2 0V5.449l-4.976 4.975a.6.6 0 0 1-.848-.848l6-6Z" clip-rule="evenodd"/>
</svg>`;
  const BankFill = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M3 8.777a1 1 0 0 1 .5-.866l8-4.622a1 1 0 0 1 1 0l8 4.622a1 1 0 0 1 .5.866V10a1 1 0 0 1-1 1h-1v7h1a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1v-1a1 1 0 0 1 1-1h1v-7H4a1 1 0 0 1-1-1V8.777ZM8 11v7h2.5v-7H8Zm5.5 0v7H16v-7h-2.5Zm0-3.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0Z" clip-rule="evenodd"/>
</svg>`;
  const BellSlash = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M8.465 2.985A6.3 6.3 0 0 1 18.3 8.2c0 1.944.25 3.454.591 4.61a.6.6 0 1 1-1.15.34c-.378-1.277-.64-2.902-.64-4.95a5.1 5.1 0 0 0-7.963-4.221.6.6 0 0 1-.673-.994Zm-5.44.04a.6.6 0 0 1 .85 0l3.069 3.07a.598.598 0 0 1 .05.05l13.98 13.98a.6.6 0 0 1-.848.85l-3.624-3.625H5.704c-.555 0-.99 0-1.302-.012a4.076 4.076 0 0 1-.422-.034.996.996 0 0 1-.758-.501 1.06 1.06 0 0 1-.122-.44.815.815 0 0 1 .035-.299c.02-.068.048-.134.075-.194.054-.119.13-.259.219-.413.178-.309.444-.736.787-1.287l.007-.012C4.988 12.928 5.7 11.03 5.7 8.2c0-.501.06-.997.175-1.476l-2.85-2.85a.6.6 0 0 1 0-.848Zm3.893 4.742A5.103 5.103 0 0 0 6.9 8.2c0 3.042-.769 5.163-1.658 6.592a51.676 51.676 0 0 0-.82 1.346h.027c.285.012.697.012 1.27.012h9.583L6.919 7.767Zm-2.801 8.342.01.003-.01-.003Zm4.92 4.044a.6.6 0 0 1 .847-.053c.564.498 1.304.8 2.116.8s1.552-.302 2.117-.8a.6.6 0 1 1 .794.9A4.386 4.386 0 0 1 12 22.1 4.386 4.386 0 0 1 9.09 21a.6.6 0 0 1-.053-.847Z" clip-rule="evenodd"/>
</svg>`;
  const Bell = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M7.547 3.745A6.3 6.3 0 0 1 18.302 8.2c0 2.83.712 4.728 1.477 5.958l.008.012c.342.55.608.978.786 1.287.09.154.165.294.22.413.026.06.053.126.074.194a.815.815 0 0 1 .035.299 1.06 1.06 0 0 1-.122.44.996.996 0 0 1-.758.501 4.077 4.077 0 0 1-.422.034c-.311.012-.747.012-1.302.012H5.706c-.555 0-.99 0-1.302-.012a4.076 4.076 0 0 1-.422-.034.996.996 0 0 1-.758-.501 1.06 1.06 0 0 1-.122-.44.814.814 0 0 1 .036-.299c.02-.068.047-.134.074-.194a4.74 4.74 0 0 1 .22-.413c.177-.309.443-.736.786-1.287l.007-.012c.765-1.23 1.477-3.129 1.477-5.958a6.3 6.3 0 0 1 1.845-4.455Zm4.455-.645a5.1 5.1 0 0 0-5.1 5.1c0 3.042-.769 5.163-1.658 6.592a51.644 51.644 0 0 0-.82 1.346h.027c.285.012.697.012 1.27.012h12.562c.574 0 .985 0 1.27-.011l.027-.001a51.44 51.44 0 0 0-.82-1.346c-.889-1.43-1.658-3.55-1.658-6.592a5.1 5.1 0 0 0-5.1-5.1Zm7.873 13.012a.074.074 0 0 1 .01-.003l-.01.003ZM4.119 16.11Zm4.92 4.044a.6.6 0 0 1 .847-.053c.564.498 1.304.8 2.116.8s1.552-.302 2.117-.8a.6.6 0 1 1 .794.9 4.386 4.386 0 0 1-2.91 1.1A4.386 4.386 0 0 1 9.091 21a.6.6 0 0 1-.053-.847Z" clip-rule="evenodd"/>
</svg>`;
  const BiFunnel = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M5.076 2.835h13.848c.26 0 .493 0 .687.016.208.017.429.055.645.165.313.16.568.415.728.728.11.216.148.437.165.645a9 9 0 0 1 .016.687v.808c0 .197 0 .396-.046.59a1.63 1.63 0 0 1-.2.482c-.104.17-.245.31-.384.45l-.033.033-5.063 5.063c-.195.195-.213.219-.225.237a.334.334 0 0 0-.04.097c-.005.02-.009.05-.009.327v4.994c0 .266.001.533-.079.783-.07.219-.184.42-.336.593-.173.198-.402.335-.63.47a.616.616 0 0 1-.055.033l-1.826 1.096c-.374.225-.693.416-.96.545-.27.13-.586.247-.934.215a1.665 1.665 0 0 1-1.187-.673c-.207-.281-.269-.613-.296-.91-.027-.295-.027-.668-.027-1.104v-6.042c0-.277-.004-.306-.01-.327a.335.335 0 0 0-.04-.097c-.01-.018-.028-.042-.224-.237L3.498 7.439l-.032-.033c-.14-.14-.281-.28-.386-.45a1.665 1.665 0 0 1-.199-.482 2.497 2.497 0 0 1-.046-.637v-.761c0-.26 0-.493.016-.687a1.69 1.69 0 0 1 .166-.645c.16-.313.414-.568.727-.728a1.69 1.69 0 0 1 .645-.165c.194-.016.428-.016.687-.016Zm-.723 1.364-.005.003a.335.335 0 0 0-.146.146l-.003.005a.856.856 0 0 0-.023.144 8.39 8.39 0 0 0-.01.603v.737c-.001.277.003.306.008.327a.335.335 0 0 0 .04.097c.012.018.03.042.225.237l5.063 5.063.032.033c.14.14.281.28.386.45a1.7 1.7 0 0 1 .199.481c.047.195.046.394.046.591v6.058c0 .476 0 .786.022 1.013.016.182.042.24.045.248.056.075.14.122.233.132a.835.835 0 0 0 .237-.088c.205-.1.471-.258.88-.503l1.8-1.08c.32-.193.351-.22.37-.241a.336.336 0 0 0 .067-.12c.009-.026.016-.067.016-.44v-4.979c0-.197 0-.396.046-.59.04-.17.108-.333.2-.482a2.5 2.5 0 0 1 .418-.483l5.062-5.063c.195-.195.213-.219.225-.237a.334.334 0 0 0 .04-.097c.005-.02.01-.05.01-.327V5.1c0-.291-.002-.47-.012-.603a.847.847 0 0 0-.026-.15.335.335 0 0 0-.146-.145l-.005-.003a.852.852 0 0 0-.144-.023 8.39 8.39 0 0 0-.603-.011H5.1c-.29 0-.47 0-.603.011a.854.854 0 0 0-.144.023Z" clip-rule="evenodd"/>
</svg>`;
  const BookmarkFill = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M6.078 2.1h11.844c.261 0 .492 0 .684.016.203.016.415.054.62.158a1.6 1.6 0 0 1 .7.7c.104.205.142.417.158.62.016.192.016.423.016.684v16.06c0 .206 0 .4-.014.559-.015.16-.051.384-.196.583a1.1 1.1 0 0 1-.775.448 1.146 1.146 0 0 1-.603-.123c-.145-.067-.313-.164-.492-.267l-5.52-3.19c-.326-.19-.377-.21-.417-.22a.4.4 0 0 0-.166 0c-.04.01-.09.03-.417.22l-5.52 3.19c-.18.103-.347.2-.491.267a1.146 1.146 0 0 1-.604.123 1.1 1.1 0 0 1-.775-.448 1.147 1.147 0 0 1-.196-.583 6.579 6.579 0 0 1-.014-.56V4.279c0-.261 0-.492.016-.684.016-.203.054-.415.158-.62a1.6 1.6 0 0 1 .7-.7c.205-.104.417-.142.62-.158.192-.016.423-.016.684-.016Z" clip-rule="evenodd"/>
</svg>`;
  const Bookmark = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M6.078 2.1h11.844c.261 0 .492 0 .684.016.203.016.415.054.62.158a1.6 1.6 0 0 1 .7.7c.104.205.142.416.158.62.016.192.016.423.016.684v16.06c0 .206 0 .4-.014.559-.015.16-.051.384-.196.583a1.1 1.1 0 0 1-.775.447 1.146 1.146 0 0 1-.603-.122 6.562 6.562 0 0 1-.492-.267l-5.52-3.19c-.326-.19-.377-.21-.417-.22a.4.4 0 0 0-.166 0c-.04.01-.09.03-.417.22l-5.52 3.19c-.18.103-.347.2-.491.267a1.146 1.146 0 0 1-.604.122 1.1 1.1 0 0 1-.775-.447 1.147 1.147 0 0 1-.196-.583 6.578 6.578 0 0 1-.014-.56V4.279c0-.261 0-.492.016-.684a1.62 1.62 0 0 1 .158-.62 1.6 1.6 0 0 1 .7-.7c.205-.104.417-.142.62-.158.192-.016.423-.016.684-.016Zm-.586 1.212a.494.494 0 0 0-.174.032.4.4 0 0 0-.174.174.493.493 0 0 0-.032.174A8.432 8.432 0 0 0 5.1 4.3v16.014c0 .148 0 .257.003.342.074-.04.169-.095.297-.17l5.5-3.178.053-.031c.237-.137.463-.268.714-.322a1.6 1.6 0 0 1 .666 0c.251.054.477.185.714.322l.054.031 5.499 3.179c.128.074.223.129.297.169.003-.085.003-.194.003-.342V4.3c0-.29 0-.471-.012-.608a.493.493 0 0 0-.032-.174.4.4 0 0 0-.174-.174.493.493 0 0 0-.174-.032A8.44 8.44 0 0 0 17.9 3.3H6.1c-.29 0-.471 0-.608.012Z" clip-rule="evenodd"/>
</svg>`;
  const BoxArrowUpRight = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M9.274 3.9H9.3a.6.6 0 0 1 0 1.2c-.85 0-1.451 0-1.922.039-.463.038-.745.11-.968.223A2.4 2.4 0 0 0 5.361 6.41c-.113.223-.184.505-.222.968-.039.47-.04 1.072-.04 1.922v5.4c0 .85.001 1.451.04 1.922.038.463.11.745.222.968a2.4 2.4 0 0 0 1.05 1.048c.222.114.504.185.967.223.47.038 1.072.039 1.922.039h5.4c.85 0 1.451 0 1.921-.039.464-.038.746-.11.969-.223a2.4 2.4 0 0 0 1.048-1.048c.113-.223.185-.505.223-.968.038-.47.039-1.072.039-1.922a.6.6 0 1 1 1.2 0v.026c0 .818 0 1.469-.043 1.993-.044.538-.136.996-.35 1.415a3.6 3.6 0 0 1-1.573 1.574c-.42.213-.878.305-1.415.35-.525.042-1.175.042-1.993.042H9.274c-.818 0-1.469 0-1.993-.043-.538-.044-.996-.136-1.415-.35a3.6 3.6 0 0 1-1.574-1.573c-.213-.42-.305-.877-.35-1.415-.042-.524-.042-1.175-.042-1.993V9.274c0-.818 0-1.468.043-1.993.044-.538.136-.996.35-1.415a3.6 3.6 0 0 1 1.573-1.574c.42-.213.877-.305 1.415-.35C7.805 3.9 8.456 3.9 9.274 3.9Zm3.626.6a.6.6 0 0 1 .6-.6h6a.6.6 0 0 1 .6.6v6a.6.6 0 1 1-1.2 0V5.949l-5.976 5.975a.6.6 0 0 1-.848-.848L18.05 5.1H13.5a.6.6 0 0 1-.6-.6Z" clip-rule="evenodd"/>
</svg>`;
  const BoxSeam = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M12.314 1.933a1.526 1.526 0 0 0-.627 0c-.237.05-.45.17-.666.293l-.05.03-3.506 1.987a.597.597 0 0 0-.023.013l-3.46 1.962-.054.03c-.229.13-.453.256-.623.444-.149.165-.26.358-.328.569-.078.24-.077.498-.077.765v7.948c0 .267 0 .525.077.765.068.21.18.404.328.569.17.188.394.315.623.444l.053.03 6.99 3.963.05.029c.216.122.43.244.665.293.207.044.42.044.628 0 .236-.05.45-.17.665-.293l.05-.03 6.99-3.962.053-.03c.229-.13.453-.256.623-.444.149-.165.26-.358.328-.569.078-.24.078-.498.077-.765V8.026c0-.267.001-.525-.077-.765a1.567 1.567 0 0 0-.328-.569c-.17-.188-.394-.315-.623-.444l-.053-.03-6.99-3.963-.05-.029c-.216-.122-.43-.244-.665-.293ZM7.75 5.46 4.717 7.18 12 11.31l3.034-1.72L7.75 5.46Zm8.788 4.656a.559.559 0 0 0 .017-.01L19.9 8.211v7.701c0 .37-.007.422-.018.458a.367.367 0 0 1-.077.133c-.023.025-.06.055-.378.235l-6.827 3.87V12.35l3.938-2.233ZM16.25 8.9 8.967 4.77l2.595-1.472c.303-.171.342-.186.371-.192.044-.01.09-.01.134 0 .029.006.069.02.371.192l6.845 3.882L16.25 8.9Zm-4.85 3.45v8.259l-6.827-3.87c-.318-.181-.355-.21-.378-.236a.367.367 0 0 1-.076-.133c-.012-.036-.019-.087-.019-.458V8.211l7.3 4.139Z" clip-rule="evenodd"/>
</svg>`;
  const Building = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M14.175 2.4h3.65c.539 0 .98 0 1.337.03.371.03.706.094 1.018.253a2.6 2.6 0 0 1 1.137 1.137c.159.312.223.647.254 1.018.029.358.029.798.029 1.337V20.4h.4a.6.6 0 1 1 0 1.2H2a.6.6 0 1 1 0-1.2h.4v-6.225c0-.539 0-.98.03-1.338.03-.37.094-.705.253-1.017a2.6 2.6 0 0 1 1.137-1.137c.312-.159.647-.223 1.017-.254.359-.029.8-.029 1.338-.029H10.4V6.175c0-.539 0-.98.03-1.337.03-.371.094-.706.253-1.018a2.6 2.6 0 0 1 1.136-1.137c.313-.159.648-.223 1.018-.254.358-.029.8-.029 1.338-.029ZM10.4 11.6H6.2c-.57 0-.961 0-1.265.025-.296.024-.455.069-.57.128a1.4 1.4 0 0 0-.613.611c-.058.116-.103.275-.127.571-.025.304-.025.695-.025 1.265v6.2h6.8v-8.8Zm1.2 8.8V6.2c0-.57 0-.961.025-1.265.024-.296.069-.455.127-.57a1.4 1.4 0 0 1 .612-.612c.115-.06.275-.104.571-.128.304-.025.695-.025 1.265-.025h3.6c.57 0 .961 0 1.265.025.296.024.455.069.57.128a1.4 1.4 0 0 1 .612.611c.059.116.103.275.128.571.024.304.025.695.025 1.265v14.2h-8.8ZM13.9 7a.6.6 0 0 1 .6-.6h3a.6.6 0 1 1 0 1.2h-3a.6.6 0 0 1-.6-.6Zm0 4a.6.6 0 0 1 .6-.6h3a.6.6 0 1 1 0 1.2h-3a.6.6 0 0 1-.6-.6Zm0 4a.6.6 0 0 1 .6-.6h3a.6.6 0 1 1 0 1.2h-3a.6.6 0 0 1-.6-.6Z" clip-rule="evenodd"/>
</svg>`;
  const Bus = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M6.2 15.325c0-.345.28-.625.625-.625H8.25a.625.625 0 1 1 0 1.25H6.825a.625.625 0 0 1-.625-.625Zm8.925 0c0-.345.28-.625.625-.625h1.425a.625.625 0 1 1 0 1.25H15.75a.625.625 0 0 1-.625-.625Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M8.033 1.875h7.934c.775 0 1.395 0 1.896.04.514.043.957.131 1.365.339a3.474 3.474 0 0 1 1.518 1.518c.208.408.296.851.338 1.365.014.175.024.364.03.57a.63.63 0 0 1 .005.207c.006.332.006.703.006 1.119v7.084c0 .775 0 1.395-.04 1.896-.043.514-.131.957-.339 1.365a3.474 3.474 0 0 1-1.518 1.518l-.003.002v1.86c0 .117 0 .24-.009.345a1.11 1.11 0 0 1-.11.421 1.1 1.1 0 0 1-.482.481 1.11 1.11 0 0 1-.421.111 4.263 4.263 0 0 1-.345.009h-1.84c-.118 0-.24 0-.346-.009a1.11 1.11 0 0 1-.421-.11 1.1 1.1 0 0 1-.481-.482 1.11 1.11 0 0 1-.111-.421c-.009-.105-.009-.228-.009-.345v-1.483h-5.3v1.483c0 .117 0 .24-.009.345a1.11 1.11 0 0 1-.11.421 1.1 1.1 0 0 1-.482.481 1.11 1.11 0 0 1-.421.111 4.263 4.263 0 0 1-.345.009h-1.84c-.118 0-.24 0-.346-.009a1.11 1.11 0 0 1-.421-.11 1.1 1.1 0 0 1-.481-.482 1.11 1.11 0 0 1-.111-.421c-.01-.105-.009-.228-.009-.345v-1.86l-.003-.002a3.474 3.474 0 0 1-1.518-1.518c-.208-.408-.296-.851-.338-1.365-.041-.501-.041-1.12-.041-1.896V7.033c0-.416 0-.787.006-1.119a.63.63 0 0 1 .005-.208c.006-.205.016-.394.03-.569.042-.514.13-.957.338-1.365a3.475 3.475 0 0 1 1.518-1.518c.408-.208.851-.296 1.365-.338.501-.041 1.12-.041 1.896-.041ZM4.126 6.45l-.001.61v4.315h15.75V6.45H4.124ZM19.835 5.2H4.165c.037-.413.103-.664.203-.86.213-.419.553-.76.972-.972.202-.103.462-.17.899-.206.444-.037 1.013-.037 1.821-.037h7.88c.808 0 1.377 0 1.821.037.437.035.697.103.9.206.418.213.758.553.971.972.1.196.166.447.203.86Zm.04 7.425H4.125v1.465c0 .808 0 1.377.037 1.821.035.437.103.697.206.9.213.418.553.758.972.971.202.103.462.17.899.206.444.037 1.013.037 1.821.037h7.88c.808 0 1.377 0 1.821-.037.437-.035.697-.103.9-.206a2.22 2.22 0 0 0 .971-.972c.103-.202.17-.462.206-.899.037-.444.037-1.013.037-1.821v-1.465Zm-3.975 6.65v1.6h2.075v-1.651a7.433 7.433 0 0 1-.112.01c-.501.041-1.12.041-1.896.041H15.9Zm-7.8 0h-.067c-.775 0-1.395 0-1.896-.04a7.495 7.495 0 0 1-.112-.01v1.65H8.1v-1.6Z" clip-rule="evenodd"/>
</svg>`;
  const Calculator = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M7.774 2.4h8.452c.818 0 1.468 0 1.993.043.537.044.996.136 1.415.35a3.6 3.6 0 0 1 1.573 1.573c.214.42.306.877.35 1.415.043.525.043 1.175.043 1.993v8.452c0 .818 0 1.469-.043 1.993-.044.538-.136.996-.35 1.415a3.6 3.6 0 0 1-1.573 1.574c-.42.213-.878.305-1.415.35-.525.042-1.175.042-1.993.042H7.774c-.818 0-1.469 0-1.993-.043-.538-.044-.996-.136-1.415-.35a3.6 3.6 0 0 1-1.574-1.573c-.213-.42-.305-.877-.35-1.415-.042-.524-.042-1.175-.042-1.993V7.774c0-.818 0-1.468.043-1.993.044-.538.136-.996.35-1.415a3.6 3.6 0 0 1 1.573-1.574c.42-.213.877-.305 1.415-.35C6.305 2.4 6.956 2.4 7.774 2.4ZM5.878 3.639c-.463.038-.745.11-.968.223A2.4 2.4 0 0 0 3.861 4.91c-.113.223-.184.505-.222.968-.039.47-.04 1.072-.04 1.922v8.4c0 .85.001 1.451.04 1.922.038.463.11.745.222.968a2.4 2.4 0 0 0 1.05 1.048c.222.114.504.185.967.223.47.038 1.072.039 1.922.039h8.4c.85 0 1.451 0 1.921-.039.464-.038.746-.11.969-.223a2.4 2.4 0 0 0 1.048-1.048c.113-.223.185-.505.223-.968.038-.47.039-1.072.039-1.922V7.8c0-.85 0-1.451-.039-1.922-.038-.463-.11-.745-.223-.968a2.4 2.4 0 0 0-1.049-1.048c-.222-.114-.504-.185-.968-.223C17.651 3.6 17.05 3.6 16.2 3.6H7.8c-.85 0-1.451 0-1.922.039ZM8.5 5.9a.6.6 0 0 1 .6.6v1.4h1.4a.6.6 0 1 1 0 1.2H9.1v1.4a.6.6 0 1 1-1.2 0V9.1H6.5a.6.6 0 0 1 0-1.2h1.4V6.5a.6.6 0 0 1 .6-.6Zm8.576.176a.6.6 0 0 1 .848.848l-11 11a.6.6 0 0 1-.848-.848l11-11ZM12.9 15.5a.6.6 0 0 1 .6-.6h4a.6.6 0 1 1 0 1.2h-4a.6.6 0 0 1-.6-.6Z" clip-rule="evenodd"/>
</svg>`;
  const CalendarCheck = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M9.424 15.576a.6.6 0 1 0-.848.848l2 2a.6.6 0 0 0 .848 0l4.5-4.5a.6.6 0 0 0-.848-.848L11 17.15l-1.576-1.575Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M8 2c.332 0 .6.32.6.714V4h6.8V2.714c0-.394.269-.714.6-.714.332 0 .6.32.6.714V4c1.418.002 2.173.027 2.762.327a3 3 0 0 1 1.311 1.311C21 6.28 21 7.12 21 8.8v8.4c0 1.68 0 2.52-.327 3.162a3 3 0 0 1-1.311 1.311C18.72 22 17.88 22 16.2 22H7.8c-1.68 0-2.52 0-3.162-.327a3 3 0 0 1-1.311-1.311C3 19.72 3 18.88 3 17.2V8.8c0-1.68 0-2.52.327-3.162a3 3 0 0 1 1.311-1.311c.589-.3 1.344-.325 2.762-.327V2.714C7.4 2.32 7.67 2 8 2Zm-.6 3.2a19.76 19.76 0 0 0-1.473.037c-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744C4.202 7.367 4.2 7.94 4.2 8.8v.6h15.6v-.6c0-.86 0-1.433-.037-1.873-.035-.426-.096-.62-.16-.744a1.8 1.8 0 0 0-.786-.787c-.123-.063-.318-.124-.744-.16A19.86 19.86 0 0 0 16.6 5.2v1.086c0 .394-.268.714-.6.714-.331 0-.6-.32-.6-.714V5.2H8.6v1.086C8.6 6.68 8.332 7 8 7c-.331 0-.6-.32-.6-.714V5.2Zm12.4 5.4H4.2v6.6c0 .86 0 1.433.037 1.873.035.426.096.62.16.744a1.8 1.8 0 0 0 .786.787c.123.063.318.124.744.16.44.035 1.013.036 1.873.036h8.4c.86 0 1.433 0 1.873-.037.426-.035.62-.096.744-.16a1.8 1.8 0 0 0 .787-.786c.063-.123.124-.318.16-.744.035-.44.036-1.013.036-1.873v-6.6Z" clip-rule="evenodd"/>
</svg>`;
  const CalendarX = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M10.304 13.176a.6.6 0 0 0-.849.848l1.697 1.697-1.697 1.697a.6.6 0 1 0 .849.849L12 16.57l1.697 1.697a.6.6 0 0 0 .848-.849l-1.697-1.697 1.697-1.697a.6.6 0 0 0-.848-.848L12 14.873l-1.697-1.697Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M8.6 2.714C8.6 2.32 8.332 2 8 2c-.331 0-.6.32-.6.714V4c-1.418.002-2.173.027-2.762.327a3 3 0 0 0-1.311 1.311C3 6.28 3 7.12 3 8.8v8.4c0 1.68 0 2.52.327 3.162a3 3 0 0 0 1.311 1.311C5.28 22 6.12 22 7.8 22h8.4c1.68 0 2.52 0 3.162-.327a3 3 0 0 0 1.311-1.311C21 19.72 21 18.88 21 17.2V8.8c0-1.68 0-2.52-.327-3.162a3 3 0 0 0-1.311-1.311c-.589-.3-1.344-.325-2.762-.327V2.714C16.6 2.32 16.332 2 16 2c-.331 0-.6.32-.6.714V4H8.6V2.714ZM5.927 5.237c.368-.03.83-.036 1.473-.037v1.086c0 .394.27.714.6.714.332 0 .6-.32.6-.714V5.2h6.8v1.086c0 .394.269.714.6.714.332 0 .6-.32.6-.714V5.2c.644.001 1.105.007 1.473.037.426.035.62.096.744.16a1.8 1.8 0 0 1 .787.786c.063.123.124.318.16.744.035.44.036 1.013.036 1.873v.6H4.2v-.6c0-.86 0-1.433.037-1.873.035-.426.096-.62.16-.744a1.8 1.8 0 0 1 .786-.787c.123-.063.318-.124.744-.16ZM4.2 10.6h15.6v6.6c0 .86 0 1.433-.037 1.873-.035.426-.096.62-.16.744a1.8 1.8 0 0 1-.786.787c-.123.063-.318.124-.744.16-.44.035-1.013.036-1.873.036H7.8c-.86 0-1.433 0-1.873-.037-.426-.035-.62-.096-.744-.16a1.8 1.8 0 0 1-.787-.786c-.063-.123-.124-.318-.16-.744-.035-.44-.036-1.013-.036-1.873v-6.6Z" clip-rule="evenodd"/>
</svg>`;
  const Calendar = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M8 2c.332 0 .6.32.6.714V4h6.8V2.714c0-.394.269-.714.6-.714.332 0 .6.32.6.714V4c1.418.002 2.173.027 2.762.327a3 3 0 0 1 1.311 1.311C21 6.28 21 7.12 21 8.8v8.4c0 1.68 0 2.52-.327 3.162a3 3 0 0 1-1.311 1.311C18.72 22 17.88 22 16.2 22H7.8c-1.68 0-2.52 0-3.162-.327a3 3 0 0 1-1.311-1.311C3 19.72 3 18.88 3 17.2V8.8c0-1.68 0-2.52.327-3.162a3 3 0 0 1 1.311-1.311c.589-.3 1.344-.325 2.762-.327V2.714C7.4 2.32 7.67 2 8 2Zm-.6 3.2a19.76 19.76 0 0 0-1.473.037c-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744C4.202 7.367 4.2 7.94 4.2 8.8v.6h15.6v-.6c0-.86 0-1.433-.037-1.873-.035-.426-.096-.62-.16-.744a1.8 1.8 0 0 0-.786-.787c-.123-.063-.318-.124-.744-.16A19.86 19.86 0 0 0 16.6 5.2v1.086c0 .394-.268.714-.6.714-.331 0-.6-.32-.6-.714V5.2H8.6v1.086C8.6 6.68 8.332 7 8 7c-.331 0-.6-.32-.6-.714V5.2Zm12.4 5.4H4.2v6.6c0 .86 0 1.433.037 1.873.035.426.096.62.16.744a1.8 1.8 0 0 0 .786.787c.123.063.318.124.744.16.44.035 1.013.036 1.873.036h8.4c.86 0 1.433 0 1.873-.037.426-.035.62-.096.744-.16a1.8 1.8 0 0 0 .787-.786c.063-.123.124-.318.16-.744.035-.44.036-1.013.036-1.873v-6.6Z" clip-rule="evenodd"/>
</svg>`;
  const Camera = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M9.563 1.4h4.874c.116 0 .2 0 .279.005A2.6 2.6 0 0 1 16.97 3.03c.03.074.056.153.092.263l.006.017c.045.134.06.177.073.212a1.4 1.4 0 0 0 1.215.875c.038.003.086.003.237.003h.04c.331 0 .543 0 .72.018a3.6 3.6 0 0 1 3.228 3.227c.018.178.018.38.018.695v7.886c0 .818 0 1.469-.043 1.993-.044.538-.136.996-.35 1.415a3.6 3.6 0 0 1-1.573 1.574c-.42.213-.878.305-1.415.35-.525.042-1.175.042-1.993.042H6.774c-.818 0-1.469 0-1.993-.043-.538-.044-.996-.136-1.415-.35a3.6 3.6 0 0 1-1.574-1.573c-.213-.42-.305-.877-.35-1.415-.042-.524-.042-1.175-.042-1.993V8.34c0-.315 0-.517.017-.695a3.6 3.6 0 0 1 3.228-3.227c.177-.018.39-.018.72-.018h.04c.151 0 .2 0 .238-.003a1.4 1.4 0 0 0 1.214-.875c.015-.035.029-.078.074-.212l.005-.017c.037-.11.064-.19.093-.263a2.6 2.6 0 0 1 2.255-1.625c.08-.005.163-.005.279-.005Zm.018 1.2c-.141 0-.186 0-.224.003a1.4 1.4 0 0 0-1.215.875 4.244 4.244 0 0 0-.073.212l-.006.017a2.6 2.6 0 0 1-2.348 1.888c-.078.005-.167.005-.29.005h-.02c-.384 0-.531 0-.642.012a2.4 2.4 0 0 0-2.151 2.151c-.011.111-.012.25-.012.614V16.2c0 .85 0 1.451.039 1.922.038.463.11.745.222.968a2.4 2.4 0 0 0 1.05 1.048c.222.114.504.185.967.223.47.038 1.072.039 1.922.039h10.4c.85 0 1.451 0 1.921-.039.464-.038.746-.11.969-.223a2.4 2.4 0 0 0 1.048-1.048c.113-.223.185-.505.223-.968.038-.47.039-1.072.039-1.922V8.377c0-.364 0-.503-.012-.614a2.4 2.4 0 0 0-2.152-2.151 7.757 7.757 0 0 0-.642-.012h-.02c-.123 0-.21 0-.29-.005A2.6 2.6 0 0 1 16.03 3.97c-.03-.074-.056-.153-.093-.263l-.005-.017a4.328 4.328 0 0 0-.074-.212 1.4 1.4 0 0 0-1.214-.875 4.25 4.25 0 0 0-.224-.003H9.58ZM12 9.1a3.4 3.4 0 1 0 0 6.8 3.4 3.4 0 0 0 0-6.8Zm-4.6 3.4a4.6 4.6 0 1 1 9.2 0 4.6 4.6 0 0 1-9.2 0Z" clip-rule="evenodd"/>
</svg>`;
  const Car = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M4.725 13.05c0-.345.28-.625.625-.625H8.2a.625.625 0 1 1 0 1.25H5.35a.625.625 0 0 1-.625-.625Zm10.45 0c0-.345.28-.625.625-.625h2.85a.625.625 0 1 1 0 1.25H15.8a.625.625 0 0 1-.625-.625Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M8.38 3.875h7.241c.678 0 1.186-.001 1.634.175a2.54 2.54 0 0 1 1.013.73c.308.37.469.851.683 1.495l.035.106 1.064 3.194h1.45a.625.625 0 1 1 0 1.25h-.18c.164.198.308.415.426.647.208.408.296.851.338 1.365.041.501.041 1.12.041 1.896v2.457c0 .378 0 .657-.049.903a2.525 2.525 0 0 1-1.983 1.983c-.246.05-.525.05-.903.049h-.54a2.525 2.525 0 0 1-2.52-2.375H7.87a2.525 2.525 0 0 1-2.52 2.375h-.54c-.378 0-.657 0-.903-.049a2.525 2.525 0 0 1-1.983-1.983c-.05-.246-.05-.525-.049-.903v-2.457c0-.775 0-1.395.04-1.896.043-.514.131-.957.339-1.365.118-.232.262-.449.427-.647H2.5a.625.625 0 1 1 0-1.25h1.45l1.064-3.194.036-.106c.213-.644.374-1.126.683-1.495.27-.324.619-.575 1.012-.73.448-.176.956-.176 1.634-.175ZM5.255 9.607c.48-.032 1.062-.032 1.777-.032h9.934c.715 0 1.298 0 1.777.032l-.944-2.83c-.266-.799-.355-1.032-.491-1.195a1.275 1.275 0 0 0-.512-.369c-.198-.078-.447-.088-1.288-.088H8.49c-.841 0-1.09.01-1.288.088a1.275 1.275 0 0 0-.512.37c-.136.162-.225.395-.49 1.193l-.945 2.831Zm-.017 1.255c-.437.035-.697.103-.9.206a2.225 2.225 0 0 0-.971.972c-.103.202-.17.462-.206.899-.036.444-.037 1.013-.037 1.821v2.365c0 .471.003.616.025.724.1.506.496.9 1.001 1.002.108.021.253.024.724.024h.475c.704 0 1.275-.57 1.275-1.275a1.1 1.1 0 0 1 1.1-1.1h8.55a1.1 1.1 0 0 1 1.1 1.1c0 .704.57 1.275 1.275 1.275h.475c.471 0 .616-.003.724-.024.506-.101.9-.496 1.002-1.002.021-.108.024-.253.024-.724V14.76c0-.808 0-1.377-.037-1.821-.035-.437-.103-.697-.206-.9a2.225 2.225 0 0 0-.972-.971c-.202-.103-.462-.17-.899-.206-.444-.037-1.013-.037-1.821-.037H7.06c-.808 0-1.377 0-1.82.037Z" clip-rule="evenodd"/>
</svg>`;
  const ChatDots = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M6.653 10.583a1.097 1.097 0 1 1 2.194 0 1.097 1.097 0 0 1-2.194 0Zm4.25 0a1.097 1.097 0 1 1 2.194 0 1.097 1.097 0 0 1-2.194 0Zm4.25 0a1.097 1.097 0 1 1 2.194 0 1.097 1.097 0 0 1-2.194 0Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M8.006 2.875h7.988c.77 0 1.387 0 1.884.04.512.042.953.13 1.359.337.65.332 1.18.86 1.511 1.511.207.406.295.847.336 1.359.041.498.041 1.114.041 1.884v5.154c0 .77 0 1.387-.04 1.885-.042.511-.13.953-.337 1.358a3.46 3.46 0 0 1-1.511 1.512c-.406.207-.847.294-1.358.336-.498.04-1.115.04-1.885.04H13.59c-.614 0-.835.004-1.04.046a2.21 2.21 0 0 0-.56.196c-.187.096-.361.231-.841.615l-2.273 1.819a7.34 7.34 0 0 1-.489.37c-.138.092-.36.222-.636.222-.334 0-.65-.151-.858-.413-.173-.215-.21-.47-.225-.635-.015-.17-.015-.383-.015-.613V18.29c-.503-.005-.88-.027-1.215-.116a3.458 3.458 0 0 1-2.445-2.446c-.118-.44-.118-.957-.118-1.738V8.006c0-.77 0-1.386.04-1.884.042-.512.13-.953.337-1.359.332-.65.86-1.18 1.511-1.511.406-.207.847-.295 1.359-.336.498-.041 1.114-.041 1.884-.041ZM6.223 4.162c-.433.035-.692.102-.892.204a2.2 2.2 0 0 0-.965.965c-.102.2-.169.458-.204.892-.036.441-.037 1.007-.037 1.81v5.856c0 .918.005 1.255.075 1.516.204.762.8 1.357 1.562 1.561.26.07.597.076 1.516.076.345 0 .625.28.625.625v2.475c.06-.046.129-.101.212-.168l2.253-1.802.049-.04c.413-.33.69-.552 1.004-.712.277-.142.572-.245.878-.308.345-.07.7-.07 1.228-.07h2.44c.803 0 1.369 0 1.81-.037.433-.035.692-.102.892-.204.416-.212.754-.55.965-.965.102-.2.17-.459.204-.893.037-.44.037-1.006.037-1.81v-5.1c0-.803 0-1.369-.037-1.81-.035-.434-.102-.692-.204-.892a2.208 2.208 0 0 0-.965-.965c-.2-.102-.459-.169-.892-.204-.441-.037-1.007-.037-1.81-.037H8.033c-.803 0-1.369 0-1.81.037ZM7.922 20.46v.002-.002Z" clip-rule="evenodd"/>
</svg>`;
  const ChatLeftText = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M8.007 2.9h7.986c.771 0 1.386 0 1.883.04.51.042.948.13 1.35.334a3.45 3.45 0 0 1 1.5 1.5c.204.402.292.84.333 1.35.041.497.041 1.112.041 1.883v5.152c0 .772 0 1.387-.04 1.884-.042.51-.13.947-.334 1.35a3.433 3.433 0 0 1-1.5 1.5c-.402.204-.84.291-1.35.333-.497.04-1.112.04-1.883.04h-6.18c-.614 0-.837.004-1.046.046a2.2 2.2 0 0 0-.567.2c-.19.096-.366.233-.845.617l-2.272 1.818c-.18.143-.345.276-.487.37-.138.09-.354.217-.623.217-.326 0-.635-.148-.839-.403-.167-.21-.204-.457-.219-.622-.015-.17-.015-.381-.015-.612V8.007c0-.771 0-1.386.04-1.883.042-.51.13-.948.334-1.35a3.433 3.433 0 0 1 1.5-1.5c.402-.204.84-.292 1.35-.333C6.62 2.9 7.236 2.9 8.007 2.9ZM6.221 4.137c-.435.035-.697.102-.902.206-.42.215-.761.556-.976.976-.104.205-.17.467-.206.902-.037.443-.037 1.01-.037 1.812v11.84c0 .13 0 .235.002.32.067-.052.149-.117.25-.2l2.254-1.801.047-.039c.415-.331.69-.551 1.001-.71.276-.141.569-.244.872-.306.342-.07.694-.07 1.225-.07h6.216c.803 0 1.37 0 1.812-.037.435-.036.697-.103.902-.207a2.24 2.24 0 0 0 .976-.976c.104-.204.17-.466.206-.902.037-.442.037-1.008.037-1.812v-5.1c0-.803 0-1.37-.037-1.812-.035-.435-.102-.697-.206-.902a2.233 2.233 0 0 0-.976-.976c-.205-.104-.467-.17-.902-.206-.443-.037-1.009-.037-1.812-.037H8.033c-.803 0-1.37 0-1.812.037Zm.457 4.557a.6.6 0 0 1 .6-.6H12a.6.6 0 1 1 0 1.2H7.278a.6.6 0 0 1-.6-.6Zm0 3.306a.6.6 0 0 1 .6-.6h7.555a.6.6 0 0 1 0 1.2H7.278a.6.6 0 0 1-.6-.6Z" clip-rule="evenodd"/>
</svg>`;
  const Chat = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M8.006 2.875h7.988c.77 0 1.387 0 1.884.04.512.042.953.13 1.359.337.65.332 1.18.86 1.511 1.511.207.406.295.847.336 1.359.041.498.041 1.114.041 1.884v5.154c0 .77 0 1.387-.04 1.885-.042.511-.13.953-.337 1.358a3.46 3.46 0 0 1-1.511 1.512c-.406.207-.847.294-1.358.336-.498.04-1.115.04-1.885.04H13.59c-.614 0-.835.004-1.04.046a2.21 2.21 0 0 0-.56.196c-.187.096-.361.231-.841.615l-2.273 1.819a7.34 7.34 0 0 1-.489.37c-.138.092-.36.222-.636.222-.334 0-.65-.151-.858-.413-.173-.215-.21-.47-.225-.635-.015-.17-.015-.383-.015-.613V18.29c-.503-.005-.88-.027-1.215-.116a3.458 3.458 0 0 1-2.445-2.446c-.118-.44-.118-.957-.118-1.738V8.006c0-.77 0-1.386.04-1.884.042-.512.13-.953.337-1.359.332-.65.86-1.18 1.511-1.511.406-.207.847-.295 1.359-.336.498-.041 1.114-.041 1.884-.041ZM6.223 4.162c-.433.035-.692.102-.892.204a2.2 2.2 0 0 0-.965.965c-.102.2-.169.458-.204.892-.036.441-.037 1.007-.037 1.81v5.856c0 .918.005 1.255.075 1.516.204.762.8 1.357 1.562 1.561.26.07.597.076 1.516.076.345 0 .625.28.625.625v2.475c.06-.046.129-.101.212-.168l2.253-1.802.049-.04c.413-.33.69-.552 1.004-.712.277-.142.572-.245.878-.308.345-.07.7-.07 1.228-.07h2.44c.803 0 1.369 0 1.81-.037.433-.035.692-.102.892-.204.416-.212.754-.55.965-.965.102-.2.17-.459.204-.893.037-.44.037-1.006.037-1.81v-5.1c0-.803 0-1.369-.037-1.81-.035-.434-.102-.692-.204-.892a2.208 2.208 0 0 0-.965-.965c-.2-.102-.459-.169-.892-.204-.441-.037-1.007-.037-1.81-.037H8.033c-.803 0-1.369 0-1.81.037ZM7.922 20.46v.002-.002Z" clip-rule="evenodd"/>
</svg>`;
  const CheckCircleFill = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M7.076 11.576a.6.6 0 0 1 .848 0L10.5 14.15l5.576-5.575a.6.6 0 0 1 .848.848l-6 6a.6.6 0 0 1-.848 0l-3-3a.6.6 0 0 1 0-.848ZM22 12c0 5.523-4.477 10-10 10S2 17.523 2 12 6.477 2 12 2s10 4.477 10 10Z" clip-rule="evenodd"/>
</svg>`;
  const CheckCircle = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M7.076 11.576a.6.6 0 0 1 .848 0L10.5 14.15l5.576-5.575a.6.6 0 0 1 .848.848l-6 6a.6.6 0 0 1-.848 0l-3-3a.6.6 0 0 1 0-.848ZM12 20.8a8.8 8.8 0 1 0 0-17.6 8.8 8.8 0 0 0 0 17.6ZM22 12c0 5.523-4.477 10-10 10S2 17.523 2 12 6.477 2 12 2s10 4.477 10 10Z" clip-rule="evenodd"/>
</svg>`;
  const Check = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M20.424 5.576a.6.6 0 0 1 0 .848l-11 11a.6.6 0 0 1-.848 0l-5-5a.6.6 0 0 1 .848-.848L9 16.15 19.576 5.576a.6.6 0 0 1 .848 0Z" clip-rule="evenodd"/>
</svg>`;
  const ChevronDown = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M5.576 8.576a.6.6 0 0 1 .848 0L12 14.15l5.576-5.575a.6.6 0 0 1 .848.848l-6 6a.6.6 0 0 1-.848 0l-6-6a.6.6 0 0 1 0-.848Z" clip-rule="evenodd"/>
</svg>`;
  const ChevronLeft = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M15.424 5.576a.6.6 0 0 1 0 .848L9.848 12l5.576 5.576a.6.6 0 0 1-.848.848l-6-6a.6.6 0 0 1 0-.848l6-6a.6.6 0 0 1 .848 0Z" clip-rule="evenodd"/>
</svg>`;
  const ChevronRight = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M8.576 5.576a.6.6 0 0 1 .848 0l6 6a.6.6 0 0 1 0 .848l-6 6a.6.6 0 0 1-.848-.848L14.15 12 8.576 6.424a.6.6 0 0 1 0-.848Z" clip-rule="evenodd"/>
</svg>`;
  const ChevronSelectorVertical = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M11.558 3.558a.625.625 0 0 1 .884 0l5 5a.625.625 0 1 1-.884.884L12 4.884 7.442 9.442a.625.625 0 1 1-.884-.884l5-5Zm-5 11a.625.625 0 0 1 .884 0L12 19.116l4.558-4.558a.625.625 0 1 1 .884.884l-5 5a.625.625 0 0 1-.884 0l-5-5a.625.625 0 0 1 0-.884Z"/>
</svg>`;
  const ChevronUp = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M11.576 8.576a.6.6 0 0 1 .848 0l6 6a.6.6 0 0 1-.848.848L12 9.85l-5.576 5.575a.6.6 0 0 1-.848-.848l6-6Z" clip-rule="evenodd"/>
</svg>`;
  const Clock = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M12.6 6a.6.6 0 1 0-1.2 0v6a.6.6 0 0 0 .332.537l4 2a.6.6 0 1 0 .537-1.074L12.6 11.63V6Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M12 22c5.523 0 10-4.477 10-10S17.523 2 12 2 2 6.477 2 12s4.477 10 10 10Zm8.8-10a8.8 8.8 0 1 1-17.6 0 8.8 8.8 0 0 1 17.6 0Z" clip-rule="evenodd"/>
</svg>`;
  const CloudCheck = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M15.925 11.076a.6.6 0 0 1 0 .848l-4.5 4.5a.6.6 0 0 1-.849 0l-2-2a.6.6 0 1 1 .849-.848L11 15.15l4.076-4.075a.6.6 0 0 1 .849 0Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M12 4.4a6.602 6.602 0 0 0-6.425 5.084A5.101 5.101 0 0 0 6.5 19.6h11a5.1 5.1 0 0 0 .925-10.116A6.602 6.602 0 0 0 12 4.4Zm-5.328 5.717a5.402 5.402 0 0 1 10.656 0 .6.6 0 0 0 .537.5A3.9 3.9 0 0 1 17.5 18.4h-11a3.9 3.9 0 0 1-.365-7.783.6.6 0 0 0 .537-.5Z" clip-rule="evenodd"/>
</svg>`;
  const CloudDownload = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M5.575 7.484a6.602 6.602 0 0 1 12.85 0 5.101 5.101 0 0 1 1.909 9.257.6.6 0 1 1-.668-.997 3.9 3.9 0 0 0-1.801-7.127.6.6 0 0 1-.537-.5 5.402 5.402 0 0 0-10.656 0 .6.6 0 0 1-.537.5 3.9 3.9 0 0 0-1.801 7.127.6.6 0 0 1-.668.997 5.101 5.101 0 0 1 1.909-9.257ZM12 11.4a.6.6 0 0 1 .6.6v7.552l2.976-2.976a.6.6 0 0 1 .848.848l-4 4a.6.6 0 0 1-.848 0l-4-4a.6.6 0 0 1 .848-.848l2.976 2.976V12a.6.6 0 0 1 .6-.6Z" clip-rule="evenodd"/>
</svg>`;
  const CloudUpload = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M5.575 7.484a6.602 6.602 0 0 1 12.85 0 5.101 5.101 0 0 1 1.909 9.257.6.6 0 1 1-.668-.997 3.9 3.9 0 0 0-1.801-7.127.6.6 0 0 1-.537-.5 5.402 5.402 0 0 0-10.656 0 .6.6 0 0 1-.537.5 3.9 3.9 0 0 0-1.801 7.127.6.6 0 0 1-.668.997 5.101 5.101 0 0 1 1.909-9.257Zm5.825 5.964-2.976 2.976a.6.6 0 0 1-.848-.848l4-4a.6.6 0 0 1 .848 0l4 4a.6.6 0 0 1-.848.848L12.6 13.448V21a.6.6 0 1 1-1.2 0v-7.552Z" clip-rule="evenodd"/>
</svg>`;
  const Cloud = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M5.575 9.484a6.602 6.602 0 0 1 12.85 0A5.101 5.101 0 0 1 17.5 19.6h-11a5.1 5.1 0 0 1-.925-10.116ZM12 5.6a5.402 5.402 0 0 0-5.328 4.517.6.6 0 0 1-.537.5A3.9 3.9 0 0 0 6.5 18.4h11a3.9 3.9 0 0 0 .365-7.783.6.6 0 0 1-.537-.5A5.402 5.402 0 0 0 12 5.6Z" clip-rule="evenodd"/>
</svg>`;
  const Compass = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M15.819 7.514c-.252-.09-.498-.047-.664-.008-.17.04-.375.108-.599.183L10.07 9.184l-.03.01c-.106.035-.255.084-.386.173a1.1 1.1 0 0 0-.287.287c-.09.13-.138.28-.173.386l-.01.03-1.495 4.486c-.075.224-.143.43-.183.599-.04.166-.081.412.008.664a1.1 1.1 0 0 0 .667.666c.252.09.498.048.664.01.17-.04.375-.11.599-.184l4.486-1.495.03-.01a1.5 1.5 0 0 0 .386-.173 1.1 1.1 0 0 0 .287-.287c.089-.13.138-.28.173-.386l.01-.03 1.495-4.486c.075-.224.143-.43.183-.599.04-.166.081-.412-.009-.664a1.1 1.1 0 0 0-.666-.667Zm-.907 1.321c.16-.053.28-.093.374-.122-.028.094-.068.214-.121.375l-1.488 4.463a9.04 9.04 0 0 1-.029.086l-.003.008-.008.003-.086.03-4.463 1.487c-.16.053-.28.093-.375.122.029-.094.068-.214.122-.375l1.488-4.463c.011-.035.02-.063.029-.086l.002-.008.009-.003a9.04 9.04 0 0 1 .086-.03l4.463-1.487Z" clip-rule="evenodd"/>
  <path fill="currentColor" fill-rule="evenodd" d="M12 22c5.523 0 10-4.477 10-10S17.523 2 12 2 2 6.477 2 12s4.477 10 10 10Zm8.8-10a8.8 8.8 0 1 1-17.6 0 8.8 8.8 0 0 1 17.6 0Z" clip-rule="evenodd"/>
</svg>`;
  const Cross = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M6.576 6.576a.6.6 0 0 1 .848 0L12 11.152l4.576-4.576a.6.6 0 0 1 .848.848L12.848 12l4.576 4.576a.6.6 0 0 1-.848.848L12 12.85l-4.576 4.575a.6.6 0 0 1-.848-.848L11.15 12 6.576 7.424a.6.6 0 0 1 0-.848Z" clip-rule="evenodd"/>
</svg>`;
  const CursorFill = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="m5.207 3.488.024.009 15.04 5.399c.273.098.514.184.696.268.163.074.427.208.573.476.169.31.174.685.013 1-.139.271-.4.412-.56.49-.18.09-.419.182-.69.287l-6.334 2.464-.064.025-.025.063-2.463 6.335c-.105.27-.198.51-.287.69-.079.16-.22.42-.49.559-.316.16-.69.156-1-.013-.268-.146-.402-.41-.477-.573a9.65 9.65 0 0 1-.268-.696L3.496 5.231l-.008-.024a7.47 7.47 0 0 1-.195-.59c-.042-.16-.093-.409-.004-.665.108-.31.352-.555.663-.663.256-.088.504-.038.665.004.167.043.37.116.59.195Z" clip-rule="evenodd"/>
</svg>`;
  const Cursor = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="m5.207 3.488.024.008 15.04 5.4c.273.097.514.184.696.268.163.074.427.208.573.476.169.31.174.685.013 1-.139.271-.4.412-.56.49-.18.089-.418.182-.689.287l-6.335 2.463-.063.025a7.215 7.215 0 0 0-.026.064l-2.463 6.335c-.105.27-.198.51-.286.689-.08.16-.22.421-.491.56-.315.16-.69.156-1-.013-.268-.146-.402-.41-.476-.573-.084-.182-.17-.423-.269-.696L3.496 5.23l-.008-.024a7.47 7.47 0 0 1-.195-.59c-.042-.16-.092-.41-.004-.665.108-.311.352-.555.663-.663.256-.088.504-.038.665.004.167.043.37.116.59.195Zm-.69 1.029.109.308 5.39 15.016c.056.157.102.283.141.387.042-.103.09-.228.151-.383l2.454-6.31.01-.025c.033-.086.082-.214.162-.326a1.07 1.07 0 0 1 .25-.25 1.446 1.446 0 0 1 .35-.172l6.31-2.454c.156-.06.281-.11.384-.151a18 18 0 0 0-.387-.141L4.825 4.626a21.865 21.865 0 0 0-.308-.11Z" clip-rule="evenodd"/>
</svg>`;
  const DashCircle = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M7.4 12a.6.6 0 0 1 .6-.6h8a.6.6 0 1 1 0 1.2H8a.6.6 0 0 1-.6-.6Zm4.6 8.8a8.8 8.8 0 1 0 0-17.6 8.8 8.8 0 0 0 0 17.6ZM22 12c0 5.523-4.477 10-10 10S2 17.523 2 12 6.477 2 12 2s10 4.477 10 10Z" clip-rule="evenodd"/>
</svg>`;
  const DashSquare = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M7.4 12a.6.6 0 0 1 .6-.6h8a.6.6 0 1 1 0 1.2H8a.6.6 0 0 1-.6-.6Zm8.8-7.8H7.8c-.86 0-1.433 0-1.873.037-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744C4.202 6.367 4.2 6.94 4.2 7.8v8.4c0 .86 0 1.433.037 1.873.035.426.096.62.16.744a1.8 1.8 0 0 0 .786.787c.123.063.318.124.744.16.44.035 1.013.036 1.873.036h8.4c.86 0 1.433 0 1.873-.037.426-.035.62-.096.744-.16a1.8 1.8 0 0 0 .787-.786c.063-.123.124-.318.16-.744.035-.44.036-1.013.036-1.873V7.8c0-.86 0-1.433-.037-1.873-.035-.426-.096-.62-.16-.744a1.8 1.8 0 0 0-.786-.787c-.123-.063-.318-.124-.744-.16-.44-.035-1.013-.036-1.873-.036Zm-12.873.438C3 5.28 3 6.12 3 7.8v8.4c0 1.68 0 2.52.327 3.162a3 3 0 0 0 1.311 1.311C5.28 21 6.12 21 7.8 21h8.4c1.68 0 2.52 0 3.162-.327a3 3 0 0 0 1.311-1.311C21 18.72 21 17.88 21 16.2V7.8c0-1.68 0-2.52-.327-3.162a3 3 0 0 0-1.311-1.311C18.72 3 17.88 3 16.2 3H7.8c-1.68 0-2.52 0-3.162.327a3 3 0 0 0-1.311 1.311Z" clip-rule="evenodd"/>
</svg>`;
  const Dash = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M4.4 12a.6.6 0 0 1 .6-.6h14a.6.6 0 1 1 0 1.2H5a.6.6 0 0 1-.6-.6Z" clip-rule="evenodd"/>
</svg>`;
  const Download = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M12 2.4a.6.6 0 0 1 .6.6v10.552l3.976-3.976a.6.6 0 0 1 .848.848l-5 5a.6.6 0 0 1-.848 0l-5-5a.6.6 0 0 1 .848-.848l3.976 3.976V3a.6.6 0 0 1 .6-.6Zm-9 12a.6.6 0 0 1 .6.6v1.2c0 .85 0 1.451.039 1.922.038.463.11.745.222.968a2.4 2.4 0 0 0 1.05 1.048c.222.114.504.185.967.223.47.038 1.072.039 1.922.039h8.4c.85 0 1.451 0 1.921-.039.464-.038.746-.11.969-.223a2.4 2.4 0 0 0 1.048-1.048c.113-.223.185-.505.223-.968.038-.47.039-1.072.039-1.922V15a.6.6 0 1 1 1.2 0v1.226c0 .818 0 1.469-.043 1.993-.044.538-.136.996-.35 1.415a3.6 3.6 0 0 1-1.573 1.574c-.42.213-.878.305-1.415.35-.525.042-1.175.042-1.993.042H7.774c-.818 0-1.469 0-1.993-.043-.538-.044-.996-.136-1.415-.35a3.6 3.6 0 0 1-1.574-1.573c-.213-.42-.305-.877-.35-1.415-.042-.524-.042-1.175-.042-1.993V15a.6.6 0 0 1 .6-.6Z" clip-rule="evenodd"/>
</svg>`;
  const Edit = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M17.458 2.658a2.746 2.746 0 1 1 3.884 3.884l-8.963 8.963-.046.046c-.301.301-.524.524-.79.687-.235.144-.49.25-.759.314-.303.073-.618.073-1.044.073H8A.625.625 0 0 1 7.375 16v-1.74c0-.426 0-.74.072-1.044.065-.268.17-.524.315-.76.163-.265.386-.488.687-.789l.046-.046 8.963-8.963Zm3 .884a1.496 1.496 0 0 0-2.116 0l-8.963 8.963c-.367.367-.475.48-.551.605a1.368 1.368 0 0 0-.165.397c-.034.142-.038.3-.038.819v1.049h1.05c.518 0 .676-.004.818-.038.14-.034.274-.09.397-.165.124-.076.238-.184.605-.551l8.963-8.963a1.496 1.496 0 0 0 0-2.116Z" clip-rule="evenodd"/>
  <path fill="currentColor" d="M7.273 3.875H10.5a.625.625 0 1 1 0 1.25H7.3c-.85 0-1.45 0-1.92.039-.461.038-.74.109-.958.22-.447.228-.81.59-1.038 1.038-.111.218-.182.497-.22.958-.039.47-.039 1.07-.039 1.92v7.4c0 .85 0 1.45.039 1.92.038.461.109.74.22.958.228.447.59.81 1.038 1.038.218.111.497.183.958.22.47.039 1.07.039 1.92.039h7.4c.85 0 1.45 0 1.92-.039.461-.037.74-.109.958-.22.447-.228.81-.59 1.038-1.038.111-.218.183-.497.22-.959.039-.468.039-1.069.039-1.919v-3.2a.625.625 0 1 1 1.25 0v3.227c0 .817 0 1.468-.043 1.994-.044.54-.136 1.001-.352 1.425a3.625 3.625 0 0 1-1.584 1.584c-.424.216-.886.308-1.425.352-.526.043-1.177.043-1.994.043H7.273c-.817 0-1.469 0-1.994-.043-.54-.044-1.001-.136-1.425-.352a3.625 3.625 0 0 1-1.584-1.584c-.216-.424-.308-.886-.352-1.425-.043-.526-.043-1.177-.043-1.994V9.273c0-.817 0-1.469.043-1.994.044-.54.136-1.001.352-1.425A3.625 3.625 0 0 1 3.854 4.27c.424-.216.886-.308 1.425-.352.525-.043 1.177-.043 1.994-.043Z"/>
</svg>`;
  const ExclamationCircleFill = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M22 12c0 5.523-4.477 10-10 10S2 17.523 2 12 6.477 2 12 2s10 4.477 10 10ZM12 7.4a.6.6 0 0 1 .6.6v5a.6.6 0 1 1-1.2 0V8a.6.6 0 0 1 .6-.6Zm0 7.75a.85.85 0 0 0 0 1.7h.01a.85.85 0 1 0 0-1.7H12Z" clip-rule="evenodd"/>
</svg>`;
  const ExclamationCircle = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M12.6 8a.6.6 0 1 0-1.2 0v5a.6.6 0 1 0 1.2 0V8Zm-1.45 8c0-.47.38-.85.85-.85h.01a.85.85 0 0 1 0 1.7H12a.85.85 0 0 1-.85-.85Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M12 22c5.523 0 10-4.477 10-10S17.523 2 12 2 2 6.477 2 12s4.477 10 10 10Zm8.8-10a8.8 8.8 0 1 1-17.6 0 8.8 8.8 0 0 1 17.6 0Z" clip-rule="evenodd"/>
</svg>`;
  const ExclamationTriangleFill = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M11.36 2.286a1.574 1.574 0 0 1 1.28 0c.295.13.5.368.664.6.163.23.34.537.55.898l8.043 13.892c.21.363.388.67.506.927.12.26.224.556.19.878a1.574 1.574 0 0 1-.64 1.11c-.261.19-.57.249-.854.275-.282.026-.637.026-1.056.026H3.957c-.419 0-.774 0-1.056-.026-.284-.026-.593-.085-.855-.275a1.574 1.574 0 0 1-.64-1.11c-.033-.322.07-.618.19-.878.12-.256.297-.564.507-.927l8.043-13.892c.21-.361.387-.668.55-.898.164-.232.37-.47.664-.6Zm1.24 6.801a.6.6 0 1 0-1.2 0v4.872a.6.6 0 1 0 1.2 0V9.087Zm-.6 6.945a.85.85 0 0 0 0 1.7h.01a.85.85 0 1 0 0-1.7H12Z" clip-rule="evenodd"/>
</svg>`;
  const ExclamationTriangle = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M12 8.487a.6.6 0 0 1 .6.6v4.872a.6.6 0 0 1-1.2 0V9.087a.6.6 0 0 1 .6-.6Zm-.85 8.395c0-.47.38-.85.85-.85h.01a.85.85 0 1 1 0 1.7H12a.85.85 0 0 1-.85-.85Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M12.64 2.286a1.574 1.574 0 0 0-1.28 0c-.295.131-.5.368-.665.6-.162.23-.34.537-.549.898L2.103 17.677c-.21.362-.388.67-.507.926-.12.26-.223.556-.19.878.047.444.28.847.64 1.11.262.19.57.25.855.275.282.026.637.026 1.056.026h16.086c.419 0 .774 0 1.056-.026.284-.026.593-.084.854-.275.361-.263.594-.666.64-1.11.034-.322-.07-.618-.19-.878a12.493 12.493 0 0 0-.506-.927L13.854 3.784c-.21-.361-.387-.668-.55-.897-.165-.233-.37-.47-.665-.601Zm-.792 1.096a.374.374 0 0 1 .304 0c.003.002.055.032.173.198.127.18.277.438.505.83l8.014 13.843c.228.394.377.654.47.854.086.186.086.246.086.25a.374.374 0 0 1-.152.263c-.003.002-.056.033-.26.051-.219.02-.519.021-.974.021H3.986c-.455 0-.755 0-.975-.02-.21-.02-.259-.052-.259-.052a.374.374 0 0 1-.152-.263c0-.004 0-.065.086-.25.092-.2.242-.46.47-.854L11.17 4.41c.227-.393.378-.651.505-.83.122-.173.173-.199.173-.199Z" clip-rule="evenodd"/>
</svg>`;
  const Exclamation = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M12.6 8a.6.6 0 1 0-1.2 0v5a.6.6 0 1 0 1.2 0V8Zm-1.45 8c0-.47.38-.85.85-.85h.01a.85.85 0 0 1 0 1.7H12a.85.85 0 0 1-.85-.85Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M3 7.8c0-1.68 0-2.52.327-3.162a3 3 0 0 1 1.311-1.311C5.28 3 6.12 3 7.8 3h8.4c1.68 0 2.52 0 3.162.327a3 3 0 0 1 1.311 1.311C21 5.28 21 6.12 21 7.8v8.4c0 1.68 0 2.52-.327 3.162a3 3 0 0 1-1.311 1.311C18.72 21 17.88 21 16.2 21H7.8c-1.68 0-2.52 0-3.162-.327a3 3 0 0 1-1.311-1.311C3 18.72 3 17.88 3 16.2V7.8Zm4.8-3.6h8.4c.86 0 1.433 0 1.873.037.426.035.62.096.744.16a1.8 1.8 0 0 1 .787.786c.063.123.124.318.16.744.035.44.036 1.013.036 1.873v8.4c0 .86 0 1.433-.037 1.873-.035.426-.096.62-.16.744a1.8 1.8 0 0 1-.786.787c-.123.063-.318.124-.744.16-.44.035-1.013.036-1.873.036H7.8c-.86 0-1.433 0-1.873-.037-.426-.035-.62-.096-.744-.16a1.8 1.8 0 0 1-.787-.786c-.063-.123-.124-.318-.16-.744-.035-.44-.036-1.013-.036-1.873V7.8c0-.86 0-1.433.037-1.873.035-.426.096-.62.16-.744a1.8 1.8 0 0 1 .786-.787c.123-.063.318-.124.744-.16C6.367 4.202 6.94 4.2 7.8 4.2Z" clip-rule="evenodd"/>
</svg>`;
  const EyeFill = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M5.333 7.014C7.017 5.61 9.263 4.4 12 4.4c2.738 0 4.984 1.21 6.667 2.614 1.682 1.404 2.84 3.033 3.42 3.952.008.01.014.021.02.032.12.19.24.377.3.644a1.76 1.76 0 0 1 0 .715c-.06.268-.18.456-.3.645l-.02.031c-.58.92-1.738 2.548-3.42 3.952C16.984 18.391 14.738 19.6 12 19.6s-4.983-1.21-6.667-2.615c-1.682-1.404-2.84-3.032-3.42-3.951l-.02-.032c-.12-.19-.239-.377-.3-.645a1.763 1.763 0 0 1 0-.715c.061-.267.18-.455.3-.644l.02-.032c.58-.92 1.738-2.548 3.42-3.952ZM12 9.6a2.4 2.4 0 1 0 0 4.8 2.4 2.4 0 0 0 0-4.8ZM8.4 12a3.6 3.6 0 1 1 7.2 0 3.6 3.6 0 0 1-7.2 0Z" clip-rule="evenodd"/>
</svg>`;
  const EyeSlashFill = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M3.425 2.576a.6.6 0 1 0-.849.848l3.22 3.22c-.158.122-.313.245-.463.37-1.682 1.404-2.84 3.033-3.42 3.952l-.02.032c-.12.19-.239.377-.3.645a1.762 1.762 0 0 0 0 .714c.061.268.18.456.3.645l.02.031c.58.92 1.738 2.548 3.42 3.952C7.017 18.391 9.263 19.6 12 19.6c2.008 0 3.75-.65 5.201-1.55l3.375 3.374a.6.6 0 0 0 .849-.848l-3.22-3.22v-.002l-3.27-3.27v.002l-.867-.867.001-.002-3.286-3.286-.002.001-.867-.867h.002L6.8 5.95 3.425 2.577Zm5.64 7.338a3.6 3.6 0 0 0 5.02 5.02l-.866-.866a2.4 2.4 0 0 1-3.287-3.287l-.866-.867Z" clip-rule="evenodd"/>
  <path fill="currentColor" d="M12.08 8.4a3.6 3.6 0 0 1 3.52 3.52l4.108 4.108a17.903 17.903 0 0 0 2.38-2.994l.02-.032c.12-.19.238-.377.3-.645a1.76 1.76 0 0 0 0-.714c-.062-.268-.18-.456-.3-.645l-.02-.032c-.58-.92-1.739-2.548-3.42-3.952C16.983 5.61 14.737 4.4 12 4.4c-1.2 0-2.304.232-3.309.611l3.39 3.39Z"/>
</svg>`;
  const EyeSlash = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M2.576 2.576a.6.6 0 0 1 .849 0l3.657 3.657a.598.598 0 0 1 .123.123l10.43 10.431a.6.6 0 0 1 .143.142l3.647 3.647a.6.6 0 0 1-.849.848l-3.375-3.375c-1.45.9-3.194 1.551-5.2 1.551-2.739 0-4.984-1.21-6.668-2.615-1.682-1.404-2.84-3.032-3.42-3.951a8.717 8.717 0 0 0-.02-.032c-.12-.19-.239-.377-.3-.645a1.762 1.762 0 0 1 0-.715c.061-.268.18-.455.3-.645l.02-.032c.63-.998 1.947-2.841 3.883-4.32l-3.22-3.22a.6.6 0 0 1 0-.85ZM6.653 7.5c-1.842 1.37-3.114 3.139-3.725 4.105-.146.232-.154.255-.166.305l-.003.027a.674.674 0 0 0 0 .124l.003.027c.012.05.02.073.165.304.545.862 1.625 2.377 3.175 3.671C7.652 17.357 9.633 18.4 12 18.4c1.63 0 3.078-.494 4.327-1.225l-2.24-2.24a3.6 3.6 0 0 1-5.02-5.02L6.652 7.5Zm3.28 3.28a2.4 2.4 0 0 0 3.287 3.287L9.933 10.78ZM12 5.6c-.402 0-.791.03-1.17.086a.6.6 0 0 1-.175-1.187A9.187 9.187 0 0 1 12 4.4c2.738 0 4.984 1.21 6.667 2.615 1.682 1.404 2.84 3.032 3.42 3.951l.02.032c.12.19.24.377.3.645.05.213.05.502 0 .715-.06.268-.18.456-.3.646l-.02.032a18.08 18.08 0 0 1-1.41 1.93.6.6 0 1 1-.92-.77 16.91 16.91 0 0 0 1.315-1.8c.147-.234.155-.257.166-.307l.004-.027a.706.706 0 0 0 0-.124l-.004-.027c-.011-.05-.019-.073-.165-.304-.544-.862-1.624-2.377-3.175-3.671C16.35 6.643 14.368 5.6 12 5.6Z" clip-rule="evenodd"/>
</svg>`;
  const Eye = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M6.102 7.936c-1.55 1.294-2.63 2.809-3.175 3.671-.146.231-.153.254-.165.304l-.003.027a.676.676 0 0 0 0 .124l.003.027c.012.05.02.073.165.304.545.862 1.625 2.377 3.175 3.671C7.652 17.357 9.633 18.4 12 18.4c2.367 0 4.35-1.043 5.898-2.336 1.55-1.294 2.63-2.809 3.175-3.671.146-.231.154-.254.165-.304l.004-.027a.667.667 0 0 0 0-.124l-.004-.027c-.011-.05-.019-.073-.165-.304-.544-.862-1.624-2.377-3.175-3.671C16.35 6.643 14.368 5.6 12 5.6c-2.367 0-4.349 1.043-5.898 2.336Zm-.769-.921C7.017 5.609 9.263 4.4 12 4.4c2.738 0 4.984 1.21 6.667 2.615 1.682 1.404 2.84 3.032 3.42 3.951l.02.032c.12.19.24.377.3.645a1.76 1.76 0 0 1 0 .714c-.06.268-.18.456-.3.645l-.02.032c-.58.92-1.738 2.547-3.42 3.951C16.984 18.391 14.738 19.6 12 19.6s-4.983-1.21-6.667-2.615c-1.682-1.404-2.84-3.032-3.42-3.951l-.02-.032c-.12-.19-.239-.377-.3-.645a1.763 1.763 0 0 1 0-.714c.061-.268.18-.456.3-.645l.02-.032c.58-.92 1.738-2.547 3.42-3.951ZM12 9.6a2.4 2.4 0 1 0 0 4.8 2.4 2.4 0 0 0 0-4.8ZM8.4 12a3.6 3.6 0 1 1 7.2 0 3.6 3.6 0 0 1-7.2 0Z" clip-rule="evenodd"/>
</svg>`;
  const Facebook = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M21 12.055C21 7.054 16.97 3 12.001 3 7.03 3.001 3 7.054 3 12.056c0 4.519 3.291 8.265 7.593 8.944v-6.327H8.309v-2.617h2.286V10.06c0-2.27 1.344-3.522 3.4-3.522.985 0 2.014.176 2.014.176v2.228h-1.135c-1.117 0-1.466.698-1.466 1.415v1.698h2.495l-.398 2.617h-2.098v6.327C17.71 20.319 21 16.574 21 12.055Z"/>
</svg>`;
  const FileEarmarkText = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M14.6 2.639a2.503 2.503 0 0 0-.275-.197 3.003 3.003 0 0 0-.893-.365C13.094 2 12.727 2 12.012 2H8.8c-1.68 0-2.52 0-3.162.327a3 3 0 0 0-1.311 1.311C4 4.28 4 5.12 4 6.8v10.4c0 1.68 0 2.52.327 3.162a3 3 0 0 0 1.311 1.311C6.28 22 7.12 22 8.8 22h6.4c1.68 0 2.52 0 3.162-.327a3 3 0 0 0 1.311-1.311C20 19.72 20 18.88 20 17.2V9.988c0-.715 0-1.082-.077-1.42a2.997 2.997 0 0 0-.365-.893 2.485 2.485 0 0 0-.197-.275c-.172-.211-.407-.446-.767-.806l-3.188-3.188c-.36-.36-.595-.595-.806-.767Zm-1.2.68a1.805 1.805 0 0 0-.222-.07c-.176-.041-.375-.049-1.166-.049H8.8c-.86 0-1.433 0-1.873.037-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744C5.202 5.367 5.2 5.94 5.2 6.8v10.4c0 .86 0 1.433.037 1.873.035.426.096.62.16.744a1.8 1.8 0 0 0 .786.787c.123.063.318.124.744.16.44.035 1.013.036 1.873.036h6.4c.86 0 1.433 0 1.873-.037.426-.035.62-.096.744-.16a1.8 1.8 0 0 0 .787-.786c.063-.123.124-.318.16-.744.035-.44.036-1.013.036-1.873V9.988c0-.79-.008-.99-.05-1.166a1.805 1.805 0 0 0-.069-.222h-3.103c-.261 0-.492 0-.684-.016a1.626 1.626 0 0 1-.62-.158 1.6 1.6 0 0 1-.7-.7 1.626 1.626 0 0 1-.158-.62c-.016-.192-.016-.423-.016-.684V3.32ZM17.703 7.4H15.6c-.29 0-.471 0-.608-.012a.493.493 0 0 1-.174-.032.4.4 0 0 1-.174-.174.494.494 0 0 1-.032-.174A8.479 8.479 0 0 1 14.6 6.4V4.297L17.703 7.4ZM14.6 17a.6.6 0 0 1-.6.6H8a.6.6 0 1 1 0-1.2h6a.6.6 0 0 1 .6.6Zm2-4a.6.6 0 0 1-.6.6H8a.6.6 0 1 1 0-1.2h8a.6.6 0 0 1 .6.6Z" clip-rule="evenodd"/>
</svg>`;
  const FilePdf = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M7.686 16.125a.911.911 0 0 0 .493.473c.213.072.447.06.652-.033.358-.148.716-.491 1.042-.885a12.82 12.82 0 0 0 1.149-1.699c.734-.217 1.485-.37 2.246-.457.3.395.643.754 1.025 1.07.314.248.677.453 1.05.468a.963.963 0 0 0 .573-.155c.172-.118.31-.28.399-.468a1.31 1.31 0 0 0 .155-.633.952.952 0 0 0-.225-.583c-.254-.304-.67-.45-1.08-.523a6.47 6.47 0 0 0-1.5-.056 12.32 12.32 0 0 1-1.103-1.897c.28-.743.49-1.445.585-2.019.04-.246.06-.48.053-.69a1.399 1.399 0 0 0-.143-.606.787.787 0 0 0-.537-.41c-.227-.049-.461 0-.677.086-.423.17-.647.528-.731.926-.083.383-.045.828.051 1.278.115.5.277.988.484 1.457-.345.86-.745 1.696-1.195 2.506A8.645 8.645 0 0 0 8.785 14c-.417.247-.786.54-1.01.886-.235.366-.308.803-.09 1.24Zm1.528-1.398c.156-.092.33-.182.516-.268a9.2 9.2 0 0 1-.506.682c-.315.38-.56.58-.715.643a.304.304 0 0 1-.039.014.257.257 0 0 1-.03-.05c-.062-.124-.06-.242.046-.406.12-.184.359-.397.728-.615Zm3.497-1.981c-.381.057-.76.13-1.136.217v-.001c.199-.389.386-.782.563-1.181.177.33.368.651.573.965Zm1.617.724c.168.182.332.337.488.46.27.214.458.285.56.289a.12.12 0 0 0 .08-.017.345.345 0 0 0 .105-.141.49.49 0 0 0 .066-.225.107.107 0 0 0-.029-.07c-.058-.07-.225-.172-.583-.236a4.363 4.363 0 0 0-.687-.06Zm-2.24-3.947a7.41 7.41 0 0 0 .225-.93c.035-.211.048-.385.043-.523a.689.689 0 0 0-.036-.222.581.581 0 0 0-.163.045c-.098.039-.178.119-.22.318-.046.216-.035.528.05.925.028.124.061.254.102.387Z" clip-rule="evenodd"/>
  <path fill="currentColor" fill-rule="evenodd" d="M4 6.8c0-1.68 0-2.52.327-3.162a3 3 0 0 1 1.311-1.311C6.28 2 7.12 2 8.8 2h6.4c1.68 0 2.52 0 3.162.327a3 3 0 0 1 1.311 1.311C20 4.28 20 5.12 20 6.8v10.4c0 1.68 0 2.52-.327 3.162a3 3 0 0 1-1.311 1.311C17.72 22 16.88 22 15.2 22H8.8c-1.68 0-2.52 0-3.162-.327a3 3 0 0 1-1.311-1.311C4 19.72 4 18.88 4 17.2V6.8Zm11.2 14H8.8c-.86 0-1.433 0-1.873-.037-.426-.035-.62-.096-.744-.16a1.8 1.8 0 0 1-.787-.786c-.063-.123-.124-.318-.16-.744-.035-.44-.036-1.013-.036-1.873V6.8c0-.86 0-1.433.037-1.873.035-.426.096-.62.16-.744a1.8 1.8 0 0 1 .786-.787c.123-.063.318-.124.744-.16C7.367 3.202 7.94 3.2 8.8 3.2h6.4c.86 0 1.433 0 1.873.037.426.035.62.096.744.16a1.8 1.8 0 0 1 .787.786c.063.123.124.318.16.744.035.44.036 1.013.036 1.873v10.4c0 .86 0 1.433-.037 1.873-.035.426-.096.62-.16.744a1.8 1.8 0 0 1-.786.787c-.123.063-.318.124-.744.16-.44.035-1.013.036-1.873.036Z" clip-rule="evenodd"/>
</svg>`;
  const FilePlus = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M14.727 1.9H9.274c-.818 0-1.468 0-1.993.043-.537.044-.995.136-1.415.35a3.6 3.6 0 0 0-1.573 1.573c-.214.42-.306.877-.35 1.415C3.9 5.806 3.9 6.456 3.9 7.274v9.452c0 .818 0 1.469.043 1.993.044.538.136.996.35 1.415a3.6 3.6 0 0 0 1.573 1.574c.42.213.878.305 1.415.35.525.042 1.175.042 1.993.042H12.5a.6.6 0 1 0 0-1.2H9.3c-.85 0-1.451 0-1.921-.039-.463-.038-.746-.11-.968-.223a2.4 2.4 0 0 1-1.049-1.048c-.113-.223-.185-.505-.223-.968-.038-.47-.039-1.072-.039-1.922V7.3c0-.85 0-1.451.04-1.922.037-.463.109-.745.222-.968a2.4 2.4 0 0 1 1.049-1.048c.222-.114.505-.185.968-.223C7.849 3.1 8.45 3.1 9.3 3.1h5.4c.85 0 1.452 0 1.922.039.463.038.746.11.968.223a2.4 2.4 0 0 1 1.049 1.048c.113.223.185.505.223.968.038.47.038 1.072.038 1.922V11a.6.6 0 1 0 1.2 0V7.274c0-.818 0-1.468-.043-1.993-.043-.538-.135-.996-.349-1.415a3.6 3.6 0 0 0-1.573-1.574c-.42-.213-.878-.305-1.415-.35-.525-.042-1.175-.042-1.993-.042Z"/>
  <path fill="currentColor" d="M18.6 15a.6.6 0 0 0-1.2 0v2.4H15a.6.6 0 0 0 0 1.2h2.4V21a.6.6 0 1 0 1.2 0v-2.4H21a.6.6 0 1 0 0-1.2h-2.4V15Z"/>
</svg>`;
  const FileText = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M14.6 11a.6.6 0 0 1-.6.6H8a.6.6 0 1 1 0-1.2h6a.6.6 0 0 1 .6.6Zm-4 4a.6.6 0 0 1-.6.6H8a.6.6 0 1 1 0-1.2h2a.6.6 0 0 1 .6.6Zm6-8a.6.6 0 0 1-.6.6H8a.6.6 0 0 1 0-1.2h8a.6.6 0 0 1 .6.6ZM8.8 20.8h6.4c.86 0 1.433 0 1.873-.037.426-.035.62-.096.744-.16a1.8 1.8 0 0 0 .787-.786c.063-.123.124-.318.16-.744.035-.44.036-1.013.036-1.873V6.8c0-.86 0-1.433-.037-1.873-.035-.426-.096-.62-.16-.744a1.8 1.8 0 0 0-.786-.787c-.123-.063-.318-.124-.744-.16-.44-.035-1.013-.036-1.873-.036H8.8c-.86 0-1.433 0-1.873.037-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744C5.202 5.367 5.2 5.94 5.2 6.8v10.4c0 .86 0 1.433.037 1.873.035.426.096.62.16.744a1.8 1.8 0 0 0 .786.787c.123.063.318.124.744.16.44.035 1.013.036 1.873.036ZM4.327 3.638C4 4.28 4 5.12 4 6.8v10.4c0 1.68 0 2.52.327 3.162a3 3 0 0 0 1.311 1.311C6.28 22 7.12 22 8.8 22h6.4c1.68 0 2.52 0 3.162-.327a3 3 0 0 0 1.311-1.311C20 19.72 20 18.88 20 17.2V6.8c0-1.68 0-2.52-.327-3.162a3 3 0 0 0-1.311-1.311C17.72 2 16.88 2 15.2 2H8.8c-1.68 0-2.52 0-3.162.327a3 3 0 0 0-1.311 1.311Z" clip-rule="evenodd"/>
</svg>`;
  const File = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M8.8 20.8h6.4c.86 0 1.433 0 1.873-.037.426-.035.62-.096.744-.16a1.8 1.8 0 0 0 .787-.786c.063-.123.124-.318.16-.744.035-.44.036-1.013.036-1.873V6.8c0-.86 0-1.433-.037-1.873-.035-.426-.096-.62-.16-.744a1.8 1.8 0 0 0-.786-.787c-.123-.063-.318-.124-.744-.16-.44-.035-1.013-.036-1.873-.036H8.8c-.86 0-1.433 0-1.873.037-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744C5.202 5.367 5.2 5.94 5.2 6.8v10.4c0 .86 0 1.433.037 1.873.035.426.096.62.16.744a1.8 1.8 0 0 0 .786.787c.123.063.318.124.744.16.44.035 1.013.036 1.873.036ZM4.327 3.638C4 4.28 4 5.12 4 6.8v10.4c0 1.68 0 2.52.327 3.162a3 3 0 0 0 1.311 1.311C6.28 22 7.12 22 8.8 22h6.4c1.68 0 2.52 0 3.162-.327a3 3 0 0 0 1.311-1.311C20 19.72 20 18.88 20 17.2V6.8c0-1.68 0-2.52-.327-3.162a3 3 0 0 0-1.311-1.311C17.72 2 16.88 2 15.2 2H8.8c-1.68 0-2.52 0-3.162.327a3 3 0 0 0-1.311 1.311Z" clip-rule="evenodd"/>
</svg>`;
  const Files = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M18.8 6.8v9.8a.6.6 0 1 0 1.2 0V6.8c0-1.68 0-2.52-.327-3.162a3 3 0 0 0-1.311-1.311C17.72 2 16.88 2 15.2 2H9.4a.6.6 0 1 0 0 1.2h5.8c.86 0 1.432 0 1.873.037.425.035.62.096.744.16a1.8 1.8 0 0 1 .787.786c.063.123.124.318.159.744.036.44.037 1.013.037 1.873Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M4 9.8c0-1.68 0-2.52.327-3.162a3 3 0 0 1 1.311-1.311C6.28 5 7.12 5 8.8 5h3.4c1.68 0 2.52 0 3.162.327a3 3 0 0 1 1.311 1.311C17 7.28 17 8.12 17 9.8v7.4c0 1.68 0 2.52-.327 3.162a3 3 0 0 1-1.311 1.311C14.72 22 13.88 22 12.2 22H8.8c-1.68 0-2.52 0-3.162-.327a3 3 0 0 1-1.311-1.311C4 19.72 4 18.88 4 17.2V9.8Zm8.2 11H8.8c-.86 0-1.433 0-1.873-.037-.426-.035-.62-.096-.744-.16a1.8 1.8 0 0 1-.787-.786c-.063-.123-.124-.318-.16-.744-.035-.44-.036-1.013-.036-1.873V9.8c0-.86 0-1.433.037-1.873.035-.426.096-.62.16-.744a1.8 1.8 0 0 1 .786-.787c.123-.063.318-.124.744-.16C7.367 6.202 7.94 6.2 8.8 6.2h3.4c.86 0 1.433 0 1.873.037.426.035.62.096.744.16a1.8 1.8 0 0 1 .787.786c.063.123.124.318.16.744.035.44.036 1.013.036 1.873v7.4c0 .86 0 1.433-.037 1.873-.035.426-.096.62-.16.744a1.8 1.8 0 0 1-.786.787c-.123.063-.318.124-.744.16-.44.035-1.013.036-1.873.036Z" clip-rule="evenodd"/>
</svg>`;
  const FolderCheck = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M15.925 11.924a.6.6 0 1 0-.849-.848L11 15.15l-1.575-1.575a.6.6 0 1 0-.849.848l2 2a.6.6 0 0 0 .849 0l4.5-4.5Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M12.871 6.9h3.856c.817 0 1.468 0 1.993.043.537.044.995.136 1.415.35a3.6 3.6 0 0 1 1.573 1.573c.214.42.306.877.35 1.415.042.524.042 1.175.042 1.993v3.452c0 .818 0 1.469-.043 1.993-.043.538-.135.996-.349 1.415a3.6 3.6 0 0 1-1.573 1.574c-.42.213-.878.305-1.415.35-.525.042-1.176.042-1.993.042H7.274c-.818 0-1.468 0-1.993-.043-.537-.044-.995-.136-1.415-.35a3.6 3.6 0 0 1-1.573-1.573c-.214-.42-.306-.877-.35-1.415-.043-.524-.043-1.175-.043-1.993V6.675c0-.539 0-.98.03-1.337.03-.371.095-.706.254-1.018A2.6 2.6 0 0 1 3.32 3.183c.313-.159.647-.224 1.018-.254.358-.029.799-.029 1.337-.029h2.943c.625 0 1.08 0 1.494.142a2.6 2.6 0 0 1 .972.6c.312.307.516.714.795 1.273L12.87 6.9ZM8.523 4.1c.761 0 .999.008 1.198.076a1.4 1.4 0 0 1 .523.324c.15.147.264.356.604 1.037L11.53 6.9H3.1v-.2c0-.57 0-.961.026-1.265.024-.296.068-.455.127-.57a1.4 1.4 0 0 1 .612-.612c.115-.06.274-.104.57-.128C4.74 4.1 5.13 4.1 5.7 4.1h2.823Zm3.99 4H3.1v7.6c0 .85 0 1.451.04 1.922.037.463.109.745.222.968a2.4 2.4 0 0 0 1.049 1.048c.222.114.505.185.968.223.47.038 1.071.039 1.921.039h9.4c.85 0 1.452 0 1.922-.039.463-.038.746-.11.968-.223a2.4 2.4 0 0 0 1.049-1.049c.113-.222.185-.504.223-.967.038-.47.038-1.072.038-1.922v-3.4c0-.85 0-1.451-.038-1.922-.038-.463-.11-.745-.223-.968a2.4 2.4 0 0 0-1.049-1.048c-.222-.114-.505-.185-.968-.223C18.152 8.1 17.55 8.1 16.7 8.1h-4.187Z" clip-rule="evenodd"/>
</svg>`;
  const FolderMinus = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M9 13.4h6a.6.6 0 0 1 0 1.2H9a.6.6 0 1 1 0-1.2Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M16.727 6.9H12.87l-.992-1.985c-.28-.559-.483-.966-.795-1.273a2.6 2.6 0 0 0-.972-.6C9.698 2.9 9.243 2.9 8.618 2.9H5.675c-.538 0-.979 0-1.337.03-.37.03-.705.094-1.018.253A2.6 2.6 0 0 0 2.184 4.32c-.16.312-.224.647-.254 1.018-.03.358-.03.798-.03 1.337v9.051c0 .818 0 1.469.043 1.993.044.538.136.996.35 1.415a3.6 3.6 0 0 0 1.573 1.574c.42.213.878.305 1.415.35.525.042 1.175.042 1.993.042h9.453c.817 0 1.468 0 1.993-.043.537-.044.995-.136 1.415-.35a3.6 3.6 0 0 0 1.573-1.573c.214-.42.306-.877.35-1.415.042-.524.042-1.175.042-1.993v-3.452c0-.818 0-1.468-.043-1.993-.043-.538-.135-.996-.349-1.415a3.6 3.6 0 0 0-1.573-1.574c-.42-.213-.878-.305-1.415-.35-.525-.042-1.175-.042-1.993-.042ZM9.72 4.176c-.2-.068-.437-.076-1.198-.076H5.7c-.57 0-.96 0-1.264.025-.297.024-.456.069-.571.128a1.4 1.4 0 0 0-.612.611c-.059.116-.103.275-.127.571C3.1 5.74 3.1 6.13 3.1 6.7v.2h8.43l-.682-1.363c-.34-.68-.454-.89-.604-1.037a1.4 1.4 0 0 0-.523-.324ZM12.488 8.1H16.7c.85 0 1.452 0 1.922.039.463.038.746.11.968.223a2.4 2.4 0 0 1 1.049 1.048c.113.223.185.505.223.968.038.47.038 1.072.038 1.922v3.4c0 .85 0 1.451-.038 1.922-.038.463-.11.745-.223.968a2.4 2.4 0 0 1-1.049 1.048c-.222.114-.505.185-.968.223-.47.038-1.072.039-1.922.039H7.3c-.85 0-1.451 0-1.921-.039-.463-.038-.746-.11-.968-.223a2.4 2.4 0 0 1-1.049-1.049c-.113-.222-.185-.504-.223-.967-.038-.47-.039-1.072-.039-1.922V8.1h9.388Z" clip-rule="evenodd"/>
</svg>`;
  const FolderPlus = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M12.6 11a.6.6 0 0 0-1.2 0v2.4H9a.6.6 0 0 0 0 1.2h2.4V17a.6.6 0 1 0 1.2 0v-2.4H15a.6.6 0 1 0 0-1.2h-2.4V11Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M12.871 6.9h3.856c.817 0 1.468 0 1.993.043.537.044.995.136 1.415.35a3.6 3.6 0 0 1 1.573 1.573c.214.42.306.877.35 1.415.042.524.042 1.175.042 1.993v3.452c0 .818 0 1.469-.043 1.993-.043.538-.135.996-.349 1.415a3.6 3.6 0 0 1-1.573 1.574c-.42.213-.878.305-1.415.35-.525.042-1.176.042-1.993.042H7.274c-.818 0-1.468 0-1.993-.043-.537-.044-.995-.136-1.415-.35a3.6 3.6 0 0 1-1.573-1.573c-.214-.42-.306-.877-.35-1.415-.043-.524-.043-1.175-.043-1.993V6.675c0-.539 0-.98.03-1.337.03-.371.095-.706.254-1.018A2.6 2.6 0 0 1 3.32 3.183c.313-.159.647-.224 1.018-.254.358-.029.799-.029 1.337-.029h2.943c.625 0 1.08 0 1.494.142a2.6 2.6 0 0 1 .972.6c.312.307.516.714.795 1.273L12.87 6.9ZM8.523 4.1c.761 0 .999.008 1.198.076a1.4 1.4 0 0 1 .523.324c.15.147.264.356.604 1.037L11.53 6.9H3.1v-.2c0-.57 0-.961.026-1.265.024-.296.068-.455.127-.57a1.4 1.4 0 0 1 .612-.612c.115-.06.274-.104.57-.128C4.74 4.1 5.13 4.1 5.7 4.1h2.823Zm3.99 4H3.1v7.6c0 .85 0 1.451.04 1.922.037.463.109.745.222.968a2.4 2.4 0 0 0 1.049 1.048c.222.114.505.185.968.223.47.038 1.071.039 1.921.039h9.4c.85 0 1.452 0 1.922-.039.463-.038.746-.11.968-.223a2.4 2.4 0 0 0 1.049-1.049c.113-.222.185-.504.223-.967.038-.47.038-1.072.038-1.922v-3.4c0-.85 0-1.451-.038-1.922-.038-.463-.11-.745-.223-.968a2.4 2.4 0 0 0-1.049-1.048c-.222-.114-.505-.185-.968-.223C18.152 8.1 17.55 8.1 16.7 8.1h-4.187Z" clip-rule="evenodd"/>
</svg>`;
  const Folder = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M9.72 4.176c-.199-.068-.436-.076-1.198-.076H5.7c-.57 0-.961 0-1.265.025-.296.024-.455.069-.57.128a1.4 1.4 0 0 0-.613.611c-.058.116-.103.275-.127.571C3.1 5.74 3.1 6.13 3.1 6.7v.2h8.43l-.682-1.363c-.34-.68-.454-.89-.605-1.037a1.4 1.4 0 0 0-.523-.324ZM12.87 6.9 11.922 5l-.043-.085c-.279-.559-.482-.966-.795-1.273a2.6 2.6 0 0 0-.971-.6C9.698 2.9 9.242 2.9 8.618 2.9H5.675c-.539 0-.98 0-1.338.03-.37.03-.705.094-1.017.253A2.6 2.6 0 0 0 2.183 4.32c-.159.312-.224.647-.254 1.018-.03.358-.03.798-.03 1.337v9.051c0 .818 0 1.469.044 1.993.044.538.136.996.35 1.415a3.6 3.6 0 0 0 1.573 1.574c.42.213.877.305 1.415.35.524.042 1.175.042 1.993.042h9.452c.818 0 1.468 0 1.993-.043.537-.044.996-.136 1.415-.35a3.6 3.6 0 0 0 1.573-1.573c.214-.42.306-.877.35-1.415.043-.524.043-1.175.043-1.993v-3.452c0-.818 0-1.468-.043-1.993-.044-.538-.136-.996-.35-1.415a3.6 3.6 0 0 0-1.573-1.574c-.42-.213-.878-.305-1.415-.35-.525-.042-1.175-.042-1.993-.042h-3.855Zm-.382 1.2H16.7c.85 0 1.451 0 1.921.039.464.038.746.11.969.223a2.4 2.4 0 0 1 1.048 1.048c.113.223.185.505.223.968.038.47.039 1.072.039 1.922v3.4c0 .85 0 1.451-.039 1.922-.038.463-.11.745-.223.968a2.4 2.4 0 0 1-1.049 1.048c-.222.114-.504.185-.968.223-.47.038-1.071.039-1.921.039H7.3c-.85 0-1.451 0-1.922-.039-.463-.038-.745-.11-.968-.223a2.4 2.4 0 0 1-1.049-1.049c-.113-.222-.184-.504-.222-.967-.039-.47-.04-1.072-.04-1.922V8.1h9.389Z" clip-rule="evenodd"/>
</svg>`;
  const Gear = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M12 2.6a1.218 1.218 0 0 0-1.218 1.218v.157a2.1 2.1 0 0 1-1.273 1.922.6.6 0 0 1-.188.047 2.1 2.1 0 0 1-2.2-.474l-.055-.055a1.218 1.218 0 1 0-1.724 1.724l.055.055a2.1 2.1 0 0 1 .432 2.304 2.1 2.1 0 0 1-1.93 1.357h-.08a1.218 1.218 0 1 0 0 2.436h.156a2.1 2.1 0 0 1 1.92 1.27 2.1 2.1 0 0 1-.425 2.318l-.055.055a1.219 1.219 0 1 0 1.724 1.724l.055-.055.003-.003.002-.002a2.1 2.1 0 0 1 2.299-.427 2.1 2.1 0 0 1 1.356 1.915v.096a1.218 1.218 0 0 0 2.437 0v-.157a2.1 2.1 0 0 1 1.27-1.92 2.1 2.1 0 0 1 2.313.42l.005.005.054.055a1.22 1.22 0 1 0 1.725-1.724l-.055-.055-.005-.005a2.099 2.099 0 0 1-.421-2.313 2.1 2.1 0 0 1 1.92-1.27h.085a1.218 1.218 0 1 0 0-2.436h-.157a2.1 2.1 0 0 1-1.922-1.273.6.6 0 0 1-.047-.188 2.1 2.1 0 0 1 .47-2.195l.002-.003.002-.002.055-.055a1.219 1.219 0 1 0-1.724-1.724l-.055.055-.005.005a2.1 2.1 0 0 1-2.313.421 2.1 2.1 0 0 1-1.27-1.92v-.085A1.218 1.218 0 0 0 12 2.6Zm-1.71-.492a2.418 2.418 0 0 1 4.128 1.71v.08a.9.9 0 0 0 .551.826.9.9 0 0 0 .991-.178l.052-.052a2.417 2.417 0 0 1 3.421 0 2.418 2.418 0 0 1 0 3.421l-.052.052a.9.9 0 0 0-.178.99c.024.054.04.11.047.168a.9.9 0 0 0 .779.457h.153a2.418 2.418 0 1 1 0 4.836h-.08a.9.9 0 0 0-.823.546l-.003.006a.9.9 0 0 0 .178.99l.052.052a2.42 2.42 0 1 1-3.421 3.421l-.052-.052a.9.9 0 0 0-.99-.178l-.007.003a.9.9 0 0 0-.545.823v.153a2.418 2.418 0 1 1-4.837 0v-.074a.9.9 0 0 0-.624-.832.9.9 0 0 0-.99.178l-.052.052a2.419 2.419 0 1 1-3.421-3.421l.051-.052a.9.9 0 0 0 .178-.99v-.004l-.002-.003a.9.9 0 0 0-.823-.545h-.153a2.418 2.418 0 1 1 0-4.836h.074a.9.9 0 0 0 .832-.625.9.9 0 0 0-.178-.99l-.052-.052a2.42 2.42 0 1 1 3.421-3.421l.052.052a.9.9 0 0 0 .99.178.6.6 0 0 1 .168-.047.9.9 0 0 0 .457-.779v-.153c0-.641.254-1.256.708-1.71ZM8.4 12a3.6 3.6 0 1 1 7.2 0 3.6 3.6 0 0 1-7.2 0ZM12 9.6a2.4 2.4 0 1 0 0 4.8 2.4 2.4 0 0 0 0-4.8Z" clip-rule="evenodd"/>
</svg>`;
  const GeoAlt = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M12 13a3 3 0 1 0 0-6 3 3 0 0 0 0 6Zm1.8-3a1.8 1.8 0 1 1-3.6 0 1.8 1.8 0 0 1 3.6 0Z" clip-rule="evenodd"/>
  <path fill="currentColor" fill-rule="evenodd" d="M12.959 21.046c-.318.316-.639.634-.959.954l-.005-.005c-.319-.319-.637-.635-.954-.948C7.385 17.42 4 14.064 4 10a8 8 0 1 1 16 0c0 4.064-3.385 7.421-7.041 11.046ZM18.8 10c0 1.829-.824 3.572-2.25 5.425-1.207 1.566-2.75 3.098-4.42 4.754l-.13.128-.13-.128c-1.67-1.656-3.213-3.188-4.42-4.754C6.025 13.572 5.2 11.829 5.2 10a6.8 6.8 0 1 1 13.6 0Z" clip-rule="evenodd"/>
</svg>`;
  const GeoFill = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M12 2.4a3.6 3.6 0 0 0-.6 7.15V17a.6.6 0 1 0 1.2 0V9.55A3.601 3.601 0 0 0 12 2.4Z" clip-rule="evenodd"/>
  <path fill="currentColor" d="M8.316 13.963a.6.6 0 1 0-.231-1.177c-1.729.34-3.236.904-4.328 1.64-1.08.728-1.857 1.702-1.857 2.868 0 1.563 1.38 2.78 3.137 3.57 1.813.816 4.275 1.305 6.963 1.305 2.688 0 5.151-.49 6.964-1.305 1.757-.79 3.136-2.007 3.136-3.57 0-1.166-.777-2.14-1.856-2.867-1.092-.737-2.6-1.302-4.328-1.641a.6.6 0 1 0-.231 1.177c1.627.32 2.97.839 3.888 1.458.932.63 1.327 1.285 1.327 1.873 0 .797-.747 1.719-2.428 2.475-1.626.732-3.913 1.2-6.472 1.2-2.558 0-4.846-.468-6.47-1.2-1.683-.756-2.43-1.678-2.43-2.475 0-.588.395-1.244 1.328-1.873.919-.62 2.261-1.138 3.888-1.458Z"/>
</svg>`;
  const Geo = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M12 2.4a3.6 3.6 0 0 0-.6 7.15V17a.6.6 0 1 0 1.2 0V9.55A3.601 3.601 0 0 0 12 2.4ZM9.6 6a2.4 2.4 0 1 1 4.8 0 2.4 2.4 0 0 1-4.8 0Z" clip-rule="evenodd"/>
  <path fill="currentColor" d="M8.316 13.963a.6.6 0 1 0-.231-1.177c-1.729.34-3.236.904-4.328 1.64-1.08.728-1.857 1.702-1.857 2.868 0 1.563 1.38 2.78 3.137 3.57 1.813.816 4.275 1.305 6.963 1.305 2.688 0 5.151-.49 6.964-1.305 1.757-.79 3.136-2.007 3.136-3.57 0-1.166-.777-2.14-1.856-2.867-1.092-.737-2.6-1.301-4.328-1.641a.6.6 0 1 0-.231 1.177c1.627.32 2.97.839 3.888 1.459.932.628 1.327 1.285 1.327 1.872 0 .797-.747 1.719-2.428 2.475-1.626.732-3.913 1.2-6.472 1.2-2.558 0-4.846-.468-6.47-1.2-1.683-.756-2.43-1.678-2.43-2.475 0-.587.395-1.244 1.328-1.873.919-.62 2.261-1.138 3.888-1.458Z"/>
</svg>`;
  const GlobeAlt = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M16.75 5.2a.863.863 0 1 0 0 1.725.863.863 0 0 0 0-1.725Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M1.875 12c0-.387.022-.768.064-1.144l.002-.019C2.518 5.793 6.801 1.875 12 1.875c.999 0 1.964.145 2.877.415a4.425 4.425 0 0 1 6.298 4.01c0 .384-.054.752-.15 1.106a10.08 10.08 0 0 1 1.1 4.594c0 5.592-4.533 10.125-10.125 10.125S1.875 17.592 1.875 12ZM12 3.125a8.878 8.878 0 0 0-8.697 7.1l4.454-.398a1.1 1.1 0 0 1 1.053.55l1.748 3.065 2.678 1.53a1.1 1.1 0 0 1 .29 1.671L11.2 19.356v1.483A8.875 8.875 0 0 0 20.875 12a8.854 8.854 0 0 0-.544-3.066c-.146.23-.305.454-.473.673-.627.813-1.428 1.608-2.22 2.393-.15.148-.299.295-.446.443a.625.625 0 0 1-.884 0c-.147-.148-.296-.295-.446-.443-.792-.785-1.593-1.58-2.22-2.393-.75-.975-1.317-2.059-1.317-3.306 0-1.179.46-2.25 1.212-3.043A8.935 8.935 0 0 0 12 3.125ZM13.575 6.3a3.175 3.175 0 0 1 6.35 0c0 .851-.383 1.667-1.058 2.543-.57.741-1.3 1.465-2.094 2.252l-.023.023-.023-.023c-.794-.787-1.524-1.511-2.094-2.252-.675-.876-1.058-1.692-1.058-2.543ZM3.125 12c0-.17.005-.339.014-.506l4.633-.413 1.72 3.016a1.1 1.1 0 0 0 .41.41l2.556 1.46-2.243 2.618a1.1 1.1 0 0 0-.265.716v1.336A8.879 8.879 0 0 1 3.125 12Z" clip-rule="evenodd"/>
</svg>`;
  const Globe = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M1.875 12C1.875 6.408 6.408 1.875 12 1.875S22.125 6.408 22.125 12 17.592 22.125 12 22.125 1.875 17.592 1.875 12Zm1.531-2.225A8.89 8.89 0 0 0 3.125 12c0 .768.098 1.514.281 2.225h4.378a15.16 15.16 0 0 1-.209-2.238 15.16 15.16 0 0 1 .209-2.212H3.406Zm.425-1.25h4.22a15.16 15.16 0 0 1 2.53-5.287 8.887 8.887 0 0 0-6.75 5.287ZM12 3.453a13.91 13.91 0 0 0-2.655 5.072h5.31A13.911 13.911 0 0 0 12 3.453Zm2.947 6.322H9.053c-.135.73-.212 1.474-.228 2.225.016.75.093 1.495.228 2.225h5.894c.135-.73.212-1.474.228-2.225a13.92 13.92 0 0 0-.228-2.225Zm1.269 4.45c.123-.727.193-1.466.209-2.212v-.026a15.169 15.169 0 0 0-.209-2.212h4.378a8.919 8.919 0 0 1 0 4.45h-4.378Zm-1.56 1.25H9.344A13.911 13.911 0 0 0 12 20.547a13.912 13.912 0 0 0 2.655-5.072Zm-4.075 5.287a15.161 15.161 0 0 1-2.53-5.287H3.83a8.887 8.887 0 0 0 6.75 5.287Zm2.838 0a15.16 15.16 0 0 0 2.53-5.287h4.22a8.887 8.887 0 0 1-6.75 5.287Zm6.75-12.237h-4.22a15.16 15.16 0 0 0-2.53-5.287 8.887 8.887 0 0 1 6.75 5.287Z" clip-rule="evenodd"/>
</svg>`;
  const Google = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M20.666 10.378a10.6 10.6 0 0 1 .156 1.83c0 2.737-.979 5.053-2.682 6.62h.002C16.653 20.203 14.606 21 12.178 21a9 9 0 0 1 0-18 8.65 8.65 0 0 1 6.02 2.343l-2.569 2.57a4.89 4.89 0 0 0-3.451-1.35c-2.348 0-4.342 1.583-5.053 3.716a5.39 5.39 0 0 0 0 3.446h.003c.714 2.13 2.706 3.713 5.053 3.713 1.213 0 2.255-.31 3.063-.86h-.004a4.163 4.163 0 0 0 1.799-2.734h-4.861V10.38h8.488Z"/>
</svg>`;
  const GridFill = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M4.568 2c-.252 0-.498 0-.706.017a2.022 2.022 0 0 0-.77.201 2 2 0 0 0-.874.874 2.022 2.022 0 0 0-.201.77C2 4.07 2 4.316 2 4.568v3.864c0 .252 0 .498.017.706.019.229.063.499.201.77a2 2 0 0 0 .874.874c.271.138.541.182.77.201.208.017.454.017.706.017h3.864c.252 0 .498 0 .706-.017a2.03 2.03 0 0 0 .77-.201 2 2 0 0 0 .874-.874 2.03 2.03 0 0 0 .201-.77C11 8.93 11 8.684 11 8.432V4.568c0-.252 0-.498-.017-.706a2.022 2.022 0 0 0-.201-.77 2 2 0 0 0-.874-.874 2.022 2.022 0 0 0-.77-.201C8.93 2 8.684 2 8.432 2H4.568Zm14.864 0h-3.864c-.252 0-.498 0-.706.017a2.022 2.022 0 0 0-.77.201 2 2 0 0 0-.874.874 2.022 2.022 0 0 0-.201.77C13 4.07 13 4.316 13 4.568v3.864c0 .252 0 .498.017.706.019.229.063.499.201.77a2 2 0 0 0 .874.874c.271.138.541.182.77.201.208.017.454.017.706.017h3.864c.252 0 .498 0 .706-.017a2.03 2.03 0 0 0 .77-.201 2 2 0 0 0 .874-.874 2.03 2.03 0 0 0 .201-.77C22 8.93 22 8.684 22 8.432V4.568c0-.252 0-.498-.017-.706a2.022 2.022 0 0 0-.201-.77 2 2 0 0 0-.874-.874 2.022 2.022 0 0 0-.77-.201C19.93 2 19.684 2 19.432 2Zm-11 11H4.568c-.252 0-.498 0-.706.017a2.022 2.022 0 0 0-.77.201 2 2 0 0 0-.874.874 2.022 2.022 0 0 0-.201.77C2 15.07 2 15.316 2 15.568v3.864c0 .252 0 .498.017.706.019.229.063.499.201.77a2 2 0 0 0 .874.874c.271.138.541.182.77.201.208.017.454.017.706.017h3.864c.252 0 .498 0 .706-.017a2.03 2.03 0 0 0 .77-.201 2 2 0 0 0 .874-.874 2.03 2.03 0 0 0 .201-.77c.017-.208.017-.454.017-.706v-3.864c0-.252 0-.498-.017-.706a2.022 2.022 0 0 0-.201-.77 2 2 0 0 0-.874-.874 2.022 2.022 0 0 0-.77-.201C8.93 13 8.684 13 8.432 13Zm11 0h-3.864c-.252 0-.498 0-.706.017a2.022 2.022 0 0 0-.77.201 2 2 0 0 0-.874.874 2.022 2.022 0 0 0-.201.77c-.017.208-.017.454-.017.706v3.864c0 .252 0 .498.017.706.019.229.063.499.201.77a2 2 0 0 0 .874.874c.271.138.541.182.77.201.208.017.454.017.706.017h3.864c.252 0 .498 0 .706-.017a2.03 2.03 0 0 0 .77-.201 2 2 0 0 0 .874-.874 2.03 2.03 0 0 0 .201-.77c.017-.208.017-.454.017-.706v-3.864c0-.252 0-.498-.017-.706a2.022 2.022 0 0 0-.201-.77 2 2 0 0 0-.874-.874 2.022 2.022 0 0 0-.77-.201C19.93 13 19.684 13 19.432 13Z"/>
</svg>`;
  const HandThumbsDown = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M19.404 3.124a16.396 16.396 0 0 0-1.199-.024h-1.11v9.254c.106-.004.212-.004.32-.004h.79c.542 0 .913 0 1.2-.024.28-.023.426-.064.53-.118a1.3 1.3 0 0 0 .569-.568c.053-.104.095-.251.117-.53.024-.288.024-.658.024-1.2V5.54c0-.542 0-.912-.023-1.2-.023-.279-.065-.426-.118-.53a1.3 1.3 0 0 0-.569-.568c-.104-.054-.25-.095-.53-.118Zm-3.509 9.82V3.1H8.057c-.703 0-1.197 0-1.586.03-.382.03-.618.084-.81.17a2.25 2.25 0 0 0-.955.82c-.115.176-.205.402-.292.774-.088.38-.164.869-.27 1.564l-.497 3.23c-.141.915-.24 1.564-.274 2.073-.034.503.002.805.092 1.04.186.489.536.897.99 1.155.22.125.513.206 1.015.25.508.043 1.164.044 2.09.044h.787c.248 0 .468 0 .651.015.196.016.4.052.601.154.292.149.529.386.677.677.103.2.138.406.154.601.015.183.015.404.015.651v2.81c0 .962.78 1.742 1.743 1.742a.181.181 0 0 0 .165-.107l3.193-7.184c.01-.02.018-.041.027-.062.095-.215.188-.426.322-.603ZM8.034 1.9c-.674 0-1.214 0-1.654.033-.453.035-.844.107-1.213.275A3.45 3.45 0 0 0 3.7 3.465c-.222.34-.352.715-.455 1.157-.1.43-.182.964-.285 1.63l-.505 3.281c-.135.882-.243 1.582-.28 2.148-.04.578-.01 1.08.168 1.549a3.45 3.45 0 0 0 1.518 1.769c.436.248.928.352 1.505.402.565.049 1.274.049 2.165.049h.793c.276 0 .447 0 .575.01.12.01.15.026.154.028a.35.35 0 0 1 .153.153c.002.004.018.034.027.154.01.128.011.3.011.575v2.787a2.943 2.943 0 0 0 2.943 2.943 1.38 1.38 0 0 0 1.262-.82l3.192-7.184c.164-.368.193-.412.218-.438a.35.35 0 0 1 .134-.087c.034-.012.086-.021.49-.021h.746c.511 0 .93 0 1.272-.028.354-.029.676-.09.978-.245a2.5 2.5 0 0 0 1.093-1.092c.154-.302.216-.624.244-.978.028-.342.028-.761.028-1.272v-4.42c0-.51 0-.93-.027-1.272-.03-.354-.091-.676-.245-.978a2.5 2.5 0 0 0-1.093-1.093c-.302-.153-.624-.215-.978-.244-.341-.028-.76-.028-1.272-.028H8.034Z" clip-rule="evenodd"/>
</svg>`;
  const HandThumbsUp = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M10.525 2.72a1.38 1.38 0 0 1 1.262-.82 2.943 2.943 0 0 1 2.943 2.943V8.2c0 .193.157.35.35.35h3.328a3.45 3.45 0 0 1 3.41 3.975l-1.023 6.65a3.45 3.45 0 0 1-3.41 2.925H4.63a2.5 2.5 0 0 1-2.5-2.5v-6.65a2.5 2.5 0 0 1 2.5-2.5h2.232a.35.35 0 0 0 .32-.208l3.343-7.522ZM8.08 20.9h9.305a2.25 2.25 0 0 0 2.224-1.908l1.023-6.65a2.25 2.25 0 0 0-2.224-2.592H15.08a1.55 1.55 0 0 1-1.55-1.55V4.843c0-.963-.78-1.743-1.743-1.743a.18.18 0 0 0-.165.107L8.28 10.73c-.053.12-.12.23-.2.33v9.84Zm-1.2-9.25v9.25H4.63a1.3 1.3 0 0 1-1.3-1.3v-6.65a1.3 1.3 0 0 1 1.3-1.3h2.25Z" clip-rule="evenodd"/>
</svg>`;
  const HardDrive = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M8.856 3.4h6.287c.971 0 1.605 0 2.177.197a3.6 3.6 0 0 1 1.345.831c.432.423.715.99 1.149 1.858l.05.099 2.184 4.37c.172.343.284.567.364.805.071.211.122.428.153.649.035.249.035.5.035.882v2.135c0 .818 0 1.468-.043 1.993-.044.538-.136.996-.35 1.415a3.6 3.6 0 0 1-1.573 1.574c-.42.213-.878.305-1.415.35-.525.042-1.175.042-1.993.042H6.774c-.818 0-1.469 0-1.993-.043-.538-.044-.996-.136-1.415-.35a3.6 3.6 0 0 1-1.574-1.573c-.213-.42-.305-.877-.35-1.415-.042-.525-.042-1.175-.042-1.993v-2.135c0-.382 0-.633.035-.882.03-.22.082-.438.153-.649.08-.238.192-.462.363-.805l.019-.037 2.167-4.333.049-.099c.434-.868.717-1.435 1.149-1.858a3.6 3.6 0 0 1 1.345-.831c.572-.198 1.206-.197 2.176-.197Zm.11 1.2c-1.12 0-1.537.008-1.895.131a2.4 2.4 0 0 0-.896.554c-.27.265-.464.635-.965 1.637l-2.167 4.333-.072.145h18.058l-.073-.145-2.166-4.333c-.501-1.002-.695-1.372-.965-1.637a2.4 2.4 0 0 0-.897-.554c-.357-.123-.774-.131-1.895-.131H8.966Zm12.429 8H2.605c-.005.12-.005.282-.005.533V15.2c0 .85 0 1.451.039 1.922.038.463.11.745.222.968a2.4 2.4 0 0 0 1.05 1.048c.222.114.504.185.967.223.47.038 1.072.039 1.922.039h10.4c.85 0 1.451 0 1.921-.039.464-.038.746-.11.969-.223a2.4 2.4 0 0 0 1.048-1.049c.113-.222.185-.504.223-.967.038-.47.039-1.072.039-1.922v-2.067c0-.251 0-.412-.005-.533ZM5.4 16a.6.6 0 0 1 .6-.6h4a.6.6 0 0 1 0 1.2H6a.6.6 0 0 1-.6-.6Z" clip-rule="evenodd"/>
</svg>`;
  const Heart = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M11.993 4.621C9.874 2.6 6.633 2.14 4.141 4.269c-2.63 2.248-3.01 6.025-.933 8.697.81 1.044 2.41 2.63 3.968 4.1a175.563 175.563 0 0 0 3.908 3.566l.012.01c.076.067.157.14.233.197.088.066.202.139.35.183.204.06.425.06.629 0a1.1 1.1 0 0 0 .35-.183c.076-.058.157-.13.233-.197l.012-.01a176.27 176.27 0 0 0 3.909-3.566c1.557-1.47 3.156-3.056 3.968-4.1 2.07-2.664 1.746-6.47-.94-8.702-2.525-2.098-5.73-1.665-7.847.357Zm-.474 1.314C9.803 3.93 7.026 3.45 4.953 5.22c-2.129 1.819-2.42 4.84-.758 6.979.742.956 2.271 2.478 3.839 3.958a174.322 174.322 0 0 0 3.96 3.61l.08-.071a174.3 174.3 0 0 0 3.88-3.54c1.567-1.48 3.096-3.001 3.839-3.957 1.667-2.146 1.402-5.183-.752-6.974-2.12-1.762-4.862-1.29-6.572.71a.625.625 0 0 1-.95 0Z" clip-rule="evenodd"/>
</svg>`;
  const HouseDoor = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M12.104 2.88a.4.4 0 0 0-.209 0c-.049.014-.114.05-.509.358L4.604 8.513c-.48.373-.627.494-.73.633a1.4 1.4 0 0 0-.222.455c-.047.166-.052.356-.052.964V17.8c0 .57 0 .961.025 1.265.024.296.069.455.128.57a1.4 1.4 0 0 0 .611.612c.116.06.275.104.571.128.304.024.695.025 1.265.025h2.2v-6.822c0-.261 0-.492.016-.684a1.62 1.62 0 0 1 .158-.62 1.6 1.6 0 0 1 .7-.7 1.62 1.62 0 0 1 .62-.158c.192-.016.423-.016.684-.016h2.844c.261 0 .492 0 .684.016.204.016.415.054.62.158a1.6 1.6 0 0 1 .7.7c.104.205.142.417.158.62.016.192.016.423.016.684V20.4h2.2c.57 0 .961 0 1.265-.025.296-.024.455-.069.57-.128a1.4 1.4 0 0 0 .612-.611c.06-.116.104-.275.128-.571.024-.304.025-.695.025-1.265v-7.235c0-.608-.005-.798-.052-.964a1.4 1.4 0 0 0-.223-.455c-.102-.14-.249-.26-.729-.633l-6.782-5.275c-.395-.308-.46-.344-.51-.357Zm5.721 18.72c.539 0 .98 0 1.337-.03.371-.03.706-.094 1.018-.253a2.6 2.6 0 0 0 1.137-1.137c.159-.312.223-.647.254-1.018.029-.358.029-.798.029-1.337V10.49c0-.502 0-.867-.096-1.213a2.598 2.598 0 0 0-.414-.845c-.213-.288-.502-.513-.898-.82l-.06-.046-6.781-5.276-.067-.051c-.283-.221-.552-.431-.866-.517a1.6 1.6 0 0 0-.836 0c-.315.086-.584.296-.867.517l-.066.051-6.782 5.276-.06.046c-.395.307-.684.532-.897.82a2.6 2.6 0 0 0-.414.845c-.096.346-.096.711-.096 1.213v7.335c0 .539 0 .98.03 1.337.03.371.094.706.253 1.018a2.6 2.6 0 0 0 1.137 1.137c.312.159.647.224 1.017.254.359.029.8.029 1.338.029h11.65ZM14.4 20.4v-6.8c0-.29 0-.471-.012-.608a.49.49 0 0 0-.032-.174.4.4 0 0 0-.175-.174.493.493 0 0 0-.173-.032 8.48 8.48 0 0 0-.608-.012h-2.8c-.29 0-.471 0-.608.012a.494.494 0 0 0-.174.032.4.4 0 0 0-.174.174.493.493 0 0 0-.032.174 8.435 8.435 0 0 0-.012.608v6.8h4.8Z" clip-rule="evenodd"/>
</svg>`;
  const House = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M12.104 2.88a.4.4 0 0 0-.209 0c-.049.014-.114.05-.509.358L4.604 8.513c-.48.373-.627.494-.73.633a1.4 1.4 0 0 0-.222.455c-.047.166-.052.356-.052.964V17.8c0 .57 0 .961.025 1.265.024.296.069.455.128.57a1.4 1.4 0 0 0 .611.612c.116.06.275.104.571.128.304.024.695.025 1.265.025h11.6c.57 0 .961 0 1.265-.025.296-.024.455-.069.57-.128a1.4 1.4 0 0 0 .612-.611c.06-.116.104-.275.128-.571.024-.304.025-.695.025-1.265v-7.235c0-.608-.005-.798-.052-.964a1.4 1.4 0 0 0-.223-.455c-.102-.14-.249-.26-.729-.633l-6.782-5.275c-.395-.308-.46-.344-.51-.357Zm-.522-1.158a1.6 1.6 0 0 1 .836 0c.314.086.584.296.866.517l.067.051 6.782 5.276.06.046c.395.307.684.532.897.82.188.254.329.54.414.845.096.346.096.711.096 1.213v7.335c0 .539 0 .98-.03 1.337-.03.371-.094.706-.253 1.018a2.6 2.6 0 0 1-1.137 1.137c-.312.159-.647.224-1.018.254-.358.029-.798.029-1.337.029H6.175c-.539 0-.98 0-1.338-.03-.37-.03-.705-.094-1.017-.253a2.6 2.6 0 0 1-1.137-1.137c-.159-.312-.224-.647-.254-1.018-.03-.358-.03-.798-.029-1.337V10.49c0-.502 0-.867.096-1.213a2.6 2.6 0 0 1 .414-.845c.213-.288.502-.513.897-.82l.06-.046 6.782-5.276.067-.051c.282-.221.551-.431.866-.517Z" clip-rule="evenodd"/>
</svg>`;
  const Image = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M7.774 2.4h8.452c.818 0 1.468 0 1.993.043.537.044.996.136 1.415.35a3.6 3.6 0 0 1 1.573 1.573c.214.42.306.877.35 1.415.043.525.043 1.175.043 1.993v8.452c0 .818 0 1.469-.043 1.993-.044.538-.136.996-.35 1.415a3.6 3.6 0 0 1-1.573 1.574c-.42.213-.878.305-1.415.35-.525.042-1.175.042-1.993.042H6.905c-.28 0-.53 0-.726-.017l-.031-.003a10.076 10.076 0 0 1-.367-.023c-.538-.044-.996-.136-1.415-.35a3.6 3.6 0 0 1-1.574-1.573c-.213-.42-.305-.877-.35-1.415-.042-.524-.042-1.175-.042-1.993V7.774c0-.818 0-1.468.043-1.993.044-.538.136-.996.35-1.415a3.6 3.6 0 0 1 1.573-1.574c.42-.213.877-.305 1.415-.35C6.305 2.4 6.956 2.4 7.774 2.4Zm.026 18h8.4c.85 0 1.451 0 1.921-.039.464-.038.746-.11.969-.223a2.4 2.4 0 0 0 1.048-1.048c.113-.223.185-.505.223-.968.038-.47.039-1.072.039-1.922v-.951l-3.693-3.693a8.424 8.424 0 0 0-.438-.422.495.495 0 0 0-.145-.1.4.4 0 0 0-.248 0 .495.495 0 0 0-.145.1 8.424 8.424 0 0 0-.438.422L6.79 20.059c-.14.139-.246.245-.327.331.367.01.803.01 1.337.01Zm12.6-6.848-2.86-2.86a8.963 8.963 0 0 0-.494-.473 1.625 1.625 0 0 0-.552-.326 1.6 1.6 0 0 0-.989 0 1.6 1.6 0 0 0-.55.326c-.147.125-.31.288-.495.472L5.923 19.23a8.558 8.558 0 0 0-.501.525c-.092.11-.217.273-.278.48a1.565 1.565 0 0 1-.234-.096 2.4 2.4 0 0 1-1.049-1.048c-.113-.223-.184-.505-.222-.968-.039-.47-.04-1.072-.04-1.922V7.8c0-.85.001-1.451.04-1.922.038-.463.11-.745.222-.968a2.4 2.4 0 0 1 1.05-1.048c.222-.114.504-.185.967-.223C6.348 3.6 6.95 3.6 7.8 3.6h8.4c.85 0 1.451 0 1.921.039.464.038.746.11.969.223a2.4 2.4 0 0 1 1.048 1.048c.113.223.185.505.223.968.038.47.039 1.072.039 1.922v5.752ZM8.5 7.1a1.4 1.4 0 1 0 0 2.8 1.4 1.4 0 0 0 0-2.8ZM5.9 8.5a2.6 2.6 0 1 1 5.2 0 2.6 2.6 0 0 1-5.2 0Z" clip-rule="evenodd"/>
</svg>`;
  const InBox = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M5.882 12.6H3.2v2.6c0 .86 0 1.433.037 1.873.035.426.096.62.16.744a1.8 1.8 0 0 0 .786.787c.123.063.318.124.744.16.44.035 1.013.036 1.873.036h10.4c.86 0 1.433 0 1.873-.037.426-.035.62-.096.744-.16a1.8 1.8 0 0 0 .787-.786c.063-.123.124-.318.16-.744.035-.44.036-1.013.036-1.873v-2.6h-2.682c-.458 0-.877.259-1.081.668a2.41 2.41 0 0 1-2.155 1.332H9.118a2.409 2.409 0 0 1-2.155-1.332 1.209 1.209 0 0 0-1.081-.668ZM20.8 11.4h-2.682a2.41 2.41 0 0 0-2.155 1.332c-.204.41-.623.668-1.081.668H9.118c-.458 0-.877-.259-1.081-.668A2.409 2.409 0 0 0 5.882 11.4H3.2V8.8c0-.86 0-1.433.037-1.873.035-.426.096-.62.16-.744a1.8 1.8 0 0 1 .786-.787c.123-.063.318-.124.744-.16C5.367 5.202 5.94 5.2 6.8 5.2h10.4c.86 0 1.433 0 1.873.037.426.035.62.096.744.16a1.8 1.8 0 0 1 .787.786c.063.123.124.318.16.744.035.44.036 1.013.036 1.873v2.6ZM22 8.8c0-1.68 0-2.52-.327-3.162a3 3 0 0 0-1.311-1.311C19.72 4 18.88 4 17.2 4H6.8c-1.68 0-2.52 0-3.162.327a3 3 0 0 0-1.311 1.311C2 6.28 2 7.12 2 8.8v6.4c0 1.68 0 2.52.327 3.162a3 3 0 0 0 1.311 1.311C4.28 20 5.12 20 6.8 20h10.4c1.68 0 2.52 0 3.162-.327a3 3 0 0 0 1.311-1.311C22 17.72 22 16.88 22 15.2V8.8Z" clip-rule="evenodd"/>
</svg>`;
  const InfoCircleFill = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M12 1.4C6.146 1.4 1.4 6.146 1.4 12c0 5.854 4.746 10.6 10.6 10.6 5.854 0 10.6-4.746 10.6-10.6 0-5.854-4.746-10.6-10.6-10.6Zm.6 9.6a.6.6 0 1 0-1.2 0v5a.6.6 0 1 0 1.2 0v-5Zm-1.45-3c0-.47.38-.85.85-.85h.01a.85.85 0 1 1 0 1.7H12a.85.85 0 0 1-.85-.85Z" clip-rule="evenodd"/>
</svg>`;
  const InfoCircle = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M12 2.6a9.4 9.4 0 1 0 0 18.8 9.4 9.4 0 0 0 0-18.8ZM1.4 12C1.4 6.146 6.146 1.4 12 1.4c5.854 0 10.6 4.746 10.6 10.6 0 5.854-4.746 10.6-10.6 10.6-5.854 0-10.6-4.746-10.6-10.6ZM12 10.4a.6.6 0 0 1 .6.6v5a.6.6 0 1 1-1.2 0v-5a.6.6 0 0 1 .6-.6Z" clip-rule="evenodd"/>
  <path fill="currentColor" d="M12 7.15a.85.85 0 0 0 0 1.7h.01a.85.85 0 1 0 0-1.7H12Z"/>
</svg>`;
  const Instagram = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M12 3c-2.442 0-2.75.011-3.71.054-.959.045-1.612.196-2.185.419-.6.225-1.145.58-1.594 1.038-.458.45-.812.994-1.038 1.594-.223.571-.375 1.226-.419 2.182C3.011 9.25 3 9.556 3 12.002c0 2.444.011 2.75.054 3.71.045.958.196 1.611.419 2.184a4.42 4.42 0 0 0 1.038 1.594c.5.5 1.001.809 1.593 1.038.574.223 1.226.375 2.185.419.96.043 1.266.054 3.711.054s2.75-.011 3.71-.054c.958-.045 1.613-.196 2.186-.419.6-.226 1.144-.58 1.593-1.038.5-.5.808-1.002 1.038-1.594.222-.573.374-1.226.419-2.185.043-.96.054-1.265.054-3.71 0-2.445-.011-2.75-.054-3.711-.045-.958-.197-1.612-.419-2.184a4.417 4.417 0 0 0-1.038-1.594 4.4 4.4 0 0 0-1.594-1.038c-.574-.223-1.229-.375-2.186-.419C14.75 3.011 14.444 3 11.998 3H12Zm-.807 1.622h.808c2.403 0 2.688.008 3.636.052.878.04 1.355.187 1.672.31.42.162.72.358 1.035.673.315.315.51.614.673 1.035.123.316.27.793.309 1.67.044.95.053 1.234.053 3.636s-.01 2.687-.053 3.636c-.04.877-.187 1.353-.31 1.67a2.77 2.77 0 0 1-.673 1.034 2.78 2.78 0 0 1-1.035.673c-.315.124-.792.27-1.67.31-.95.043-1.234.053-3.637.053s-2.689-.01-3.637-.052c-.878-.041-1.353-.187-1.67-.311a2.788 2.788 0 0 1-1.036-.673 2.79 2.79 0 0 1-.675-1.035c-.122-.316-.27-.793-.309-1.67-.043-.949-.052-1.233-.052-3.637s.01-2.687.052-3.635c.04-.878.187-1.355.31-1.672.164-.42.36-.72.674-1.035a2.78 2.78 0 0 1 1.035-.673c.318-.124.794-.27 1.671-.31.83-.039 1.152-.05 2.83-.051v.002Zm5.612 1.494a1.08 1.08 0 1 0 0 2.16 1.08 1.08 0 0 0 0-2.16ZM12 7.38a4.623 4.623 0 1 0-.144 9.244A4.623 4.623 0 0 0 12 7.379ZM12 9a3 3 0 1 1 0 6.001 3 3 0 0 1 0-6Z"/>
</svg>`;
  const Laptop = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M6.564 3.875h10.872c.51 0 .93 0 1.273.028.355.029.681.091.987.247.476.242.862.629 1.104 1.104.156.306.218.632.247.987.028.343.028.763.028 1.273v7.651c.487.172.861.574.996 1.077.055.204.054.432.054.666v.145c0 .505 0 .878-.086 1.2a2.525 2.525 0 0 1-1.785 1.786c-.323.086-.696.086-1.2.086H4.946c-.505 0-.878 0-1.2-.086a2.525 2.525 0 0 1-1.786-1.786c-.086-.322-.086-.695-.086-1.2v-.403c0-.686.438-1.27 1.05-1.485v-7.65c0-.51 0-.931.028-1.274.03-.355.091-.681.247-.987A2.525 2.525 0 0 1 4.304 4.15c.306-.156.632-.218.987-.247.343-.028.763-.028 1.273-.028Zm-2.389 11.2h4.389c.188 0 .377 0 .56.043.16.04.315.103.455.19.162.098.294.231.427.364l.031.031.06.06c.185.185.209.203.227.214.029.018.06.031.094.039.02.005.05.009.312.009h2.54c.263 0 .292-.004.312-.009a.324.324 0 0 0 .094-.039c.018-.011.042-.029.227-.214l.06-.06.031-.03c.133-.134.266-.267.427-.366.14-.086.294-.15.455-.189.184-.044.372-.043.56-.043h4.389V7.54c0-.542 0-.912-.024-1.197-.022-.278-.064-.421-.115-.522a1.275 1.275 0 0 0-.557-.557c-.1-.051-.244-.092-.522-.115a16.383 16.383 0 0 0-1.197-.024H6.59c-.542 0-.911 0-1.197.024-.278.023-.421.064-.522.115a1.27 1.27 0 0 0-.557.557c-.051.1-.092.244-.115.522-.023.285-.024.655-.024 1.197v7.535Zm11.305 1.25c-.262 0-.292.004-.312.009a.324.324 0 0 0-.094.039c-.018.011-.042.029-.227.214l-.06.06-.03.03c-.134.134-.266.267-.428.366-.14.086-.294.15-.455.189a2.364 2.364 0 0 1-.56.043h-2.628c-.188 0-.376 0-.56-.043a1.574 1.574 0 0 1-.455-.19 2.364 2.364 0 0 1-.427-.364l-.031-.031-.06-.06c-.185-.185-.209-.203-.227-.214a.324.324 0 0 0-.094-.039c-.02-.005-.05-.009-.312-.009H3.44a.325.325 0 0 0-.314.325v.317c0 .629.005.82.043.963.118.44.462.784.902.902.142.038.334.043.963.043h13.934c.629 0 .821-.005.963-.043.44-.118.784-.462.902-.902.038-.142.043-.334.043-.963 0-.153 0-.247-.003-.318-.003-.068-.008-.083-.008-.083a.325.325 0 0 0-.23-.23s-.015-.005-.083-.008a7.964 7.964 0 0 0-.318-.003H15.48Z" clip-rule="evenodd"/>
</svg>`;
  const Layers = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M11.802 4.348c.13-.024.265-.024.396 0 .152.029.29.098.384.146l.026.013 9.16 4.58a.6.6 0 0 1 0 1.074l-3.677 1.838 3.677 1.838a.6.6 0 0 1 0 1.074l-9.16 4.58-.026.013a1.454 1.454 0 0 1-.384.145 1.074 1.074 0 0 1-.396 0 1.454 1.454 0 0 1-.384-.145l-.026-.013-9.16-4.58a.6.6 0 0 1 0-1.074L5.908 12l-3.676-1.84a.6.6 0 0 1 0-1.074l9.16-4.58.026-.013c.094-.048.231-.117.384-.146Zm-4.278 7.117a.527.527 0 0 0-.011-.005L3.842 9.624l8.086-4.043.072-.036.072.036 8.086 4.043-3.671 1.836a.634.634 0 0 0-.012.005l-4.404 2.202-.071.036-.072-.036-4.404-2.202ZM7.25 12.67l-3.408 1.704 8.086 4.043.072.036.072-.036 8.086-4.043-3.408-1.704-4.142 2.07-.026.014a1.454 1.454 0 0 1-.384.145 1.074 1.074 0 0 1-.396 0 1.454 1.454 0 0 1-.384-.145l-.026-.013L7.25 12.67Z" clip-rule="evenodd"/>
</svg>`;
  const LayoutTextWindowReverse = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M17.1 12a.6.6 0 0 1-.6.6h-4a.6.6 0 1 1 0-1.2h4a.6.6 0 0 1 .6.6Zm0 4a.6.6 0 0 1-.6.6h-4a.6.6 0 1 1 0-1.2h4a.6.6 0 0 1 .6.6Zm0-8a.6.6 0 0 1-.6.6h-4a.6.6 0 1 1 0-1.2h4a.6.6 0 0 1 .6.6ZM8.4 19.8V4.2h-.6c-.86 0-1.433 0-1.873.037-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744C4.202 6.367 4.2 6.94 4.2 7.8v8.4c0 .86 0 1.433.037 1.873.035.426.096.62.16.744a1.8 1.8 0 0 0 .786.787c.123.063.318.124.744.16.44.035 1.013.036 1.873.036h.6Zm1.2 0h6.6c.86 0 1.433 0 1.873-.037.426-.035.62-.096.744-.16a1.8 1.8 0 0 0 .787-.786c.063-.123.124-.318.16-.744.035-.44.036-1.013.036-1.873V7.8c0-.86 0-1.433-.037-1.873-.035-.426-.096-.62-.16-.744a1.8 1.8 0 0 0-.786-.787c-.123-.063-.318-.124-.744-.16-.44-.035-1.013-.036-1.873-.036H9.6v15.6Zm6.6 1.2c1.68 0 2.52 0 3.162-.327a3 3 0 0 0 1.311-1.311C21 18.72 21 17.88 21 16.2V7.8c0-1.68 0-2.52-.327-3.162a3 3 0 0 0-1.311-1.311C18.72 3 17.88 3 16.2 3H7.8c-1.68 0-2.52 0-3.162.327a3 3 0 0 0-1.311 1.311C3 5.28 3 6.12 3 7.8v8.4c0 1.68 0 2.52.327 3.162a3 3 0 0 0 1.311 1.311C5.28 21 6.12 21 7.8 21h8.4Z" clip-rule="evenodd"/>
</svg>`;
  const LayoutTextWindow = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M6.9 12a.6.6 0 0 1 .6-.6h4a.6.6 0 1 1 0 1.2h-4a.6.6 0 0 1-.6-.6Zm0-4a.6.6 0 0 1 .6-.6h4a.6.6 0 1 1 0 1.2h-4a.6.6 0 0 1-.6-.6Zm0 8a.6.6 0 0 1 .6-.6h4a.6.6 0 1 1 0 1.2h-4a.6.6 0 0 1-.6-.6Zm8.7-11.8v15.6h.6c.86 0 1.433 0 1.873-.037.426-.035.62-.096.744-.16a1.8 1.8 0 0 0 .787-.786c.063-.123.124-.318.16-.744.035-.44.036-1.013.036-1.873V7.8c0-.86 0-1.433-.037-1.873-.035-.426-.096-.62-.16-.744a1.8 1.8 0 0 0-.786-.787c-.123-.063-.318-.124-.744-.16-.44-.035-1.013-.036-1.873-.036h-.6Zm-1.2 0H7.8c-.86 0-1.433 0-1.873.037-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744C4.202 6.367 4.2 6.94 4.2 7.8v8.4c0 .86 0 1.433.037 1.873.035.426.096.62.16.744a1.8 1.8 0 0 0 .786.787c.123.063.318.124.744.16.44.035 1.013.036 1.873.036h6.6V4.2ZM7.8 3c-1.68 0-2.52 0-3.162.327a3 3 0 0 0-1.311 1.311C3 5.28 3 6.12 3 7.8v8.4c0 1.68 0 2.52.327 3.162a3 3 0 0 0 1.311 1.311C5.28 21 6.12 21 7.8 21h8.4c1.68 0 2.52 0 3.162-.327a3 3 0 0 0 1.311-1.311C21 18.72 21 17.88 21 16.2V7.8c0-1.68 0-2.52-.327-3.162a3 3 0 0 0-1.311-1.311C18.72 3 17.88 3 16.2 3H7.8Z" clip-rule="evenodd"/>
</svg>`;
  const Layout = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M11.4 12V4.2H7.8c-.86 0-1.433 0-1.873.037-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744C4.202 6.367 4.2 6.94 4.2 7.8v8.4c0 .86 0 1.433.037 1.873.035.426.096.62.16.744a1.8 1.8 0 0 0 .786.787c.123.063.318.124.744.16.44.035 1.013.036 1.873.036h3.6V12Zm1.2 7.8v-7.2h7.2v3.6c0 .86 0 1.433-.037 1.873-.035.426-.096.62-.16.744a1.8 1.8 0 0 1-.786.787c-.123.063-.318.124-.744.16-.44.035-1.013.036-1.873.036h-3.6ZM7.8 21c-1.68 0-2.52 0-3.162-.327a3 3 0 0 1-1.311-1.311C3 18.72 3 17.88 3 16.2V7.8c0-1.68 0-2.52.327-3.162a3 3 0 0 1 1.311-1.311C5.28 3 6.12 3 7.8 3h8.4c1.68 0 2.52 0 3.162.327a3 3 0 0 1 1.311 1.311C21 5.28 21 6.12 21 7.8v8.4c0 1.68 0 2.52-.327 3.162a3 3 0 0 1-1.311 1.311C18.72 21 17.88 21 16.2 21H7.8Zm12-9.6h-7.2V4.2h3.6c.86 0 1.433 0 1.873.037.426.035.62.096.744.16a1.8 1.8 0 0 1 .787.786c.063.123.124.318.16.744.035.44.036 1.013.036 1.873v3.6Z" clip-rule="evenodd"/>
</svg>`;
  const Lightbulb = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M12 1.875c.345 0 .625.28.625.625v.95a.625.625 0 1 1-1.25 0V2.5c0-.345.28-.625.625-.625ZM4.813 4.813a.625.625 0 0 1 .884 0l.57.57a.625.625 0 1 1-.884.884l-.57-.57a.625.625 0 0 1 0-.884Zm14.374 0a.625.625 0 0 1 0 .884l-.57.57a.625.625 0 0 1-.884-.884l.57-.57a.625.625 0 0 1 .884 0Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M5.675 12a6.325 6.325 0 1 1 8.85 5.8v1.8a2.525 2.525 0 0 1-5.05 0v-1.8a6.327 6.327 0 0 1-3.8-5.8ZM12 6.925a5.075 5.075 0 1 0 0 10.15 5.075 5.075 0 0 0 0-10.15Zm-1.275 11.271V19.6a1.275 1.275 0 1 0 2.55 0v-1.404a6.352 6.352 0 0 1-2.55 0Z" clip-rule="evenodd"/>
  <path fill="currentColor" d="M1.875 12c0-.345.28-.625.625-.625h.95a.625.625 0 1 1 0 1.25H2.5A.625.625 0 0 1 1.875 12Zm18.05 0c0-.345.28-.625.625-.625h.95a.625.625 0 1 1 0 1.25h-.95a.625.625 0 0 1-.625-.625Z"/>
</svg>`;
  const Link = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M9.4 12A5.6 5.6 0 0 1 15 6.4h2a5.6 5.6 0 1 1 0 11.2h-.5a.6.6 0 1 1 0-1.2h.5a4.4 4.4 0 1 0 0-8.8h-2a4.4 4.4 0 0 0-4.4 4.4.6.6 0 1 1-1.2 0ZM7 7.6a4.4 4.4 0 0 0 0 8.8h2a4.4 4.4 0 0 0 4.4-4.4.6.6 0 1 1 1.2 0A5.6 5.6 0 0 1 9 17.6H7A5.6 5.6 0 1 1 7 6.4h.5a.6.6 0 0 1 0 1.2H7Z" clip-rule="evenodd"/>
</svg>`;
  const Linkedin = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M3 4.29C3 3.576 3.592 3 4.322 3h15.356C20.408 3 21 3.577 21 4.29v15.42c0 .713-.592 1.29-1.322 1.29H4.322C3.592 21 3 20.423 3 19.71V4.29Zm5.56 13.778V9.94h-2.7v8.128h2.7ZM7.21 8.83c.942 0 1.529-.623 1.529-1.404-.017-.798-.585-1.404-1.51-1.404S5.7 6.629 5.7 7.426c0 .78.586 1.404 1.493 1.404h.018Zm5.522 9.238v-4.54c0-.242.018-.485.09-.658.195-.485.64-.988 1.386-.988.978 0 1.368.745 1.368 1.838v4.348h2.701v-4.662c0-2.497-1.332-3.658-3.109-3.658-1.433 0-2.076.787-2.436 1.342v.028h-.018l.018-.028V9.94h-2.7c.034.763 0 8.128 0 8.128h2.7Z"/>
</svg>`;
  const List = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M2.4 6a.6.6 0 0 1 .6-.6h18a.6.6 0 1 1 0 1.2H3a.6.6 0 0 1-.6-.6Zm0 6a.6.6 0 0 1 .6-.6h18a.6.6 0 1 1 0 1.2H3a.6.6 0 0 1-.6-.6Zm0 6a.6.6 0 0 1 .6-.6h18a.6.6 0 1 1 0 1.2H3a.6.6 0 0 1-.6-.6Z" clip-rule="evenodd"/>
</svg>`;
  const LockFill = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M7 10h-.5A2.5 2.5 0 0 0 4 12.5v7A2.5 2.5 0 0 0 6.5 22h11a2.5 2.5 0 0 0 2.5-2.5v-7a2.5 2.5 0 0 0-2.5-2.5H17V7A5 5 0 0 0 7 7v3Zm2 0h6V7a3 3 0 1 0-6 0v3Z" clip-rule="evenodd"/>
</svg>`;
  const Lock = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M7 10V7a5 5 0 0 1 10 0v3h.5a2.5 2.5 0 0 1 2.5 2.5v7a2.5 2.5 0 0 1-2.5 2.5h-11A2.5 2.5 0 0 1 4 19.5v-7A2.5 2.5 0 0 1 6.5 10H7Zm8.8-3v3H8.2V7a3.8 3.8 0 0 1 7.6 0Zm-9.3 4.2a1.3 1.3 0 0 0-1.3 1.3v7a1.3 1.3 0 0 0 1.3 1.3h11a1.3 1.3 0 0 0 1.3-1.3v-7a1.3 1.3 0 0 0-1.3-1.3h-11Z" clip-rule="evenodd"/>
</svg>`;
  const Login = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M17.777 4.162c-.441-.037-1.007-.037-1.81-.037h-1.134a.625.625 0 0 1 0-1.25h1.16c.771 0 1.388 0 1.885.04.512.042.953.13 1.359.337.65.332 1.18.86 1.511 1.511.207.406.295.847.336 1.359.041.498.041 1.114.041 1.884v7.988c0 .77 0 1.387-.04 1.884-.042.512-.13.953-.337 1.359a3.46 3.46 0 0 1-1.511 1.511c-.406.207-.847.295-1.358.336-.498.041-1.115.041-1.885.041h-1.16a.625.625 0 0 1 0-1.25h1.133c.803 0 1.369 0 1.81-.037.433-.035.692-.102.892-.204a2.2 2.2 0 0 0 .965-.965c.102-.2.169-.459.204-.892.037-.441.037-1.007.037-1.81V8.033c0-.803 0-1.369-.037-1.81-.035-.434-.102-.692-.204-.892a2.208 2.208 0 0 0-.965-.965c-.2-.102-.459-.169-.892-.204Z"/>
  <path fill="currentColor" d="M9.67 6.836a.625.625 0 0 1 .883 0l4.722 4.722a.625.625 0 0 1 0 .884l-4.722 4.722a.625.625 0 0 1-.884-.884l3.655-3.655H3.5a.625.625 0 1 1 0-1.25h9.824L9.67 7.72a.625.625 0 0 1 0-.884Z"/>
</svg>`;
  const Logout = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M8.006 2.875h1.16a.625.625 0 1 1 0 1.25H8.034c-.803 0-1.369 0-1.81.037-.434.035-.692.102-.892.204a2.2 2.2 0 0 0-.965.965c-.102.2-.169.458-.204.892-.037.441-.037 1.007-.037 1.81v7.934c0 .803 0 1.369.037 1.81.035.433.102.692.204.892a2.2 2.2 0 0 0 .965.965c.2.102.458.169.892.204.441.037 1.007.037 1.81.037h1.134a.625.625 0 1 1 0 1.25h-1.16c-.771 0-1.387 0-1.885-.04-.512-.042-.953-.13-1.359-.337a3.459 3.459 0 0 1-1.511-1.511c-.207-.406-.295-.847-.336-1.358-.041-.498-.041-1.115-.041-1.885V8.006c0-.77 0-1.386.04-1.884.042-.512.13-.953.337-1.359.332-.65.86-1.18 1.511-1.511.406-.207.847-.295 1.359-.336.498-.041 1.114-.041 1.884-.041Z"/>
  <path fill="currentColor" d="M15.336 6.836a.625.625 0 0 1 .884 0l4.722 4.722a.625.625 0 0 1 0 .884l-4.722 4.722a.625.625 0 0 1-.884-.884l3.655-3.655H9.167a.625.625 0 1 1 0-1.25h9.824L15.336 7.72a.625.625 0 0 1 0-.884Z"/>
</svg>`;
  const Luggage = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M12.742 12.75h4.69c.118 0 .24 0 .346.009.118.01.268.033.421.11a1.1 1.1 0 0 1 .481.482c.078.153.102.303.111.421.009.105.009.228.009.345v2.316c0 .117 0 .24-.009.345a1.11 1.11 0 0 1-.11.421 1.1 1.1 0 0 1-.482.481 1.108 1.108 0 0 1-.421.111 4.412 4.412 0 0 1-.345.009h-4.69c-.118 0-.24 0-.346-.009a1.108 1.108 0 0 1-.421-.11 1.1 1.1 0 0 1-.481-.482 1.11 1.11 0 0 1-.111-.421c-.009-.105-.009-.228-.009-.345v-2.316c0-.117 0-.24.008-.345a1.11 1.11 0 0 1 .112-.421 1.1 1.1 0 0 1 .48-.481 1.11 1.11 0 0 1 .422-.111c.105-.009.228-.009.345-.009ZM12.625 14v2.55h4.925V14h-4.925Z" clip-rule="evenodd"/>
  <path fill="currentColor" fill-rule="evenodd" d="M11.9 2.875h.2c.787 0 1.306 0 1.75.118a3.475 3.475 0 0 1 2.457 2.458c.088.332.11.652.116 1.124h.544c.775 0 1.395 0 1.896.04.514.043.957.131 1.365.339a3.474 3.474 0 0 1 1.518 1.518c.208.408.296.851.338 1.365.041.501.041 1.12.041 1.896v4.234c0 .775 0 1.395-.04 1.896-.043.514-.131.957-.339 1.365a3.475 3.475 0 0 1-1.518 1.518c-.408.208-.851.296-1.365.338-.501.041-1.12.041-1.896.041H7.033c-.775 0-1.395 0-1.896-.04-.514-.043-.957-.131-1.365-.339a3.475 3.475 0 0 1-1.518-1.518c-.208-.408-.296-.851-.338-1.365-.041-.501-.041-1.12-.041-1.896v-4.234c0-.775 0-1.395.04-1.896.043-.514.131-.957.339-1.365a3.475 3.475 0 0 1 1.518-1.518c.408-.208.851-.296 1.365-.338.501-.041 1.12-.041 1.896-.041h.544c.005-.472.027-.792.116-1.124a3.475 3.475 0 0 1 2.458-2.458c.443-.118.962-.118 1.748-.118Zm-4.84 4.95c-.808 0-1.377 0-1.821.037-.437.035-.697.103-.9.206a2.225 2.225 0 0 0-.971.972c-.103.202-.17.462-.206.9-.037.443-.037 1.012-.037 1.82v4.18c0 .808 0 1.377.037 1.821.035.437.103.697.206.9.213.418.553.758.972.971.202.103.462.17.899.206.444.037 1.013.037 1.821.037h9.88c.808 0 1.377 0 1.821-.037.437-.035.697-.103.9-.206a2.22 2.22 0 0 0 .971-.972c.103-.202.17-.462.206-.899.037-.444.037-1.013.037-1.821v-4.18c0-.808 0-1.377-.037-1.82-.035-.438-.103-.698-.206-.9a2.225 2.225 0 0 0-.972-.972c-.202-.103-.462-.17-.899-.206-.444-.036-1.013-.037-1.821-.037H7.06Zm8.113-1.25H8.826c.006-.43.023-.61.074-.8A2.225 2.225 0 0 1 10.474 4.2c.263-.07.602-.076 1.526-.076s1.263.005 1.526.076a2.225 2.225 0 0 1 1.573 1.573c.051.19.068.371.073.801Z" clip-rule="evenodd"/>
</svg>`;
  const Mail = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M2.004 7.735c.004-.291.012-.55.028-.78.013-.202.032-.383.059-.548a2.56 2.56 0 0 1 .236-.769 3 3 0 0 1 1.311-1.311C4.28 4 5.12 4 6.8 4h10.4c1.68 0 2.52 0 3.162.327a3 3 0 0 1 1.311 1.311c.114.223.188.47.236.769.027.165.046.346.06.548.015.23.022.489.027.78C22 8.05 22 8.401 22 8.8v6.4c0 1.68 0 2.52-.327 3.162a3 3 0 0 1-1.311 1.311C19.72 20 18.88 20 17.2 20H6.8c-1.68 0-2.52 0-3.162-.327a3 3 0 0 1-1.311-1.311C2 17.72 2 16.88 2 15.2V8.8c0-.4 0-.751.004-1.065Zm18.796.837V15.2c0 .86 0 1.433-.037 1.873-.035.426-.096.62-.16.744a1.8 1.8 0 0 1-.786.787c-.123.063-.318.124-.744.16-.44.035-1.013.036-1.873.036H6.8c-.86 0-1.433 0-1.873-.037-.426-.035-.62-.096-.744-.16a1.8 1.8 0 0 1-.787-.786c-.063-.123-.124-.318-.16-.744-.035-.44-.036-1.013-.036-1.873V8.572l6.62 4.635.09.062c.574.403.992.695 1.461.813.413.102.845.102 1.258 0 .47-.118.887-.41 1.461-.813l.09-.062 6.62-4.635Zm-.024-1.448-7.285 5.1c-.702.491-.927.637-1.152.693a1.4 1.4 0 0 1-.678 0c-.225-.056-.45-.202-1.152-.693l-7.285-5.1c.003-.068.008-.134.013-.197.035-.426.096-.62.16-.744a1.8 1.8 0 0 1 .786-.787c.123-.063.318-.124.744-.16C5.367 5.202 5.94 5.2 6.8 5.2h10.4c.86 0 1.433 0 1.873.037.426.035.62.096.744.16a1.8 1.8 0 0 1 .787.786c.063.123.124.318.16.744.004.063.009.129.012.197Z" clip-rule="evenodd"/>
</svg>`;
  const Map$1 = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M21.283 2.471A.6.6 0 0 1 21.6 3v14.4a.6.6 0 0 1-.267.5l-5.4 3.6a.6.6 0 0 1-.63.021L9.3 18.091l-6.002 3.43A.6.6 0 0 1 2.4 21V6.6a.6.6 0 0 1 .302-.52l6.3-3.6a.6.6 0 0 1 .596 0l5.978 3.415 5.091-3.394a.6.6 0 0 1 .616-.03ZM15 6.948 9.9 4.034v13.018l5.1 2.914V6.948Zm1.2 12.93 4.2-2.8V4.122l-4.2 2.8V19.88Zm-7.5-2.826V4.034L3.6 6.948v13.018l5.1-2.914Z" clip-rule="evenodd"/>
</svg>`;
  const Menu = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none">
  <path d="M2.375 6C2.375 5.65482 2.65482 5.375 3 5.375H21C21.3452 5.375 21.625 5.65482 21.625 6C21.625 6.34518 21.3452 6.625 21 6.625H3C2.65482 6.625 2.375 6.34518 2.375 6Z" fill="currentColor"/>
  <path d="M2.375 12C2.375 11.6548 2.65482 11.375 3 11.375H21C21.3452 11.375 21.625 11.6548 21.625 12C21.625 12.3452 21.3452 12.625 21 12.625H3C2.65482 12.625 2.375 12.3452 2.375 12Z" fill="currentColor"/>
  <path d="M2.375 18C2.375 17.6548 2.65482 17.375 3 17.375H15C15.3452 17.375 15.625 17.6548 15.625 18C15.625 18.3452 15.3452 18.625 15 18.625H3C2.65482 18.625 2.375 18.3452 2.375 18Z" fill="currentColor"/>
</svg>`;
  const Microphone = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M8.525 5.35a3.475 3.475 0 1 1 6.95 0V12a3.475 3.475 0 1 1-6.95 0V5.35ZM12 3.125A2.225 2.225 0 0 0 9.775 5.35V12a2.225 2.225 0 0 0 4.45 0V5.35A2.225 2.225 0 0 0 12 3.125Z" clip-rule="evenodd"/>
  <path fill="currentColor" d="M5.35 9.475c.345 0 .625.28.625.625V12a6.025 6.025 0 0 0 12.05 0v-1.9a.625.625 0 1 1 1.25 0V12a7.276 7.276 0 0 1-6.65 7.248v1.627H15.8a.625.625 0 1 1 0 1.25H8.2a.625.625 0 1 1 0-1.25h3.175v-1.627A7.276 7.276 0 0 1 4.725 12v-1.9c0-.345.28-.625.625-.625Z"/>
</svg>`;
  const Monitor = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M7.033 3.975h9.934c.775 0 1.395 0 1.896.041.514.042.957.13 1.365.338a3.474 3.474 0 0 1 1.518 1.518c.208.408.296.851.338 1.365.041.501.041 1.12.041 1.896v2.034c0 .775 0 1.395-.04 1.896-.043.514-.131.957-.339 1.365a3.474 3.474 0 0 1-1.518 1.518c-.408.208-.851.296-1.365.338-.501.041-1.12.041-1.896.041h-4.342v2.55H15.8a.625.625 0 1 1 0 1.25H8.2a.625.625 0 1 1 0-1.25h3.175v-2.55H7.033c-.775 0-1.395 0-1.896-.04-.514-.043-.957-.131-1.365-.339a3.474 3.474 0 0 1-1.518-1.518c-.208-.408-.296-.851-.338-1.365-.041-.5-.041-1.12-.041-1.896V9.133c0-.775 0-1.395.04-1.896.043-.514.131-.957.339-1.365a3.475 3.475 0 0 1 1.518-1.518c.408-.208.851-.296 1.365-.338.501-.04 1.12-.04 1.896-.04Zm9.907 11.1c.808 0 1.377 0 1.821-.037.437-.035.697-.103.9-.205.418-.214.758-.554.971-.973.103-.202.17-.462.206-.899.037-.444.037-1.013.037-1.82V9.16c0-.81 0-1.378-.037-1.822-.035-.436-.103-.697-.206-.899a2.225 2.225 0 0 0-.972-.972c-.202-.103-.462-.17-.899-.206-.444-.036-1.013-.037-1.821-.037H7.06c-.808 0-1.377 0-1.821.037-.437.036-.697.103-.9.206a2.225 2.225 0 0 0-.971.972c-.103.202-.17.463-.206.9-.037.443-.037 1.012-.037 1.82v1.98c0 .808 0 1.377.037 1.821.035.437.103.697.206.9.213.418.553.758.972.972.202.102.462.17.899.205.444.037 1.013.037 1.821.037h9.88Z" clip-rule="evenodd"/>
</svg>`;
  const Paperclip = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M10.4 3.6a2.7 2.7 0 0 0-2.7 2.7v9.75a4.35 4.35 0 1 0 8.7 0V5.93a.6.6 0 1 1 1.2 0v10.12a5.55 5.55 0 1 1-11.1 0V6.3a3.9 3.9 0 0 1 7.8 0v9.701a2.25 2.25 0 0 1-4.5 0V7.186a.6.6 0 1 1 1.2 0v8.815a1.05 1.05 0 1 0 2.1 0V6.3a2.7 2.7 0 0 0-2.7-2.7Z" clip-rule="evenodd"/>
</svg>`;
  const Passport = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M8.525 9.15a3.475 3.475 0 1 1 6.95 0 3.475 3.475 0 0 1-6.95 0ZM12 6.925a2.225 2.225 0 1 0 0 4.45 2.225 2.225 0 0 0 0-4.45Z" clip-rule="evenodd"/>
  <path fill="currentColor" d="M9.475 15.8c0-.345.28-.625.625-.625h3.8a.625.625 0 1 1 0 1.25h-3.8a.625.625 0 0 1-.625-.625Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M9.033 1.875h5.934c.775 0 1.395 0 1.896.04.514.043.957.131 1.365.339a3.474 3.474 0 0 1 1.518 1.518c.208.408.296.851.338 1.365.041.501.041 1.12.041 1.896v9.934c0 .775 0 1.395-.04 1.896-.043.514-.131.957-.339 1.365a3.474 3.474 0 0 1-1.518 1.518c-.408.208-.851.296-1.365.338-.501.041-1.12.041-1.896.041H9.033c-.775 0-1.395 0-1.896-.04-.514-.043-.957-.131-1.365-.339a3.474 3.474 0 0 1-1.518-1.518c-.208-.408-.296-.851-.338-1.365-.041-.501-.041-1.12-.041-1.896V7.033c0-.775 0-1.395.04-1.896.043-.514.131-.957.339-1.365a3.475 3.475 0 0 1 1.518-1.518c.408-.208.851-.296 1.365-.338.501-.041 1.12-.041 1.896-.041ZM7.239 3.162c-.437.035-.697.103-.9.206a2.225 2.225 0 0 0-.971.972c-.103.202-.17.462-.206.899-.037.444-.037 1.013-.037 1.821v9.88c0 .808 0 1.377.037 1.821.035.437.103.697.206.9.213.418.553.758.972.971.202.103.462.17.899.206.444.037 1.013.037 1.821.037h5.88c.808 0 1.377 0 1.821-.037.437-.035.697-.103.9-.206a2.22 2.22 0 0 0 .971-.972c.103-.202.17-.462.206-.899.037-.444.037-1.013.037-1.821V7.06c0-.808 0-1.377-.037-1.821-.035-.437-.103-.697-.206-.9a2.225 2.225 0 0 0-.972-.971c-.202-.103-.462-.17-.899-.206-.444-.037-1.013-.037-1.821-.037H9.06c-.808 0-1.377 0-1.821.037Z" clip-rule="evenodd"/>
</svg>`;
  const Pencil = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M16.576 2.576a3.428 3.428 0 1 1 4.848 4.848L10.118 18.73a6.38 6.38 0 0 1-.582.542 3.595 3.595 0 0 1-.504.328c-.2.107-.41.188-.732.312l-.155.06-.057.021-5.373 2.067a.6.6 0 0 1-.775-.776L4.088 15.7c.123-.321.204-.532.312-.732a3.6 3.6 0 0 1 .327-.504 6.39 6.39 0 0 1 .543-.582L16.576 2.576ZM5.229 16.08c-.028.069-.063.16-.11.283l-1.574 4.091 4.09-1.573.04-.015c.104-.04.182-.071.244-.097a13.1 13.1 0 0 0-.214-.216l-2.259-2.26a13.142 13.142 0 0 0-.217-.213Zm3.752 2.085a1.846 1.846 0 0 0-.06-.075c-.094-.113-.22-.239-.351-.37l-2.291-2.29a5.982 5.982 0 0 0-.37-.35 1.805 1.805 0 0 0-.076-.06c.072-.077.169-.174.312-.316l11.28-11.28a2.228 2.228 0 0 1 3.15 3.152L9.297 17.856c-.143.142-.24.238-.315.31Z" clip-rule="evenodd"/>
</svg>`;
  const PendingCircle = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M18.209 4.942a9.364 9.364 0 0 0-6.21-2.342A9.4 9.4 0 0 0 2.6 12c0 2.38.885 4.553 2.343 6.21L18.21 4.941Zm.849.849L5.79 19.058A9.364 9.364 0 0 0 12 21.4a9.4 9.4 0 0 0 9.4-9.4c0-2.38-.884-4.553-2.342-6.21ZM12 1.4c5.854 0 10.6 4.746 10.6 10.6 0 5.854-4.746 10.6-10.6 10.6-5.854 0-10.6-4.746-10.6-10.6C1.4 6.146 6.146 1.4 12 1.4Z" clip-rule="evenodd"/>
</svg>`;
  const PersonDash = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M10 3.6a3.9 3.9 0 1 0 0 7.8 3.9 3.9 0 0 0 0-7.8ZM4.9 7.5a5.1 5.1 0 1 1 10.2 0 5.1 5.1 0 0 1-10.2 0Zm2.479 7.4h4.62a.6.6 0 1 1 0 1.2H7.5c-1.438 0-2.025.006-2.486.146a3.4 3.4 0 0 0-2.267 2.267c-.14.461-.146 1.048-.146 2.487a.6.6 0 1 1-1.2 0v-.121c0-1.28 0-2.06.198-2.714a4.6 4.6 0 0 1 3.067-3.067C5.32 14.9 6.1 14.9 7.38 14.9Zm8.02 3.1a.6.6 0 0 1 .6-.6h6a.6.6 0 1 1 0 1.2h-6a.6.6 0 0 1-.6-.6Z" clip-rule="evenodd"/>
</svg>`;
  const PersonPlus = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M10 3.6a3.9 3.9 0 1 0 0 7.8 3.9 3.9 0 0 0 0-7.8ZM4.9 7.5a5.1 5.1 0 1 1 10.2 0 5.1 5.1 0 0 1-10.2 0ZM19 14.4a.6.6 0 0 1 .6.6v2.4H22a.6.6 0 1 1 0 1.2h-2.4V21a.6.6 0 1 1-1.2 0v-2.4H16a.6.6 0 0 1 0-1.2h2.4V15a.6.6 0 0 1 .6-.6Zm-11.621.5h4.62a.6.6 0 1 1 0 1.2H7.5c-1.438 0-2.025.006-2.486.146a3.4 3.4 0 0 0-2.267 2.267c-.14.461-.146 1.048-.146 2.487a.6.6 0 1 1-1.2 0v-.121c0-1.28 0-2.06.198-2.714a4.6 4.6 0 0 1 3.067-3.067C5.32 14.9 6.1 14.9 7.38 14.9Z" clip-rule="evenodd"/>
</svg>`;
  const PersonX = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M10 3.6a3.9 3.9 0 1 0 0 7.8 3.9 3.9 0 0 0 0-7.8ZM4.9 7.5a5.1 5.1 0 1 1 10.2 0 5.1 5.1 0 0 1-10.2 0Zm2.479 7.4h4.62a.6.6 0 1 1 0 1.2H7.5c-1.438 0-2.025.006-2.486.146a3.4 3.4 0 0 0-2.267 2.267c-.14.461-.146 1.048-.146 2.487a.6.6 0 1 1-1.2 0v-.121c0-1.28 0-2.06.198-2.714a4.6 4.6 0 0 1 3.067-3.067C5.32 14.9 6.1 14.9 7.38 14.9Zm8.697.676a.6.6 0 0 1 .848 0L19 17.65l2.076-2.075a.6.6 0 1 1 .848.848L19.85 18.5l2.075 2.076a.6.6 0 0 1-.848.848L19 19.35l-2.076 2.075a.6.6 0 1 1-.848-.848L18.15 18.5l-2.075-2.076a.6.6 0 0 1 0-.848Z" clip-rule="evenodd"/>
</svg>`;
  const Person = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M12 3.6a3.9 3.9 0 1 0 0 7.8 3.9 3.9 0 0 0 0-7.8ZM6.9 7.5a5.1 5.1 0 1 1 10.2 0 5.1 5.1 0 0 1-10.2 0Zm2.479 7.4h5.242c1.28 0 2.06 0 2.714.198a4.6 4.6 0 0 1 3.067 3.067c.198.654.198 1.434.198 2.714V21a.6.6 0 1 1-1.2 0c0-1.44-.007-2.026-.146-2.487a3.4 3.4 0 0 0-2.267-2.267c-.461-.14-1.048-.146-2.487-.146h-5c-1.44 0-2.026.006-2.487.146a3.4 3.4 0 0 0-2.267 2.267c-.14.461-.146 1.048-.146 2.487a.6.6 0 1 1-1.2 0v-.121c0-1.28 0-2.06.198-2.714a4.6 4.6 0 0 1 3.067-3.067c.654-.198 1.434-.198 2.714-.198Z" clip-rule="evenodd"/>
</svg>`;
  const Phone = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M9.875 17.5c0-.345.28-.625.625-.625h3a.625.625 0 1 1 0 1.25h-3a.625.625 0 0 1-.625-.625Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M8.674 1.875h6.652c.538 0 .98 0 1.338.03.373.03.711.095 1.028.256.494.252.895.653 1.147 1.147.161.317.226.655.257 1.028.029.359.029.8.029 1.338v12.652c0 .538 0 .98-.03 1.338-.03.373-.095.711-.256 1.028a2.625 2.625 0 0 1-1.147 1.147c-.317.161-.655.226-1.027.257-.36.029-.801.029-1.339.029H8.674c-.538 0-.98 0-1.338-.03-.373-.03-.711-.095-1.028-.256a2.625 2.625 0 0 1-1.147-1.147c-.161-.317-.226-.655-.257-1.027-.029-.36-.029-.801-.029-1.339V5.674c0-.538 0-.98.03-1.338.03-.373.095-.711.256-1.028a2.625 2.625 0 0 1 1.147-1.147c.317-.161.655-.226 1.028-.257.359-.029.8-.029 1.338-.029ZM7.437 3.15c-.295.024-.45.068-.561.125-.259.132-.47.342-.601.6-.057.112-.1.267-.125.562-.025.302-.025.693-.025 1.263v12.6c0 .57 0 .96.025 1.263.024.295.068.45.125.561.132.259.342.47.6.601.112.057.267.1.562.125.302.024.693.025 1.263.025h6.6c.57 0 .96 0 1.263-.025.295-.024.45-.068.561-.125.259-.132.47-.342.601-.6.057-.112.1-.267.125-.562.024-.302.025-.693.025-1.263V5.7c0-.57 0-.96-.025-1.263-.024-.295-.068-.45-.125-.561a1.374 1.374 0 0 0-.6-.601c-.112-.057-.267-.1-.562-.125-.302-.025-.693-.025-1.263-.025H8.7c-.57 0-.96 0-1.263.025Z" clip-rule="evenodd"/>
</svg>`;
  const PinMapFill = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M5.4 8a6.6 6.6 0 1 1 13.2 0c0 2.278-1.271 3.926-2.605 5.314-.321.335-.653.661-.975.978l-.042.041c-.338.332-.664.655-.973.98-.619.652-1.133 1.284-1.468 1.955a.6.6 0 0 1-1.074 0c-.335-.67-.85-1.303-1.469-1.956a40.359 40.359 0 0 0-.972-.979l-.042-.04a47.782 47.782 0 0 1-.975-.979C6.67 11.926 5.4 10.278 5.4 8Zm5 0a1.6 1.6 0 1 1 3.2 0 1.6 1.6 0 0 1-3.2 0Zm-4.851 6.044a.6.6 0 0 1-.307.791c-.88.388-1.555.837-2.002 1.306-.445.467-.64.925-.64 1.359 0 .86.803 1.837 2.575 2.635C6.891 20.907 9.303 21.4 12 21.4s5.109-.493 6.825-1.265c1.772-.798 2.575-1.776 2.575-2.635 0-.434-.196-.892-.64-1.359-.448-.469-1.123-.918-2.002-1.306a.6.6 0 0 1 .484-1.098c.972.43 1.797.958 2.386 1.576.593.622.972 1.362.972 2.187 0 1.626-1.436 2.898-3.283 3.729-1.903.857-4.49 1.37-7.317 1.37-2.826 0-5.414-.513-7.317-1.37-1.848-.831-3.283-2.103-3.283-3.73 0-.824.379-1.564.971-2.186.59-.618 1.415-1.147 2.387-1.576a.6.6 0 0 1 .79.307Z" clip-rule="evenodd"/>
</svg>`;
  const Pin = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M8.337 1.4h7.327c.373 0 .693 0 .95.023.264.024.544.078.793.243a1.6 1.6 0 0 1 .683 1.008c.06.293.007.573-.07.828-.073.247-.192.544-.33.89l-1.018 2.545a1.812 1.812 0 0 0-.058.15.404.404 0 0 0-.011.06 1.774 1.774 0 0 0-.003.161v2.13c0 .233.003.266.008.292.008.035.02.07.036.101.012.024.03.051.176.232l1.588 1.986c.317.396.58.726.762 1 .18.271.35.588.35.95a1.6 1.6 0 0 1-.602 1.252c-.282.225-.636.29-.96.32-.327.029-.75.029-1.257.029h-4.1V22a.6.6 0 1 1-1.2 0v-6.4H7.3c-.508 0-.93 0-1.258-.03-.323-.03-.677-.095-.96-.32a1.6 1.6 0 0 1-.601-1.252c0-.36.17-.678.35-.948.181-.275.445-.605.762-1.001l1.588-1.986c.145-.18.163-.208.176-.232a.4.4 0 0 0 .035-.101 1.83 1.83 0 0 0 .008-.291v-2.13c0-.129 0-.147-.002-.162a.4.4 0 0 0-.012-.06 1.77 1.77 0 0 0-.057-.15L6.31 4.392a11.29 11.29 0 0 1-.331-.89c-.076-.255-.13-.535-.07-.828a1.6 1.6 0 0 1 .683-1.008c.25-.165.53-.219.794-.243.257-.023.577-.023.95-.023Zm8.334 13c.545 0 .912 0 1.18-.025.259-.023.319-.063.32-.063a.4.4 0 0 0 .149-.311s-.007-.072-.15-.29c-.149-.223-.378-.51-.718-.936l-1.57-1.962-.023-.03a2.427 2.427 0 0 1-.284-.406 1.599 1.599 0 0 1-.142-.406 2.43 2.43 0 0 1-.033-.494v-2.19c0-.094 0-.185.01-.277.01-.08.025-.16.047-.239.024-.089.058-.173.093-.26l.008-.02 1.008-2.52c.15-.378.249-.624.305-.812.055-.186.045-.238.044-.24a.4.4 0 0 0-.17-.252c-.003-.002-.047-.031-.24-.049-.196-.017-.46-.018-.868-.018H8.364c-.408 0-.672 0-.868.018-.193.018-.237.047-.24.049a.4.4 0 0 0-.17.252c0 .002-.012.054.044.24.056.188.154.434.305.812l1.008 2.52.008.02c.035.087.069.171.093.26a1.6 1.6 0 0 1 .046.24c.01.091.01.182.01.276v2.19c0 .17 0 .333-.032.494a1.599 1.599 0 0 1-.143.406 2.429 2.429 0 0 1-.283.406l-.024.03-1.57 1.962c-.34.426-.569.713-.717.936-.143.218-.15.29-.15.29a.4.4 0 0 0 .15.311s.06.04.32.063c.266.024.634.025 1.178.025h9.342Z" clip-rule="evenodd"/>
</svg>`;
  const Placeholder = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M12 20.8a8.8 8.8 0 1 0 0-17.6 8.8 8.8 0 0 0 0 17.6ZM22 12c0 5.523-4.477 10-10 10S2 17.523 2 12 6.477 2 12 2s10 4.477 10 10Z" clip-rule="evenodd"/>
</svg>`;
  const Plane = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M16.91 2.787a2.997 2.997 0 0 1 4.321 4.155l-2.654 2.78c-.235.245-.258.278-.27.303a.33.33 0 0 0-.034.125c-.002.027 0 .066.077.398L20 17.701l.014.057c.056.243.113.485.094.729a1.58 1.58 0 0 1-.175.61c-.114.218-.29.393-.466.57l-.042.04-.374.375c-.272.272-.507.507-.71.676-.209.174-.458.344-.768.398a1.58 1.58 0 0 1-1.217-.287c-.253-.188-.4-.451-.509-.7-.106-.242-.21-.556-.333-.922l-1.609-4.827-2.48 2.48c-.216.216-.237.244-.249.266a.332.332 0 0 0-.039.11c-.004.025-.005.06.028.363l.176 1.58.006.05c.024.217.049.433.014.647a1.58 1.58 0 0 1-.186.531c-.107.189-.261.342-.415.496l-.037.036-.206.207c-.21.21-.397.396-.562.535a1.621 1.621 0 0 1-.633.353 1.58 1.58 0 0 1-1.09-.108 1.623 1.623 0 0 1-.551-.47 9.556 9.556 0 0 1-.447-.635l-1.512-2.269a1.687 1.687 0 0 0-.087-.126.326.326 0 0 0-.037-.037 1.72 1.72 0 0 0-.126-.087L3.203 16.83a9.606 9.606 0 0 1-.635-.446 1.623 1.623 0 0 1-.47-.552 1.58 1.58 0 0 1-.108-1.09c.067-.255.207-.459.353-.633.139-.165.325-.351.535-.562l.207-.207.036-.036c.154-.154.307-.308.496-.415a1.58 1.58 0 0 1 .531-.186c.214-.034.43-.01.647.014l.05.006 1.58.175c.302.034.338.033.362.029a.33.33 0 0 0 .111-.04c.022-.011.05-.032.265-.248l2.481-2.48-4.827-1.61a11.71 11.71 0 0 1-.923-.332c-.248-.11-.511-.256-.699-.509a1.58 1.58 0 0 1-.287-1.217c.054-.31.224-.56.398-.767.17-.204.404-.439.676-.71l.374-.375.042-.042c.176-.176.35-.352.568-.466a1.58 1.58 0 0 1 .61-.175c.245-.019.487.038.73.094l.057.013 7.126 1.645c.334.077.375.08.402.078a.33.33 0 0 0 .136-.04c.024-.014.056-.038.295-.285l2.589-2.674Zm3.39.85a1.747 1.747 0 0 0-2.491.02L15.22 6.33a14.22 14.22 0 0 0-.04.041c-.17.177-.34.352-.55.468-.2.11-.422.176-.65.192-.24.017-.478-.038-.716-.093l-.056-.013L6.081 5.28c-.34-.078-.381-.08-.41-.079a.33.33 0 0 0-.127.037c-.024.013-.058.037-.305.284l-.354.354c-.298.298-.49.492-.62.646a.713.713 0 0 0-.128.187.33.33 0 0 0 .06.252.713.713 0 0 0 .198.11c.184.08.443.167.843.3L11 9.293a.625.625 0 0 1 .244 1.036l-3.196 3.195-.036.036c-.154.155-.307.309-.495.416a1.58 1.58 0 0 1-.532.186c-.214.034-.43.01-.646-.014l-.051-.006-1.58-.176c-.302-.033-.337-.032-.362-.028a.33.33 0 0 0-.111.039c-.022.012-.05.033-.265.248l-.189.189a9.07 9.07 0 0 0-.48.5.55.55 0 0 0-.1.145.33.33 0 0 0 .022.227.55.55 0 0 0 .127.123c.121.097.294.212.569.396l2.247 1.498.018.012a1.579 1.579 0 0 1 .403.34c.061.073.113.15.164.227l.012.018 1.498 2.247c.184.276.3.448.396.569a.55.55 0 0 0 .123.127.33.33 0 0 0 .227.022.544.544 0 0 0 .145-.1c.119-.1.266-.246.5-.48l.189-.189c.215-.215.236-.243.248-.265a.328.328 0 0 0 .039-.111c.004-.025.005-.06-.028-.362l-.176-1.58a29.217 29.217 0 0 0-.006-.05c-.024-.217-.048-.433-.014-.647a1.58 1.58 0 0 1 .186-.532c.107-.188.261-.341.415-.495l.037-.036 3.195-3.196a.625.625 0 0 1 1.035.244l1.92 5.76c.134.4.22.659.301.843a.71.71 0 0 0 .11.198.33.33 0 0 0 .253.06c-.014.002.03 0 .186-.128.154-.13.348-.322.646-.62l.354-.354c.247-.247.271-.28.284-.305a.33.33 0 0 0 .037-.128c.002-.028 0-.068-.08-.41l-1.65-7.152-.013-.056c-.055-.236-.11-.472-.093-.71a1.58 1.58 0 0 1 .164-.6c.108-.214.275-.388.443-.564l.04-.041 2.654-2.78a1.747 1.747 0 0 0-.028-2.441Z" clip-rule="evenodd"/>
</svg>`;
  const PlusCircle = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M12 7.4a.6.6 0 0 1 .6.6v3.4H16a.6.6 0 1 1 0 1.2h-3.4V16a.6.6 0 1 1-1.2 0v-3.4H8a.6.6 0 1 1 0-1.2h3.4V8a.6.6 0 0 1 .6-.6Zm0 13.4a8.8 8.8 0 1 0 0-17.6 8.8 8.8 0 0 0 0 17.6ZM22 12c0 5.523-4.477 10-10 10S2 17.523 2 12 6.477 2 12 2s10 4.477 10 10Z" clip-rule="evenodd"/>
</svg>`;
  const PlusSquare = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M12 7.4a.6.6 0 0 1 .6.6v3.4H16a.6.6 0 1 1 0 1.2h-3.4V16a.6.6 0 1 1-1.2 0v-3.4H8a.6.6 0 1 1 0-1.2h3.4V8a.6.6 0 0 1 .6-.6Zm4.2-3.2H7.8c-.86 0-1.433 0-1.873.037-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744C4.202 6.367 4.2 6.94 4.2 7.8v8.4c0 .86 0 1.433.037 1.873.035.426.096.62.16.744a1.8 1.8 0 0 0 .786.787c.123.063.318.124.744.16.44.035 1.013.036 1.873.036h8.4c.86 0 1.433 0 1.873-.037.426-.035.62-.096.744-.16a1.8 1.8 0 0 0 .787-.786c.063-.123.124-.318.16-.744.035-.44.036-1.013.036-1.873V7.8c0-.86 0-1.433-.037-1.873-.035-.426-.096-.62-.16-.744a1.8 1.8 0 0 0-.786-.787c-.123-.063-.318-.124-.744-.16-.44-.035-1.013-.036-1.873-.036Zm-12.873.438C3 5.28 3 6.12 3 7.8v8.4c0 1.68 0 2.52.327 3.162a3 3 0 0 0 1.311 1.311C5.28 21 6.12 21 7.8 21h8.4c1.68 0 2.52 0 3.162-.327a3 3 0 0 0 1.311-1.311C21 18.72 21 17.88 21 16.2V7.8c0-1.68 0-2.52-.327-3.162a3 3 0 0 0-1.311-1.311C18.72 3 17.88 3 16.2 3H7.8c-1.68 0-2.52 0-3.162.327a3 3 0 0 0-1.311 1.311Z" clip-rule="evenodd"/>
</svg>`;
  const Plus = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M12 4.4a.6.6 0 0 1 .6.6v6.4H19a.6.6 0 1 1 0 1.2h-6.4V19a.6.6 0 1 1-1.2 0v-6.4H5a.6.6 0 1 1 0-1.2h6.4V5a.6.6 0 0 1 .6-.6Z" clip-rule="evenodd"/>
</svg>`;
  const Printer = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M9.175 1.4h5.65c.539 0 .98 0 1.337.03.371.03.706.094 1.018.253a2.6 2.6 0 0 1 1.137 1.137c.159.312.223.647.254 1.018.029.358.029.798.029 1.337V6.41c.224.007.43.016.62.032.537.044.995.136 1.414.35a3.6 3.6 0 0 1 1.574 1.573c.213.42.305.877.35 1.415.042.524.042 1.175.042 1.993V14.1c0 .834 0 1.373-.123 1.832a3.6 3.6 0 0 1-2.545 2.545c-.36.097-.77.117-1.332.122v.226c0 .539 0 .98-.03 1.338-.03.37-.094.705-.253 1.017a2.6 2.6 0 0 1-1.137 1.137c-.312.159-.647.224-1.018.254-.358.029-.798.029-1.337.029h-5.65c-.539 0-.98 0-1.338-.03-.37-.03-.705-.094-1.017-.253a2.6 2.6 0 0 1-1.137-1.137c-.159-.312-.224-.647-.254-1.017a17.79 17.79 0 0 1-.03-1.338V18.6c-.561-.005-.97-.025-1.33-.122a3.6 3.6 0 0 1-2.546-2.545c-.123-.46-.123-.998-.123-1.832v-2.326c0-.818 0-1.468.043-1.993.044-.538.136-.996.35-1.415a3.6 3.6 0 0 1 1.573-1.574c.42-.213.877-.305 1.415-.35.19-.015.395-.024.619-.03V5.174c0-.539 0-.98.03-1.337.03-.371.094-.706.253-1.018A2.6 2.6 0 0 1 6.82 1.683c.312-.159.647-.223 1.017-.254.359-.029.8-.029 1.338-.029ZM6.6 6.4h10.8V5.2c0-.57 0-.961-.025-1.265-.024-.296-.069-.455-.128-.57a1.4 1.4 0 0 0-.611-.612c-.116-.06-.275-.104-.571-.128C15.76 2.6 15.37 2.6 14.8 2.6H9.2c-.57 0-.961 0-1.265.025-.296.024-.455.069-.57.128a1.4 1.4 0 0 0-.612.611c-.06.116-.104.275-.128.571C6.6 4.24 6.6 4.63 6.6 5.2v1.2Zm0 12.4c0 .57 0 .961.025 1.265.024.296.069.455.128.57a1.4 1.4 0 0 0 .611.612c.116.06.275.104.571.128.304.024.695.025 1.265.025h5.6c.57 0 .961 0 1.265-.025.296-.024.455-.069.57-.128a1.4 1.4 0 0 0 .612-.611c.06-.116.104-.275.128-.571.024-.304.025-.695.025-1.265v-1.6c0-.57 0-.961-.025-1.265-.024-.296-.069-.455-.128-.57a1.4 1.4 0 0 0-.611-.612c-.116-.06-.275-.104-.571-.128A17.797 17.797 0 0 0 14.8 14.6H9.2c-.57 0-.961 0-1.265.025-.296.024-.455.069-.57.128a1.4 1.4 0 0 0-.612.611c-.06.116-.104.275-.128.571-.025.304-.025.695-.025 1.265v1.6Zm12-1.402v-.223c0-.539 0-.98-.03-1.338-.03-.37-.094-.705-.253-1.017a2.6 2.6 0 0 0-1.137-1.137c-.312-.159-.647-.223-1.018-.254-.358-.029-.798-.029-1.337-.029h-5.65c-.539 0-.98 0-1.338.03-.37.03-.705.094-1.017.253a2.6 2.6 0 0 0-1.137 1.137c-.159.312-.224.647-.254 1.018-.03.358-.03.798-.03 1.337v.223c-.539-.005-.803-.021-1.02-.08a2.4 2.4 0 0 1-1.697-1.697C2.605 15.335 2.6 14.97 2.6 14v-2.2c0-.85 0-1.451.039-1.922.038-.463.11-.745.223-.968A2.4 2.4 0 0 1 3.91 7.862c.223-.114.505-.185.968-.223C5.348 7.6 5.95 7.6 6.8 7.6h10.4c.85 0 1.451 0 1.922.039.463.038.745.11.968.223a2.4 2.4 0 0 1 1.048 1.048c.114.223.185.505.223.968.038.47.039 1.072.039 1.922V14c0 .969-.005 1.335-.082 1.621a2.4 2.4 0 0 1-1.697 1.697c-.217.058-.481.075-1.021.08ZM14.4 10.5a.6.6 0 0 1 .6-.6h3a.6.6 0 1 1 0 1.2h-3a.6.6 0 0 1-.6-.6Z" clip-rule="evenodd"/>
</svg>`;
  const QuestionCircle = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M10.704 7.926A2.4 2.4 0 0 1 14.32 10c0 .681-.52 1.275-1.233 1.75a6.449 6.449 0 0 1-1.334.673l-.02.007-.004.001a.6.6 0 0 0-.41.569v1a.6.6 0 1 0 1.2 0v-.59a7.654 7.654 0 0 0 1.233-.66c.787-.525 1.768-1.431 1.768-2.75a3.6 3.6 0 0 0-6.996-1.2.6.6 0 0 0 1.132.4 2.4 2.4 0 0 1 1.048-1.274ZM11.15 17c0-.47.38-.85.85-.85h.01a.85.85 0 0 1 0 1.7H12a.85.85 0 0 1-.85-.85Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M12 1.4C6.146 1.4 1.4 6.146 1.4 12c0 5.854 4.746 10.6 10.6 10.6 5.854 0 10.6-4.746 10.6-10.6 0-5.854-4.746-10.6-10.6-10.6ZM2.6 12a9.4 9.4 0 1 1 18.8 0 9.4 9.4 0 0 1-18.8 0Z" clip-rule="evenodd"/>
</svg>`;
  const Rocket = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M11.868 20.653a.625.625 0 0 1-.737-.614v-4.614L8.574 12.87H3.961a.625.625 0 0 1-.615-.737v-.002l.001-.002.002-.008.005-.03.022-.104a11.948 11.948 0 0 1 .443-1.55c.314-.866.856-2.016 1.744-2.61.513-.342 1.13-.492 1.716-.546a8.03 8.03 0 0 1 1.739.052 12.509 12.509 0 0 1 1.519.296 13.175 13.175 0 0 1 10.967-5.753.625.625 0 0 1 .62.625c0 2.707-.764 7.437-5.748 10.979l.032.129c.087.349.19.834.26 1.374a8.03 8.03 0 0 1 .052 1.738c-.054.587-.204 1.203-.546 1.716-.594.888-1.744 1.431-2.61 1.745a11.957 11.957 0 0 1-1.655.464l-.029.006-.008.002h-.004Zm3.808-16.052a11.925 11.925 0 0 1 5.184-1.463c-.125 2.584-1.087 6.562-5.547 9.556a21.152 21.152 0 0 1-3.404 1.742l-2.343-2.344a20.805 20.805 0 0 1 1.743-3.36l.003-.006a11.925 11.925 0 0 1 4.364-4.125Zm-3.294 10.992c.992-.4 1.954-.87 2.879-1.406.06.275.123.603.168.955.062.483.09.993.047 1.463-.045.474-.158.862-.342 1.138-.351.525-1.15.957-1.996 1.263a9.84 9.84 0 0 1-.756.241v-3.654ZM9.834 8.744c-.28-.062-.615-.126-.976-.173a6.795 6.795 0 0 0-1.463-.046c-.474.044-.862.157-1.137.34-.525.352-.957 1.151-1.264 1.997-.099.272-.178.531-.241.757h3.656c.405-.992.881-1.953 1.425-2.875Z" clip-rule="evenodd"/>
  <path fill="currentColor" fill-rule="evenodd" d="M4.046 16.15a2.75 2.75 0 0 1 3.67.114l.007.007c1.019 1.006 1.013 2.633.127 3.683-.387.46-.932.81-1.483 1.08a10.57 10.57 0 0 1-1.72.64 16.562 16.562 0 0 1-2.016.439l-.034.005h-.01l-.003.001h-.001a.626.626 0 0 1-.702-.702v-.004l.001-.01.005-.034c.005-.03.01-.072.02-.126a16.55 16.55 0 0 1 .419-1.89 10.57 10.57 0 0 1 .64-1.72c.27-.551.62-1.096 1.08-1.483Zm.258 4.323c-.375.107-.73.19-1.03.254.063-.3.146-.656.253-1.03a9.424 9.424 0 0 1 .562-1.515c.234-.478.492-.848.762-1.075a1.499 1.499 0 0 1 1.998.057c.517.515.541 1.397.046 1.984l-.002.001c-.227.27-.597.529-1.074.762a9.42 9.42 0 0 1-1.515.562Z" clip-rule="evenodd"/>
</svg>`;
  const Save = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M15.498 3.639c-.145-.035-.306-.039-.824-.039H7.6v2.8c0 .29 0 .471.012.608.01.13.027.165.032.174a.4.4 0 0 0 .174.174.493.493 0 0 0 .174.032c.137.012.318.012.608.012h6.8c.29 0 .471 0 .608-.012a.493.493 0 0 0 .174-.032.4.4 0 0 0 .174-.174.494.494 0 0 0 .032-.174c.011-.137.012-.318.012-.608V4.249c-.28-.278-.384-.373-.497-.443a1.401 1.401 0 0 0-.405-.167Zm1.926-.063-.063-.063-.045-.045c-.302-.303-.522-.523-.786-.685a2.6 2.6 0 0 0-.752-.311c-.3-.072-.612-.072-1.04-.072H7.774l-.733.001a.608.608 0 0 0-.09.001 16.91 16.91 0 0 0-1.17.04c-.538.045-.996.137-1.415.35a3.6 3.6 0 0 0-1.574 1.574c-.213.42-.305.877-.35 1.415C2.4 6.306 2.4 6.956 2.4 7.774v8.452c0 .818 0 1.469.043 1.993.044.538.136.996.35 1.415a3.6 3.6 0 0 0 1.573 1.574c.42.213.877.305 1.415.35a16.376 16.376 0 0 0 1.26.04c.228.002.472.002.733.002h8.452l.733-.001a.622.622 0 0 0 .09-.001c.449-.004.835-.014 1.17-.04.537-.045.996-.137 1.415-.35a3.6 3.6 0 0 0 1.573-1.574c.214-.42.306-.877.35-1.415.043-.524.043-1.175.043-1.993V9.262c0-.428 0-.74-.072-1.04a2.602 2.602 0 0 0-.311-.752c-.162-.264-.383-.484-.685-.786l-.045-.046-3.063-3.063Zm.176 1.873v.973c0 .261 0 .492-.016.684a1.626 1.626 0 0 1-.159.62 1.6 1.6 0 0 1-.699.7 1.626 1.626 0 0 1-.62.158c-.192.016-.423.016-.684.016H8.578c-.261 0-.492 0-.684-.016a1.626 1.626 0 0 1-.62-.158 1.6 1.6 0 0 1-.7-.7 1.626 1.626 0 0 1-.158-.62C6.4 6.914 6.4 6.683 6.4 6.422v-2.81a9.325 9.325 0 0 0-.522.027c-.463.038-.745.11-.968.223A2.4 2.4 0 0 0 3.861 4.91c-.113.223-.184.505-.222.968-.039.47-.04 1.072-.04 1.922v8.4c0 .85.001 1.451.04 1.922.038.463.11.745.222.968a2.4 2.4 0 0 0 1.05 1.048c.222.114.504.185.967.223.158.013.33.022.522.027v-5.81c0-.261 0-.492.016-.684a1.62 1.62 0 0 1 .158-.62 1.6 1.6 0 0 1 .7-.7 1.62 1.62 0 0 1 .62-.158c.192-.016.423-.016.684-.016h6.844c.261 0 .492 0 .684.016.203.016.415.054.62.158a1.6 1.6 0 0 1 .7.7c.104.205.142.417.158.62.016.192.016.423.016.684v5.81c.191-.005.364-.014.521-.027.464-.038.746-.11.969-.223a2.4 2.4 0 0 0 1.048-1.048c.113-.223.185-.505.223-.968.038-.47.039-1.072.039-1.922V9.325c0-.517-.004-.678-.039-.823a1.399 1.399 0 0 0-.167-.405c-.078-.127-.19-.244-.556-.61L17.6 5.449ZM16.4 20.4v-5.8c0-.29 0-.471-.012-.608a.494.494 0 0 0-.032-.174.4.4 0 0 0-.175-.174.494.494 0 0 0-.173-.032 8.477 8.477 0 0 0-.608-.012H8.6c-.29 0-.471 0-.608.012a.493.493 0 0 0-.174.032.4.4 0 0 0-.174.174.494.494 0 0 0-.032.174 8.437 8.437 0 0 0-.012.608v5.8h8.8Z" clip-rule="evenodd"/>
</svg>`;
  const Search = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M10.2 3.8a6.4 6.4 0 1 0 0 12.8 6.4 6.4 0 0 0 0-12.8Zm-7.6 6.4a7.6 7.6 0 1 1 13.382 4.933l4.842 4.843a.6.6 0 1 1-.848.848l-4.843-4.842A7.6 7.6 0 0 1 2.6 10.2Z" clip-rule="evenodd"/>
</svg>`;
  const Send = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M19.686 2.941c.163-.047.428-.11.702-.02.326.11.581.365.69.691.092.274.028.539-.019.702-.05.173-.133.383-.222.614l-6.188 15.855c-.1.257-.19.487-.276.662-.078.157-.218.416-.49.557a1.093 1.093 0 0 1-1.01 0c-.271-.142-.411-.401-.489-.559-.086-.174-.175-.405-.276-.662l-2.469-6.35-.02-.05a6.937 6.937 0 0 0-.05-.02l-6.35-2.47c-.258-.1-.488-.19-.662-.275-.158-.078-.417-.218-.558-.49a1.093 1.093 0 0 1 0-1.009c.14-.272.4-.412.557-.49a8.91 8.91 0 0 1 .661-.276l15.855-6.188c.23-.09.441-.172.614-.222ZM19.2 5.684l-5.705 14.62-.116.293-.115-.294-2.431-6.252L19.2 5.684Zm-9.251 7.484L18.316 4.8l-14.62 5.704-.293.116.294.115 6.252 2.431Z" clip-rule="evenodd"/>
</svg>`;
  const SgCrest = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="#DB0000" d="M5.174 8.413s-.632.925.196 2.12c0 0 .13-.609 1.437-.609h1.569c1.481 0 2.591-1.465 1.895-2.977 0 0 1.045.113 1.394-.564.349-.676-.022-.947-.544-.947H8.485c0 .485-.893.552-.893 0H6.111s-1.111 0-1.133.97c0 0 .251-.158.5-.18v.258s-.304.057-.446.136c-.141.079-.348.293-.152.846.196.552.273.744.273.744s.316-.283.828-.283h.6c1.066 0 .87 1.071-.197 1.071-1.068 0-1.209-.586-1.209-.586l-.001.001Z"/>
  <path fill="#DB0000" d="M10.74 7.297s.359.023.62-.214c0 0 2.363 1.906-1.143 5.74-3.508 3.834-.796 6.316-.796 6.316S8.79 19.77 9.149 21c0 0-1.46-.853-2.575-2.301-1.612-2.093-2.598-5.295 1.83-7.85 0 0 2.923-1.522 2.335-3.552ZM7.127 5.075s.472-.872 1.568-.872c.864 0 1.06-.46 1.06-.46S10.134 3 12.036 3c1.744 0 2.92.602 3.87 1.406 0 0-2.563-1.647-5.09.67H7.127Z"/>
  <path fill="#DB0000" d="M17.786 10.594c-.073-2.722-2.106-5.639-6.477-5.473 4.27-3.745 11.676 4.615 5.576 9.007 0 0 1.02-1.508.9-3.534Z"/>
  <path fill="#DB0000" d="M11.963 5.421c5.33-.165 7.232 6.45 3.79 9.428l-3.456 1.73s-.45-1.504 1.22-3.264c1.671-1.758 3.282-5.051-1.335-7.217 0 0 .087-.45-.218-.676h-.001Z"/>
  <path fill="#DB0000" d="M11.687 6.91s.261-.256.349-.466c3.964 1.713 3.34 4.616.972 7.052-1.452 1.548-1.002 3.218-1.002 3.218s-1.77 1.142-2.381 2.135c0 0-2.565-2.261.987-6.014 3.485-3.684 1.075-5.925 1.075-5.925Z"/>
</svg>`;
  const Share = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M18 2.6a2.4 2.4 0 1 0 0 4.8 2.4 2.4 0 0 0 0-4.8Zm-2.764 4.706a3.6 3.6 0 1 0-.605-1.036L8.763 9.694a3.6 3.6 0 1 0 0 4.613l5.868 3.418a3.6 3.6 0 1 0 .607-1.035l-5.87-3.42c.15-.395.23-.823.23-1.27 0-.447-.08-.875-.23-1.27l5.867-3.424ZM8.049 10.75a.6.6 0 0 0 .049.083c.192.345.302.743.302 1.167a2.389 2.389 0 0 1-.35 1.25 2.4 2.4 0 1 1 0-2.5Zm7.829 7.128a.607.607 0 0 0 .104-.178 2.4 2.4 0 1 1-.104.178Z" clip-rule="evenodd"/>
</svg>`;
  const SlashCircle = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M4.942 5.79A9.364 9.364 0 0 0 2.6 12a9.4 9.4 0 0 0 9.4 9.4c2.38 0 4.553-.884 6.209-2.342L4.942 5.79Zm.849-.848L19.058 18.21A9.364 9.364 0 0 0 21.4 12 9.4 9.4 0 0 0 12 2.6c-2.38 0-4.553.884-6.21 2.342ZM1.4 12C1.4 6.146 6.146 1.4 12 1.4c5.854 0 10.6 4.746 10.6 10.6 0 5.854-4.746 10.6-10.6 10.6-5.854 0-10.6-4.746-10.6-10.6Z" clip-rule="evenodd"/>
</svg>`;
  const Sliders = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M18 5.6a2.4 2.4 0 1 0 0 4.8 2.4 2.4 0 0 0 0-4.8Zm-3.55 1.8a3.6 3.6 0 1 1 0 1.2H3a.6.6 0 0 1 0-1.2h11.45ZM6 13.6a2.4 2.4 0 1 0 0 4.8 2.4 2.4 0 0 0 0-4.8ZM2.4 16a3.6 3.6 0 0 1 7.15-.6H21a.6.6 0 1 1 0 1.2H9.55A3.601 3.601 0 0 1 2.4 16Z" clip-rule="evenodd"/>
</svg>`;
  const Speedometer = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M2.619 11.4H4.5a.6.6 0 1 1 0 1.2H2.619a9.361 9.361 0 0 0 2.323 5.61l1.33-1.331a.6.6 0 0 1 .85.848l-1.331 1.33a9.361 9.361 0 0 0 5.609 2.324V19.5a.6.6 0 0 1 1.2 0v1.881a9.362 9.362 0 0 0 5.61-2.323l-1.33-1.329a.6.6 0 0 1 .849-.849l1.329 1.33a9.361 9.361 0 0 0 2.323-5.61H19.5a.6.6 0 0 1 0-1.2h1.881a9.36 9.36 0 0 0-2.29-5.57l-4.876 4.808a2.6 2.6 0 1 1-.848-.85l4.88-4.811A9.361 9.361 0 0 0 12.6 2.619V4.5a.6.6 0 1 1-1.2 0V2.619a9.362 9.362 0 0 0-5.65 2.36l1.332 1.333a.6.6 0 0 1-.848.849L4.906 5.833A9.36 9.36 0 0 0 2.619 11.4Zm16.957 8.013A10.566 10.566 0 0 0 22.6 12c0-5.854-4.746-10.6-10.6-10.6C6.146 1.4 1.4 6.146 1.4 12c0 2.886 1.153 5.502 3.024 7.414a.604.604 0 0 0 .162.162A10.566 10.566 0 0 0 12 22.6c2.886 0 5.502-1.153 7.413-3.024a.6.6 0 0 0 .163-.163ZM12 10.6a1.4 1.4 0 1 0 0 2.8 1.4 1.4 0 0 0 0-2.8Z" clip-rule="evenodd"/>
</svg>`;
  const StarFill = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M11.527 2.137a1.1 1.1 0 0 1 .946 0c.243.116.387.322.477.469.092.15.189.345.294.56l2.198 4.452c.017.035.03.062.043.085l.004.009.009.001.094.014 4.917.719c.236.034.452.066.622.107.168.04.408.113.593.309a1.1 1.1 0 0 1 .292.9c-.035.267-.187.468-.298.598a7.53 7.53 0 0 1-.442.453l-3.556 3.463-.068.067-.007.007.002.01.015.094.84 4.892c.04.235.077.45.09.625.014.172.019.423-.11.66a1.1 1.1 0 0 1-.766.557c-.265.049-.502-.034-.661-.1a7.468 7.468 0 0 1-.567-.28l-4.395-2.311-.085-.044-.008-.005a14.009 14.009 0 0 0-.093.049l-4.395 2.311a7.468 7.468 0 0 1-.567.28c-.159.066-.397.149-.661.1a1.1 1.1 0 0 1-.767-.557c-.128-.237-.123-.488-.11-.66.014-.174.051-.39.091-.625l.84-4.893.015-.094.002-.01-.007-.006-.068-.067-3.556-3.463c-.171-.167-.328-.32-.442-.453-.112-.13-.263-.33-.298-.598a1.1 1.1 0 0 1 .292-.9c.185-.196.425-.269.592-.31.17-.04.387-.072.623-.106l4.916-.719.095-.014.01-.001.003-.009.043-.085 2.198-4.453c.105-.214.202-.41.294-.56.09-.146.233-.352.476-.468Z" clip-rule="evenodd"/>
</svg>`;
  const Star = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M11.527 2.137a1.1 1.1 0 0 1 .946 0c.243.116.387.322.477.468.092.15.189.346.294.56l2.198 4.453c.017.035.03.062.043.085l.004.009.009.001.094.014 4.917.719c.236.034.452.066.622.107.168.04.408.113.593.309a1.1 1.1 0 0 1 .292.9c-.035.267-.187.468-.298.598-.114.134-.271.286-.442.453l-3.556 3.463-.068.067-.007.007.002.01.015.093.84 4.893c.04.235.077.45.09.625.014.172.019.423-.11.66a1.1 1.1 0 0 1-.766.556c-.265.05-.502-.033-.661-.099a7.468 7.468 0 0 1-.567-.28l-4.395-2.311a6.864 6.864 0 0 0-.085-.044L12 18.448l-.008.005-.085.044-4.395 2.311a7.571 7.571 0 0 1-.567.28c-.159.066-.397.148-.661.1a1.1 1.1 0 0 1-.767-.557c-.128-.237-.123-.488-.11-.66.014-.175.051-.39.091-.625l.84-4.893a9.161 9.161 0 0 0 .017-.103l-.007-.007-.068-.067-3.556-3.463c-.171-.167-.328-.32-.442-.453-.112-.13-.263-.33-.298-.598a1.1 1.1 0 0 1 .292-.9c.185-.196.425-.269.592-.31.17-.04.387-.072.623-.106l4.916-.719a9.093 9.093 0 0 0 .104-.015l.004-.009.043-.085 2.198-4.453c.105-.214.202-.41.294-.56.09-.146.233-.352.476-.468ZM12 3.362a16.06 16.06 0 0 0-.18.357l-2.186 4.43c-.005.01-.01.019-.014.03a1.507 1.507 0 0 1-.236.373 1.1 1.1 0 0 1-.342.249c-.15.07-.313.092-.429.109l-.032.004-4.891.715c-.17.025-.296.044-.395.061.07.072.161.16.284.28l3.538 3.447.024.022c.084.082.202.196.283.34a1.1 1.1 0 0 1 .13.403c.02.165-.008.327-.028.442l-.006.032-.835 4.867c-.029.17-.05.296-.064.395.09-.044.203-.104.355-.184l4.372-2.3.03-.015c.102-.054.248-.132.41-.163a1.1 1.1 0 0 1 .424 0c.162.031.308.109.41.163l.03.016 4.372 2.3c.152.08.266.139.355.183a15.737 15.737 0 0 0-.065-.395l-.834-4.867-.006-.032a1.505 1.505 0 0 1-.029-.442 1.1 1.1 0 0 1 .131-.402c.08-.145.2-.26.283-.34l.024-.023L20.42 9.97c.123-.12.214-.21.283-.28a15.706 15.706 0 0 0-.394-.062l-4.891-.715-.033-.004a1.507 1.507 0 0 1-.428-.11 1.1 1.1 0 0 1-.342-.248c-.112-.121-.184-.269-.236-.374l-.014-.03-2.187-4.43a15.985 15.985 0 0 0-.18-.356Z" clip-rule="evenodd"/>
</svg>`;
  const Stoplights = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M9.4 8a2.6 2.6 0 1 1 5.2 0 2.6 2.6 0 0 1-5.2 0ZM12 6.6a1.4 1.4 0 1 0 0 2.8 1.4 1.4 0 0 0 0-2.8Zm0 6.8a2.6 2.6 0 1 0 0 5.2 2.6 2.6 0 0 0 0-5.2ZM10.6 16a1.4 1.4 0 1 1 2.8 0 1.4 1.4 0 0 1-2.8 0Z" clip-rule="evenodd"/>
  <path fill="currentColor" fill-rule="evenodd" d="M9.774 1.4h4.452c.818 0 1.468 0 1.993.043.537.044.996.136 1.415.35a3.6 3.6 0 0 1 1.573 1.573c.214.42.306.877.35 1.415.043.525.043 1.175.043 1.993v10.452c0 .818 0 1.469-.043 1.993-.044.538-.136.996-.35 1.415a3.6 3.6 0 0 1-1.573 1.574c-.42.213-.878.305-1.415.35-.525.042-1.175.042-1.993.042H9.774c-.818 0-1.469 0-1.993-.043-.538-.044-.996-.136-1.415-.35a3.6 3.6 0 0 1-1.574-1.573c-.213-.42-.305-.877-.35-1.415-.042-.524-.042-1.175-.042-1.993V6.774c0-.818 0-1.468.043-1.993.044-.538.136-.996.35-1.415a3.6 3.6 0 0 1 1.573-1.574c.42-.213.877-.305 1.415-.35C8.305 1.4 8.956 1.4 9.774 1.4ZM7.878 2.639c-.463.038-.745.11-.968.223A2.4 2.4 0 0 0 5.861 3.91c-.113.223-.184.505-.222.968-.039.47-.04 1.072-.04 1.922v10.4c0 .85.001 1.451.04 1.922.038.463.11.745.222.968a2.4 2.4 0 0 0 1.05 1.048c.222.114.504.185.967.223.47.039 1.072.039 1.922.039h4.4c.85 0 1.451 0 1.921-.039.464-.038.746-.11.969-.223a2.4 2.4 0 0 0 1.048-1.048c.113-.223.185-.505.223-.968.038-.47.039-1.072.039-1.922V6.8c0-.85 0-1.451-.039-1.922-.038-.463-.11-.745-.223-.968a2.4 2.4 0 0 0-1.049-1.048c-.222-.114-.504-.185-.968-.223C15.651 2.6 15.05 2.6 14.2 2.6H9.8c-.85 0-1.451 0-1.922.039Z" clip-rule="evenodd"/>
</svg>`;
  const SwitchHorizontal = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M16.058 3.058a.625.625 0 0 1 .884 0l4 4a.625.625 0 0 1 0 .884l-4 4a.625.625 0 1 1-.884-.884l2.933-2.933H3.5a.625.625 0 1 1 0-1.25h15.491l-2.933-2.933a.625.625 0 0 1 0-.884Zm-8.116 9a.625.625 0 0 1 0 .884l-2.933 2.933H20.5a.625.625 0 1 1 0 1.25H5.009l2.933 2.933a.625.625 0 1 1-.884.884l-4-4a.625.625 0 0 1 0-.884l4-4a.625.625 0 0 1 .884 0Z"/>
</svg>`;
  const SwitchVertical = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M7.058 3.058a.625.625 0 0 1 .884 0l4 4a.625.625 0 1 1-.884.884L8.125 5.009V20.5a.625.625 0 1 1-1.25 0V5.009L3.942 7.942a.625.625 0 1 1-.884-.884l4-4Zm8.817.442a.625.625 0 1 1 1.25 0v15.491l2.933-2.933a.625.625 0 1 1 .884.884l-4 4a.625.625 0 0 1-.884 0l-4-4a.625.625 0 1 1 .884-.884l2.933 2.933V3.5Z"/>
</svg>`;
  const Tablet = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M10.5 16.875a.625.625 0 1 0 0 1.25h3a.625.625 0 1 0 0-1.25h-3Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M16.526 1.875H7.474c-.503 0-.918 0-1.257.028-.352.03-.676.092-.98.249-.471.243-.852.63-1.091 1.105-.154.305-.215.63-.243.985-.028.342-.028.762-.028 1.272v12.972c0 .51 0 .93.028 1.272.028.355.09.68.243.985.239.475.62.862 1.091 1.105.304.157.628.22.98.249a16.5 16.5 0 0 0 1.257.028h9.052c.503 0 .919 0 1.257-.028.352-.03.676-.092.98-.249.471-.243.852-.63 1.091-1.105.154-.305.215-.63.243-.985.028-.342.028-.762.028-1.272V5.514c0-.51 0-.93-.028-1.272-.028-.355-.09-.68-.243-.985a2.513 2.513 0 0 0-1.091-1.105c-.304-.157-.628-.22-.98-.249a16.473 16.473 0 0 0-1.257-.028ZM5.811 3.262c.097-.05.236-.09.51-.113.28-.023.644-.024 1.179-.024h9c.535 0 .899 0 1.18.024.273.022.413.063.51.113.234.122.426.316.547.556.051.101.092.245.115.524.023.286.023.656.023 1.198v12.92c0 .542 0 .912-.023 1.198-.023.278-.064.423-.115.524-.12.24-.313.434-.547.556-.098.05-.237.09-.51.113-.281.024-.645.024-1.18.024h-9c-.535 0-.899 0-1.18-.024-.273-.022-.412-.063-.51-.113a1.263 1.263 0 0 1-.547-.556c-.051-.101-.092-.245-.114-.524a16.605 16.605 0 0 1-.024-1.198V5.54c0-.542 0-.912.024-1.198.022-.279.063-.423.114-.524.12-.24.313-.434.548-.556Z" clip-rule="evenodd"/>
</svg>`;
  const Telephone = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M7.012 3.744a1.335 1.335 0 0 0-1.205 0c-.17.085-.347.252-.894.8l-.153.152c-.53.53-.718.725-.865.986A2.68 2.68 0 0 0 3.6 6.817c0 .304.053.5.21 1.057a17.818 17.818 0 0 0 4.563 7.753 17.818 17.818 0 0 0 7.753 4.562c.557.158.753.21 1.057.211a2.68 2.68 0 0 0 1.134-.295c.262-.147.456-.335.987-.865l.152-.153c.548-.547.715-.725.8-.894a1.335 1.335 0 0 0 0-1.205c-.085-.169-.252-.346-.8-.894l-.188-.188c-.36-.36-.476-.472-.58-.54a1.335 1.335 0 0 0-1.455 0c-.105.068-.22.18-.58.54l-.02.02a2.3 2.3 0 0 1-.286.256c-.38.271-.903.36-1.351.23a2.07 2.07 0 0 1-.33-.135l-.02-.01a14.729 14.729 0 0 1-4.043-2.87 14.726 14.726 0 0 1-2.87-4.044l-.01-.02a1.946 1.946 0 0 1-.135-.329 1.611 1.611 0 0 1 .23-1.35c.076-.107.165-.196.256-.286l.02-.02c.36-.36.472-.476.54-.58a1.335 1.335 0 0 0 0-1.456c-.068-.104-.18-.22-.54-.58l-.188-.189c-.548-.547-.725-.714-.894-.8ZM5.265 2.673a2.535 2.535 0 0 1 2.288 0c.364.184.686.506 1.128.949l.073.073.189.188.048.048c.291.292.503.503.648.727.547.84.547 1.923 0 2.764-.145.224-.357.435-.648.726l-.048.048c-.124.124-.138.14-.149.156a.416.416 0 0 0-.054.317c.006.02.01.033.074.165a13.527 13.527 0 0 0 2.637 3.715 13.529 13.529 0 0 0 3.715 2.637c.132.063.146.068.165.074a.416.416 0 0 0 .317-.054c.016-.011.032-.025.156-.149l.048-.048c.291-.291.502-.503.726-.648a2.535 2.535 0 0 1 2.764 0c.224.145.435.357.726.648l.048.048.189.189.073.073c.443.442.765.764.949 1.128a2.533 2.533 0 0 1 0 2.288c-.184.364-.506.685-.949 1.128a49.66 49.66 0 0 0-.073.073l-.152.152-.048.048c-.468.467-.779.779-1.2 1.015a3.86 3.86 0 0 1-1.726.449c-.482-.001-.828-.1-1.341-.245l-.04-.012a19.019 19.019 0 0 1-8.274-4.867A19.02 19.02 0 0 1 2.656 8.2l-.01-.039C2.498 7.648 2.4 7.303 2.4 6.82a3.86 3.86 0 0 1 .449-1.725c.236-.421.548-.733 1.015-1.2l.048-.048.152-.152.073-.073c.443-.443.764-.765 1.128-.95Z" clip-rule="evenodd"/>
</svg>`;
  const ThreeDotsVertical = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M10.4 5a1.6 1.6 0 1 1 3.2 0 1.6 1.6 0 0 1-3.2 0Zm0 7a1.6 1.6 0 1 1 3.2 0 1.6 1.6 0 0 1-3.2 0Zm0 7a1.6 1.6 0 1 1 3.2 0 1.6 1.6 0 0 1-3.2 0Z" clip-rule="evenodd"/>
</svg>`;
  const ThreeDots = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M3.4 12a1.6 1.6 0 1 1 3.2 0 1.6 1.6 0 0 1-3.2 0Zm7 0a1.6 1.6 0 1 1 3.2 0 1.6 1.6 0 0 1-3.2 0Zm7 0a1.6 1.6 0 1 1 3.2 0 1.6 1.6 0 0 1-3.2 0Z" clip-rule="evenodd"/>
</svg>`;
  const Ticket = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M10.1 6.925c.345 0 .625.28.625.625v.95a.625.625 0 1 1-1.25 0v-.95c0-.345.28-.625.625-.625Zm0 3.975c.345 0 .625.28.625.625v.95a.625.625 0 1 1-1.25 0v-.95c0-.345.28-.625.625-.625Zm0 3.975c.345 0 .625.28.625.625v.95a.625.625 0 1 1-1.25 0v-.95c0-.345.28-.625.625-.625Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M5.514 3.975h12.972c.51 0 .93 0 1.273.028.355.029.681.091.987.247.475.242.862.629 1.104 1.104.156.306.218.632.247.987.028.343.028.763.028 1.273v1.161c0 .345-.28.625-.625.625a2.7 2.7 0 1 0 0 5.4c.345 0 .625.28.625.625v1.16c0 .51 0 .931-.028 1.274-.029.355-.091.681-.247.987a2.525 2.525 0 0 1-1.104 1.104c-.306.156-.632.218-.987.247-.343.028-.763.028-1.273.028H5.514c-.51 0-.93 0-1.273-.028-.355-.029-.681-.091-.987-.247a2.525 2.525 0 0 1-1.104-1.104c-.156-.306-.218-.632-.247-.987a16.913 16.913 0 0 1-.028-1.273v-1.161c0-.345.28-.625.625-.625a2.7 2.7 0 0 0 0-5.4.625.625 0 0 1-.625-.625v-1.16c0-.511 0-.931.028-1.274.029-.355.091-.681.247-.987A2.525 2.525 0 0 1 3.254 4.25c.306-.156.632-.218.987-.247.343-.028.763-.028 1.273-.028ZM4.343 5.249c-.278.023-.421.064-.522.115a1.27 1.27 0 0 0-.557.557c-.051.1-.092.244-.115.522-.024.285-.024.655-.024 1.197v.56a3.951 3.951 0 0 1 0 7.8v.56c0 .542 0 .912.024 1.197.023.278.064.421.115.522.122.24.317.435.557.557.1.051.244.092.522.115.285.023.655.024 1.197.024h12.92c.542 0 .912 0 1.197-.024.278-.023.421-.064.522-.115a1.27 1.27 0 0 0 .557-.557c.051-.1.092-.244.115-.522.024-.286.024-.655.024-1.197V16a3.951 3.951 0 0 1 0-7.8v-.56c0-.542 0-.912-.024-1.197-.023-.278-.064-.421-.115-.522a1.275 1.275 0 0 0-.557-.557c-.1-.051-.244-.092-.522-.115a16.375 16.375 0 0 0-1.197-.024H5.54c-.542 0-.912 0-1.197.024Z" clip-rule="evenodd"/>
</svg>`;
  const ToggleOff = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M1.4 12A5.6 5.6 0 0 1 7 6.4h10a5.6 5.6 0 1 1 0 11.2H7A5.6 5.6 0 0 1 1.4 12Zm9.064 4.4H17a4.4 4.4 0 1 0 0-8.8h-6.536A5.59 5.59 0 0 1 12.6 12a5.59 5.59 0 0 1-2.136 4.4ZM7 7.6a4.4 4.4 0 1 0 0 8.8 4.4 4.4 0 0 0 0-8.8Z" clip-rule="evenodd"/>
</svg>`;
  const ToggleOn = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M1.4 12A5.6 5.6 0 0 1 7 6.4h10a5.6 5.6 0 1 1 0 11.2H7A5.6 5.6 0 0 1 1.4 12ZM17 16.4a4.4 4.4 0 1 0 0-8.8 4.4 4.4 0 0 0 0 8.8Zm-3.465-8.8A5.59 5.59 0 0 0 11.4 12a5.59 5.59 0 0 0 2.135 4.4H7a4.4 4.4 0 1 1 0-8.8h6.535Z" clip-rule="evenodd"/>
</svg>`;
  const Train = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M7.125 14.616a1.155 1.155 0 1 1 2.31.002 1.155 1.155 0 0 1-2.31-.002Zm7.438 0a1.155 1.155 0 1 1 2.31.002 1.155 1.155 0 0 1-2.31-.002Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M8.573 1.875h6.854c.87 0 1.56 0 2.117.045.57.047 1.055.144 1.499.369a3.81 3.81 0 0 1 1.666 1.661c.226.443.324.927.37 1.496.046.555.046 1.243.046 2.11v5.711c0 .867 0 1.555-.046 2.11-.046.569-.144 1.053-.37 1.496a3.807 3.807 0 0 1-1.666 1.66 3.16 3.16 0 0 1-.79.272l1.212 2.415a.625.625 0 1 1-1.117.56l-1.428-2.845c-.429.013-.922.013-1.493.013H8.573c-.57 0-1.064 0-1.493-.013L5.652 21.78a.625.625 0 1 1-1.117-.56l1.212-2.415a3.16 3.16 0 0 1-.79-.271 3.807 3.807 0 0 1-1.666-1.661c-.226-.443-.324-.927-.37-1.496-.046-.555-.046-1.244-.046-2.11V7.556c0-.867 0-1.555.046-2.11.046-.569.144-1.053.37-1.496a3.807 3.807 0 0 1 1.666-1.66c.444-.225.929-.322 1.499-.369.557-.045 1.247-.045 2.117-.045Zm-4.448 8.663v2.702c0 .9 0 1.537.041 2.035.04.491.117.792.238 1.029.245.48.637.87 1.12 1.115.238.121.54.198 1.033.238.5.04 1.14.041 2.043.041h6.8c.903 0 1.542 0 2.043-.041.493-.04.795-.117 1.034-.238a2.557 2.557 0 0 0 1.12-1.115c.12-.237.196-.538.237-1.029.04-.498.041-1.135.041-2.035v-2.702H4.125Zm15.75-1.25H4.125V7.583c0-.9 0-1.537.041-2.035.04-.491.117-.792.238-1.029.245-.48.637-.87 1.12-1.115.238-.121.54-.198 1.033-.238.5-.04 1.14-.041 2.043-.041h6.8c.903 0 1.542 0 2.043.041.493.04.795.117 1.034.238.482.244.874.635 1.12 1.115.12.237.196.538.237 1.029.04.498.041 1.135.041 2.035v1.705Z" clip-rule="evenodd"/>
  <path fill="currentColor" d="M8.719 21.5c0-.345.28-.625.625-.625h5.312a.625.625 0 1 1 0 1.25H9.344a.625.625 0 0 1-.625-.625Z"/>
</svg>`;
  const Translate = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M8.2 2.875c.345 0 .625.28.625.625v1.275H13.9a.625.625 0 1 1 0 1.25h-1.854c-.487 2.48-1.45 4.753-2.816 6.723.377.253.757.466 1.126.632a.625.625 0 1 1-.512 1.14 9.047 9.047 0 0 1-1.364-.77 17.074 17.074 0 0 1-5.702 4.56.625.625 0 1 1-.556-1.12 15.824 15.824 0 0 0 5.265-4.201C6.337 12 5.322 10.74 4.774 9.443a.625.625 0 0 1 1.152-.486c.448 1.06 1.303 2.149 2.312 3.028a16.49 16.49 0 0 0 2.533-5.96H2.5a.625.625 0 0 1 0-1.25h5.075V3.5c0-.345.28-.625.625-.625Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="m13.261 17.325-1.647 3.445a.625.625 0 1 1-1.128-.54l4.55-9.514a7.1 7.1 0 0 1 .282-.552c.085-.144.229-.358.479-.479a1.1 1.1 0 0 1 .956 0c.25.121.394.335.48.479.087.149.18.342.28.552l4.55 9.514a.625.625 0 0 1-1.127.54l-1.647-3.445H13.26Zm3.014-6.3.122.253 2.294 4.797h-4.832l2.294-4.797.122-.252Z" clip-rule="evenodd"/>
</svg>`;
  const Trash = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M11.175 1.4h1.65c.539 0 .98 0 1.337.03.371.03.706.094 1.018.253a2.6 2.6 0 0 1 1.137 1.137c.159.312.223.647.254 1.018.029.358.029.798.029 1.337V5.4H21a.6.6 0 1 1 0 1.2h-1.4v10.626c0 .818 0 1.469-.043 1.993-.044.538-.136.996-.35 1.415a3.6 3.6 0 0 1-1.573 1.574c-.42.213-.878.305-1.415.35-.525.042-1.175.042-1.993.042H9.774c-.818 0-1.469 0-1.993-.043-.538-.044-.996-.136-1.415-.35a3.6 3.6 0 0 1-1.574-1.573c-.213-.42-.305-.877-.35-1.415-.042-.524-.042-1.175-.042-1.993V6.6H3a.6.6 0 0 1 0-1.2h4.4v-.225c0-.539 0-.98.03-1.337.03-.371.094-.706.253-1.018A2.6 2.6 0 0 1 8.82 1.683c.312-.159.647-.223 1.017-.254.358-.029.8-.029 1.338-.029ZM5.6 6.6v10.6c0 .85 0 1.451.039 1.922.038.463.11.745.222.968a2.4 2.4 0 0 0 1.05 1.048c.222.114.504.185.967.223.47.038 1.072.039 1.922.039h4.4c.85 0 1.451 0 1.921-.039.464-.038.746-.11.969-.223a2.4 2.4 0 0 0 1.048-1.048c.113-.223.185-.505.223-.968.038-.47.039-1.072.039-1.922V6.6H5.6Zm9.8-1.2H8.6v-.2c0-.57 0-.961.025-1.265.024-.296.069-.455.127-.57a1.4 1.4 0 0 1 .612-.612c.116-.06.275-.104.571-.128.304-.025.695-.025 1.265-.025h1.6c.57 0 .961 0 1.265.025.296.024.455.069.57.128a1.4 1.4 0 0 1 .612.611c.059.116.103.275.128.571.024.304.025.695.025 1.265v.2ZM10 10.9a.6.6 0 0 1 .6.6v5a.6.6 0 1 1-1.2 0v-5a.6.6 0 0 1 .6-.6Zm4 0a.6.6 0 0 1 .6.6v5a.6.6 0 1 1-1.2 0v-5a.6.6 0 0 1 .6-.6Z" clip-rule="evenodd"/>
</svg>`;
  const Truck = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M5.514 2.875h7.272c.51 0 .93 0 1.273.028.355.029.681.091.987.247.475.242.862.629 1.104 1.104.156.306.218.632.247.987.028.343.028.763.028 1.273v1.011h1.639c.188 0 .377 0 .56.044.16.038.315.102.455.188.162.099.294.232.427.365l.031.031 1.96 1.96.03.03c.134.134.267.266.366.428.086.14.15.294.188.455.045.184.044.372.044.56v2.667c0 .246 0 .468-.015.652a1.598 1.598 0 0 1-.157.61 1.575 1.575 0 0 1-.688.688c-.204.105-.413.14-.61.157-.184.015-.406.015-.652.015h-.341a3 3 0 1 1-4.874 0H9.212a3 3 0 1 1-4.86-.02 5.726 5.726 0 0 1-.11-.008c-.356-.029-.682-.091-.988-.247a2.525 2.525 0 0 1-1.104-1.104c-.156-.306-.218-.632-.247-.987a16.912 16.912 0 0 1-.028-1.273V6.514c0-.51 0-.93.028-1.273.029-.355.091-.681.247-.987A2.525 2.525 0 0 1 3.254 3.15c.306-.156.632-.218.987-.247.343-.028.763-.028 1.273-.028Zm1.261 13.5a1.75 1.75 0 1 0 0 3.5 1.75 1.75 0 0 0 0-3.5Zm8.4-1.25V6.54c0-.542 0-.912-.024-1.197-.022-.278-.064-.421-.115-.522a1.275 1.275 0 0 0-.557-.557c-.1-.051-.244-.092-.522-.115a16.381 16.381 0 0 0-1.197-.024H5.54c-.542 0-.912 0-1.197.024-.278.023-.421.064-.522.115a1.27 1.27 0 0 0-.557.557c-.051.1-.092.244-.115.522-.024.285-.024.655-.024 1.197v6.17c0 .542 0 .911.024 1.197.023.278.064.421.115.522.122.24.317.435.557.557.1.051.244.092.522.115.285.023.655.024 1.197.024h9.635Zm1.25-6.35v6.35h3.555c.276 0 .446 0 .573-.01a.822.822 0 0 0 .145-.025.325.325 0 0 0 .142-.143s.003-.006.008-.026a.822.822 0 0 0 .016-.118c.01-.127.011-.297.011-.573v-2.6c0-.263-.004-.292-.009-.312a.325.325 0 0 0-.039-.094c-.011-.018-.029-.042-.214-.227l-1.96-1.96c-.185-.185-.209-.203-.227-.214a.326.326 0 0 0-.094-.039c-.02-.005-.05-.009-.312-.009h-1.595Zm.8 7.6a1.75 1.75 0 1 0 0 3.5 1.75 1.75 0 0 0 0-3.5Z" clip-rule="evenodd"/>
</svg>`;
  const TwitterX = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M17.176 3.844h2.76l-6.03 6.91L21 20.156h-5.554l-4.35-5.702-4.979 5.702H3.355l6.45-7.39L3 3.843h5.695l3.933 5.212 4.548-5.212ZM16.207 18.5h1.53L7.864 5.413h-1.64L16.206 18.5Z"/>
</svg>`;
  const Unlock = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M7 7v3h-.5A2.5 2.5 0 0 0 4 12.5v7A2.5 2.5 0 0 0 6.5 22h11a2.5 2.5 0 0 0 2.5-2.5v-7a2.5 2.5 0 0 0-2.5-2.5H8.2V7a3.8 3.8 0 0 1 7.553-.598c.052.328.316.598.647.598s.604-.27.565-.599A5 5 0 0 0 7 7Zm-1.8 5.5a1.3 1.3 0 0 1 1.3-1.3h11a1.3 1.3 0 0 1 1.3 1.3v7a1.3 1.3 0 0 1-1.3 1.3h-11a1.3 1.3 0 0 1-1.3-1.3v-7Z" clip-rule="evenodd"/>
</svg>`;
  const Upload = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M11.576 2.576a.6.6 0 0 1 .848 0l5 5a.6.6 0 0 1-.848.848L12.6 4.45V15a.6.6 0 1 1-1.2 0V4.449L7.424 8.424a.6.6 0 0 1-.848-.848l5-5ZM3 14.4a.6.6 0 0 1 .6.6v1.2c0 .85 0 1.451.039 1.922.038.463.11.745.222.968a2.4 2.4 0 0 0 1.05 1.048c.222.114.504.185.967.223.47.038 1.072.039 1.922.039h8.4c.85 0 1.451 0 1.921-.039.464-.038.746-.11.969-.223a2.4 2.4 0 0 0 1.048-1.048c.113-.223.185-.505.223-.968.038-.47.039-1.072.039-1.922V15a.6.6 0 1 1 1.2 0v1.226c0 .818 0 1.469-.043 1.993-.044.538-.136.996-.35 1.415a3.6 3.6 0 0 1-1.573 1.574c-.42.213-.878.305-1.415.35-.525.042-1.175.042-1.993.042H7.774c-.818 0-1.469 0-1.993-.043-.538-.044-.996-.136-1.415-.35a3.6 3.6 0 0 1-1.574-1.573c-.213-.42-.305-.877-.35-1.415-.042-.524-.042-1.175-.042-1.993V15a.6.6 0 0 1 .6-.6Z" clip-rule="evenodd"/>
</svg>`;
  const UserCircle = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M7.975 9.875a4.025 4.025 0 1 1 8.05 0 4.025 4.025 0 0 1-8.05 0ZM12 7.1a2.775 2.775 0 1 0 0 5.55 2.775 2.775 0 0 0 0-5.55Z" clip-rule="evenodd"/>
  <path fill="currentColor" fill-rule="evenodd" d="M1.875 12C1.875 6.408 6.408 1.875 12 1.875S22.125 6.408 22.125 12 17.592 22.125 12 22.125 1.875 17.592 1.875 12ZM12 3.125a8.875 8.875 0 0 0-6.873 14.49 4.025 4.025 0 0 1 2.688-1.913c.39-.077.842-.077 1.555-.077h5.26c.713 0 1.166 0 1.555.077a4.025 4.025 0 0 1 2.688 1.913A8.875 8.875 0 0 0 12 3.125Zm5.96 15.452a2.775 2.775 0 0 0-2.019-1.649c-.252-.05-.571-.053-1.39-.053H9.45c-.82 0-1.138.003-1.391.053a2.776 2.776 0 0 0-2.018 1.649A8.843 8.843 0 0 0 12 20.875c2.294 0 4.384-.87 5.96-2.298Z" clip-rule="evenodd"/>
</svg>`;
  const UserSquare = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M7.975 9.875a4.025 4.025 0 1 1 8.05 0 4.025 4.025 0 0 1-8.05 0ZM12 7.1a2.775 2.775 0 1 0 0 5.55 2.775 2.775 0 0 0 0-5.55Z" clip-rule="evenodd"/>
  <path fill="currentColor" fill-rule="evenodd" d="M7.553 2.875h8.894c.691 0 1.248 0 1.699.037.464.038.87.118 1.245.31.598.303 1.084.79 1.388 1.387.191.375.271.781.31 1.245.036.451.036 1.008.036 1.7v8.893c0 .691 0 1.248-.037 1.699-.038.464-.118.87-.31 1.245a3.175 3.175 0 0 1-1.387 1.388c-.131.067-.267.12-.41.164-.602.182-1.377.182-2.447.182H7.466c-1.07 0-1.845 0-2.447-.182a2.49 2.49 0 0 1-.41-.164A3.175 3.175 0 0 1 3.22 19.39c-.191-.375-.271-.781-.31-1.245-.036-.451-.036-1.008-.036-1.7V7.554c0-.691 0-1.248.037-1.699.038-.464.118-.87.31-1.245a3.175 3.175 0 0 1 1.387-1.39c.375-.191.781-.271 1.245-.31.451-.036 1.008-.036 1.7-.036ZM5.956 4.158c-.387.031-.61.09-.78.177a1.925 1.925 0 0 0-.841.841c-.087.17-.146.393-.177.78-.033.394-.033.9-.033 1.624v8.84c0 .724 0 1.23.033 1.624.031.386.09.61.177.78.073.143.163.276.268.395a3.33 3.33 0 0 1 .05-.354 4.025 4.025 0 0 1 3.162-3.163c.39-.077.842-.077 1.555-.077h5.26c.713 0 1.165 0 1.555.077a4.025 4.025 0 0 1 3.163 3.163c.022.112.038.229.05.355.104-.12.194-.253.267-.396.087-.17.146-.394.177-.78.033-.394.033-.9.033-1.624V7.58c0-.724 0-1.23-.033-1.624-.031-.387-.09-.61-.177-.78a1.925 1.925 0 0 0-.841-.841c-.17-.087-.394-.146-.78-.177-.394-.033-.9-.033-1.624-.033H7.58c-.724 0-1.23 0-1.624.033ZM18.172 19.83c-.004-.359-.017-.556-.05-.722a2.775 2.775 0 0 0-2.18-2.18c-.254-.051-.572-.054-1.392-.054h-5.1c-.82 0-1.139.003-1.391.053a2.775 2.775 0 0 0-2.18 2.18c-.034.167-.047.364-.051.723.382.04.915.044 1.752.044h8.84c.837 0 1.37-.003 1.752-.044Z" clip-rule="evenodd"/>
</svg>`;
  const Users = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M4.875 7a4.625 4.625 0 1 1 9.25 0 4.625 4.625 0 0 1-9.25 0ZM9.5 3.625a3.375 3.375 0 1 0 0 6.75 3.375 3.375 0 0 0 0-6.75Z" clip-rule="evenodd"/>
  <path fill="currentColor" d="M14.92 3.056a.625.625 0 0 1 .815-.345 4.626 4.626 0 0 1 0 8.578.625.625 0 0 1-.47-1.16 3.376 3.376 0 0 0 0-6.259.625.625 0 0 1-.344-.814ZM7.977 14.375h3.046c.912 0 1.629 0 2.208.04.59.04 1.082.123 1.539.312a4.625 4.625 0 0 1 2.503 2.503c.189.456.272.95.313 1.539.039.579.039 1.296.039 2.208V21a.625.625 0 1 1-1.25 0c0-.94 0-1.614-.037-2.146-.036-.526-.105-.867-.22-1.146a3.375 3.375 0 0 0-1.826-1.826c-.28-.115-.62-.184-1.146-.22-.532-.037-1.206-.037-2.146-.037H8c-.94 0-1.614 0-2.146.037-.526.035-.867.104-1.146.22-.827.342-1.484 1-1.826 1.826-.116.28-.185.62-.22 1.146-.037.532-.037 1.206-.037 2.146a.625.625 0 1 1-1.25 0v-.023c0-.912 0-1.629.04-2.208.04-.59.123-1.082.312-1.539a4.625 4.625 0 0 1 2.503-2.503c.456-.189.95-.272 1.539-.313.579-.039 1.296-.039 2.208-.039Zm10.418.595a.625.625 0 0 1 .76-.45 4.627 4.627 0 0 1 3.47 4.48v2a.625.625 0 1 1-1.25 0v-2a3.377 3.377 0 0 0-2.53-3.269.625.625 0 0 1-.45-.76Z"/>
</svg>`;
  const VideoRecorder = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M7.273 3.875h4.454c.817 0 1.468 0 1.994.043.54.044 1.001.136 1.425.352a3.625 3.625 0 0 1 1.584 1.584c.216.424.308.886.352 1.425.042.517.043 1.157.043 1.956l2.578-1.45a1.625 1.625 0 0 1 2.422 1.416v5.58a1.625 1.625 0 0 1-2.422 1.417l-2.578-1.45c0 .807 0 1.452-.043 1.973-.044.54-.136 1.001-.352 1.425a3.625 3.625 0 0 1-1.584 1.584c-.424.216-.886.308-1.425.352-.526.043-1.177.043-1.994.043H7.273c-.817 0-1.469 0-1.994-.043-.54-.044-1.001-.136-1.425-.352a3.625 3.625 0 0 1-1.584-1.584c-.216-.424-.308-.886-.352-1.425-.043-.526-.043-1.177-.043-1.994V9.273c0-.817 0-1.469.043-1.994.044-.54.136-1.001.352-1.425A3.625 3.625 0 0 1 3.854 4.27c.424-.216.886-.308 1.425-.352.525-.043 1.177-.043 1.994-.043ZM15.875 9.3c0-.85 0-1.45-.039-1.92-.037-.461-.109-.74-.22-.958a2.375 2.375 0 0 0-1.038-1.038c-.218-.111-.497-.182-.958-.22-.47-.039-1.07-.039-1.92-.039H7.3c-.85 0-1.45 0-1.92.039-.461.038-.74.109-.958.22-.447.228-.81.59-1.038 1.038-.111.218-.182.497-.22.958-.039.47-.039 1.07-.039 1.92v5.4c0 .85 0 1.45.039 1.92.038.461.109.74.22.958.228.447.59.81 1.038 1.038.218.111.497.183.958.22.47.039 1.07.039 1.92.039h4.4c.85 0 1.45 0 1.92-.039.461-.037.74-.109.958-.22.447-.228.81-.59 1.038-1.038.111-.218.183-.497.22-.959.038-.468.039-1.069.039-1.919V9.3Zm1.25 4.014 3.191 1.795c.25.14.559-.04.559-.327v-5.58a.375.375 0 0 0-.559-.327l-3.191 1.795v2.644Z" clip-rule="evenodd"/>
</svg>`;
  const VolumeMax = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M11.912 3.086c.359-.029.71.117.943.39.197.231.236.518.253.701.017.197.017.448.017.727v14.192c0 .28 0 .53-.017.727-.017.183-.056.47-.253.7a1.12 1.12 0 0 1-.943.391c-.303-.023-.533-.2-.674-.317a8.979 8.979 0 0 1-.527-.502l-3.184-3.184c-.194-.195-.222-.217-.245-.23a.374.374 0 0 0-.109-.046c-.026-.006-.061-.01-.336-.01h-1.76c-.26 0-.492 0-.685-.016a1.649 1.649 0 0 1-.63-.161 1.625 1.625 0 0 1-.71-.71 1.65 1.65 0 0 1-.161-.63c-.016-.193-.016-.425-.016-.685V9.577c0-.26 0-.492.016-.685a1.65 1.65 0 0 1 .161-.63 1.63 1.63 0 0 1 .71-.71 1.65 1.65 0 0 1 .63-.161c.193-.016.425-.016.685-.016h1.76c.275 0 .31-.004.336-.01a.375.375 0 0 0 .109-.045c.023-.015.05-.037.245-.23l3.184-3.185a8.99 8.99 0 0 1 .527-.502c.14-.118.371-.294.674-.317Zm-.04 1.428c-.078.076-.174.172-.296.294L8.411 7.973l-.033.032c-.14.141-.277.279-.443.38-.146.09-.304.155-.47.195-.19.045-.383.045-.582.045H5.1c-.29 0-.47 0-.606.011-.127.01-.16.027-.164.03a.375.375 0 0 0-.164.164c-.002.004-.02.037-.03.164a8.42 8.42 0 0 0-.011.606v4.8c0 .29 0 .47.012.606.01.127.027.16.029.164.036.07.093.128.164.164a.483.483 0 0 0 .164.03c.136.01.316.01.606.01h1.783c.199 0 .393 0 .582.046.166.04.324.105.47.194.166.102.303.24.443.38l.033.033 3.165 3.165c.122.122.218.218.297.294.002-.11.002-.246.002-.417V4.93c0-.171 0-.307-.002-.417Z" clip-rule="evenodd"/>
  <path fill="currentColor" d="M18.366 5.993a.625.625 0 0 1 .872.142A10.011 10.011 0 0 1 21.125 12c0 2.188-.7 4.214-1.887 5.865a.625.625 0 0 1-1.014-.73A8.761 8.761 0 0 0 19.875 12a8.76 8.76 0 0 0-1.651-5.135.625.625 0 0 1 .142-.872Zm-3.138 2.351a.625.625 0 0 1 .87.156 6.1 6.1 0 0 1 1.099 3.5 6.1 6.1 0 0 1-1.098 3.5.625.625 0 1 1-1.026-.715A4.85 4.85 0 0 0 15.947 12a4.85 4.85 0 0 0-.874-2.785.625.625 0 0 1 .155-.87Z"/>
</svg>`;
  const VolumeX = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M11.912 3.086c.359-.029.71.117.943.39.197.231.236.518.253.701.017.197.017.448.017.727v14.192c0 .28 0 .53-.017.727-.017.183-.056.47-.253.7a1.12 1.12 0 0 1-.943.391c-.303-.023-.533-.2-.674-.317a8.979 8.979 0 0 1-.527-.502l-3.184-3.184c-.194-.195-.222-.217-.245-.23a.374.374 0 0 0-.109-.046c-.026-.006-.061-.01-.336-.01h-1.76c-.26 0-.492 0-.685-.016a1.649 1.649 0 0 1-.63-.161 1.625 1.625 0 0 1-.71-.71 1.65 1.65 0 0 1-.161-.63c-.016-.193-.016-.425-.016-.685V9.577c0-.26 0-.492.016-.685a1.65 1.65 0 0 1 .161-.63 1.63 1.63 0 0 1 .71-.71 1.65 1.65 0 0 1 .63-.161c.193-.016.425-.016.685-.016h1.76c.275 0 .31-.004.336-.01a.375.375 0 0 0 .109-.045c.023-.015.05-.037.245-.23l3.184-3.185a8.99 8.99 0 0 1 .527-.502c.14-.118.371-.294.674-.317Zm-.04 1.428c-.078.076-.174.172-.296.294L8.411 7.973l-.033.032c-.14.141-.277.279-.443.38-.146.09-.304.155-.47.195-.19.045-.383.045-.582.045H5.1c-.29 0-.47 0-.606.011-.127.01-.16.027-.164.03a.375.375 0 0 0-.164.164c-.002.004-.02.037-.03.164a8.42 8.42 0 0 0-.011.606v4.8c0 .29 0 .47.012.606.01.127.027.16.029.164.036.07.093.128.164.164a.483.483 0 0 0 .164.03c.136.01.316.01.606.01h1.783c.199 0 .393 0 .582.046.166.04.324.105.47.194.166.102.303.24.443.38l.033.033 3.165 3.165c.122.122.218.218.297.294.002-.11.002-.246.002-.417V4.93c0-.171 0-.307-.002-.417Z" clip-rule="evenodd"/>
  <path fill="currentColor" d="M15.058 9.058a.625.625 0 0 1 .884 0L18 11.116l2.058-2.058a.625.625 0 1 1 .884.884L18.884 12l2.058 2.058a.625.625 0 0 1-.884.884L18 12.884l-2.058 2.058a.625.625 0 1 1-.884-.884L17.116 12l-2.058-2.058a.625.625 0 0 1 0-.884Z"/>
</svg>`;
  const WindowDash = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M15 14H9a.6.6 0 1 0 0 1.2h6a.6.6 0 1 0 0-1.2Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M20.673 4.638C21 5.28 21 6.12 21 7.8v8.4c0 1.68 0 2.52-.327 3.162a3 3 0 0 1-1.311 1.311C18.72 21 17.88 21 16.2 21H7.8c-1.68 0-2.52 0-3.162-.327a3 3 0 0 1-1.311-1.311C3 18.72 3 17.88 3 16.2V7.8c0-1.68 0-2.52.327-3.162a3 3 0 0 1 1.311-1.311C5.28 3 6.12 3 7.8 3h8.4c1.68 0 2.52 0 3.162.327a3 3 0 0 1 1.311 1.311ZM4.2 9.6h15.6v6.6c0 .86 0 1.433-.037 1.873-.035.426-.096.62-.16.744a1.8 1.8 0 0 1-.786.787c-.123.063-.318.124-.744.16-.44.035-1.013.036-1.873.036H7.8c-.86 0-1.433 0-1.873-.037-.426-.035-.62-.096-.744-.16a1.8 1.8 0 0 1-.787-.786c-.063-.123-.124-.318-.16-.744-.035-.44-.036-1.013-.036-1.873V9.6Zm0-1.2h15.6v-.6c0-.86 0-1.433-.037-1.873-.035-.426-.096-.62-.16-.744a1.8 1.8 0 0 0-.786-.787c-.123-.063-.318-.124-.744-.16-.44-.035-1.013-.036-1.873-.036H7.8c-.86 0-1.433 0-1.873.037-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744C4.202 6.367 4.2 6.94 4.2 7.8v.6Z" clip-rule="evenodd"/>
</svg>`;
  const WindowDesktop = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M15 17H9a.6.6 0 1 0 0 1.2h6a.6.6 0 1 0 0-1.2Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M20.673 4.638C21 5.28 21 6.12 21 7.8v8.4c0 1.68 0 2.52-.327 3.162a3 3 0 0 1-1.311 1.311C18.72 21 17.88 21 16.2 21H7.8c-1.68 0-2.52 0-3.162-.327a3 3 0 0 1-1.311-1.311C3 18.72 3 17.88 3 16.2V7.8c0-1.68 0-2.52.327-3.162a3 3 0 0 1 1.311-1.311C5.28 3 6.12 3 7.8 3h8.4c1.68 0 2.52 0 3.162.327a3 3 0 0 1 1.311 1.311ZM4.2 9.6h15.6v6.6c0 .86 0 1.433-.037 1.873-.035.426-.096.62-.16.744a1.8 1.8 0 0 1-.786.787c-.123.063-.318.124-.744.16-.44.035-1.013.036-1.873.036H7.8c-.86 0-1.433 0-1.873-.037-.426-.035-.62-.096-.744-.16a1.8 1.8 0 0 1-.787-.786c-.063-.123-.124-.318-.16-.744-.035-.44-.036-1.013-.036-1.873V9.6Zm0-1.2h15.6v-.6c0-.86 0-1.433-.037-1.873-.035-.426-.096-.62-.16-.744a1.8 1.8 0 0 0-.786-.787c-.123-.063-.318-.124-.744-.16-.44-.035-1.013-.036-1.873-.036H7.8c-.86 0-1.433 0-1.873.037-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744C4.202 6.367 4.2 6.94 4.2 7.8v.6Z" clip-rule="evenodd"/>
</svg>`;
  const WindowDock = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M7.5 14h1a.6.6 0 1 1 0 1.2h-1a.6.6 0 1 1 0-1.2Zm4 0h1a.6.6 0 1 1 0 1.2h-1a.6.6 0 1 1 0-1.2Zm5 0h-1a.6.6 0 1 0 0 1.2h1a.6.6 0 1 0 0-1.2Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M20.673 4.638C21 5.28 21 6.12 21 7.8v8.4c0 1.68 0 2.52-.327 3.162a3 3 0 0 1-1.311 1.311C18.72 21 17.88 21 16.2 21H7.8c-1.68 0-2.52 0-3.162-.327a3 3 0 0 1-1.311-1.311C3 18.72 3 17.88 3 16.2V7.8c0-1.68 0-2.52.327-3.162a3 3 0 0 1 1.311-1.311C5.28 3 6.12 3 7.8 3h8.4c1.68 0 2.52 0 3.162.327a3 3 0 0 1 1.311 1.311ZM4.2 9.6h15.6v6.6c0 .86 0 1.433-.037 1.873-.035.426-.096.62-.16.744a1.8 1.8 0 0 1-.786.787c-.123.063-.318.124-.744.16-.44.035-1.013.036-1.873.036H7.8c-.86 0-1.433 0-1.873-.037-.426-.035-.62-.096-.744-.16a1.8 1.8 0 0 1-.787-.786c-.063-.123-.124-.318-.16-.744-.035-.44-.036-1.013-.036-1.873V9.6Zm0-1.2h15.6v-.6c0-.86 0-1.433-.037-1.873-.035-.426-.096-.62-.16-.744a1.8 1.8 0 0 0-.786-.787c-.123-.063-.318-.124-.744-.16-.44-.035-1.013-.036-1.873-.036H7.8c-.86 0-1.433 0-1.873.037-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744C4.202 6.367 4.2 6.94 4.2 7.8v.6Z" clip-rule="evenodd"/>
</svg>`;
  const WindowFullscreen = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M8.273 2.88H8.5a.62.62 0 1 1 0 1.24h-.2c-.85 0-1.45 0-1.92.039-.462.038-.742.109-.96.22a2.38 2.38 0 0 0-1.04 1.04c-.112.22-.184.5-.221.961-.039.47-.04 1.07-.04 1.92v.2a.62.62 0 1 1-1.24 0v-.227c0-.817 0-1.468.044-1.994.044-.538.136-1 .351-1.422a3.62 3.62 0 0 1 1.582-1.582c.423-.216.884-.308 1.423-.352.526-.043 1.177-.043 1.994-.043Zm9.347 1.279c-.47-.039-1.07-.039-1.92-.039h-.2a.62.62 0 0 1 0-1.24h.227c.817 0 1.468 0 1.994.043.538.044 1 .136 1.422.352a3.62 3.62 0 0 1 1.582 1.582c.216.422.308.884.352 1.422.043.526.043 1.177.043 1.994V8.5a.62.62 0 0 1-1.24 0v-.2c0-.85 0-1.45-.039-1.92-.038-.462-.109-.742-.22-.96a2.38 2.38 0 0 0-1.04-1.04c-.22-.112-.5-.183-.961-.221ZM3.5 14.88a.62.62 0 0 1 .62.62v.2c0 .85 0 1.45.039 1.92.037.462.109.742.22.96a2.38 2.38 0 0 0 1.04 1.04c.22.112.5.183.961.221.47.038 1.07.039 1.92.039h.2a.62.62 0 0 1 0 1.24h-.227c-.817 0-1.468 0-1.994-.043-.539-.044-1-.136-1.423-.352a3.62 3.62 0 0 1-1.582-1.582c-.215-.422-.307-.884-.351-1.422-.043-.526-.043-1.177-.043-1.994V15.5a.62.62 0 0 1 .62-.62Zm17 0a.62.62 0 0 1 .62.62v.227c0 .817 0 1.468-.043 1.994-.044.538-.136 1-.352 1.422a3.619 3.619 0 0 1-1.582 1.582c-.422.216-.884.308-1.422.352-.526.043-1.177.043-1.994.043H15.5a.62.62 0 0 1 0-1.24h.2c.85 0 1.45 0 1.92-.039.462-.038.741-.109.96-.22a2.38 2.38 0 0 0 1.04-1.04c.112-.22.183-.5.221-.961.038-.47.039-1.07.039-1.92v-.2a.62.62 0 0 1 .62-.62Z"/>
</svg>`;
  const WindowPlus = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M12 11a.6.6 0 0 1 .6.6V14H15a.6.6 0 1 1 0 1.2h-2.4v2.4a.6.6 0 1 1-1.2 0v-2.4H9A.6.6 0 1 1 9 14h2.4v-2.4a.6.6 0 0 1 .6-.6Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M20.673 4.638C21 5.28 21 6.12 21 7.8v8.4c0 1.68 0 2.52-.327 3.162a3 3 0 0 1-1.311 1.311C18.72 21 17.88 21 16.2 21H7.8c-1.68 0-2.52 0-3.162-.327a3 3 0 0 1-1.311-1.311C3 18.72 3 17.88 3 16.2V7.8c0-1.68 0-2.52.327-3.162a3 3 0 0 1 1.311-1.311C5.28 3 6.12 3 7.8 3h8.4c1.68 0 2.52 0 3.162.327a3 3 0 0 1 1.311 1.311ZM4.2 9.6h15.6v6.6c0 .86 0 1.433-.037 1.873-.035.426-.096.62-.16.744a1.8 1.8 0 0 1-.786.787c-.123.063-.318.124-.744.16-.44.035-1.013.036-1.873.036H7.8c-.86 0-1.433 0-1.873-.037-.426-.035-.62-.096-.744-.16a1.8 1.8 0 0 1-.787-.786c-.063-.123-.124-.318-.16-.744-.035-.44-.036-1.013-.036-1.873V9.6Zm0-1.2h15.6v-.6c0-.86 0-1.433-.037-1.873-.035-.426-.096-.62-.16-.744a1.8 1.8 0 0 0-.786-.787c-.123-.063-.318-.124-.744-.16-.44-.035-1.013-.036-1.873-.036H7.8c-.86 0-1.433 0-1.873.037-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744C4.202 6.367 4.2 6.94 4.2 7.8v.6Z" clip-rule="evenodd"/>
</svg>`;
  const WindowSidebar = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M19.8 8.4v-.6c0-.86 0-1.433-.037-1.873-.035-.426-.096-.62-.16-.744a1.8 1.8 0 0 0-.786-.787c-.123-.063-.318-.124-.744-.16-.44-.035-1.013-.036-1.873-.036H7.8c-.86 0-1.433 0-1.873.037-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744C4.202 6.367 4.2 6.94 4.2 7.8v.6h15.6ZM4.2 9.6h4.2v10.2h-.6c-.86 0-1.433 0-1.873-.037-.426-.035-.62-.096-.744-.16a1.8 1.8 0 0 1-.787-.786c-.063-.123-.124-.318-.16-.744-.035-.44-.036-1.013-.036-1.873V9.6Zm5.4 10.2V9.6h10.2v6.6c0 .86 0 1.433-.037 1.873-.035.426-.096.62-.16.744a1.8 1.8 0 0 1-.786.787c-.123.063-.318.124-.744.16-.44.035-1.013.036-1.873.036H9.6ZM7.8 21c-1.68 0-2.52 0-3.162-.327a3 3 0 0 1-1.311-1.311C3 18.72 3 17.88 3 16.2V7.8c0-1.68 0-2.52.327-3.162a3 3 0 0 1 1.311-1.311C5.28 3 6.12 3 7.8 3h8.4c1.68 0 2.52 0 3.162.327a3 3 0 0 1 1.311 1.311C21 5.28 21 6.12 21 7.8v8.4c0 1.68 0 2.52-.327 3.162a3 3 0 0 1-1.311 1.311C18.72 21 17.88 21 16.2 21H7.8Z" clip-rule="evenodd"/>
</svg>`;
  const WindowSplit = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M19.8 8.4v-.6c0-.86 0-1.433-.037-1.873-.035-.426-.096-.62-.16-.744a1.8 1.8 0 0 0-.786-.787c-.123-.063-.318-.124-.744-.16-.44-.035-1.013-.036-1.873-.036H7.8c-.86 0-1.433 0-1.873.037-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744C4.202 6.367 4.2 6.94 4.2 7.8v.6h15.6ZM4.2 9.6h7.2v10.2H7.8c-.86 0-1.433 0-1.873-.037-.426-.035-.62-.096-.744-.16a1.8 1.8 0 0 1-.787-.786c-.063-.123-.124-.318-.16-.744-.035-.44-.036-1.013-.036-1.873V9.6Zm8.4 10.2V9.6h7.2v6.6c0 .86 0 1.433-.037 1.873-.035.426-.096.62-.16.744a1.8 1.8 0 0 1-.786.787c-.123.063-.318.124-.744.16-.44.035-1.013.036-1.873.036h-3.6ZM7.8 21c-1.68 0-2.52 0-3.162-.327a3 3 0 0 1-1.311-1.311C3 18.72 3 17.88 3 16.2V7.8c0-1.68 0-2.52.327-3.162a3 3 0 0 1 1.311-1.311C5.28 3 6.12 3 7.8 3h8.4c1.68 0 2.52 0 3.162.327a3 3 0 0 1 1.311 1.311C21 5.28 21 6.12 21 7.8v8.4c0 1.68 0 2.52-.327 3.162a3 3 0 0 1-1.311 1.311C18.72 21 17.88 21 16.2 21H7.8Z" clip-rule="evenodd"/>
</svg>`;
  const WindowStack = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M17.973 17.973c.603-.035 1.027-.116 1.39-.3a3 3 0 0 0 1.31-1.311C21 15.72 21 14.88 21 13.2V7.8c0-1.68 0-2.52-.327-3.162a3 3 0 0 0-1.31-1.311C18.72 3 17.88 3 16.2 3h-5.4c-1.68 0-2.52 0-3.162.327a3 3 0 0 0-1.31 1.311c-.185.362-.265.786-.3 1.39-.603.034-1.028.115-1.39.299a3 3 0 0 0-1.311 1.311C3 8.28 3 9.12 3 10.8v5.4c0 1.68 0 2.52.327 3.162a3 3 0 0 0 1.311 1.311C5.28 21 6.12 21 7.8 21h5.4c1.68 0 2.52 0 3.162-.327a3 3 0 0 0 1.311-1.311c.184-.362.265-.786.3-1.39ZM17.538 7.4a3 3 0 0 0-1.176-1.073C15.72 6 14.88 6 13.2 6H7.232l.005-.073c.035-.426.097-.62.16-.744a1.8 1.8 0 0 1 .786-.787c.124-.063.319-.124.745-.16.44-.035 1.012-.036 1.872-.036h5.4c.86 0 1.433 0 1.873.037.426.035.62.096.744.16a1.8 1.8 0 0 1 .787.786c.063.123.125.318.16.744.03.368.035.83.036 1.473h-2.262Zm.398 1.2C18 9.134 18 9.826 18 10.8v5.969l.073-.006c.426-.035.62-.096.744-.16a1.8 1.8 0 0 0 .787-.786c.063-.123.125-.318.16-.744.035-.44.036-1.013.036-1.873V8.6h-1.864ZM4.2 11.6h12.6v4.6c0 .86 0 1.433-.037 1.873-.035.426-.096.62-.16.744a1.8 1.8 0 0 1-.786.787c-.123.063-.318.124-.744.16-.44.035-1.013.036-1.873.036H7.8c-.86 0-1.433 0-1.873-.037-.426-.035-.62-.096-.744-.16a1.8 1.8 0 0 1-.787-.786c-.063-.123-.124-.318-.16-.744-.035-.44-.036-1.013-.036-1.873v-4.6Zm0-1.2h12.6a19.706 19.706 0 0 0-.037-1.473c-.035-.426-.096-.62-.16-.744a1.8 1.8 0 0 0-.786-.787c-.123-.063-.318-.124-.744-.16-.44-.035-1.013-.036-1.873-.036H7.8c-.86 0-1.433 0-1.873.037-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744-.03.368-.035.83-.036 1.473Z" clip-rule="evenodd"/>
</svg>`;
  const WindowX = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M14.546 12.054a.6.6 0 0 1 0 .849L12.849 14.6l1.697 1.697a.6.6 0 0 1-.849.848L12 15.448l-1.697 1.697a.6.6 0 1 1-.849-.848l1.697-1.697-1.697-1.697a.6.6 0 1 1 .849-.849L12 13.751l1.697-1.697a.6.6 0 0 1 .849 0Z"/>
  <path fill="currentColor" fill-rule="evenodd" d="M20.673 4.638C21 5.28 21 6.12 21 7.8v8.4c0 1.68 0 2.52-.327 3.162a3 3 0 0 1-1.311 1.311C18.72 21 17.88 21 16.2 21H7.8c-1.68 0-2.52 0-3.162-.327a3 3 0 0 1-1.311-1.311C3 18.72 3 17.88 3 16.2V7.8c0-1.68 0-2.52.327-3.162a3 3 0 0 1 1.311-1.311C5.28 3 6.12 3 7.8 3h8.4c1.68 0 2.52 0 3.162.327a3 3 0 0 1 1.311 1.311ZM4.2 9.6h15.6v6.6c0 .86 0 1.433-.037 1.873-.035.426-.096.62-.16.744a1.8 1.8 0 0 1-.786.787c-.123.063-.318.124-.744.16-.44.035-1.013.036-1.873.036H7.8c-.86 0-1.433 0-1.873-.037-.426-.035-.62-.096-.744-.16a1.8 1.8 0 0 1-.787-.786c-.063-.123-.124-.318-.16-.744-.035-.44-.036-1.013-.036-1.873V9.6Zm0-1.2h15.6v-.6c0-.86 0-1.433-.037-1.873-.035-.426-.096-.62-.16-.744a1.8 1.8 0 0 0-.786-.787c-.123-.063-.318-.124-.744-.16-.44-.035-1.013-.036-1.873-.036H7.8c-.86 0-1.433 0-1.873.037-.426.035-.62.096-.744.16a1.8 1.8 0 0 0-.787.786c-.063.123-.124.318-.16.744C4.202 6.367 4.2 6.94 4.2 7.8v.6Z" clip-rule="evenodd"/>
</svg>`;
  const Window = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M19.8 9.6H4.2v6.6c0 .86 0 1.433.037 1.873.035.426.096.62.16.744a1.8 1.8 0 0 0 .786.787c.123.063.318.124.744.16.44.035 1.013.036 1.873.036h8.4c.86 0 1.433 0 1.873-.037.426-.035.62-.096.744-.16a1.8 1.8 0 0 0 .787-.786c.063-.123.124-.318.16-.744.035-.44.036-1.013.036-1.873V9.6Zm0-1.2H4.2v-.6c0-.86 0-1.433.037-1.873.035-.426.096-.62.16-.744a1.8 1.8 0 0 1 .786-.787c.123-.063.318-.124.744-.16C6.367 4.202 6.94 4.2 7.8 4.2h8.4c.86 0 1.433 0 1.873.037.426.035.62.096.744.16a1.8 1.8 0 0 1 .787.786c.063.123.124.318.16.744.035.44.036 1.013.036 1.873v.6Zm1.2-.6c0-1.68 0-2.52-.327-3.162a3 3 0 0 0-1.311-1.311C18.72 3 17.88 3 16.2 3H7.8c-1.68 0-2.52 0-3.162.327a3 3 0 0 0-1.311 1.311C3 5.28 3 6.12 3 7.8v8.4c0 1.68 0 2.52.327 3.162a3 3 0 0 0 1.311 1.311C5.28 21 6.12 21 7.8 21h8.4c1.68 0 2.52 0 3.162-.327a3 3 0 0 0 1.311-1.311C21 18.72 21 17.88 21 16.2V7.8Z" clip-rule="evenodd"/>
</svg>`;
  const XCircleFill = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M15.424 8.576a.6.6 0 0 1 0 .848L12.85 12l2.575 2.576a.6.6 0 0 1-.848.848L12 12.85l-2.576 2.575a.6.6 0 1 1-.848-.848L11.15 12 8.576 9.424a.6.6 0 1 1 .848-.848L12 11.15l2.576-2.575a.6.6 0 0 1 .848 0ZM22 12c0 5.523-4.477 10-10 10S2 17.523 2 12 6.477 2 12 2s10 4.477 10 10Z" clip-rule="evenodd"/>
</svg>`;
  const XCircle = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M15.424 8.576a.6.6 0 0 1 0 .848L12.85 12l2.575 2.576a.6.6 0 0 1-.848.848L12 12.85l-2.576 2.575a.6.6 0 1 1-.848-.848L11.15 12 8.576 9.424a.6.6 0 1 1 .848-.848L12 11.15l2.576-2.575a.6.6 0 0 1 .848 0ZM12 20.8a8.8 8.8 0 1 0 0-17.6 8.8 8.8 0 0 0 0 17.6ZM22 12c0 5.523-4.477 10-10 10S2 17.523 2 12 6.477 2 12 2s10 4.477 10 10Z" clip-rule="evenodd"/>
</svg>`;
  const Youtube = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" d="M12.058 5.678h.1c.925.003 5.61.037 6.874.377a2.261 2.261 0 0 1 1.592 1.597c.114.428.194.994.248 1.578l.011.117.025.292.009.117c.073 1.028.082 1.992.083 2.202v.084a36.093 36.093 0 0 1-.092 2.318l-.01.118-.01.117c-.056.644-.139 1.283-.264 1.753a2.258 2.258 0 0 1-1.592 1.598c-1.305.35-6.265.375-6.953.376h-.16c-.347 0-1.785-.006-3.293-.058l-.19-.007-.099-.004-.384-.016c-1.25-.055-2.438-.144-2.986-.293a2.258 2.258 0 0 1-1.592-1.596c-.125-.47-.208-1.11-.265-1.753l-.018-.235A35.32 35.32 0 0 1 3 12.07v-.14c.002-.241.011-1.077.072-2l.008-.115.003-.059.01-.117.024-.292.011-.117c.054-.584.134-1.151.248-1.578a2.258 2.258 0 0 1 1.592-1.597c.548-.147 1.737-.237 2.986-.293l.19-.008.291-.01.193-.008c1.07-.034 2.142-.053 3.213-.057h.217v-.001ZM10.2 9.289v5.42l4.676-2.708L10.2 9.289Z"/>
</svg>`;
  const ZoomIn = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M11 3.6a7.4 7.4 0 1 0 5.159 12.706.607.607 0 0 1 .146-.147A7.4 7.4 0 0 0 11 3.6Zm6.49 13.042a8.6 8.6 0 1 0-.849.849l3.935 3.933a.6.6 0 0 0 .848-.848l-3.933-3.934ZM11 7.4a.6.6 0 0 1 .6.6v2.4H14a.6.6 0 1 1 0 1.2h-2.4V14a.6.6 0 1 1-1.2 0v-2.4H8a.6.6 0 1 1 0-1.2h2.4V8a.6.6 0 0 1 .6-.6Z" clip-rule="evenodd"/>
</svg>`;
  const ZoomOut = `
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="none" viewBox="0 0 24 24">
  <path fill="currentColor" fill-rule="evenodd" d="M11 3.6a7.4 7.4 0 1 0 5.159 12.706.607.607 0 0 1 .146-.147A7.4 7.4 0 0 0 11 3.6Zm6.49 13.042a8.6 8.6 0 1 0-.849.849l3.935 3.933a.6.6 0 0 0 .848-.848l-3.933-3.934ZM7.4 11a.6.6 0 0 1 .6-.6h6a.6.6 0 1 1 0 1.2H8a.6.6 0 0 1-.6-.6Z" clip-rule="evenodd"/>
</svg>`;

  var iconRegistry = /*#__PURE__*/Object.freeze({
    __proto__: null,
    Archive: Archive,
    ArrowBarDown: ArrowBarDown,
    ArrowBarLeft: ArrowBarLeft,
    ArrowBarRight: ArrowBarRight,
    ArrowBarUp: ArrowBarUp,
    ArrowCircleDown: ArrowCircleDown,
    ArrowCircleLeft: ArrowCircleLeft,
    ArrowCircleRight: ArrowCircleRight,
    ArrowCircleUp: ArrowCircleUp,
    ArrowClockwise: ArrowClockwise,
    ArrowDown: ArrowDown,
    ArrowLeft: ArrowLeft,
    ArrowRepeat: ArrowRepeat,
    ArrowRight: ArrowRight,
    ArrowSquareDown: ArrowSquareDown,
    ArrowSquareLeft: ArrowSquareLeft,
    ArrowSquareRight: ArrowSquareRight,
    ArrowSquareUp: ArrowSquareUp,
    ArrowUp: ArrowUp,
    BankFill: BankFill,
    BellSlash: BellSlash,
    Bell: Bell,
    BiFunnel: BiFunnel,
    BookmarkFill: BookmarkFill,
    Bookmark: Bookmark,
    BoxArrowUpRight: BoxArrowUpRight,
    BoxSeam: BoxSeam,
    Building: Building,
    Bus: Bus,
    Calculator: Calculator,
    CalendarCheck: CalendarCheck,
    CalendarX: CalendarX,
    Calendar: Calendar,
    Camera: Camera,
    Car: Car,
    ChatDots: ChatDots,
    ChatLeftText: ChatLeftText,
    Chat: Chat,
    CheckCircleFill: CheckCircleFill,
    CheckCircle: CheckCircle,
    Check: Check,
    ChevronDown: ChevronDown,
    ChevronLeft: ChevronLeft,
    ChevronRight: ChevronRight,
    ChevronSelectorVertical: ChevronSelectorVertical,
    ChevronUp: ChevronUp,
    Clock: Clock,
    CloudCheck: CloudCheck,
    CloudDownload: CloudDownload,
    CloudUpload: CloudUpload,
    Cloud: Cloud,
    Compass: Compass,
    Cross: Cross,
    CursorFill: CursorFill,
    Cursor: Cursor,
    DashCircle: DashCircle,
    DashSquare: DashSquare,
    Dash: Dash,
    Download: Download,
    Edit: Edit,
    ExclamationCircleFill: ExclamationCircleFill,
    ExclamationCircle: ExclamationCircle,
    ExclamationTriangleFill: ExclamationTriangleFill,
    ExclamationTriangle: ExclamationTriangle,
    Exclamation: Exclamation,
    EyeFill: EyeFill,
    EyeSlashFill: EyeSlashFill,
    EyeSlash: EyeSlash,
    Eye: Eye,
    Facebook: Facebook,
    FileEarmarkText: FileEarmarkText,
    FilePdf: FilePdf,
    FilePlus: FilePlus,
    FileText: FileText,
    File: File,
    Files: Files,
    FolderCheck: FolderCheck,
    FolderMinus: FolderMinus,
    FolderPlus: FolderPlus,
    Folder: Folder,
    Gear: Gear,
    GeoAlt: GeoAlt,
    GeoFill: GeoFill,
    Geo: Geo,
    GlobeAlt: GlobeAlt,
    Globe: Globe,
    Google: Google,
    GridFill: GridFill,
    HandThumbsDown: HandThumbsDown,
    HandThumbsUp: HandThumbsUp,
    HardDrive: HardDrive,
    Heart: Heart,
    HouseDoor: HouseDoor,
    House: House,
    Image: Image,
    InBox: InBox,
    InfoCircleFill: InfoCircleFill,
    InfoCircle: InfoCircle,
    Instagram: Instagram,
    Laptop: Laptop,
    Layers: Layers,
    LayoutTextWindowReverse: LayoutTextWindowReverse,
    LayoutTextWindow: LayoutTextWindow,
    Layout: Layout,
    Lightbulb: Lightbulb,
    Link: Link,
    Linkedin: Linkedin,
    List: List,
    LockFill: LockFill,
    Lock: Lock,
    Login: Login,
    Logout: Logout,
    Luggage: Luggage,
    Mail: Mail,
    Map: Map$1,
    Menu: Menu,
    Microphone: Microphone,
    Monitor: Monitor,
    Paperclip: Paperclip,
    Passport: Passport,
    Pencil: Pencil,
    PendingCircle: PendingCircle,
    PersonDash: PersonDash,
    PersonPlus: PersonPlus,
    PersonX: PersonX,
    Person: Person,
    Phone: Phone,
    PinMapFill: PinMapFill,
    Pin: Pin,
    Placeholder: Placeholder,
    Plane: Plane,
    PlusCircle: PlusCircle,
    PlusSquare: PlusSquare,
    Plus: Plus,
    Printer: Printer,
    QuestionCircle: QuestionCircle,
    Rocket: Rocket,
    Save: Save,
    Search: Search,
    Send: Send,
    SgCrest: SgCrest,
    Share: Share,
    SlashCircle: SlashCircle,
    Sliders: Sliders,
    Speedometer: Speedometer,
    StarFill: StarFill,
    Star: Star,
    Stoplights: Stoplights,
    SwitchHorizontal: SwitchHorizontal,
    SwitchVertical: SwitchVertical,
    Tablet: Tablet,
    Telephone: Telephone,
    ThreeDotsVertical: ThreeDotsVertical,
    ThreeDots: ThreeDots,
    Ticket: Ticket,
    ToggleOff: ToggleOff,
    ToggleOn: ToggleOn,
    Train: Train,
    Translate: Translate,
    Trash: Trash,
    Truck: Truck,
    TwitterX: TwitterX,
    Unlock: Unlock,
    Upload: Upload,
    UserCircle: UserCircle,
    UserSquare: UserSquare,
    Users: Users,
    VideoRecorder: VideoRecorder,
    VolumeMax: VolumeMax,
    VolumeX: VolumeX,
    WindowDash: WindowDash,
    WindowDesktop: WindowDesktop,
    WindowDock: WindowDock,
    WindowFullscreen: WindowFullscreen,
    WindowPlus: WindowPlus,
    WindowSidebar: WindowSidebar,
    WindowSplit: WindowSplit,
    WindowStack: WindowStack,
    WindowX: WindowX,
    Window: Window,
    XCircleFill: XCircleFill,
    XCircle: XCircle,
    Youtube: Youtube,
    ZoomIn: ZoomIn,
    ZoomOut: ZoomOut
  });

}));
//# sourceMappingURL=index.umd.js.map
