(function (factory) {
  typeof define === 'function' && define.amd ? define(factory) :
  factory();
})((function () { 'use strict';

  /******************************************************************************
  Copyright (c) Microsoft Corporation.

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
  REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
  AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
  INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
  LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
  OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
  PERFORMANCE OF THIS SOFTWARE.
  ***************************************************************************** */

  function __decorate(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
  }

  typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
    var e = new Error(message);
    return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
  };

  var top = 'top';
  var bottom = 'bottom';
  var right = 'right';
  var left = 'left';
  var auto = 'auto';
  var basePlacements = [top, bottom, right, left];
  var start = 'start';
  var end = 'end';
  var clippingParents = 'clippingParents';
  var viewport = 'viewport';
  var popper = 'popper';
  var reference = 'reference';
  var variationPlacements = /*#__PURE__*/basePlacements.reduce(function (acc, placement) {
    return acc.concat([placement + "-" + start, placement + "-" + end]);
  }, []);
  var placements = /*#__PURE__*/[].concat(basePlacements, [auto]).reduce(function (acc, placement) {
    return acc.concat([placement, placement + "-" + start, placement + "-" + end]);
  }, []); // modifiers that need to read the DOM

  var beforeRead = 'beforeRead';
  var read = 'read';
  var afterRead = 'afterRead'; // pure-logic modifiers

  var beforeMain = 'beforeMain';
  var main = 'main';
  var afterMain = 'afterMain'; // modifier with the purpose to write to the DOM (or write into a framework state)

  var beforeWrite = 'beforeWrite';
  var write = 'write';
  var afterWrite = 'afterWrite';
  var modifierPhases = [beforeRead, read, afterRead, beforeMain, main, afterMain, beforeWrite, write, afterWrite];

  function getNodeName(element) {
    return element ? (element.nodeName || '').toLowerCase() : null;
  }

  function getWindow(node) {
    if (node == null) {
      return window;
    }

    if (node.toString() !== '[object Window]') {
      var ownerDocument = node.ownerDocument;
      return ownerDocument ? ownerDocument.defaultView || window : window;
    }

    return node;
  }

  function isElement$1(node) {
    var OwnElement = getWindow(node).Element;
    return node instanceof OwnElement || node instanceof Element;
  }

  function isHTMLElement(node) {
    var OwnElement = getWindow(node).HTMLElement;
    return node instanceof OwnElement || node instanceof HTMLElement;
  }

  function isShadowRoot(node) {
    // IE 11 has no ShadowRoot
    if (typeof ShadowRoot === 'undefined') {
      return false;
    }

    var OwnElement = getWindow(node).ShadowRoot;
    return node instanceof OwnElement || node instanceof ShadowRoot;
  }

  // and applies them to the HTMLElements such as popper and arrow

  function applyStyles(_ref) {
    var state = _ref.state;
    Object.keys(state.elements).forEach(function (name) {
      var style = state.styles[name] || {};
      var attributes = state.attributes[name] || {};
      var element = state.elements[name]; // arrow is optional + virtual elements

      if (!isHTMLElement(element) || !getNodeName(element)) {
        return;
      } // Flow doesn't support to extend this property, but it's the most
      // effective way to apply styles to an HTMLElement
      // $FlowFixMe[cannot-write]


      Object.assign(element.style, style);
      Object.keys(attributes).forEach(function (name) {
        var value = attributes[name];

        if (value === false) {
          element.removeAttribute(name);
        } else {
          element.setAttribute(name, value === true ? '' : value);
        }
      });
    });
  }

  function effect$2(_ref2) {
    var state = _ref2.state;
    var initialStyles = {
      popper: {
        position: state.options.strategy,
        left: '0',
        top: '0',
        margin: '0'
      },
      arrow: {
        position: 'absolute'
      },
      reference: {}
    };
    Object.assign(state.elements.popper.style, initialStyles.popper);
    state.styles = initialStyles;

    if (state.elements.arrow) {
      Object.assign(state.elements.arrow.style, initialStyles.arrow);
    }

    return function () {
      Object.keys(state.elements).forEach(function (name) {
        var element = state.elements[name];
        var attributes = state.attributes[name] || {};
        var styleProperties = Object.keys(state.styles.hasOwnProperty(name) ? state.styles[name] : initialStyles[name]); // Set all values to an empty string to unset them

        var style = styleProperties.reduce(function (style, property) {
          style[property] = '';
          return style;
        }, {}); // arrow is optional + virtual elements

        if (!isHTMLElement(element) || !getNodeName(element)) {
          return;
        }

        Object.assign(element.style, style);
        Object.keys(attributes).forEach(function (attribute) {
          element.removeAttribute(attribute);
        });
      });
    };
  } // eslint-disable-next-line import/no-unused-modules


  var applyStyles$1 = {
    name: 'applyStyles',
    enabled: true,
    phase: 'write',
    fn: applyStyles,
    effect: effect$2,
    requires: ['computeStyles']
  };

  function getBasePlacement(placement) {
    return placement.split('-')[0];
  }

  var max = Math.max;
  var min = Math.min;
  var round = Math.round;

  function getUAString() {
    var uaData = navigator.userAgentData;

    if (uaData != null && uaData.brands && Array.isArray(uaData.brands)) {
      return uaData.brands.map(function (item) {
        return item.brand + "/" + item.version;
      }).join(' ');
    }

    return navigator.userAgent;
  }

  function isLayoutViewport() {
    return !/^((?!chrome|android).)*safari/i.test(getUAString());
  }

  function getBoundingClientRect(element, includeScale, isFixedStrategy) {
    if (includeScale === void 0) {
      includeScale = false;
    }

    if (isFixedStrategy === void 0) {
      isFixedStrategy = false;
    }

    var clientRect = element.getBoundingClientRect();
    var scaleX = 1;
    var scaleY = 1;

    if (includeScale && isHTMLElement(element)) {
      scaleX = element.offsetWidth > 0 ? round(clientRect.width) / element.offsetWidth || 1 : 1;
      scaleY = element.offsetHeight > 0 ? round(clientRect.height) / element.offsetHeight || 1 : 1;
    }

    var _ref = isElement$1(element) ? getWindow(element) : window,
        visualViewport = _ref.visualViewport;

    var addVisualOffsets = !isLayoutViewport() && isFixedStrategy;
    var x = (clientRect.left + (addVisualOffsets && visualViewport ? visualViewport.offsetLeft : 0)) / scaleX;
    var y = (clientRect.top + (addVisualOffsets && visualViewport ? visualViewport.offsetTop : 0)) / scaleY;
    var width = clientRect.width / scaleX;
    var height = clientRect.height / scaleY;
    return {
      width: width,
      height: height,
      top: y,
      right: x + width,
      bottom: y + height,
      left: x,
      x: x,
      y: y
    };
  }

  // means it doesn't take into account transforms.

  function getLayoutRect(element) {
    var clientRect = getBoundingClientRect(element); // Use the clientRect sizes if it's not been transformed.
    // Fixes https://github.com/popperjs/popper-core/issues/1223

    var width = element.offsetWidth;
    var height = element.offsetHeight;

    if (Math.abs(clientRect.width - width) <= 1) {
      width = clientRect.width;
    }

    if (Math.abs(clientRect.height - height) <= 1) {
      height = clientRect.height;
    }

    return {
      x: element.offsetLeft,
      y: element.offsetTop,
      width: width,
      height: height
    };
  }

  function contains(parent, child) {
    var rootNode = child.getRootNode && child.getRootNode(); // First, attempt with faster native method

    if (parent.contains(child)) {
      return true;
    } // then fallback to custom implementation with Shadow DOM support
    else if (rootNode && isShadowRoot(rootNode)) {
        var next = child;

        do {
          if (next && parent.isSameNode(next)) {
            return true;
          } // $FlowFixMe[prop-missing]: need a better way to handle this...


          next = next.parentNode || next.host;
        } while (next);
      } // Give up, the result is false


    return false;
  }

  function getComputedStyle$1(element) {
    return getWindow(element).getComputedStyle(element);
  }

  function isTableElement(element) {
    return ['table', 'td', 'th'].indexOf(getNodeName(element)) >= 0;
  }

  function getDocumentElement(element) {
    // $FlowFixMe[incompatible-return]: assume body is always available
    return ((isElement$1(element) ? element.ownerDocument : // $FlowFixMe[prop-missing]
    element.document) || window.document).documentElement;
  }

  function getParentNode(element) {
    if (getNodeName(element) === 'html') {
      return element;
    }

    return (// this is a quicker (but less type safe) way to save quite some bytes from the bundle
      // $FlowFixMe[incompatible-return]
      // $FlowFixMe[prop-missing]
      element.assignedSlot || // step into the shadow DOM of the parent of a slotted node
      element.parentNode || ( // DOM Element detected
      isShadowRoot(element) ? element.host : null) || // ShadowRoot detected
      // $FlowFixMe[incompatible-call]: HTMLElement is a Node
      getDocumentElement(element) // fallback

    );
  }

  function getTrueOffsetParent(element) {
    if (!isHTMLElement(element) || // https://github.com/popperjs/popper-core/issues/837
    getComputedStyle$1(element).position === 'fixed') {
      return null;
    }

    return element.offsetParent;
  } // `.offsetParent` reports `null` for fixed elements, while absolute elements
  // return the containing block


  function getContainingBlock(element) {
    var isFirefox = /firefox/i.test(getUAString());
    var isIE = /Trident/i.test(getUAString());

    if (isIE && isHTMLElement(element)) {
      // In IE 9, 10 and 11 fixed elements containing block is always established by the viewport
      var elementCss = getComputedStyle$1(element);

      if (elementCss.position === 'fixed') {
        return null;
      }
    }

    var currentNode = getParentNode(element);

    if (isShadowRoot(currentNode)) {
      currentNode = currentNode.host;
    }

    while (isHTMLElement(currentNode) && ['html', 'body'].indexOf(getNodeName(currentNode)) < 0) {
      var css = getComputedStyle$1(currentNode); // This is non-exhaustive but covers the most common CSS properties that
      // create a containing block.
      // https://developer.mozilla.org/en-US/docs/Web/CSS/Containing_block#identifying_the_containing_block

      if (css.transform !== 'none' || css.perspective !== 'none' || css.contain === 'paint' || ['transform', 'perspective'].indexOf(css.willChange) !== -1 || isFirefox && css.willChange === 'filter' || isFirefox && css.filter && css.filter !== 'none') {
        return currentNode;
      } else {
        currentNode = currentNode.parentNode;
      }
    }

    return null;
  } // Gets the closest ancestor positioned element. Handles some edge cases,
  // such as table ancestors and cross browser bugs.


  function getOffsetParent(element) {
    var window = getWindow(element);
    var offsetParent = getTrueOffsetParent(element);

    while (offsetParent && isTableElement(offsetParent) && getComputedStyle$1(offsetParent).position === 'static') {
      offsetParent = getTrueOffsetParent(offsetParent);
    }

    if (offsetParent && (getNodeName(offsetParent) === 'html' || getNodeName(offsetParent) === 'body' && getComputedStyle$1(offsetParent).position === 'static')) {
      return window;
    }

    return offsetParent || getContainingBlock(element) || window;
  }

  function getMainAxisFromPlacement(placement) {
    return ['top', 'bottom'].indexOf(placement) >= 0 ? 'x' : 'y';
  }

  function within(min$1, value, max$1) {
    return max(min$1, min(value, max$1));
  }
  function withinMaxClamp(min, value, max) {
    var v = within(min, value, max);
    return v > max ? max : v;
  }

  function getFreshSideObject() {
    return {
      top: 0,
      right: 0,
      bottom: 0,
      left: 0
    };
  }

  function mergePaddingObject(paddingObject) {
    return Object.assign({}, getFreshSideObject(), paddingObject);
  }

  function expandToHashMap(value, keys) {
    return keys.reduce(function (hashMap, key) {
      hashMap[key] = value;
      return hashMap;
    }, {});
  }

  var toPaddingObject = function toPaddingObject(padding, state) {
    padding = typeof padding === 'function' ? padding(Object.assign({}, state.rects, {
      placement: state.placement
    })) : padding;
    return mergePaddingObject(typeof padding !== 'number' ? padding : expandToHashMap(padding, basePlacements));
  };

  function arrow(_ref) {
    var _state$modifiersData$;

    var state = _ref.state,
        name = _ref.name,
        options = _ref.options;
    var arrowElement = state.elements.arrow;
    var popperOffsets = state.modifiersData.popperOffsets;
    var basePlacement = getBasePlacement(state.placement);
    var axis = getMainAxisFromPlacement(basePlacement);
    var isVertical = [left, right].indexOf(basePlacement) >= 0;
    var len = isVertical ? 'height' : 'width';

    if (!arrowElement || !popperOffsets) {
      return;
    }

    var paddingObject = toPaddingObject(options.padding, state);
    var arrowRect = getLayoutRect(arrowElement);
    var minProp = axis === 'y' ? top : left;
    var maxProp = axis === 'y' ? bottom : right;
    var endDiff = state.rects.reference[len] + state.rects.reference[axis] - popperOffsets[axis] - state.rects.popper[len];
    var startDiff = popperOffsets[axis] - state.rects.reference[axis];
    var arrowOffsetParent = getOffsetParent(arrowElement);
    var clientSize = arrowOffsetParent ? axis === 'y' ? arrowOffsetParent.clientHeight || 0 : arrowOffsetParent.clientWidth || 0 : 0;
    var centerToReference = endDiff / 2 - startDiff / 2; // Make sure the arrow doesn't overflow the popper if the center point is
    // outside of the popper bounds

    var min = paddingObject[minProp];
    var max = clientSize - arrowRect[len] - paddingObject[maxProp];
    var center = clientSize / 2 - arrowRect[len] / 2 + centerToReference;
    var offset = within(min, center, max); // Prevents breaking syntax highlighting...

    var axisProp = axis;
    state.modifiersData[name] = (_state$modifiersData$ = {}, _state$modifiersData$[axisProp] = offset, _state$modifiersData$.centerOffset = offset - center, _state$modifiersData$);
  }

  function effect$1(_ref2) {
    var state = _ref2.state,
        options = _ref2.options;
    var _options$element = options.element,
        arrowElement = _options$element === void 0 ? '[data-popper-arrow]' : _options$element;

    if (arrowElement == null) {
      return;
    } // CSS selector


    if (typeof arrowElement === 'string') {
      arrowElement = state.elements.popper.querySelector(arrowElement);

      if (!arrowElement) {
        return;
      }
    }

    if (!contains(state.elements.popper, arrowElement)) {
      return;
    }

    state.elements.arrow = arrowElement;
  } // eslint-disable-next-line import/no-unused-modules


  var arrow$1 = {
    name: 'arrow',
    enabled: true,
    phase: 'main',
    fn: arrow,
    effect: effect$1,
    requires: ['popperOffsets'],
    requiresIfExists: ['preventOverflow']
  };

  function getVariation(placement) {
    return placement.split('-')[1];
  }

  var unsetSides = {
    top: 'auto',
    right: 'auto',
    bottom: 'auto',
    left: 'auto'
  }; // Round the offsets to the nearest suitable subpixel based on the DPR.
  // Zooming can change the DPR, but it seems to report a value that will
  // cleanly divide the values into the appropriate subpixels.

  function roundOffsetsByDPR(_ref, win) {
    var x = _ref.x,
        y = _ref.y;
    var dpr = win.devicePixelRatio || 1;
    return {
      x: round(x * dpr) / dpr || 0,
      y: round(y * dpr) / dpr || 0
    };
  }

  function mapToStyles(_ref2) {
    var _Object$assign2;

    var popper = _ref2.popper,
        popperRect = _ref2.popperRect,
        placement = _ref2.placement,
        variation = _ref2.variation,
        offsets = _ref2.offsets,
        position = _ref2.position,
        gpuAcceleration = _ref2.gpuAcceleration,
        adaptive = _ref2.adaptive,
        roundOffsets = _ref2.roundOffsets,
        isFixed = _ref2.isFixed;
    var _offsets$x = offsets.x,
        x = _offsets$x === void 0 ? 0 : _offsets$x,
        _offsets$y = offsets.y,
        y = _offsets$y === void 0 ? 0 : _offsets$y;

    var _ref3 = typeof roundOffsets === 'function' ? roundOffsets({
      x: x,
      y: y
    }) : {
      x: x,
      y: y
    };

    x = _ref3.x;
    y = _ref3.y;
    var hasX = offsets.hasOwnProperty('x');
    var hasY = offsets.hasOwnProperty('y');
    var sideX = left;
    var sideY = top;
    var win = window;

    if (adaptive) {
      var offsetParent = getOffsetParent(popper);
      var heightProp = 'clientHeight';
      var widthProp = 'clientWidth';

      if (offsetParent === getWindow(popper)) {
        offsetParent = getDocumentElement(popper);

        if (getComputedStyle$1(offsetParent).position !== 'static' && position === 'absolute') {
          heightProp = 'scrollHeight';
          widthProp = 'scrollWidth';
        }
      } // $FlowFixMe[incompatible-cast]: force type refinement, we compare offsetParent with window above, but Flow doesn't detect it


      offsetParent = offsetParent;

      if (placement === top || (placement === left || placement === right) && variation === end) {
        sideY = bottom;
        var offsetY = isFixed && offsetParent === win && win.visualViewport ? win.visualViewport.height : // $FlowFixMe[prop-missing]
        offsetParent[heightProp];
        y -= offsetY - popperRect.height;
        y *= gpuAcceleration ? 1 : -1;
      }

      if (placement === left || (placement === top || placement === bottom) && variation === end) {
        sideX = right;
        var offsetX = isFixed && offsetParent === win && win.visualViewport ? win.visualViewport.width : // $FlowFixMe[prop-missing]
        offsetParent[widthProp];
        x -= offsetX - popperRect.width;
        x *= gpuAcceleration ? 1 : -1;
      }
    }

    var commonStyles = Object.assign({
      position: position
    }, adaptive && unsetSides);

    var _ref4 = roundOffsets === true ? roundOffsetsByDPR({
      x: x,
      y: y
    }, getWindow(popper)) : {
      x: x,
      y: y
    };

    x = _ref4.x;
    y = _ref4.y;

    if (gpuAcceleration) {
      var _Object$assign;

      return Object.assign({}, commonStyles, (_Object$assign = {}, _Object$assign[sideY] = hasY ? '0' : '', _Object$assign[sideX] = hasX ? '0' : '', _Object$assign.transform = (win.devicePixelRatio || 1) <= 1 ? "translate(" + x + "px, " + y + "px)" : "translate3d(" + x + "px, " + y + "px, 0)", _Object$assign));
    }

    return Object.assign({}, commonStyles, (_Object$assign2 = {}, _Object$assign2[sideY] = hasY ? y + "px" : '', _Object$assign2[sideX] = hasX ? x + "px" : '', _Object$assign2.transform = '', _Object$assign2));
  }

  function computeStyles(_ref5) {
    var state = _ref5.state,
        options = _ref5.options;
    var _options$gpuAccelerat = options.gpuAcceleration,
        gpuAcceleration = _options$gpuAccelerat === void 0 ? true : _options$gpuAccelerat,
        _options$adaptive = options.adaptive,
        adaptive = _options$adaptive === void 0 ? true : _options$adaptive,
        _options$roundOffsets = options.roundOffsets,
        roundOffsets = _options$roundOffsets === void 0 ? true : _options$roundOffsets;
    var commonStyles = {
      placement: getBasePlacement(state.placement),
      variation: getVariation(state.placement),
      popper: state.elements.popper,
      popperRect: state.rects.popper,
      gpuAcceleration: gpuAcceleration,
      isFixed: state.options.strategy === 'fixed'
    };

    if (state.modifiersData.popperOffsets != null) {
      state.styles.popper = Object.assign({}, state.styles.popper, mapToStyles(Object.assign({}, commonStyles, {
        offsets: state.modifiersData.popperOffsets,
        position: state.options.strategy,
        adaptive: adaptive,
        roundOffsets: roundOffsets
      })));
    }

    if (state.modifiersData.arrow != null) {
      state.styles.arrow = Object.assign({}, state.styles.arrow, mapToStyles(Object.assign({}, commonStyles, {
        offsets: state.modifiersData.arrow,
        position: 'absolute',
        adaptive: false,
        roundOffsets: roundOffsets
      })));
    }

    state.attributes.popper = Object.assign({}, state.attributes.popper, {
      'data-popper-placement': state.placement
    });
  } // eslint-disable-next-line import/no-unused-modules


  var computeStyles$1 = {
    name: 'computeStyles',
    enabled: true,
    phase: 'beforeWrite',
    fn: computeStyles,
    data: {}
  };

  var passive = {
    passive: true
  };

  function effect(_ref) {
    var state = _ref.state,
        instance = _ref.instance,
        options = _ref.options;
    var _options$scroll = options.scroll,
        scroll = _options$scroll === void 0 ? true : _options$scroll,
        _options$resize = options.resize,
        resize = _options$resize === void 0 ? true : _options$resize;
    var window = getWindow(state.elements.popper);
    var scrollParents = [].concat(state.scrollParents.reference, state.scrollParents.popper);

    if (scroll) {
      scrollParents.forEach(function (scrollParent) {
        scrollParent.addEventListener('scroll', instance.update, passive);
      });
    }

    if (resize) {
      window.addEventListener('resize', instance.update, passive);
    }

    return function () {
      if (scroll) {
        scrollParents.forEach(function (scrollParent) {
          scrollParent.removeEventListener('scroll', instance.update, passive);
        });
      }

      if (resize) {
        window.removeEventListener('resize', instance.update, passive);
      }
    };
  } // eslint-disable-next-line import/no-unused-modules


  var eventListeners = {
    name: 'eventListeners',
    enabled: true,
    phase: 'write',
    fn: function fn() {},
    effect: effect,
    data: {}
  };

  var hash$1 = {
    left: 'right',
    right: 'left',
    bottom: 'top',
    top: 'bottom'
  };
  function getOppositePlacement(placement) {
    return placement.replace(/left|right|bottom|top/g, function (matched) {
      return hash$1[matched];
    });
  }

  var hash = {
    start: 'end',
    end: 'start'
  };
  function getOppositeVariationPlacement(placement) {
    return placement.replace(/start|end/g, function (matched) {
      return hash[matched];
    });
  }

  function getWindowScroll(node) {
    var win = getWindow(node);
    var scrollLeft = win.pageXOffset;
    var scrollTop = win.pageYOffset;
    return {
      scrollLeft: scrollLeft,
      scrollTop: scrollTop
    };
  }

  function getWindowScrollBarX(element) {
    // If <html> has a CSS width greater than the viewport, then this will be
    // incorrect for RTL.
    // Popper 1 is broken in this case and never had a bug report so let's assume
    // it's not an issue. I don't think anyone ever specifies width on <html>
    // anyway.
    // Browsers where the left scrollbar doesn't cause an issue report `0` for
    // this (e.g. Edge 2019, IE11, Safari)
    return getBoundingClientRect(getDocumentElement(element)).left + getWindowScroll(element).scrollLeft;
  }

  function getViewportRect(element, strategy) {
    var win = getWindow(element);
    var html = getDocumentElement(element);
    var visualViewport = win.visualViewport;
    var width = html.clientWidth;
    var height = html.clientHeight;
    var x = 0;
    var y = 0;

    if (visualViewport) {
      width = visualViewport.width;
      height = visualViewport.height;
      var layoutViewport = isLayoutViewport();

      if (layoutViewport || !layoutViewport && strategy === 'fixed') {
        x = visualViewport.offsetLeft;
        y = visualViewport.offsetTop;
      }
    }

    return {
      width: width,
      height: height,
      x: x + getWindowScrollBarX(element),
      y: y
    };
  }

  // of the `<html>` and `<body>` rect bounds if horizontally scrollable

  function getDocumentRect(element) {
    var _element$ownerDocumen;

    var html = getDocumentElement(element);
    var winScroll = getWindowScroll(element);
    var body = (_element$ownerDocumen = element.ownerDocument) == null ? void 0 : _element$ownerDocumen.body;
    var width = max(html.scrollWidth, html.clientWidth, body ? body.scrollWidth : 0, body ? body.clientWidth : 0);
    var height = max(html.scrollHeight, html.clientHeight, body ? body.scrollHeight : 0, body ? body.clientHeight : 0);
    var x = -winScroll.scrollLeft + getWindowScrollBarX(element);
    var y = -winScroll.scrollTop;

    if (getComputedStyle$1(body || html).direction === 'rtl') {
      x += max(html.clientWidth, body ? body.clientWidth : 0) - width;
    }

    return {
      width: width,
      height: height,
      x: x,
      y: y
    };
  }

  function isScrollParent(element) {
    // Firefox wants us to check `-x` and `-y` variations as well
    var _getComputedStyle = getComputedStyle$1(element),
        overflow = _getComputedStyle.overflow,
        overflowX = _getComputedStyle.overflowX,
        overflowY = _getComputedStyle.overflowY;

    return /auto|scroll|overlay|hidden/.test(overflow + overflowY + overflowX);
  }

  function getScrollParent(node) {
    if (['html', 'body', '#document'].indexOf(getNodeName(node)) >= 0) {
      // $FlowFixMe[incompatible-return]: assume body is always available
      return node.ownerDocument.body;
    }

    if (isHTMLElement(node) && isScrollParent(node)) {
      return node;
    }

    return getScrollParent(getParentNode(node));
  }

  /*
  given a DOM element, return the list of all scroll parents, up the list of ancesors
  until we get to the top window object. This list is what we attach scroll listeners
  to, because if any of these parent elements scroll, we'll need to re-calculate the
  reference element's position.
  */

  function listScrollParents(element, list) {
    var _element$ownerDocumen;

    if (list === void 0) {
      list = [];
    }

    var scrollParent = getScrollParent(element);
    var isBody = scrollParent === ((_element$ownerDocumen = element.ownerDocument) == null ? void 0 : _element$ownerDocumen.body);
    var win = getWindow(scrollParent);
    var target = isBody ? [win].concat(win.visualViewport || [], isScrollParent(scrollParent) ? scrollParent : []) : scrollParent;
    var updatedList = list.concat(target);
    return isBody ? updatedList : // $FlowFixMe[incompatible-call]: isBody tells us target will be an HTMLElement here
    updatedList.concat(listScrollParents(getParentNode(target)));
  }

  function rectToClientRect(rect) {
    return Object.assign({}, rect, {
      left: rect.x,
      top: rect.y,
      right: rect.x + rect.width,
      bottom: rect.y + rect.height
    });
  }

  function getInnerBoundingClientRect(element, strategy) {
    var rect = getBoundingClientRect(element, false, strategy === 'fixed');
    rect.top = rect.top + element.clientTop;
    rect.left = rect.left + element.clientLeft;
    rect.bottom = rect.top + element.clientHeight;
    rect.right = rect.left + element.clientWidth;
    rect.width = element.clientWidth;
    rect.height = element.clientHeight;
    rect.x = rect.left;
    rect.y = rect.top;
    return rect;
  }

  function getClientRectFromMixedType(element, clippingParent, strategy) {
    return clippingParent === viewport ? rectToClientRect(getViewportRect(element, strategy)) : isElement$1(clippingParent) ? getInnerBoundingClientRect(clippingParent, strategy) : rectToClientRect(getDocumentRect(getDocumentElement(element)));
  } // A "clipping parent" is an overflowable container with the characteristic of
  // clipping (or hiding) overflowing elements with a position different from
  // `initial`


  function getClippingParents(element) {
    var clippingParents = listScrollParents(getParentNode(element));
    var canEscapeClipping = ['absolute', 'fixed'].indexOf(getComputedStyle$1(element).position) >= 0;
    var clipperElement = canEscapeClipping && isHTMLElement(element) ? getOffsetParent(element) : element;

    if (!isElement$1(clipperElement)) {
      return [];
    } // $FlowFixMe[incompatible-return]: https://github.com/facebook/flow/issues/1414


    return clippingParents.filter(function (clippingParent) {
      return isElement$1(clippingParent) && contains(clippingParent, clipperElement) && getNodeName(clippingParent) !== 'body';
    });
  } // Gets the maximum area that the element is visible in due to any number of
  // clipping parents


  function getClippingRect(element, boundary, rootBoundary, strategy) {
    var mainClippingParents = boundary === 'clippingParents' ? getClippingParents(element) : [].concat(boundary);
    var clippingParents = [].concat(mainClippingParents, [rootBoundary]);
    var firstClippingParent = clippingParents[0];
    var clippingRect = clippingParents.reduce(function (accRect, clippingParent) {
      var rect = getClientRectFromMixedType(element, clippingParent, strategy);
      accRect.top = max(rect.top, accRect.top);
      accRect.right = min(rect.right, accRect.right);
      accRect.bottom = min(rect.bottom, accRect.bottom);
      accRect.left = max(rect.left, accRect.left);
      return accRect;
    }, getClientRectFromMixedType(element, firstClippingParent, strategy));
    clippingRect.width = clippingRect.right - clippingRect.left;
    clippingRect.height = clippingRect.bottom - clippingRect.top;
    clippingRect.x = clippingRect.left;
    clippingRect.y = clippingRect.top;
    return clippingRect;
  }

  function computeOffsets(_ref) {
    var reference = _ref.reference,
        element = _ref.element,
        placement = _ref.placement;
    var basePlacement = placement ? getBasePlacement(placement) : null;
    var variation = placement ? getVariation(placement) : null;
    var commonX = reference.x + reference.width / 2 - element.width / 2;
    var commonY = reference.y + reference.height / 2 - element.height / 2;
    var offsets;

    switch (basePlacement) {
      case top:
        offsets = {
          x: commonX,
          y: reference.y - element.height
        };
        break;

      case bottom:
        offsets = {
          x: commonX,
          y: reference.y + reference.height
        };
        break;

      case right:
        offsets = {
          x: reference.x + reference.width,
          y: commonY
        };
        break;

      case left:
        offsets = {
          x: reference.x - element.width,
          y: commonY
        };
        break;

      default:
        offsets = {
          x: reference.x,
          y: reference.y
        };
    }

    var mainAxis = basePlacement ? getMainAxisFromPlacement(basePlacement) : null;

    if (mainAxis != null) {
      var len = mainAxis === 'y' ? 'height' : 'width';

      switch (variation) {
        case start:
          offsets[mainAxis] = offsets[mainAxis] - (reference[len] / 2 - element[len] / 2);
          break;

        case end:
          offsets[mainAxis] = offsets[mainAxis] + (reference[len] / 2 - element[len] / 2);
          break;
      }
    }

    return offsets;
  }

  function detectOverflow(state, options) {
    if (options === void 0) {
      options = {};
    }

    var _options = options,
        _options$placement = _options.placement,
        placement = _options$placement === void 0 ? state.placement : _options$placement,
        _options$strategy = _options.strategy,
        strategy = _options$strategy === void 0 ? state.strategy : _options$strategy,
        _options$boundary = _options.boundary,
        boundary = _options$boundary === void 0 ? clippingParents : _options$boundary,
        _options$rootBoundary = _options.rootBoundary,
        rootBoundary = _options$rootBoundary === void 0 ? viewport : _options$rootBoundary,
        _options$elementConte = _options.elementContext,
        elementContext = _options$elementConte === void 0 ? popper : _options$elementConte,
        _options$altBoundary = _options.altBoundary,
        altBoundary = _options$altBoundary === void 0 ? false : _options$altBoundary,
        _options$padding = _options.padding,
        padding = _options$padding === void 0 ? 0 : _options$padding;
    var paddingObject = mergePaddingObject(typeof padding !== 'number' ? padding : expandToHashMap(padding, basePlacements));
    var altContext = elementContext === popper ? reference : popper;
    var popperRect = state.rects.popper;
    var element = state.elements[altBoundary ? altContext : elementContext];
    var clippingClientRect = getClippingRect(isElement$1(element) ? element : element.contextElement || getDocumentElement(state.elements.popper), boundary, rootBoundary, strategy);
    var referenceClientRect = getBoundingClientRect(state.elements.reference);
    var popperOffsets = computeOffsets({
      reference: referenceClientRect,
      element: popperRect,
      strategy: 'absolute',
      placement: placement
    });
    var popperClientRect = rectToClientRect(Object.assign({}, popperRect, popperOffsets));
    var elementClientRect = elementContext === popper ? popperClientRect : referenceClientRect; // positive = overflowing the clipping rect
    // 0 or negative = within the clipping rect

    var overflowOffsets = {
      top: clippingClientRect.top - elementClientRect.top + paddingObject.top,
      bottom: elementClientRect.bottom - clippingClientRect.bottom + paddingObject.bottom,
      left: clippingClientRect.left - elementClientRect.left + paddingObject.left,
      right: elementClientRect.right - clippingClientRect.right + paddingObject.right
    };
    var offsetData = state.modifiersData.offset; // Offsets can be applied only to the popper element

    if (elementContext === popper && offsetData) {
      var offset = offsetData[placement];
      Object.keys(overflowOffsets).forEach(function (key) {
        var multiply = [right, bottom].indexOf(key) >= 0 ? 1 : -1;
        var axis = [top, bottom].indexOf(key) >= 0 ? 'y' : 'x';
        overflowOffsets[key] += offset[axis] * multiply;
      });
    }

    return overflowOffsets;
  }

  function computeAutoPlacement(state, options) {
    if (options === void 0) {
      options = {};
    }

    var _options = options,
        placement = _options.placement,
        boundary = _options.boundary,
        rootBoundary = _options.rootBoundary,
        padding = _options.padding,
        flipVariations = _options.flipVariations,
        _options$allowedAutoP = _options.allowedAutoPlacements,
        allowedAutoPlacements = _options$allowedAutoP === void 0 ? placements : _options$allowedAutoP;
    var variation = getVariation(placement);
    var placements$1 = variation ? flipVariations ? variationPlacements : variationPlacements.filter(function (placement) {
      return getVariation(placement) === variation;
    }) : basePlacements;
    var allowedPlacements = placements$1.filter(function (placement) {
      return allowedAutoPlacements.indexOf(placement) >= 0;
    });

    if (allowedPlacements.length === 0) {
      allowedPlacements = placements$1;
    } // $FlowFixMe[incompatible-type]: Flow seems to have problems with two array unions...


    var overflows = allowedPlacements.reduce(function (acc, placement) {
      acc[placement] = detectOverflow(state, {
        placement: placement,
        boundary: boundary,
        rootBoundary: rootBoundary,
        padding: padding
      })[getBasePlacement(placement)];
      return acc;
    }, {});
    return Object.keys(overflows).sort(function (a, b) {
      return overflows[a] - overflows[b];
    });
  }

  function getExpandedFallbackPlacements(placement) {
    if (getBasePlacement(placement) === auto) {
      return [];
    }

    var oppositePlacement = getOppositePlacement(placement);
    return [getOppositeVariationPlacement(placement), oppositePlacement, getOppositeVariationPlacement(oppositePlacement)];
  }

  function flip(_ref) {
    var state = _ref.state,
        options = _ref.options,
        name = _ref.name;

    if (state.modifiersData[name]._skip) {
      return;
    }

    var _options$mainAxis = options.mainAxis,
        checkMainAxis = _options$mainAxis === void 0 ? true : _options$mainAxis,
        _options$altAxis = options.altAxis,
        checkAltAxis = _options$altAxis === void 0 ? true : _options$altAxis,
        specifiedFallbackPlacements = options.fallbackPlacements,
        padding = options.padding,
        boundary = options.boundary,
        rootBoundary = options.rootBoundary,
        altBoundary = options.altBoundary,
        _options$flipVariatio = options.flipVariations,
        flipVariations = _options$flipVariatio === void 0 ? true : _options$flipVariatio,
        allowedAutoPlacements = options.allowedAutoPlacements;
    var preferredPlacement = state.options.placement;
    var basePlacement = getBasePlacement(preferredPlacement);
    var isBasePlacement = basePlacement === preferredPlacement;
    var fallbackPlacements = specifiedFallbackPlacements || (isBasePlacement || !flipVariations ? [getOppositePlacement(preferredPlacement)] : getExpandedFallbackPlacements(preferredPlacement));
    var placements = [preferredPlacement].concat(fallbackPlacements).reduce(function (acc, placement) {
      return acc.concat(getBasePlacement(placement) === auto ? computeAutoPlacement(state, {
        placement: placement,
        boundary: boundary,
        rootBoundary: rootBoundary,
        padding: padding,
        flipVariations: flipVariations,
        allowedAutoPlacements: allowedAutoPlacements
      }) : placement);
    }, []);
    var referenceRect = state.rects.reference;
    var popperRect = state.rects.popper;
    var checksMap = new Map();
    var makeFallbackChecks = true;
    var firstFittingPlacement = placements[0];

    for (var i = 0; i < placements.length; i++) {
      var placement = placements[i];

      var _basePlacement = getBasePlacement(placement);

      var isStartVariation = getVariation(placement) === start;
      var isVertical = [top, bottom].indexOf(_basePlacement) >= 0;
      var len = isVertical ? 'width' : 'height';
      var overflow = detectOverflow(state, {
        placement: placement,
        boundary: boundary,
        rootBoundary: rootBoundary,
        altBoundary: altBoundary,
        padding: padding
      });
      var mainVariationSide = isVertical ? isStartVariation ? right : left : isStartVariation ? bottom : top;

      if (referenceRect[len] > popperRect[len]) {
        mainVariationSide = getOppositePlacement(mainVariationSide);
      }

      var altVariationSide = getOppositePlacement(mainVariationSide);
      var checks = [];

      if (checkMainAxis) {
        checks.push(overflow[_basePlacement] <= 0);
      }

      if (checkAltAxis) {
        checks.push(overflow[mainVariationSide] <= 0, overflow[altVariationSide] <= 0);
      }

      if (checks.every(function (check) {
        return check;
      })) {
        firstFittingPlacement = placement;
        makeFallbackChecks = false;
        break;
      }

      checksMap.set(placement, checks);
    }

    if (makeFallbackChecks) {
      // `2` may be desired in some cases – research later
      var numberOfChecks = flipVariations ? 3 : 1;

      var _loop = function _loop(_i) {
        var fittingPlacement = placements.find(function (placement) {
          var checks = checksMap.get(placement);

          if (checks) {
            return checks.slice(0, _i).every(function (check) {
              return check;
            });
          }
        });

        if (fittingPlacement) {
          firstFittingPlacement = fittingPlacement;
          return "break";
        }
      };

      for (var _i = numberOfChecks; _i > 0; _i--) {
        var _ret = _loop(_i);

        if (_ret === "break") break;
      }
    }

    if (state.placement !== firstFittingPlacement) {
      state.modifiersData[name]._skip = true;
      state.placement = firstFittingPlacement;
      state.reset = true;
    }
  } // eslint-disable-next-line import/no-unused-modules


  var flip$1 = {
    name: 'flip',
    enabled: true,
    phase: 'main',
    fn: flip,
    requiresIfExists: ['offset'],
    data: {
      _skip: false
    }
  };

  function getSideOffsets(overflow, rect, preventedOffsets) {
    if (preventedOffsets === void 0) {
      preventedOffsets = {
        x: 0,
        y: 0
      };
    }

    return {
      top: overflow.top - rect.height - preventedOffsets.y,
      right: overflow.right - rect.width + preventedOffsets.x,
      bottom: overflow.bottom - rect.height + preventedOffsets.y,
      left: overflow.left - rect.width - preventedOffsets.x
    };
  }

  function isAnySideFullyClipped(overflow) {
    return [top, right, bottom, left].some(function (side) {
      return overflow[side] >= 0;
    });
  }

  function hide(_ref) {
    var state = _ref.state,
        name = _ref.name;
    var referenceRect = state.rects.reference;
    var popperRect = state.rects.popper;
    var preventedOffsets = state.modifiersData.preventOverflow;
    var referenceOverflow = detectOverflow(state, {
      elementContext: 'reference'
    });
    var popperAltOverflow = detectOverflow(state, {
      altBoundary: true
    });
    var referenceClippingOffsets = getSideOffsets(referenceOverflow, referenceRect);
    var popperEscapeOffsets = getSideOffsets(popperAltOverflow, popperRect, preventedOffsets);
    var isReferenceHidden = isAnySideFullyClipped(referenceClippingOffsets);
    var hasPopperEscaped = isAnySideFullyClipped(popperEscapeOffsets);
    state.modifiersData[name] = {
      referenceClippingOffsets: referenceClippingOffsets,
      popperEscapeOffsets: popperEscapeOffsets,
      isReferenceHidden: isReferenceHidden,
      hasPopperEscaped: hasPopperEscaped
    };
    state.attributes.popper = Object.assign({}, state.attributes.popper, {
      'data-popper-reference-hidden': isReferenceHidden,
      'data-popper-escaped': hasPopperEscaped
    });
  } // eslint-disable-next-line import/no-unused-modules


  var hide$1 = {
    name: 'hide',
    enabled: true,
    phase: 'main',
    requiresIfExists: ['preventOverflow'],
    fn: hide
  };

  function distanceAndSkiddingToXY(placement, rects, offset) {
    var basePlacement = getBasePlacement(placement);
    var invertDistance = [left, top].indexOf(basePlacement) >= 0 ? -1 : 1;

    var _ref = typeof offset === 'function' ? offset(Object.assign({}, rects, {
      placement: placement
    })) : offset,
        skidding = _ref[0],
        distance = _ref[1];

    skidding = skidding || 0;
    distance = (distance || 0) * invertDistance;
    return [left, right].indexOf(basePlacement) >= 0 ? {
      x: distance,
      y: skidding
    } : {
      x: skidding,
      y: distance
    };
  }

  function offset(_ref2) {
    var state = _ref2.state,
        options = _ref2.options,
        name = _ref2.name;
    var _options$offset = options.offset,
        offset = _options$offset === void 0 ? [0, 0] : _options$offset;
    var data = placements.reduce(function (acc, placement) {
      acc[placement] = distanceAndSkiddingToXY(placement, state.rects, offset);
      return acc;
    }, {});
    var _data$state$placement = data[state.placement],
        x = _data$state$placement.x,
        y = _data$state$placement.y;

    if (state.modifiersData.popperOffsets != null) {
      state.modifiersData.popperOffsets.x += x;
      state.modifiersData.popperOffsets.y += y;
    }

    state.modifiersData[name] = data;
  } // eslint-disable-next-line import/no-unused-modules


  var offset$1 = {
    name: 'offset',
    enabled: true,
    phase: 'main',
    requires: ['popperOffsets'],
    fn: offset
  };

  function popperOffsets(_ref) {
    var state = _ref.state,
        name = _ref.name;
    // Offsets are the actual position the popper needs to have to be
    // properly positioned near its reference element
    // This is the most basic placement, and will be adjusted by
    // the modifiers in the next step
    state.modifiersData[name] = computeOffsets({
      reference: state.rects.reference,
      element: state.rects.popper,
      strategy: 'absolute',
      placement: state.placement
    });
  } // eslint-disable-next-line import/no-unused-modules


  var popperOffsets$1 = {
    name: 'popperOffsets',
    enabled: true,
    phase: 'read',
    fn: popperOffsets,
    data: {}
  };

  function getAltAxis(axis) {
    return axis === 'x' ? 'y' : 'x';
  }

  function preventOverflow(_ref) {
    var state = _ref.state,
        options = _ref.options,
        name = _ref.name;
    var _options$mainAxis = options.mainAxis,
        checkMainAxis = _options$mainAxis === void 0 ? true : _options$mainAxis,
        _options$altAxis = options.altAxis,
        checkAltAxis = _options$altAxis === void 0 ? false : _options$altAxis,
        boundary = options.boundary,
        rootBoundary = options.rootBoundary,
        altBoundary = options.altBoundary,
        padding = options.padding,
        _options$tether = options.tether,
        tether = _options$tether === void 0 ? true : _options$tether,
        _options$tetherOffset = options.tetherOffset,
        tetherOffset = _options$tetherOffset === void 0 ? 0 : _options$tetherOffset;
    var overflow = detectOverflow(state, {
      boundary: boundary,
      rootBoundary: rootBoundary,
      padding: padding,
      altBoundary: altBoundary
    });
    var basePlacement = getBasePlacement(state.placement);
    var variation = getVariation(state.placement);
    var isBasePlacement = !variation;
    var mainAxis = getMainAxisFromPlacement(basePlacement);
    var altAxis = getAltAxis(mainAxis);
    var popperOffsets = state.modifiersData.popperOffsets;
    var referenceRect = state.rects.reference;
    var popperRect = state.rects.popper;
    var tetherOffsetValue = typeof tetherOffset === 'function' ? tetherOffset(Object.assign({}, state.rects, {
      placement: state.placement
    })) : tetherOffset;
    var normalizedTetherOffsetValue = typeof tetherOffsetValue === 'number' ? {
      mainAxis: tetherOffsetValue,
      altAxis: tetherOffsetValue
    } : Object.assign({
      mainAxis: 0,
      altAxis: 0
    }, tetherOffsetValue);
    var offsetModifierState = state.modifiersData.offset ? state.modifiersData.offset[state.placement] : null;
    var data = {
      x: 0,
      y: 0
    };

    if (!popperOffsets) {
      return;
    }

    if (checkMainAxis) {
      var _offsetModifierState$;

      var mainSide = mainAxis === 'y' ? top : left;
      var altSide = mainAxis === 'y' ? bottom : right;
      var len = mainAxis === 'y' ? 'height' : 'width';
      var offset = popperOffsets[mainAxis];
      var min$1 = offset + overflow[mainSide];
      var max$1 = offset - overflow[altSide];
      var additive = tether ? -popperRect[len] / 2 : 0;
      var minLen = variation === start ? referenceRect[len] : popperRect[len];
      var maxLen = variation === start ? -popperRect[len] : -referenceRect[len]; // We need to include the arrow in the calculation so the arrow doesn't go
      // outside the reference bounds

      var arrowElement = state.elements.arrow;
      var arrowRect = tether && arrowElement ? getLayoutRect(arrowElement) : {
        width: 0,
        height: 0
      };
      var arrowPaddingObject = state.modifiersData['arrow#persistent'] ? state.modifiersData['arrow#persistent'].padding : getFreshSideObject();
      var arrowPaddingMin = arrowPaddingObject[mainSide];
      var arrowPaddingMax = arrowPaddingObject[altSide]; // If the reference length is smaller than the arrow length, we don't want
      // to include its full size in the calculation. If the reference is small
      // and near the edge of a boundary, the popper can overflow even if the
      // reference is not overflowing as well (e.g. virtual elements with no
      // width or height)

      var arrowLen = within(0, referenceRect[len], arrowRect[len]);
      var minOffset = isBasePlacement ? referenceRect[len] / 2 - additive - arrowLen - arrowPaddingMin - normalizedTetherOffsetValue.mainAxis : minLen - arrowLen - arrowPaddingMin - normalizedTetherOffsetValue.mainAxis;
      var maxOffset = isBasePlacement ? -referenceRect[len] / 2 + additive + arrowLen + arrowPaddingMax + normalizedTetherOffsetValue.mainAxis : maxLen + arrowLen + arrowPaddingMax + normalizedTetherOffsetValue.mainAxis;
      var arrowOffsetParent = state.elements.arrow && getOffsetParent(state.elements.arrow);
      var clientOffset = arrowOffsetParent ? mainAxis === 'y' ? arrowOffsetParent.clientTop || 0 : arrowOffsetParent.clientLeft || 0 : 0;
      var offsetModifierValue = (_offsetModifierState$ = offsetModifierState == null ? void 0 : offsetModifierState[mainAxis]) != null ? _offsetModifierState$ : 0;
      var tetherMin = offset + minOffset - offsetModifierValue - clientOffset;
      var tetherMax = offset + maxOffset - offsetModifierValue;
      var preventedOffset = within(tether ? min(min$1, tetherMin) : min$1, offset, tether ? max(max$1, tetherMax) : max$1);
      popperOffsets[mainAxis] = preventedOffset;
      data[mainAxis] = preventedOffset - offset;
    }

    if (checkAltAxis) {
      var _offsetModifierState$2;

      var _mainSide = mainAxis === 'x' ? top : left;

      var _altSide = mainAxis === 'x' ? bottom : right;

      var _offset = popperOffsets[altAxis];

      var _len = altAxis === 'y' ? 'height' : 'width';

      var _min = _offset + overflow[_mainSide];

      var _max = _offset - overflow[_altSide];

      var isOriginSide = [top, left].indexOf(basePlacement) !== -1;

      var _offsetModifierValue = (_offsetModifierState$2 = offsetModifierState == null ? void 0 : offsetModifierState[altAxis]) != null ? _offsetModifierState$2 : 0;

      var _tetherMin = isOriginSide ? _min : _offset - referenceRect[_len] - popperRect[_len] - _offsetModifierValue + normalizedTetherOffsetValue.altAxis;

      var _tetherMax = isOriginSide ? _offset + referenceRect[_len] + popperRect[_len] - _offsetModifierValue - normalizedTetherOffsetValue.altAxis : _max;

      var _preventedOffset = tether && isOriginSide ? withinMaxClamp(_tetherMin, _offset, _tetherMax) : within(tether ? _tetherMin : _min, _offset, tether ? _tetherMax : _max);

      popperOffsets[altAxis] = _preventedOffset;
      data[altAxis] = _preventedOffset - _offset;
    }

    state.modifiersData[name] = data;
  } // eslint-disable-next-line import/no-unused-modules


  var preventOverflow$1 = {
    name: 'preventOverflow',
    enabled: true,
    phase: 'main',
    fn: preventOverflow,
    requiresIfExists: ['offset']
  };

  function getHTMLElementScroll(element) {
    return {
      scrollLeft: element.scrollLeft,
      scrollTop: element.scrollTop
    };
  }

  function getNodeScroll(node) {
    if (node === getWindow(node) || !isHTMLElement(node)) {
      return getWindowScroll(node);
    } else {
      return getHTMLElementScroll(node);
    }
  }

  function isElementScaled(element) {
    var rect = element.getBoundingClientRect();
    var scaleX = round(rect.width) / element.offsetWidth || 1;
    var scaleY = round(rect.height) / element.offsetHeight || 1;
    return scaleX !== 1 || scaleY !== 1;
  } // Returns the composite rect of an element relative to its offsetParent.
  // Composite means it takes into account transforms as well as layout.


  function getCompositeRect(elementOrVirtualElement, offsetParent, isFixed) {
    if (isFixed === void 0) {
      isFixed = false;
    }

    var isOffsetParentAnElement = isHTMLElement(offsetParent);
    var offsetParentIsScaled = isHTMLElement(offsetParent) && isElementScaled(offsetParent);
    var documentElement = getDocumentElement(offsetParent);
    var rect = getBoundingClientRect(elementOrVirtualElement, offsetParentIsScaled, isFixed);
    var scroll = {
      scrollLeft: 0,
      scrollTop: 0
    };
    var offsets = {
      x: 0,
      y: 0
    };

    if (isOffsetParentAnElement || !isOffsetParentAnElement && !isFixed) {
      if (getNodeName(offsetParent) !== 'body' || // https://github.com/popperjs/popper-core/issues/1078
      isScrollParent(documentElement)) {
        scroll = getNodeScroll(offsetParent);
      }

      if (isHTMLElement(offsetParent)) {
        offsets = getBoundingClientRect(offsetParent, true);
        offsets.x += offsetParent.clientLeft;
        offsets.y += offsetParent.clientTop;
      } else if (documentElement) {
        offsets.x = getWindowScrollBarX(documentElement);
      }
    }

    return {
      x: rect.left + scroll.scrollLeft - offsets.x,
      y: rect.top + scroll.scrollTop - offsets.y,
      width: rect.width,
      height: rect.height
    };
  }

  function order(modifiers) {
    var map = new Map();
    var visited = new Set();
    var result = [];
    modifiers.forEach(function (modifier) {
      map.set(modifier.name, modifier);
    }); // On visiting object, check for its dependencies and visit them recursively

    function sort(modifier) {
      visited.add(modifier.name);
      var requires = [].concat(modifier.requires || [], modifier.requiresIfExists || []);
      requires.forEach(function (dep) {
        if (!visited.has(dep)) {
          var depModifier = map.get(dep);

          if (depModifier) {
            sort(depModifier);
          }
        }
      });
      result.push(modifier);
    }

    modifiers.forEach(function (modifier) {
      if (!visited.has(modifier.name)) {
        // check for visited object
        sort(modifier);
      }
    });
    return result;
  }

  function orderModifiers(modifiers) {
    // order based on dependencies
    var orderedModifiers = order(modifiers); // order based on phase

    return modifierPhases.reduce(function (acc, phase) {
      return acc.concat(orderedModifiers.filter(function (modifier) {
        return modifier.phase === phase;
      }));
    }, []);
  }

  function debounce(fn) {
    var pending;
    return function () {
      if (!pending) {
        pending = new Promise(function (resolve) {
          Promise.resolve().then(function () {
            pending = undefined;
            resolve(fn());
          });
        });
      }

      return pending;
    };
  }

  function mergeByName(modifiers) {
    var merged = modifiers.reduce(function (merged, current) {
      var existing = merged[current.name];
      merged[current.name] = existing ? Object.assign({}, existing, current, {
        options: Object.assign({}, existing.options, current.options),
        data: Object.assign({}, existing.data, current.data)
      }) : current;
      return merged;
    }, {}); // IE11 does not support Object.values

    return Object.keys(merged).map(function (key) {
      return merged[key];
    });
  }

  var DEFAULT_OPTIONS = {
    placement: 'bottom',
    modifiers: [],
    strategy: 'absolute'
  };

  function areValidElements() {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return !args.some(function (element) {
      return !(element && typeof element.getBoundingClientRect === 'function');
    });
  }

  function popperGenerator(generatorOptions) {
    if (generatorOptions === void 0) {
      generatorOptions = {};
    }

    var _generatorOptions = generatorOptions,
        _generatorOptions$def = _generatorOptions.defaultModifiers,
        defaultModifiers = _generatorOptions$def === void 0 ? [] : _generatorOptions$def,
        _generatorOptions$def2 = _generatorOptions.defaultOptions,
        defaultOptions = _generatorOptions$def2 === void 0 ? DEFAULT_OPTIONS : _generatorOptions$def2;
    return function createPopper(reference, popper, options) {
      if (options === void 0) {
        options = defaultOptions;
      }

      var state = {
        placement: 'bottom',
        orderedModifiers: [],
        options: Object.assign({}, DEFAULT_OPTIONS, defaultOptions),
        modifiersData: {},
        elements: {
          reference: reference,
          popper: popper
        },
        attributes: {},
        styles: {}
      };
      var effectCleanupFns = [];
      var isDestroyed = false;
      var instance = {
        state: state,
        setOptions: function setOptions(setOptionsAction) {
          var options = typeof setOptionsAction === 'function' ? setOptionsAction(state.options) : setOptionsAction;
          cleanupModifierEffects();
          state.options = Object.assign({}, defaultOptions, state.options, options);
          state.scrollParents = {
            reference: isElement$1(reference) ? listScrollParents(reference) : reference.contextElement ? listScrollParents(reference.contextElement) : [],
            popper: listScrollParents(popper)
          }; // Orders the modifiers based on their dependencies and `phase`
          // properties

          var orderedModifiers = orderModifiers(mergeByName([].concat(defaultModifiers, state.options.modifiers))); // Strip out disabled modifiers

          state.orderedModifiers = orderedModifiers.filter(function (m) {
            return m.enabled;
          });
          runModifierEffects();
          return instance.update();
        },
        // Sync update – it will always be executed, even if not necessary. This
        // is useful for low frequency updates where sync behavior simplifies the
        // logic.
        // For high frequency updates (e.g. `resize` and `scroll` events), always
        // prefer the async Popper#update method
        forceUpdate: function forceUpdate() {
          if (isDestroyed) {
            return;
          }

          var _state$elements = state.elements,
              reference = _state$elements.reference,
              popper = _state$elements.popper; // Don't proceed if `reference` or `popper` are not valid elements
          // anymore

          if (!areValidElements(reference, popper)) {
            return;
          } // Store the reference and popper rects to be read by modifiers


          state.rects = {
            reference: getCompositeRect(reference, getOffsetParent(popper), state.options.strategy === 'fixed'),
            popper: getLayoutRect(popper)
          }; // Modifiers have the ability to reset the current update cycle. The
          // most common use case for this is the `flip` modifier changing the
          // placement, which then needs to re-run all the modifiers, because the
          // logic was previously ran for the previous placement and is therefore
          // stale/incorrect

          state.reset = false;
          state.placement = state.options.placement; // On each update cycle, the `modifiersData` property for each modifier
          // is filled with the initial data specified by the modifier. This means
          // it doesn't persist and is fresh on each update.
          // To ensure persistent data, use `${name}#persistent`

          state.orderedModifiers.forEach(function (modifier) {
            return state.modifiersData[modifier.name] = Object.assign({}, modifier.data);
          });

          for (var index = 0; index < state.orderedModifiers.length; index++) {
            if (state.reset === true) {
              state.reset = false;
              index = -1;
              continue;
            }

            var _state$orderedModifie = state.orderedModifiers[index],
                fn = _state$orderedModifie.fn,
                _state$orderedModifie2 = _state$orderedModifie.options,
                _options = _state$orderedModifie2 === void 0 ? {} : _state$orderedModifie2,
                name = _state$orderedModifie.name;

            if (typeof fn === 'function') {
              state = fn({
                state: state,
                options: _options,
                name: name,
                instance: instance
              }) || state;
            }
          }
        },
        // Async and optimistically optimized update – it will not be executed if
        // not necessary (debounced to run at most once-per-tick)
        update: debounce(function () {
          return new Promise(function (resolve) {
            instance.forceUpdate();
            resolve(state);
          });
        }),
        destroy: function destroy() {
          cleanupModifierEffects();
          isDestroyed = true;
        }
      };

      if (!areValidElements(reference, popper)) {
        return instance;
      }

      instance.setOptions(options).then(function (state) {
        if (!isDestroyed && options.onFirstUpdate) {
          options.onFirstUpdate(state);
        }
      }); // Modifiers have the ability to execute arbitrary code before the first
      // update cycle runs. They will be executed in the same order as the update
      // cycle. This is useful when a modifier adds some persistent data that
      // other modifiers need to use, but the modifier is run after the dependent
      // one.

      function runModifierEffects() {
        state.orderedModifiers.forEach(function (_ref) {
          var name = _ref.name,
              _ref$options = _ref.options,
              options = _ref$options === void 0 ? {} : _ref$options,
              effect = _ref.effect;

          if (typeof effect === 'function') {
            var cleanupFn = effect({
              state: state,
              name: name,
              instance: instance,
              options: options
            });

            var noopFn = function noopFn() {};

            effectCleanupFns.push(cleanupFn || noopFn);
          }
        });
      }

      function cleanupModifierEffects() {
        effectCleanupFns.forEach(function (fn) {
          return fn();
        });
        effectCleanupFns = [];
      }

      return instance;
    };
  }
  var createPopper$2 = /*#__PURE__*/popperGenerator(); // eslint-disable-next-line import/no-unused-modules

  var defaultModifiers$1 = [eventListeners, popperOffsets$1, computeStyles$1, applyStyles$1];
  var createPopper$1 = /*#__PURE__*/popperGenerator({
    defaultModifiers: defaultModifiers$1
  }); // eslint-disable-next-line import/no-unused-modules

  var defaultModifiers = [eventListeners, popperOffsets$1, computeStyles$1, applyStyles$1, offset$1, flip$1, preventOverflow$1, arrow$1, hide$1];
  var createPopper = /*#__PURE__*/popperGenerator({
    defaultModifiers: defaultModifiers
  }); // eslint-disable-next-line import/no-unused-modules

  var Popper = /*#__PURE__*/Object.freeze({
    __proto__: null,
    popperGenerator: popperGenerator,
    detectOverflow: detectOverflow,
    createPopperBase: createPopper$2,
    createPopper: createPopper,
    createPopperLite: createPopper$1,
    top: top,
    bottom: bottom,
    right: right,
    left: left,
    auto: auto,
    basePlacements: basePlacements,
    start: start,
    end: end,
    clippingParents: clippingParents,
    viewport: viewport,
    popper: popper,
    reference: reference,
    variationPlacements: variationPlacements,
    placements: placements,
    beforeRead: beforeRead,
    read: read,
    afterRead: afterRead,
    beforeMain: beforeMain,
    main: main,
    afterMain: afterMain,
    beforeWrite: beforeWrite,
    write: write,
    afterWrite: afterWrite,
    modifierPhases: modifierPhases,
    applyStyles: applyStyles$1,
    arrow: arrow$1,
    computeStyles: computeStyles$1,
    eventListeners: eventListeners,
    flip: flip$1,
    hide: hide$1,
    offset: offset$1,
    popperOffsets: popperOffsets$1,
    preventOverflow: preventOverflow$1
  });

  /**
   * --------------------------------------------------------------------------
   * Bootstrap dom/data.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */

  /**
   * Constants
   */

  const elementMap = new Map();

  var Data = {
    set(element, key, instance) {
      if (!elementMap.has(element)) {
        elementMap.set(element, new Map());
      }

      const instanceMap = elementMap.get(element);

      // make it clear we only want one instance per element
      // can be removed later when multiple key/instances are fine to be used
      if (!instanceMap.has(key) && instanceMap.size !== 0) {
        // eslint-disable-next-line no-console
        console.error(`Bootstrap doesn't allow more than one instance per element. Bound instance: ${Array.from(instanceMap.keys())[0]}.`);
        return
      }

      instanceMap.set(key, instance);
    },

    get(element, key) {
      if (elementMap.has(element)) {
        return elementMap.get(element).get(key) || null
      }

      return null
    },

    remove(element, key) {
      if (!elementMap.has(element)) {
        return
      }

      const instanceMap = elementMap.get(element);

      instanceMap.delete(key);

      // free up element references if there are no instances left for an element
      if (instanceMap.size === 0) {
        elementMap.delete(element);
      }
    }
  };

  /**
   * --------------------------------------------------------------------------
   * Bootstrap util/index.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */

  const MAX_UID = 1_000_000;
  const MILLISECONDS_MULTIPLIER = 1000;
  const TRANSITION_END = 'transitionend';

  /**
   * Properly escape IDs selectors to handle weird IDs
   * @param {string} selector
   * @returns {string}
   */
  const parseSelector = selector => {
    if (selector && window.CSS && window.CSS.escape) {
      // document.querySelector needs escaping to handle IDs (html5+) containing for instance /
      selector = selector.replace(/#([^\s"#']+)/g, (match, id) => `#${CSS.escape(id)}`);
    }

    return selector
  };

  // Shout-out Angus Croll (https://goo.gl/pxwQGp)
  const toType = object => {
    if (object === null || object === undefined) {
      return `${object}`
    }

    return Object.prototype.toString.call(object).match(/\s([a-z]+)/i)[1].toLowerCase()
  };

  /**
   * Public Util API
   */

  const getUID = prefix => {
    do {
      prefix += Math.floor(Math.random() * MAX_UID);
    } while (document.getElementById(prefix))

    return prefix
  };

  const getTransitionDurationFromElement = element => {
    if (!element) {
      return 0
    }

    // Get transition-duration of the element
    let { transitionDuration, transitionDelay } = window.getComputedStyle(element);

    const floatTransitionDuration = Number.parseFloat(transitionDuration);
    const floatTransitionDelay = Number.parseFloat(transitionDelay);

    // Return 0 if element or transition duration is not found
    if (!floatTransitionDuration && !floatTransitionDelay) {
      return 0
    }

    // If multiple durations are defined, take the first
    transitionDuration = transitionDuration.split(',')[0];
    transitionDelay = transitionDelay.split(',')[0];

    return (Number.parseFloat(transitionDuration) + Number.parseFloat(transitionDelay)) * MILLISECONDS_MULTIPLIER
  };

  const triggerTransitionEnd = element => {
    element.dispatchEvent(new Event(TRANSITION_END));
  };

  const isElement = object => {
    if (!object || typeof object !== 'object') {
      return false
    }

    if (typeof object.jquery !== 'undefined') {
      object = object[0];
    }

    return typeof object.nodeType !== 'undefined'
  };

  const getElement = object => {
    // it's a jQuery object or a node element
    if (isElement(object)) {
      return object.jquery ? object[0] : object
    }

    if (typeof object === 'string' && object.length > 0) {
      return document.querySelector(parseSelector(object))
    }

    return null
  };

  const isVisible = element => {
    if (!isElement(element) || element.getClientRects().length === 0) {
      return false
    }

    const elementIsVisible = getComputedStyle(element).getPropertyValue('visibility') === 'visible';
    // Handle `details` element as its content may falsie appear visible when it is closed
    const closedDetails = element.closest('details:not([open])');

    if (!closedDetails) {
      return elementIsVisible
    }

    if (closedDetails !== element) {
      const summary = element.closest('summary');
      if (summary && summary.parentNode !== closedDetails) {
        return false
      }

      if (summary === null) {
        return false
      }
    }

    return elementIsVisible
  };

  const isDisabled = element => {
    if (!element || element.nodeType !== Node.ELEMENT_NODE) {
      return true
    }

    if (element.classList.contains('disabled')) {
      return true
    }

    if (typeof element.disabled !== 'undefined') {
      return element.disabled
    }

    return element.hasAttribute('disabled') && element.getAttribute('disabled') !== 'false'
  };

  const findShadowRoot = element => {
    if (!document.documentElement.attachShadow) {
      return null
    }

    // Can find the shadow root otherwise it'll return the document
    if (typeof element.getRootNode === 'function') {
      const root = element.getRootNode();
      return root instanceof ShadowRoot ? root : null
    }

    if (element instanceof ShadowRoot) {
      return element
    }

    // when we don't find a shadow root
    if (!element.parentNode) {
      return null
    }

    return findShadowRoot(element.parentNode)
  };

  const noop = () => {};

  const getjQuery = () => {
    if (window.jQuery && !document.body.hasAttribute('data-bs-no-jquery')) {
      return window.jQuery
    }

    return null
  };

  const DOMContentLoadedCallbacks = [];

  const onDOMContentLoaded = callback => {
    if (document.readyState === 'loading') {
      // add listener on the first call when the document is in loading state
      if (!DOMContentLoadedCallbacks.length) {
        document.addEventListener('DOMContentLoaded', () => {
          for (const callback of DOMContentLoadedCallbacks) {
            callback();
          }
        });
      }

      DOMContentLoadedCallbacks.push(callback);
    } else {
      callback();
    }
  };

  const isRTL = () => document.documentElement.dir === 'rtl';

  const defineJQueryPlugin = plugin => {
    onDOMContentLoaded(() => {
      const $ = getjQuery();
      /* istanbul ignore if */
      if ($) {
        const name = plugin.NAME;
        const JQUERY_NO_CONFLICT = $.fn[name];
        $.fn[name] = plugin.jQueryInterface;
        $.fn[name].Constructor = plugin;
        $.fn[name].noConflict = () => {
          $.fn[name] = JQUERY_NO_CONFLICT;
          return plugin.jQueryInterface
        };
      }
    });
  };

  const execute = (possibleCallback, args = [], defaultValue = possibleCallback) => {
    return typeof possibleCallback === 'function' ? possibleCallback(...args) : defaultValue
  };

  const executeAfterTransition = (callback, transitionElement, waitForTransition = true) => {
    if (!waitForTransition) {
      execute(callback);
      return
    }

    const durationPadding = 5;
    const emulatedDuration = getTransitionDurationFromElement(transitionElement) + durationPadding;

    let called = false;

    const handler = ({ target }) => {
      if (target !== transitionElement) {
        return
      }

      called = true;
      transitionElement.removeEventListener(TRANSITION_END, handler);
      execute(callback);
    };

    transitionElement.addEventListener(TRANSITION_END, handler);
    setTimeout(() => {
      if (!called) {
        triggerTransitionEnd(transitionElement);
      }
    }, emulatedDuration);
  };

  /**
   * --------------------------------------------------------------------------
   * Bootstrap dom/event-handler.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */

  /**
   * Constants
   */

  const namespaceRegex = /[^.]*(?=\..*)\.|.*/;
  const stripNameRegex = /\..*/;
  const stripUidRegex = /::\d+$/;
  const eventRegistry = {}; // Events storage
  let uidEvent = 1;
  const customEvents = {
    mouseenter: 'mouseover',
    mouseleave: 'mouseout'
  };

  const nativeEvents = new Set([
    'click',
    'dblclick',
    'mouseup',
    'mousedown',
    'contextmenu',
    'mousewheel',
    'DOMMouseScroll',
    'mouseover',
    'mouseout',
    'mousemove',
    'selectstart',
    'selectend',
    'keydown',
    'keypress',
    'keyup',
    'orientationchange',
    'touchstart',
    'touchmove',
    'touchend',
    'touchcancel',
    'pointerdown',
    'pointermove',
    'pointerup',
    'pointerleave',
    'pointercancel',
    'gesturestart',
    'gesturechange',
    'gestureend',
    'focus',
    'blur',
    'change',
    'reset',
    'select',
    'submit',
    'focusin',
    'focusout',
    'load',
    'unload',
    'beforeunload',
    'resize',
    'move',
    'DOMContentLoaded',
    'readystatechange',
    'error',
    'abort',
    'scroll'
  ]);

  /**
   * Private methods
   */

  function makeEventUid(element, uid) {
    return (uid && `${uid}::${uidEvent++}`) || element.uidEvent || uidEvent++
  }

  function getElementEvents(element) {
    const uid = makeEventUid(element);

    element.uidEvent = uid;
    eventRegistry[uid] = eventRegistry[uid] || {};

    return eventRegistry[uid]
  }

  function bootstrapHandler(element, fn) {
    return function handler(event) {
      hydrateObj(event, { delegateTarget: element });

      if (handler.oneOff) {
        EventHandler.off(element, event.type, fn);
      }

      return fn.apply(element, [event])
    }
  }

  function bootstrapDelegationHandler(element, selector, fn) {
    return function handler(event) {
      const domElements = element.querySelectorAll(selector);

      for (let { target } = event; target && target !== this; target = target.parentNode) {
        for (const domElement of domElements) {
          if (domElement !== target) {
            continue
          }

          hydrateObj(event, { delegateTarget: target });

          if (handler.oneOff) {
            EventHandler.off(element, event.type, selector, fn);
          }

          return fn.apply(target, [event])
        }
      }
    }
  }

  function findHandler(events, callable, delegationSelector = null) {
    return Object.values(events)
      .find(event => event.callable === callable && event.delegationSelector === delegationSelector)
  }

  function normalizeParameters(originalTypeEvent, handler, delegationFunction) {
    const isDelegated = typeof handler === 'string';
    // TODO: tooltip passes `false` instead of selector, so we need to check
    const callable = isDelegated ? delegationFunction : (handler || delegationFunction);
    let typeEvent = getTypeEvent(originalTypeEvent);

    if (!nativeEvents.has(typeEvent)) {
      typeEvent = originalTypeEvent;
    }

    return [isDelegated, callable, typeEvent]
  }

  function addHandler(element, originalTypeEvent, handler, delegationFunction, oneOff) {
    if (typeof originalTypeEvent !== 'string' || !element) {
      return
    }

    let [isDelegated, callable, typeEvent] = normalizeParameters(originalTypeEvent, handler, delegationFunction);

    // in case of mouseenter or mouseleave wrap the handler within a function that checks for its DOM position
    // this prevents the handler from being dispatched the same way as mouseover or mouseout does
    if (originalTypeEvent in customEvents) {
      const wrapFunction = fn => {
        return function (event) {
          if (!event.relatedTarget || (event.relatedTarget !== event.delegateTarget && !event.delegateTarget.contains(event.relatedTarget))) {
            return fn.call(this, event)
          }
        }
      };

      callable = wrapFunction(callable);
    }

    const events = getElementEvents(element);
    const handlers = events[typeEvent] || (events[typeEvent] = {});
    const previousFunction = findHandler(handlers, callable, isDelegated ? handler : null);

    if (previousFunction) {
      previousFunction.oneOff = previousFunction.oneOff && oneOff;

      return
    }

    const uid = makeEventUid(callable, originalTypeEvent.replace(namespaceRegex, ''));
    const fn = isDelegated ?
      bootstrapDelegationHandler(element, handler, callable) :
      bootstrapHandler(element, callable);

    fn.delegationSelector = isDelegated ? handler : null;
    fn.callable = callable;
    fn.oneOff = oneOff;
    fn.uidEvent = uid;
    handlers[uid] = fn;

    element.addEventListener(typeEvent, fn, isDelegated);
  }

  function removeHandler(element, events, typeEvent, handler, delegationSelector) {
    const fn = findHandler(events[typeEvent], handler, delegationSelector);

    if (!fn) {
      return
    }

    element.removeEventListener(typeEvent, fn, Boolean(delegationSelector));
    delete events[typeEvent][fn.uidEvent];
  }

  function removeNamespacedHandlers(element, events, typeEvent, namespace) {
    const storeElementEvent = events[typeEvent] || {};

    for (const [handlerKey, event] of Object.entries(storeElementEvent)) {
      if (handlerKey.includes(namespace)) {
        removeHandler(element, events, typeEvent, event.callable, event.delegationSelector);
      }
    }
  }

  function getTypeEvent(event) {
    // allow to get the native events from namespaced events ('click.bs.button' --> 'click')
    event = event.replace(stripNameRegex, '');
    return customEvents[event] || event
  }

  const EventHandler = {
    on(element, event, handler, delegationFunction) {
      addHandler(element, event, handler, delegationFunction, false);
    },

    one(element, event, handler, delegationFunction) {
      addHandler(element, event, handler, delegationFunction, true);
    },

    off(element, originalTypeEvent, handler, delegationFunction) {
      if (typeof originalTypeEvent !== 'string' || !element) {
        return
      }

      const [isDelegated, callable, typeEvent] = normalizeParameters(originalTypeEvent, handler, delegationFunction);
      const inNamespace = typeEvent !== originalTypeEvent;
      const events = getElementEvents(element);
      const storeElementEvent = events[typeEvent] || {};
      const isNamespace = originalTypeEvent.startsWith('.');

      if (typeof callable !== 'undefined') {
        // Simplest case: handler is passed, remove that listener ONLY.
        if (!Object.keys(storeElementEvent).length) {
          return
        }

        removeHandler(element, events, typeEvent, callable, isDelegated ? handler : null);
        return
      }

      if (isNamespace) {
        for (const elementEvent of Object.keys(events)) {
          removeNamespacedHandlers(element, events, elementEvent, originalTypeEvent.slice(1));
        }
      }

      for (const [keyHandlers, event] of Object.entries(storeElementEvent)) {
        const handlerKey = keyHandlers.replace(stripUidRegex, '');

        if (!inNamespace || originalTypeEvent.includes(handlerKey)) {
          removeHandler(element, events, typeEvent, event.callable, event.delegationSelector);
        }
      }
    },

    trigger(element, event, args) {
      if (typeof event !== 'string' || !element) {
        return null
      }

      const $ = getjQuery();
      const typeEvent = getTypeEvent(event);
      const inNamespace = event !== typeEvent;

      let jQueryEvent = null;
      let bubbles = true;
      let nativeDispatch = true;
      let defaultPrevented = false;

      if (inNamespace && $) {
        jQueryEvent = $.Event(event, args);

        $(element).trigger(jQueryEvent);
        bubbles = !jQueryEvent.isPropagationStopped();
        nativeDispatch = !jQueryEvent.isImmediatePropagationStopped();
        defaultPrevented = jQueryEvent.isDefaultPrevented();
      }

      const evt = hydrateObj(new Event(event, { bubbles, cancelable: true }), args);

      if (defaultPrevented) {
        evt.preventDefault();
      }

      if (nativeDispatch) {
        element.dispatchEvent(evt);
      }

      if (evt.defaultPrevented && jQueryEvent) {
        jQueryEvent.preventDefault();
      }

      return evt
    }
  };

  function hydrateObj(obj, meta = {}) {
    for (const [key, value] of Object.entries(meta)) {
      try {
        obj[key] = value;
      } catch {
        Object.defineProperty(obj, key, {
          configurable: true,
          get() {
            return value
          }
        });
      }
    }

    return obj
  }

  /**
   * --------------------------------------------------------------------------
   * Bootstrap dom/manipulator.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */

  function normalizeData(value) {
    if (value === 'true') {
      return true
    }

    if (value === 'false') {
      return false
    }

    if (value === Number(value).toString()) {
      return Number(value)
    }

    if (value === '' || value === 'null') {
      return null
    }

    if (typeof value !== 'string') {
      return value
    }

    try {
      return JSON.parse(decodeURIComponent(value))
    } catch {
      return value
    }
  }

  function normalizeDataKey(key) {
    return key.replace(/[A-Z]/g, chr => `-${chr.toLowerCase()}`)
  }

  const Manipulator = {
    setDataAttribute(element, key, value) {
      element.setAttribute(`data-bs-${normalizeDataKey(key)}`, value);
    },

    removeDataAttribute(element, key) {
      element.removeAttribute(`data-bs-${normalizeDataKey(key)}`);
    },

    getDataAttributes(element) {
      if (!element) {
        return {}
      }

      const attributes = {};
      const bsKeys = Object.keys(element.dataset).filter(key => key.startsWith('bs') && !key.startsWith('bsConfig'));

      for (const key of bsKeys) {
        let pureKey = key.replace(/^bs/, '');
        pureKey = pureKey.charAt(0).toLowerCase() + pureKey.slice(1, pureKey.length);
        attributes[pureKey] = normalizeData(element.dataset[key]);
      }

      return attributes
    },

    getDataAttribute(element, key) {
      return normalizeData(element.getAttribute(`data-bs-${normalizeDataKey(key)}`))
    }
  };

  /**
   * --------------------------------------------------------------------------
   * Bootstrap util/config.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */

  /**
   * Class definition
   */

  class Config {
    // Getters
    static get Default() {
      return {}
    }

    static get DefaultType() {
      return {}
    }

    static get NAME() {
      throw new Error('You have to implement the static method "NAME", for each component!')
    }

    _getConfig(config) {
      config = this._mergeConfigObj(config);
      config = this._configAfterMerge(config);
      this._typeCheckConfig(config);
      return config
    }

    _configAfterMerge(config) {
      return config
    }

    _mergeConfigObj(config, element) {
      const jsonConfig = isElement(element) ? Manipulator.getDataAttribute(element, 'config') : {}; // try to parse

      return {
        ...this.constructor.Default,
        ...(typeof jsonConfig === 'object' ? jsonConfig : {}),
        ...(isElement(element) ? Manipulator.getDataAttributes(element) : {}),
        ...(typeof config === 'object' ? config : {})
      }
    }

    _typeCheckConfig(config, configTypes = this.constructor.DefaultType) {
      for (const [property, expectedTypes] of Object.entries(configTypes)) {
        const value = config[property];
        const valueType = isElement(value) ? 'element' : toType(value);

        if (!new RegExp(expectedTypes).test(valueType)) {
          throw new TypeError(
            `${this.constructor.NAME.toUpperCase()}: Option "${property}" provided type "${valueType}" but expected type "${expectedTypes}".`
          )
        }
      }
    }
  }

  /**
   * --------------------------------------------------------------------------
   * Bootstrap base-component.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */

  /**
   * Constants
   */

  const VERSION = '5.3.3';

  /**
   * Class definition
   */

  class BaseComponent extends Config {
    constructor(element, config) {
      super();

      element = getElement(element);
      if (!element) {
        return
      }

      this._element = element;
      this._config = this._getConfig(config);

      Data.set(this._element, this.constructor.DATA_KEY, this);
    }

    // Public
    dispose() {
      Data.remove(this._element, this.constructor.DATA_KEY);
      EventHandler.off(this._element, this.constructor.EVENT_KEY);

      for (const propertyName of Object.getOwnPropertyNames(this)) {
        this[propertyName] = null;
      }
    }

    _queueCallback(callback, element, isAnimated = true) {
      executeAfterTransition(callback, element, isAnimated);
    }

    _getConfig(config) {
      config = this._mergeConfigObj(config, this._element);
      config = this._configAfterMerge(config);
      this._typeCheckConfig(config);
      return config
    }

    // Static
    static getInstance(element) {
      return Data.get(getElement(element), this.DATA_KEY)
    }

    static getOrCreateInstance(element, config = {}) {
      return this.getInstance(element) || new this(element, typeof config === 'object' ? config : null)
    }

    static get VERSION() {
      return VERSION
    }

    static get DATA_KEY() {
      return `bs.${this.NAME}`
    }

    static get EVENT_KEY() {
      return `.${this.DATA_KEY}`
    }

    static eventName(name) {
      return `${name}${this.EVENT_KEY}`
    }
  }

  /**
   * --------------------------------------------------------------------------
   * Bootstrap util/sanitizer.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */

  // js-docs-start allow-list
  const ARIA_ATTRIBUTE_PATTERN = /^aria-[\w-]*$/i;

  const DefaultAllowlist = {
    // Global attributes allowed on any supplied element below.
    '*': ['class', 'dir', 'id', 'lang', 'role', ARIA_ATTRIBUTE_PATTERN],
    a: ['target', 'href', 'title', 'rel'],
    area: [],
    b: [],
    br: [],
    col: [],
    code: [],
    dd: [],
    div: [],
    dl: [],
    dt: [],
    em: [],
    hr: [],
    h1: [],
    h2: [],
    h3: [],
    h4: [],
    h5: [],
    h6: [],
    i: [],
    img: ['src', 'srcset', 'alt', 'title', 'width', 'height'],
    li: [],
    ol: [],
    p: [],
    pre: [],
    s: [],
    small: [],
    span: [],
    sub: [],
    sup: [],
    strong: [],
    u: [],
    ul: []
  };
  // js-docs-end allow-list

  const uriAttributes = new Set([
    'background',
    'cite',
    'href',
    'itemtype',
    'longdesc',
    'poster',
    'src',
    'xlink:href'
  ]);

  /**
   * A pattern that recognizes URLs that are safe wrt. XSS in URL navigation
   * contexts.
   *
   * Shout-out to Angular https://github.com/angular/angular/blob/15.2.8/packages/core/src/sanitization/url_sanitizer.ts#L38
   */
  // eslint-disable-next-line unicorn/better-regex
  const SAFE_URL_PATTERN = /^(?!javascript:)(?:[a-z0-9+.-]+:|[^&:/?#]*(?:[/?#]|$))/i;

  const allowedAttribute = (attribute, allowedAttributeList) => {
    const attributeName = attribute.nodeName.toLowerCase();

    if (allowedAttributeList.includes(attributeName)) {
      if (uriAttributes.has(attributeName)) {
        return Boolean(SAFE_URL_PATTERN.test(attribute.nodeValue))
      }

      return true
    }

    // Check if a regular expression validates the attribute.
    return allowedAttributeList.filter(attributeRegex => attributeRegex instanceof RegExp)
      .some(regex => regex.test(attributeName))
  };

  function sanitizeHtml(unsafeHtml, allowList, sanitizeFunction) {
    if (!unsafeHtml.length) {
      return unsafeHtml
    }

    if (sanitizeFunction && typeof sanitizeFunction === 'function') {
      return sanitizeFunction(unsafeHtml)
    }

    const domParser = new window.DOMParser();
    const createdDocument = domParser.parseFromString(unsafeHtml, 'text/html');
    const elements = [].concat(...createdDocument.body.querySelectorAll('*'));

    for (const element of elements) {
      const elementName = element.nodeName.toLowerCase();

      if (!Object.keys(allowList).includes(elementName)) {
        element.remove();
        continue
      }

      const attributeList = [].concat(...element.attributes);
      const allowedAttributes = [].concat(allowList['*'] || [], allowList[elementName] || []);

      for (const attribute of attributeList) {
        if (!allowedAttribute(attribute, allowedAttributes)) {
          element.removeAttribute(attribute.nodeName);
        }
      }
    }

    return createdDocument.body.innerHTML
  }

  /**
   * --------------------------------------------------------------------------
   * Bootstrap dom/selector-engine.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */

  const getSelector = element => {
    let selector = element.getAttribute('data-bs-target');

    if (!selector || selector === '#') {
      let hrefAttribute = element.getAttribute('href');

      // The only valid content that could double as a selector are IDs or classes,
      // so everything starting with `#` or `.`. If a "real" URL is used as the selector,
      // `document.querySelector` will rightfully complain it is invalid.
      // See https://github.com/twbs/bootstrap/issues/32273
      if (!hrefAttribute || (!hrefAttribute.includes('#') && !hrefAttribute.startsWith('.'))) {
        return null
      }

      // Just in case some CMS puts out a full URL with the anchor appended
      if (hrefAttribute.includes('#') && !hrefAttribute.startsWith('#')) {
        hrefAttribute = `#${hrefAttribute.split('#')[1]}`;
      }

      selector = hrefAttribute && hrefAttribute !== '#' ? hrefAttribute.trim() : null;
    }

    return selector ? selector.split(',').map(sel => parseSelector(sel)).join(',') : null
  };

  const SelectorEngine = {
    find(selector, element = document.documentElement) {
      return [].concat(...Element.prototype.querySelectorAll.call(element, selector))
    },

    findOne(selector, element = document.documentElement) {
      return Element.prototype.querySelector.call(element, selector)
    },

    children(element, selector) {
      return [].concat(...element.children).filter(child => child.matches(selector))
    },

    parents(element, selector) {
      const parents = [];
      let ancestor = element.parentNode.closest(selector);

      while (ancestor) {
        parents.push(ancestor);
        ancestor = ancestor.parentNode.closest(selector);
      }

      return parents
    },

    prev(element, selector) {
      let previous = element.previousElementSibling;

      while (previous) {
        if (previous.matches(selector)) {
          return [previous]
        }

        previous = previous.previousElementSibling;
      }

      return []
    },
    // TODO: this is now unused; remove later along with prev()
    next(element, selector) {
      let next = element.nextElementSibling;

      while (next) {
        if (next.matches(selector)) {
          return [next]
        }

        next = next.nextElementSibling;
      }

      return []
    },

    focusableChildren(element) {
      const focusables = [
        'a',
        'button',
        'input',
        'textarea',
        'select',
        'details',
        '[tabindex]',
        '[contenteditable="true"]'
      ].map(selector => `${selector}:not([tabindex^="-"])`).join(',');

      return this.find(focusables, element).filter(el => !isDisabled(el) && isVisible(el))
    },

    getSelectorFromElement(element) {
      const selector = getSelector(element);

      if (selector) {
        return SelectorEngine.findOne(selector) ? selector : null
      }

      return null
    },

    getElementFromSelector(element) {
      const selector = getSelector(element);

      return selector ? SelectorEngine.findOne(selector) : null
    },

    getMultipleElementsFromSelector(element) {
      const selector = getSelector(element);

      return selector ? SelectorEngine.find(selector) : []
    }
  };

  /**
   * --------------------------------------------------------------------------
   * Bootstrap util/template-factory.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */

  /**
   * Constants
   */

  const NAME$1 = 'TemplateFactory';

  const Default$1 = {
    allowList: DefaultAllowlist,
    content: {}, // { selector : text ,  selector2 : text2 , }
    extraClass: '',
    html: false,
    sanitize: true,
    sanitizeFn: null,
    template: '<div></div>'
  };

  const DefaultType$1 = {
    allowList: 'object',
    content: 'object',
    extraClass: '(string|function)',
    html: 'boolean',
    sanitize: 'boolean',
    sanitizeFn: '(null|function)',
    template: 'string'
  };

  const DefaultContentType = {
    entry: '(string|element|function|null)',
    selector: '(string|element)'
  };

  /**
   * Class definition
   */

  class TemplateFactory extends Config {
    constructor(config) {
      super();
      this._config = this._getConfig(config);
    }

    // Getters
    static get Default() {
      return Default$1
    }

    static get DefaultType() {
      return DefaultType$1
    }

    static get NAME() {
      return NAME$1
    }

    // Public
    getContent() {
      return Object.values(this._config.content)
        .map(config => this._resolvePossibleFunction(config))
        .filter(Boolean)
    }

    hasContent() {
      return this.getContent().length > 0
    }

    changeContent(content) {
      this._checkContent(content);
      this._config.content = { ...this._config.content, ...content };
      return this
    }

    toHtml() {
      const templateWrapper = document.createElement('div');
      templateWrapper.innerHTML = this._maybeSanitize(this._config.template);

      for (const [selector, text] of Object.entries(this._config.content)) {
        this._setContent(templateWrapper, text, selector);
      }

      const template = templateWrapper.children[0];
      const extraClass = this._resolvePossibleFunction(this._config.extraClass);

      if (extraClass) {
        template.classList.add(...extraClass.split(' '));
      }

      return template
    }

    // Private
    _typeCheckConfig(config) {
      super._typeCheckConfig(config);
      this._checkContent(config.content);
    }

    _checkContent(arg) {
      for (const [selector, content] of Object.entries(arg)) {
        super._typeCheckConfig({ selector, entry: content }, DefaultContentType);
      }
    }

    _setContent(template, content, selector) {
      const templateElement = SelectorEngine.findOne(selector, template);

      if (!templateElement) {
        return
      }

      content = this._resolvePossibleFunction(content);

      if (!content) {
        templateElement.remove();
        return
      }

      if (isElement(content)) {
        this._putElementInTemplate(getElement(content), templateElement);
        return
      }

      if (this._config.html) {
        templateElement.innerHTML = this._maybeSanitize(content);
        return
      }

      templateElement.textContent = content;
    }

    _maybeSanitize(arg) {
      return this._config.sanitize ? sanitizeHtml(arg, this._config.allowList, this._config.sanitizeFn) : arg
    }

    _resolvePossibleFunction(arg) {
      return execute(arg, [this])
    }

    _putElementInTemplate(element, templateElement) {
      if (this._config.html) {
        templateElement.innerHTML = '';
        templateElement.append(element);
        return
      }

      templateElement.textContent = element.textContent;
    }
  }

  /**
   * --------------------------------------------------------------------------
   * Bootstrap tooltip.js
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
   * --------------------------------------------------------------------------
   */

  /**
   * Constants
   */

  const NAME = 'tooltip';
  const DISALLOWED_ATTRIBUTES = new Set(['sanitize', 'allowList', 'sanitizeFn']);

  const CLASS_NAME_FADE = 'fade';
  const CLASS_NAME_MODAL = 'modal';
  const CLASS_NAME_SHOW = 'show';

  const SELECTOR_TOOLTIP_INNER = '.tooltip-inner';
  const SELECTOR_MODAL = `.${CLASS_NAME_MODAL}`;

  const EVENT_MODAL_HIDE = 'hide.bs.modal';

  const TRIGGER_HOVER = 'hover';
  const TRIGGER_FOCUS = 'focus';
  const TRIGGER_CLICK = 'click';
  const TRIGGER_MANUAL = 'manual';

  const EVENT_HIDE = 'hide';
  const EVENT_HIDDEN = 'hidden';
  const EVENT_SHOW = 'show';
  const EVENT_SHOWN = 'shown';
  const EVENT_INSERTED = 'inserted';
  const EVENT_CLICK = 'click';
  const EVENT_FOCUSIN = 'focusin';
  const EVENT_FOCUSOUT = 'focusout';
  const EVENT_MOUSEENTER = 'mouseenter';
  const EVENT_MOUSELEAVE = 'mouseleave';

  const AttachmentMap = {
    AUTO: 'auto',
    TOP: 'top',
    RIGHT: isRTL() ? 'left' : 'right',
    BOTTOM: 'bottom',
    LEFT: isRTL() ? 'right' : 'left'
  };

  const Default = {
    allowList: DefaultAllowlist,
    animation: true,
    boundary: 'clippingParents',
    container: false,
    customClass: '',
    delay: 0,
    fallbackPlacements: ['top', 'right', 'bottom', 'left'],
    html: false,
    offset: [0, 6],
    placement: 'top',
    popperConfig: null,
    sanitize: true,
    sanitizeFn: null,
    selector: false,
    template: '<div class="tooltip" role="tooltip">' +
              '<div class="tooltip-arrow"></div>' +
              '<div class="tooltip-inner"></div>' +
              '</div>',
    title: '',
    trigger: 'hover focus'
  };

  const DefaultType = {
    allowList: 'object',
    animation: 'boolean',
    boundary: '(string|element)',
    container: '(string|element|boolean)',
    customClass: '(string|function)',
    delay: '(number|object)',
    fallbackPlacements: 'array',
    html: 'boolean',
    offset: '(array|string|function)',
    placement: '(string|function)',
    popperConfig: '(null|object|function)',
    sanitize: 'boolean',
    sanitizeFn: '(null|function)',
    selector: '(string|boolean)',
    template: 'string',
    title: '(string|element|function)',
    trigger: 'string'
  };

  /**
   * Class definition
   */

  class Tooltip extends BaseComponent {
    constructor(element, config) {
      if (typeof Popper === 'undefined') {
        throw new TypeError('Bootstrap\'s tooltips require Popper (https://popper.js.org)')
      }

      super(element, config);

      // Private
      this._isEnabled = true;
      this._timeout = 0;
      this._isHovered = null;
      this._activeTrigger = {};
      this._popper = null;
      this._templateFactory = null;
      this._newContent = null;

      // Protected
      this.tip = null;

      this._setListeners();

      if (!this._config.selector) {
        this._fixTitle();
      }
    }

    // Getters
    static get Default() {
      return Default
    }

    static get DefaultType() {
      return DefaultType
    }

    static get NAME() {
      return NAME
    }

    // Public
    enable() {
      this._isEnabled = true;
    }

    disable() {
      this._isEnabled = false;
    }

    toggleEnabled() {
      this._isEnabled = !this._isEnabled;
    }

    toggle() {
      if (!this._isEnabled) {
        return
      }

      this._activeTrigger.click = !this._activeTrigger.click;
      if (this._isShown()) {
        this._leave();
        return
      }

      this._enter();
    }

    dispose() {
      clearTimeout(this._timeout);

      EventHandler.off(this._element.closest(SELECTOR_MODAL), EVENT_MODAL_HIDE, this._hideModalHandler);

      if (this._element.getAttribute('data-bs-original-title')) {
        this._element.setAttribute('title', this._element.getAttribute('data-bs-original-title'));
      }

      this._disposePopper();
      super.dispose();
    }

    show() {
      if (this._element.style.display === 'none') {
        throw new Error('Please use show on visible elements')
      }

      if (!(this._isWithContent() && this._isEnabled)) {
        return
      }

      const showEvent = EventHandler.trigger(this._element, this.constructor.eventName(EVENT_SHOW));
      const shadowRoot = findShadowRoot(this._element);
      const isInTheDom = (shadowRoot || this._element.ownerDocument.documentElement).contains(this._element);

      if (showEvent.defaultPrevented || !isInTheDom) {
        return
      }

      // TODO: v6 remove this or make it optional
      this._disposePopper();

      const tip = this._getTipElement();

      this._element.setAttribute('aria-describedby', tip.getAttribute('id'));

      const { container } = this._config;

      if (!this._element.ownerDocument.documentElement.contains(this.tip)) {
        container.append(tip);
        EventHandler.trigger(this._element, this.constructor.eventName(EVENT_INSERTED));
      }

      this._popper = this._createPopper(tip);

      tip.classList.add(CLASS_NAME_SHOW);

      // If this is a touch-enabled device we add extra
      // empty mouseover listeners to the body's immediate children;
      // only needed because of broken event delegation on iOS
      // https://www.quirksmode.org/blog/archives/2014/02/mouse_event_bub.html
      if ('ontouchstart' in document.documentElement) {
        for (const element of [].concat(...document.body.children)) {
          EventHandler.on(element, 'mouseover', noop);
        }
      }

      const complete = () => {
        EventHandler.trigger(this._element, this.constructor.eventName(EVENT_SHOWN));

        if (this._isHovered === false) {
          this._leave();
        }

        this._isHovered = false;
      };

      this._queueCallback(complete, this.tip, this._isAnimated());
    }

    hide() {
      if (!this._isShown()) {
        return
      }

      const hideEvent = EventHandler.trigger(this._element, this.constructor.eventName(EVENT_HIDE));
      if (hideEvent.defaultPrevented) {
        return
      }

      const tip = this._getTipElement();
      tip.classList.remove(CLASS_NAME_SHOW);

      // If this is a touch-enabled device we remove the extra
      // empty mouseover listeners we added for iOS support
      if ('ontouchstart' in document.documentElement) {
        for (const element of [].concat(...document.body.children)) {
          EventHandler.off(element, 'mouseover', noop);
        }
      }

      this._activeTrigger[TRIGGER_CLICK] = false;
      this._activeTrigger[TRIGGER_FOCUS] = false;
      this._activeTrigger[TRIGGER_HOVER] = false;
      this._isHovered = null; // it is a trick to support manual triggering

      const complete = () => {
        if (this._isWithActiveTrigger()) {
          return
        }

        if (!this._isHovered) {
          this._disposePopper();
        }

        this._element.removeAttribute('aria-describedby');
        EventHandler.trigger(this._element, this.constructor.eventName(EVENT_HIDDEN));
      };

      this._queueCallback(complete, this.tip, this._isAnimated());
    }

    update() {
      if (this._popper) {
        this._popper.update();
      }
    }

    // Protected
    _isWithContent() {
      return Boolean(this._getTitle())
    }

    _getTipElement() {
      if (!this.tip) {
        this.tip = this._createTipElement(this._newContent || this._getContentForTemplate());
      }

      return this.tip
    }

    _createTipElement(content) {
      const tip = this._getTemplateFactory(content).toHtml();

      // TODO: remove this check in v6
      if (!tip) {
        return null
      }

      tip.classList.remove(CLASS_NAME_FADE, CLASS_NAME_SHOW);
      // TODO: v6 the following can be achieved with CSS only
      tip.classList.add(`bs-${this.constructor.NAME}-auto`);

      const tipId = getUID(this.constructor.NAME).toString();

      tip.setAttribute('id', tipId);

      if (this._isAnimated()) {
        tip.classList.add(CLASS_NAME_FADE);
      }

      return tip
    }

    setContent(content) {
      this._newContent = content;
      if (this._isShown()) {
        this._disposePopper();
        this.show();
      }
    }

    _getTemplateFactory(content) {
      if (this._templateFactory) {
        this._templateFactory.changeContent(content);
      } else {
        this._templateFactory = new TemplateFactory({
          ...this._config,
          // the `content` var has to be after `this._config`
          // to override config.content in case of popover
          content,
          extraClass: this._resolvePossibleFunction(this._config.customClass)
        });
      }

      return this._templateFactory
    }

    _getContentForTemplate() {
      return {
        [SELECTOR_TOOLTIP_INNER]: this._getTitle()
      }
    }

    _getTitle() {
      return this._resolvePossibleFunction(this._config.title) || this._element.getAttribute('data-bs-original-title')
    }

    // Private
    _initializeOnDelegatedTarget(event) {
      return this.constructor.getOrCreateInstance(event.delegateTarget, this._getDelegateConfig())
    }

    _isAnimated() {
      return this._config.animation || (this.tip && this.tip.classList.contains(CLASS_NAME_FADE))
    }

    _isShown() {
      return this.tip && this.tip.classList.contains(CLASS_NAME_SHOW)
    }

    _createPopper(tip) {
      const placement = execute(this._config.placement, [this, tip, this._element]);
      const attachment = AttachmentMap[placement.toUpperCase()];
      return createPopper(this._element, tip, this._getPopperConfig(attachment))
    }

    _getOffset() {
      const { offset } = this._config;

      if (typeof offset === 'string') {
        return offset.split(',').map(value => Number.parseInt(value, 10))
      }

      if (typeof offset === 'function') {
        return popperData => offset(popperData, this._element)
      }

      return offset
    }

    _resolvePossibleFunction(arg) {
      return execute(arg, [this._element])
    }

    _getPopperConfig(attachment) {
      const defaultBsPopperConfig = {
        placement: attachment,
        modifiers: [
          {
            name: 'flip',
            options: {
              fallbackPlacements: this._config.fallbackPlacements
            }
          },
          {
            name: 'offset',
            options: {
              offset: this._getOffset()
            }
          },
          {
            name: 'preventOverflow',
            options: {
              boundary: this._config.boundary
            }
          },
          {
            name: 'arrow',
            options: {
              element: `.${this.constructor.NAME}-arrow`
            }
          },
          {
            name: 'preSetPlacement',
            enabled: true,
            phase: 'beforeMain',
            fn: data => {
              // Pre-set Popper's placement attribute in order to read the arrow sizes properly.
              // Otherwise, Popper mixes up the width and height dimensions since the initial arrow style is for top placement
              this._getTipElement().setAttribute('data-popper-placement', data.state.placement);
            }
          }
        ]
      };

      return {
        ...defaultBsPopperConfig,
        ...execute(this._config.popperConfig, [defaultBsPopperConfig])
      }
    }

    _setListeners() {
      const triggers = this._config.trigger.split(' ');

      for (const trigger of triggers) {
        if (trigger === 'click') {
          EventHandler.on(this._element, this.constructor.eventName(EVENT_CLICK), this._config.selector, event => {
            const context = this._initializeOnDelegatedTarget(event);
            context.toggle();
          });
        } else if (trigger !== TRIGGER_MANUAL) {
          const eventIn = trigger === TRIGGER_HOVER ?
            this.constructor.eventName(EVENT_MOUSEENTER) :
            this.constructor.eventName(EVENT_FOCUSIN);
          const eventOut = trigger === TRIGGER_HOVER ?
            this.constructor.eventName(EVENT_MOUSELEAVE) :
            this.constructor.eventName(EVENT_FOCUSOUT);

          EventHandler.on(this._element, eventIn, this._config.selector, event => {
            const context = this._initializeOnDelegatedTarget(event);
            context._activeTrigger[event.type === 'focusin' ? TRIGGER_FOCUS : TRIGGER_HOVER] = true;
            context._enter();
          });
          EventHandler.on(this._element, eventOut, this._config.selector, event => {
            const context = this._initializeOnDelegatedTarget(event);
            context._activeTrigger[event.type === 'focusout' ? TRIGGER_FOCUS : TRIGGER_HOVER] =
              context._element.contains(event.relatedTarget);

            context._leave();
          });
        }
      }

      this._hideModalHandler = () => {
        if (this._element) {
          this.hide();
        }
      };

      EventHandler.on(this._element.closest(SELECTOR_MODAL), EVENT_MODAL_HIDE, this._hideModalHandler);
    }

    _fixTitle() {
      const title = this._element.getAttribute('title');

      if (!title) {
        return
      }

      if (!this._element.getAttribute('aria-label') && !this._element.textContent.trim()) {
        this._element.setAttribute('aria-label', title);
      }

      this._element.setAttribute('data-bs-original-title', title); // DO NOT USE IT. Is only for backwards compatibility
      this._element.removeAttribute('title');
    }

    _enter() {
      if (this._isShown() || this._isHovered) {
        this._isHovered = true;
        return
      }

      this._isHovered = true;

      this._setTimeout(() => {
        if (this._isHovered) {
          this.show();
        }
      }, this._config.delay.show);
    }

    _leave() {
      if (this._isWithActiveTrigger()) {
        return
      }

      this._isHovered = false;

      this._setTimeout(() => {
        if (!this._isHovered) {
          this.hide();
        }
      }, this._config.delay.hide);
    }

    _setTimeout(handler, timeout) {
      clearTimeout(this._timeout);
      this._timeout = setTimeout(handler, timeout);
    }

    _isWithActiveTrigger() {
      return Object.values(this._activeTrigger).includes(true)
    }

    _getConfig(config) {
      const dataAttributes = Manipulator.getDataAttributes(this._element);

      for (const dataAttribute of Object.keys(dataAttributes)) {
        if (DISALLOWED_ATTRIBUTES.has(dataAttribute)) {
          delete dataAttributes[dataAttribute];
        }
      }

      config = {
        ...dataAttributes,
        ...(typeof config === 'object' && config ? config : {})
      };
      config = this._mergeConfigObj(config);
      config = this._configAfterMerge(config);
      this._typeCheckConfig(config);
      return config
    }

    _configAfterMerge(config) {
      config.container = config.container === false ? document.body : getElement(config.container);

      if (typeof config.delay === 'number') {
        config.delay = {
          show: config.delay,
          hide: config.delay
        };
      }

      if (typeof config.title === 'number') {
        config.title = config.title.toString();
      }

      if (typeof config.content === 'number') {
        config.content = config.content.toString();
      }

      return config
    }

    _getDelegateConfig() {
      const config = {};

      for (const [key, value] of Object.entries(this._config)) {
        if (this.constructor.Default[key] !== value) {
          config[key] = value;
        }
      }

      config.selector = false;
      config.trigger = 'manual';

      // In the future can be replaced with:
      // const keysWithDifferentValues = Object.entries(this._config).filter(entry => this.constructor.Default[entry[0]] !== this._config[entry[0]])
      // `Object.fromEntries(keysWithDifferentValues)`
      return config
    }

    _disposePopper() {
      if (this._popper) {
        this._popper.destroy();
        this._popper = null;
      }

      if (this.tip) {
        this.tip.remove();
        this.tip = null;
      }
    }

    // Static
    static jQueryInterface(config) {
      return this.each(function () {
        const data = Tooltip.getOrCreateInstance(this, config);

        if (typeof config !== 'string') {
          return
        }

        if (typeof data[config] === 'undefined') {
          throw new TypeError(`No method named "${config}"`)
        }

        data[config]();
      })
    }
  }

  /**
   * jQuery
   */

  defineJQueryPlugin(Tooltip);

  /**
   * @license
   * Copyright 2019 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  const NODE_MODE$1 = false;
  // Allows minifiers to rename references to globalThis
  const global$4 = globalThis;
  /**
   * Whether the current browser supports `adoptedStyleSheets`.
   */
  const supportsAdoptingStyleSheets$1 = global$4.ShadowRoot &&
      (global$4.ShadyCSS === undefined || global$4.ShadyCSS.nativeShadow) &&
      'adoptedStyleSheets' in Document.prototype &&
      'replace' in CSSStyleSheet.prototype;
  const constructionToken$1 = Symbol();
  const cssTagCache$1 = new WeakMap();
  /**
   * A container for a string of CSS text, that may be used to create a CSSStyleSheet.
   *
   * CSSResult is the return value of `css`-tagged template literals and
   * `unsafeCSS()`. In order to ensure that CSSResults are only created via the
   * `css` tag and `unsafeCSS()`, CSSResult cannot be constructed directly.
   */
  class CSSResult$1 {
      constructor(cssText, strings, safeToken) {
          // This property needs to remain unminified.
          this['_$cssResult$'] = true;
          if (safeToken !== constructionToken$1) {
              throw new Error('CSSResult is not constructable. Use `unsafeCSS` or `css` instead.');
          }
          this.cssText = cssText;
          this._strings = strings;
      }
      // This is a getter so that it's lazy. In practice, this means stylesheets
      // are not created until the first element instance is made.
      get styleSheet() {
          // If `supportsAdoptingStyleSheets` is true then we assume CSSStyleSheet is
          // constructable.
          let styleSheet = this._styleSheet;
          const strings = this._strings;
          if (supportsAdoptingStyleSheets$1 && styleSheet === undefined) {
              const cacheable = strings !== undefined && strings.length === 1;
              if (cacheable) {
                  styleSheet = cssTagCache$1.get(strings);
              }
              if (styleSheet === undefined) {
                  (this._styleSheet = styleSheet = new CSSStyleSheet()).replaceSync(this.cssText);
                  if (cacheable) {
                      cssTagCache$1.set(strings, styleSheet);
                  }
              }
          }
          return styleSheet;
      }
      toString() {
          return this.cssText;
      }
  }
  /**
   * Wrap a value for interpolation in a {@linkcode css} tagged template literal.
   *
   * This is unsafe because untrusted CSS text can be used to phone home
   * or exfiltrate data to an attacker controlled site. Take care to only use
   * this with trusted input.
   */
  const unsafeCSS$1 = (value) => new CSSResult$1(typeof value === 'string' ? value : String(value), undefined, constructionToken$1);
  /**
   * Applies the given styles to a `shadowRoot`. When Shadow DOM is
   * available but `adoptedStyleSheets` is not, styles are appended to the
   * `shadowRoot` to [mimic spec behavior](https://wicg.github.io/construct-stylesheets/#using-constructed-stylesheets).
   * Note, when shimming is used, any styles that are subsequently placed into
   * the shadowRoot should be placed *before* any shimmed adopted styles. This
   * will match spec behavior that gives adopted sheets precedence over styles in
   * shadowRoot.
   */
  const adoptStyles$1 = (renderRoot, styles) => {
      if (supportsAdoptingStyleSheets$1) {
          renderRoot.adoptedStyleSheets = styles.map((s) => s instanceof CSSStyleSheet ? s : s.styleSheet);
      }
      else {
          for (const s of styles) {
              const style = document.createElement('style');
              // eslint-disable-next-line @typescript-eslint/no-explicit-any
              const nonce = global$4['litNonce'];
              if (nonce !== undefined) {
                  style.setAttribute('nonce', nonce);
              }
              style.textContent = s.cssText;
              renderRoot.appendChild(style);
          }
      }
  };
  const cssResultFromStyleSheet$1 = (sheet) => {
      let cssText = '';
      for (const rule of sheet.cssRules) {
          cssText += rule.cssText;
      }
      return unsafeCSS$1(cssText);
  };
  const getCompatibleStyle$1 = supportsAdoptingStyleSheets$1 ||
      (NODE_MODE$1 )
      ? (s) => s
      : (s) => s instanceof CSSStyleSheet ? cssResultFromStyleSheet$1(s) : s;

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  // TODO (justinfagnani): Add `hasOwn` here when we ship ES2022
  const { is: is$1, defineProperty: defineProperty$1, getOwnPropertyDescriptor: getOwnPropertyDescriptor$1, getOwnPropertyNames: getOwnPropertyNames$1, getOwnPropertySymbols: getOwnPropertySymbols$1, getPrototypeOf: getPrototypeOf$1, } = Object;
  // Lets a minifier replace globalThis references with a minified name
  const global$3 = globalThis;
  let issueWarning$4;
  const trustedTypes$2 = global$3
      .trustedTypes;
  // Temporary workaround for https://crbug.com/993268
  // Currently, any attribute starting with "on" is considered to be a
  // TrustedScript source. Such boolean attributes must be set to the equivalent
  // trusted emptyScript value.
  const emptyStringForBooleanAttribute$1 = trustedTypes$2
      ? trustedTypes$2.emptyScript
      : '';
  const polyfillSupport$3 = global$3.reactiveElementPolyfillSupportDevMode
      ;
  {
      // Ensure warnings are issued only 1x, even if multiple versions of Lit
      // are loaded.
      const issuedWarnings = (global$3.litIssuedWarnings ??=
          new Set());
      // Issue a warning, if we haven't already.
      issueWarning$4 = (code, warning) => {
          warning += ` See https://lit.dev/msg/${code} for more information.`;
          if (!issuedWarnings.has(warning)) {
              console.warn(warning);
              issuedWarnings.add(warning);
          }
      };
      issueWarning$4('dev-mode', `Lit is in dev mode. Not recommended for production!`);
      // Issue polyfill support warning.
      if (global$3.ShadyDOM?.inUse && polyfillSupport$3 === undefined) {
          issueWarning$4('polyfill-support-missing', `Shadow DOM is being polyfilled via \`ShadyDOM\` but ` +
              `the \`polyfill-support\` module has not been loaded.`);
      }
  }
  /**
   * Useful for visualizing and logging insights into what the Lit template system is doing.
   *
   * Compiled out of prod mode builds.
   */
  const debugLogEvent$2 = (event) => {
          const shouldEmit = global$3
              .emitLitDebugLogEvents;
          if (!shouldEmit) {
              return;
          }
          global$3.dispatchEvent(new CustomEvent('lit-debug', {
              detail: event,
          }));
      }
      ;
  /*
   * When using Closure Compiler, JSCompiler_renameProperty(property, object) is
   * replaced at compile time by the munged name for object[property]. We cannot
   * alias this function, so we have to use a small shim that has the same
   * behavior when not compiling.
   */
  /*@__INLINE__*/
  const JSCompiler_renameProperty$2 = (prop, _obj) => prop;
  const defaultConverter$1 = {
      toAttribute(value, type) {
          switch (type) {
              case Boolean:
                  value = value ? emptyStringForBooleanAttribute$1 : null;
                  break;
              case Object:
              case Array:
                  // if the value is `null` or `undefined` pass this through
                  // to allow removing/no change behavior.
                  value = value == null ? value : JSON.stringify(value);
                  break;
          }
          return value;
      },
      fromAttribute(value, type) {
          let fromValue = value;
          switch (type) {
              case Boolean:
                  fromValue = value !== null;
                  break;
              case Number:
                  fromValue = value === null ? null : Number(value);
                  break;
              case Object:
              case Array:
                  // Do *not* generate exception when invalid JSON is set as elements
                  // don't normally complain on being mis-configured.
                  // TODO(sorvell): Do generate exception in *dev mode*.
                  try {
                      // Assert to adhere to Bazel's "must type assert JSON parse" rule.
                      fromValue = JSON.parse(value);
                  }
                  catch (e) {
                      fromValue = null;
                  }
                  break;
          }
          return fromValue;
      },
  };
  /**
   * Change function that returns true if `value` is different from `oldValue`.
   * This method is used as the default for a property's `hasChanged` function.
   */
  const notEqual$1 = (value, old) => !is$1(value, old);
  const defaultPropertyDeclaration$2 = {
      attribute: true,
      type: String,
      converter: defaultConverter$1,
      reflect: false,
      hasChanged: notEqual$1,
  };
  // Ensure metadata is enabled. TypeScript does not polyfill
  // Symbol.metadata, so we must ensure that it exists.
  Symbol.metadata ??= Symbol('metadata');
  // Map from a class's metadata object to property options
  // Note that we must use nullish-coalescing assignment so that we only use one
  // map even if we load multiple version of this module.
  global$3.litPropertyMetadata ??= new WeakMap();
  /**
   * Base element class which manages element properties and attributes. When
   * properties change, the `update` method is asynchronously called. This method
   * should be supplied by subclasses to render updates as desired.
   * @noInheritDoc
   */
  class ReactiveElement$1
  // In the Node build, this `extends` clause will be substituted with
  // `(globalThis.HTMLElement ?? HTMLElement)`.
  //
  // This way, we will first prefer any global `HTMLElement` polyfill that the
  // user has assigned, and then fall back to the `HTMLElement` shim which has
  // been imported (see note at the top of this file about how this import is
  // generated by Rollup). Note that the `HTMLElement` variable has been
  // shadowed by this import, so it no longer refers to the global.
   extends HTMLElement {
      /**
       * Adds an initializer function to the class that is called during instance
       * construction.
       *
       * This is useful for code that runs against a `ReactiveElement`
       * subclass, such as a decorator, that needs to do work for each
       * instance, such as setting up a `ReactiveController`.
       *
       * ```ts
       * const myDecorator = (target: typeof ReactiveElement, key: string) => {
       *   target.addInitializer((instance: ReactiveElement) => {
       *     // This is run during construction of the element
       *     new MyController(instance);
       *   });
       * }
       * ```
       *
       * Decorating a field will then cause each instance to run an initializer
       * that adds a controller:
       *
       * ```ts
       * class MyElement extends LitElement {
       *   @myDecorator foo;
       * }
       * ```
       *
       * Initializers are stored per-constructor. Adding an initializer to a
       * subclass does not add it to a superclass. Since initializers are run in
       * constructors, initializers will run in order of the class hierarchy,
       * starting with superclasses and progressing to the instance's class.
       *
       * @nocollapse
       */
      static addInitializer(initializer) {
          this.__prepare();
          (this._initializers ??= []).push(initializer);
      }
      /**
       * Returns a list of attributes corresponding to the registered properties.
       * @nocollapse
       * @category attributes
       */
      static get observedAttributes() {
          // Ensure we've created all properties
          this.finalize();
          // this.__attributeToPropertyMap is only undefined after finalize() in
          // ReactiveElement itself. ReactiveElement.observedAttributes is only
          // accessed with ReactiveElement as the receiver when a subclass or mixin
          // calls super.observedAttributes
          return (this.__attributeToPropertyMap && [...this.__attributeToPropertyMap.keys()]);
      }
      /**
       * Creates a property accessor on the element prototype if one does not exist
       * and stores a {@linkcode PropertyDeclaration} for the property with the
       * given options. The property setter calls the property's `hasChanged`
       * property option or uses a strict identity check to determine whether or not
       * to request an update.
       *
       * This method may be overridden to customize properties; however,
       * when doing so, it's important to call `super.createProperty` to ensure
       * the property is setup correctly. This method calls
       * `getPropertyDescriptor` internally to get a descriptor to install.
       * To customize what properties do when they are get or set, override
       * `getPropertyDescriptor`. To customize the options for a property,
       * implement `createProperty` like this:
       *
       * ```ts
       * static createProperty(name, options) {
       *   options = Object.assign(options, {myOption: true});
       *   super.createProperty(name, options);
       * }
       * ```
       *
       * @nocollapse
       * @category properties
       */
      static createProperty(name, options = defaultPropertyDeclaration$2) {
          // If this is a state property, force the attribute to false.
          if (options.state) {
              options.attribute = false;
          }
          this.__prepare();
          this.elementProperties.set(name, options);
          if (!options.noAccessor) {
              const key = // Use Symbol.for in dev mode to make it easier to maintain state
                      // when doing HMR.
                      Symbol.for(`${String(name)} (@property() cache)`)
                  ;
              const descriptor = this.getPropertyDescriptor(name, key, options);
              if (descriptor !== undefined) {
                  defineProperty$1(this.prototype, name, descriptor);
              }
          }
      }
      /**
       * Returns a property descriptor to be defined on the given named property.
       * If no descriptor is returned, the property will not become an accessor.
       * For example,
       *
       * ```ts
       * class MyElement extends LitElement {
       *   static getPropertyDescriptor(name, key, options) {
       *     const defaultDescriptor =
       *         super.getPropertyDescriptor(name, key, options);
       *     const setter = defaultDescriptor.set;
       *     return {
       *       get: defaultDescriptor.get,
       *       set(value) {
       *         setter.call(this, value);
       *         // custom action.
       *       },
       *       configurable: true,
       *       enumerable: true
       *     }
       *   }
       * }
       * ```
       *
       * @nocollapse
       * @category properties
       */
      static getPropertyDescriptor(name, key, options) {
          const { get, set } = getOwnPropertyDescriptor$1(this.prototype, name) ?? {
              get() {
                  return this[key];
              },
              set(v) {
                  this[key] = v;
              },
          };
          if (get == null) {
              if ('value' in (getOwnPropertyDescriptor$1(this.prototype, name) ?? {})) {
                  throw new Error(`Field ${JSON.stringify(String(name))} on ` +
                      `${this.name} was declared as a reactive property ` +
                      `but it's actually declared as a value on the prototype. ` +
                      `Usually this is due to using @property or @state on a method.`);
              }
              issueWarning$4('reactive-property-without-getter', `Field ${JSON.stringify(String(name))} on ` +
                  `${this.name} was declared as a reactive property ` +
                  `but it does not have a getter. This will be an error in a ` +
                  `future version of Lit.`);
          }
          return {
              get() {
                  return get?.call(this);
              },
              set(value) {
                  const oldValue = get?.call(this);
                  set.call(this, value);
                  this.requestUpdate(name, oldValue, options);
              },
              configurable: true,
              enumerable: true,
          };
      }
      /**
       * Returns the property options associated with the given property.
       * These options are defined with a `PropertyDeclaration` via the `properties`
       * object or the `@property` decorator and are registered in
       * `createProperty(...)`.
       *
       * Note, this method should be considered "final" and not overridden. To
       * customize the options for a given property, override
       * {@linkcode createProperty}.
       *
       * @nocollapse
       * @final
       * @category properties
       */
      static getPropertyOptions(name) {
          return this.elementProperties.get(name) ?? defaultPropertyDeclaration$2;
      }
      /**
       * Initializes static own properties of the class used in bookkeeping
       * for element properties, initializers, etc.
       *
       * Can be called multiple times by code that needs to ensure these
       * properties exist before using them.
       *
       * This method ensures the superclass is finalized so that inherited
       * property metadata can be copied down.
       * @nocollapse
       */
      static __prepare() {
          if (this.hasOwnProperty(JSCompiler_renameProperty$2('elementProperties'))) {
              // Already prepared
              return;
          }
          // Finalize any superclasses
          const superCtor = getPrototypeOf$1(this);
          superCtor.finalize();
          // Create own set of initializers for this class if any exist on the
          // superclass and copy them down. Note, for a small perf boost, avoid
          // creating initializers unless needed.
          if (superCtor._initializers !== undefined) {
              this._initializers = [...superCtor._initializers];
          }
          // Initialize elementProperties from the superclass
          this.elementProperties = new Map(superCtor.elementProperties);
      }
      /**
       * Finishes setting up the class so that it's ready to be registered
       * as a custom element and instantiated.
       *
       * This method is called by the ReactiveElement.observedAttributes getter.
       * If you override the observedAttributes getter, you must either call
       * super.observedAttributes to trigger finalization, or call finalize()
       * yourself.
       *
       * @nocollapse
       */
      static finalize() {
          if (this.hasOwnProperty(JSCompiler_renameProperty$2('finalized'))) {
              return;
          }
          this.finalized = true;
          this.__prepare();
          // Create properties from the static properties block:
          if (this.hasOwnProperty(JSCompiler_renameProperty$2('properties'))) {
              const props = this.properties;
              const propKeys = [
                  ...getOwnPropertyNames$1(props),
                  ...getOwnPropertySymbols$1(props),
              ];
              for (const p of propKeys) {
                  this.createProperty(p, props[p]);
              }
          }
          // Create properties from standard decorator metadata:
          const metadata = this[Symbol.metadata];
          if (metadata !== null) {
              const properties = litPropertyMetadata.get(metadata);
              if (properties !== undefined) {
                  for (const [p, options] of properties) {
                      this.elementProperties.set(p, options);
                  }
              }
          }
          // Create the attribute-to-property map
          this.__attributeToPropertyMap = new Map();
          for (const [p, options] of this.elementProperties) {
              const attr = this.__attributeNameForProperty(p, options);
              if (attr !== undefined) {
                  this.__attributeToPropertyMap.set(attr, p);
              }
          }
          this.elementStyles = this.finalizeStyles(this.styles);
          {
              if (this.hasOwnProperty('createProperty')) {
                  issueWarning$4('no-override-create-property', 'Overriding ReactiveElement.createProperty() is deprecated. ' +
                      'The override will not be called with standard decorators');
              }
              if (this.hasOwnProperty('getPropertyDescriptor')) {
                  issueWarning$4('no-override-get-property-descriptor', 'Overriding ReactiveElement.getPropertyDescriptor() is deprecated. ' +
                      'The override will not be called with standard decorators');
              }
          }
      }
      /**
       * Takes the styles the user supplied via the `static styles` property and
       * returns the array of styles to apply to the element.
       * Override this method to integrate into a style management system.
       *
       * Styles are deduplicated preserving the _last_ instance in the list. This
       * is a performance optimization to avoid duplicated styles that can occur
       * especially when composing via subclassing. The last item is kept to try
       * to preserve the cascade order with the assumption that it's most important
       * that last added styles override previous styles.
       *
       * @nocollapse
       * @category styles
       */
      static finalizeStyles(styles) {
          const elementStyles = [];
          if (Array.isArray(styles)) {
              // Dedupe the flattened array in reverse order to preserve the last items.
              // Casting to Array<unknown> works around TS error that
              // appears to come from trying to flatten a type CSSResultArray.
              const set = new Set(styles.flat(Infinity).reverse());
              // Then preserve original order by adding the set items in reverse order.
              for (const s of set) {
                  elementStyles.unshift(getCompatibleStyle$1(s));
              }
          }
          else if (styles !== undefined) {
              elementStyles.push(getCompatibleStyle$1(styles));
          }
          return elementStyles;
      }
      /**
       * Returns the property name for the given attribute `name`.
       * @nocollapse
       */
      static __attributeNameForProperty(name, options) {
          const attribute = options.attribute;
          return attribute === false
              ? undefined
              : typeof attribute === 'string'
                  ? attribute
                  : typeof name === 'string'
                      ? name.toLowerCase()
                      : undefined;
      }
      constructor() {
          super();
          this.__instanceProperties = undefined;
          /**
           * True if there is a pending update as a result of calling `requestUpdate()`.
           * Should only be read.
           * @category updates
           */
          this.isUpdatePending = false;
          /**
           * Is set to `true` after the first update. The element code cannot assume
           * that `renderRoot` exists before the element `hasUpdated`.
           * @category updates
           */
          this.hasUpdated = false;
          /**
           * Name of currently reflecting property
           */
          this.__reflectingProperty = null;
          this.__initialize();
      }
      /**
       * Internal only override point for customizing work done when elements
       * are constructed.
       */
      __initialize() {
          this.__updatePromise = new Promise((res) => (this.enableUpdating = res));
          this._$changedProperties = new Map();
          // This enqueues a microtask that ust run before the first update, so it
          // must be called before requestUpdate()
          this.__saveInstanceProperties();
          // ensures first update will be caught by an early access of
          // `updateComplete`
          this.requestUpdate();
          this.constructor._initializers?.forEach((i) => i(this));
      }
      /**
       * Registers a `ReactiveController` to participate in the element's reactive
       * update cycle. The element automatically calls into any registered
       * controllers during its lifecycle callbacks.
       *
       * If the element is connected when `addController()` is called, the
       * controller's `hostConnected()` callback will be immediately called.
       * @category controllers
       */
      addController(controller) {
          (this.__controllers ??= new Set()).add(controller);
          // If a controller is added after the element has been connected,
          // call hostConnected. Note, re-using existence of `renderRoot` here
          // (which is set in connectedCallback) to avoid the need to track a
          // first connected state.
          if (this.renderRoot !== undefined && this.isConnected) {
              controller.hostConnected?.();
          }
      }
      /**
       * Removes a `ReactiveController` from the element.
       * @category controllers
       */
      removeController(controller) {
          this.__controllers?.delete(controller);
      }
      /**
       * Fixes any properties set on the instance before upgrade time.
       * Otherwise these would shadow the accessor and break these properties.
       * The properties are stored in a Map which is played back after the
       * constructor runs. Note, on very old versions of Safari (<=9) or Chrome
       * (<=41), properties created for native platform properties like (`id` or
       * `name`) may not have default values set in the element constructor. On
       * these browsers native properties appear on instances and therefore their
       * default value will overwrite any element default (e.g. if the element sets
       * this.id = 'id' in the constructor, the 'id' will become '' since this is
       * the native platform default).
       */
      __saveInstanceProperties() {
          const instanceProperties = new Map();
          const elementProperties = this.constructor
              .elementProperties;
          for (const p of elementProperties.keys()) {
              if (this.hasOwnProperty(p)) {
                  instanceProperties.set(p, this[p]);
                  delete this[p];
              }
          }
          if (instanceProperties.size > 0) {
              this.__instanceProperties = instanceProperties;
          }
      }
      /**
       * Returns the node into which the element should render and by default
       * creates and returns an open shadowRoot. Implement to customize where the
       * element's DOM is rendered. For example, to render into the element's
       * childNodes, return `this`.
       *
       * @return Returns a node into which to render.
       * @category rendering
       */
      createRenderRoot() {
          const renderRoot = this.shadowRoot ??
              this.attachShadow(this.constructor.shadowRootOptions);
          adoptStyles$1(renderRoot, this.constructor.elementStyles);
          return renderRoot;
      }
      /**
       * On first connection, creates the element's renderRoot, sets up
       * element styling, and enables updating.
       * @category lifecycle
       */
      connectedCallback() {
          // Create renderRoot before controllers `hostConnected`
          this.renderRoot ??=
              this.createRenderRoot();
          this.enableUpdating(true);
          this.__controllers?.forEach((c) => c.hostConnected?.());
      }
      /**
       * Note, this method should be considered final and not overridden. It is
       * overridden on the element instance with a function that triggers the first
       * update.
       * @category updates
       */
      enableUpdating(_requestedUpdate) { }
      /**
       * Allows for `super.disconnectedCallback()` in extensions while
       * reserving the possibility of making non-breaking feature additions
       * when disconnecting at some point in the future.
       * @category lifecycle
       */
      disconnectedCallback() {
          this.__controllers?.forEach((c) => c.hostDisconnected?.());
      }
      /**
       * Synchronizes property values when attributes change.
       *
       * Specifically, when an attribute is set, the corresponding property is set.
       * You should rarely need to implement this callback. If this method is
       * overridden, `super.attributeChangedCallback(name, _old, value)` must be
       * called.
       *
       * See [using the lifecycle callbacks](https://developer.mozilla.org/en-US/docs/Web/Web_Components/Using_custom_elements#using_the_lifecycle_callbacks)
       * on MDN for more information about the `attributeChangedCallback`.
       * @category attributes
       */
      attributeChangedCallback(name, _old, value) {
          this._$attributeToProperty(name, value);
      }
      __propertyToAttribute(name, value) {
          const elemProperties = this.constructor.elementProperties;
          const options = elemProperties.get(name);
          const attr = this.constructor.__attributeNameForProperty(name, options);
          if (attr !== undefined && options.reflect === true) {
              const converter = options.converter?.toAttribute !==
                  undefined
                  ? options.converter
                  : defaultConverter$1;
              const attrValue = converter.toAttribute(value, options.type);
              if (this.constructor.enabledWarnings.includes('migration') &&
                  attrValue === undefined) {
                  issueWarning$4('undefined-attribute-value', `The attribute value for the ${name} property is ` +
                      `undefined on element ${this.localName}. The attribute will be ` +
                      `removed, but in the previous version of \`ReactiveElement\`, ` +
                      `the attribute would not have changed.`);
              }
              // Track if the property is being reflected to avoid
              // setting the property again via `attributeChangedCallback`. Note:
              // 1. this takes advantage of the fact that the callback is synchronous.
              // 2. will behave incorrectly if multiple attributes are in the reaction
              // stack at time of calling. However, since we process attributes
              // in `update` this should not be possible (or an extreme corner case
              // that we'd like to discover).
              // mark state reflecting
              this.__reflectingProperty = name;
              if (attrValue == null) {
                  this.removeAttribute(attr);
              }
              else {
                  this.setAttribute(attr, attrValue);
              }
              // mark state not reflecting
              this.__reflectingProperty = null;
          }
      }
      /** @internal */
      _$attributeToProperty(name, value) {
          const ctor = this.constructor;
          // Note, hint this as an `AttributeMap` so closure clearly understands
          // the type; it has issues with tracking types through statics
          const propName = ctor.__attributeToPropertyMap.get(name);
          // Use tracking info to avoid reflecting a property value to an attribute
          // if it was just set because the attribute changed.
          if (propName !== undefined && this.__reflectingProperty !== propName) {
              const options = ctor.getPropertyOptions(propName);
              const converter = typeof options.converter === 'function'
                  ? { fromAttribute: options.converter }
                  : options.converter?.fromAttribute !== undefined
                      ? options.converter
                      : defaultConverter$1;
              // mark state reflecting
              this.__reflectingProperty = propName;
              this[propName] = converter.fromAttribute(value, options.type
              // eslint-disable-next-line @typescript-eslint/no-explicit-any
              );
              // mark state not reflecting
              this.__reflectingProperty = null;
          }
      }
      /**
       * Requests an update which is processed asynchronously. This should be called
       * when an element should update based on some state not triggered by setting
       * a reactive property. In this case, pass no arguments. It should also be
       * called when manually implementing a property setter. In this case, pass the
       * property `name` and `oldValue` to ensure that any configured property
       * options are honored.
       *
       * @param name name of requesting property
       * @param oldValue old value of requesting property
       * @param options property options to use instead of the previously
       *     configured options
       * @category updates
       */
      requestUpdate(name, oldValue, options) {
          // If we have a property key, perform property update steps.
          if (name !== undefined) {
              if (name instanceof Event) {
                  issueWarning$4(``, `The requestUpdate() method was called with an Event as the property name. This is probably a mistake caused by binding this.requestUpdate as an event listener. Instead bind a function that will call it with no arguments: () => this.requestUpdate()`);
              }
              options ??= this.constructor.getPropertyOptions(name);
              const hasChanged = options.hasChanged ?? notEqual$1;
              const newValue = this[name];
              if (hasChanged(newValue, oldValue)) {
                  this._$changeProperty(name, oldValue, options);
              }
              else {
                  // Abort the request if the property should not be considered changed.
                  return;
              }
          }
          if (this.isUpdatePending === false) {
              this.__updatePromise = this.__enqueueUpdate();
          }
      }
      /**
       * @internal
       */
      _$changeProperty(name, oldValue, options) {
          // TODO (justinfagnani): Create a benchmark of Map.has() + Map.set(
          // vs just Map.set()
          if (!this._$changedProperties.has(name)) {
              this._$changedProperties.set(name, oldValue);
          }
          // Add to reflecting properties set.
          // Note, it's important that every change has a chance to add the
          // property to `__reflectingProperties`. This ensures setting
          // attribute + property reflects correctly.
          if (options.reflect === true && this.__reflectingProperty !== name) {
              (this.__reflectingProperties ??= new Set()).add(name);
          }
      }
      /**
       * Sets up the element to asynchronously update.
       */
      async __enqueueUpdate() {
          this.isUpdatePending = true;
          try {
              // Ensure any previous update has resolved before updating.
              // This `await` also ensures that property changes are batched.
              await this.__updatePromise;
          }
          catch (e) {
              // Refire any previous errors async so they do not disrupt the update
              // cycle. Errors are refired so developers have a chance to observe
              // them, and this can be done by implementing
              // `window.onunhandledrejection`.
              Promise.reject(e);
          }
          const result = this.scheduleUpdate();
          // If `scheduleUpdate` returns a Promise, we await it. This is done to
          // enable coordinating updates with a scheduler. Note, the result is
          // checked to avoid delaying an additional microtask unless we need to.
          if (result != null) {
              await result;
          }
          return !this.isUpdatePending;
      }
      /**
       * Schedules an element update. You can override this method to change the
       * timing of updates by returning a Promise. The update will await the
       * returned Promise, and you should resolve the Promise to allow the update
       * to proceed. If this method is overridden, `super.scheduleUpdate()`
       * must be called.
       *
       * For instance, to schedule updates to occur just before the next frame:
       *
       * ```ts
       * override protected async scheduleUpdate(): Promise<unknown> {
       *   await new Promise((resolve) => requestAnimationFrame(() => resolve()));
       *   super.scheduleUpdate();
       * }
       * ```
       * @category updates
       */
      scheduleUpdate() {
          const result = this.performUpdate();
          if (this.constructor.enabledWarnings.includes('async-perform-update') &&
              typeof result?.then ===
                  'function') {
              issueWarning$4('async-perform-update', `Element ${this.localName} returned a Promise from performUpdate(). ` +
                  `This behavior is deprecated and will be removed in a future ` +
                  `version of ReactiveElement.`);
          }
          return result;
      }
      /**
       * Performs an element update. Note, if an exception is thrown during the
       * update, `firstUpdated` and `updated` will not be called.
       *
       * Call `performUpdate()` to immediately process a pending update. This should
       * generally not be needed, but it can be done in rare cases when you need to
       * update synchronously.
       *
       * @category updates
       */
      performUpdate() {
          // Abort any update if one is not pending when this is called.
          // This can happen if `performUpdate` is called early to "flush"
          // the update.
          if (!this.isUpdatePending) {
              return;
          }
          debugLogEvent$2?.({ kind: 'update' });
          if (!this.hasUpdated) {
              // Create renderRoot before first update. This occurs in `connectedCallback`
              // but is done here to support out of tree calls to `enableUpdating`/`performUpdate`.
              this.renderRoot ??=
                  this.createRenderRoot();
              {
                  // Produce warning if any reactive properties on the prototype are
                  // shadowed by class fields. Instance fields set before upgrade are
                  // deleted by this point, so any own property is caused by class field
                  // initialization in the constructor.
                  const ctor = this.constructor;
                  const shadowedProperties = [...ctor.elementProperties.keys()].filter((p) => this.hasOwnProperty(p) && p in getPrototypeOf$1(this));
                  if (shadowedProperties.length) {
                      throw new Error(`The following properties on element ${this.localName} will not ` +
                          `trigger updates as expected because they are set using class ` +
                          `fields: ${shadowedProperties.join(', ')}. ` +
                          `Native class fields and some compiled output will overwrite ` +
                          `accessors used for detecting changes. See ` +
                          `https://lit.dev/msg/class-field-shadowing ` +
                          `for more information.`);
                  }
              }
              // Mixin instance properties once, if they exist.
              if (this.__instanceProperties) {
                  // TODO (justinfagnani): should we use the stored value? Could a new value
                  // have been set since we stored the own property value?
                  for (const [p, value] of this.__instanceProperties) {
                      this[p] = value;
                  }
                  this.__instanceProperties = undefined;
              }
              // Trigger initial value reflection and populate the initial
              // changedProperties map, but only for the case of experimental
              // decorators on accessors, which will not have already populated the
              // changedProperties map. We can't know if these accessors had
              // initializers, so we just set them anyway - a difference from
              // experimental decorators on fields and standard decorators on
              // auto-accessors.
              // For context why experimentalDecorators with auto accessors are handled
              // specifically also see:
              // https://github.com/lit/lit/pull/4183#issuecomment-1711959635
              const elementProperties = this.constructor
                  .elementProperties;
              if (elementProperties.size > 0) {
                  for (const [p, options] of elementProperties) {
                      if (options.wrapped === true &&
                          !this._$changedProperties.has(p) &&
                          this[p] !== undefined) {
                          this._$changeProperty(p, this[p], options);
                      }
                  }
              }
          }
          let shouldUpdate = false;
          const changedProperties = this._$changedProperties;
          try {
              shouldUpdate = this.shouldUpdate(changedProperties);
              if (shouldUpdate) {
                  this.willUpdate(changedProperties);
                  this.__controllers?.forEach((c) => c.hostUpdate?.());
                  this.update(changedProperties);
              }
              else {
                  this.__markUpdated();
              }
          }
          catch (e) {
              // Prevent `firstUpdated` and `updated` from running when there's an
              // update exception.
              shouldUpdate = false;
              // Ensure element can accept additional updates after an exception.
              this.__markUpdated();
              throw e;
          }
          // The update is no longer considered pending and further updates are now allowed.
          if (shouldUpdate) {
              this._$didUpdate(changedProperties);
          }
      }
      /**
       * Invoked before `update()` to compute values needed during the update.
       *
       * Implement `willUpdate` to compute property values that depend on other
       * properties and are used in the rest of the update process.
       *
       * ```ts
       * willUpdate(changedProperties) {
       *   // only need to check changed properties for an expensive computation.
       *   if (changedProperties.has('firstName') || changedProperties.has('lastName')) {
       *     this.sha = computeSHA(`${this.firstName} ${this.lastName}`);
       *   }
       * }
       *
       * render() {
       *   return html`SHA: ${this.sha}`;
       * }
       * ```
       *
       * @category updates
       */
      willUpdate(_changedProperties) { }
      // Note, this is an override point for polyfill-support.
      // @internal
      _$didUpdate(changedProperties) {
          this.__controllers?.forEach((c) => c.hostUpdated?.());
          if (!this.hasUpdated) {
              this.hasUpdated = true;
              this.firstUpdated(changedProperties);
          }
          this.updated(changedProperties);
          if (this.isUpdatePending &&
              this.constructor.enabledWarnings.includes('change-in-update')) {
              issueWarning$4('change-in-update', `Element ${this.localName} scheduled an update ` +
                  `(generally because a property was set) ` +
                  `after an update completed, causing a new update to be scheduled. ` +
                  `This is inefficient and should be avoided unless the next update ` +
                  `can only be scheduled as a side effect of the previous update.`);
          }
      }
      __markUpdated() {
          this._$changedProperties = new Map();
          this.isUpdatePending = false;
      }
      /**
       * Returns a Promise that resolves when the element has completed updating.
       * The Promise value is a boolean that is `true` if the element completed the
       * update without triggering another update. The Promise result is `false` if
       * a property was set inside `updated()`. If the Promise is rejected, an
       * exception was thrown during the update.
       *
       * To await additional asynchronous work, override the `getUpdateComplete`
       * method. For example, it is sometimes useful to await a rendered element
       * before fulfilling this Promise. To do this, first await
       * `super.getUpdateComplete()`, then any subsequent state.
       *
       * @return A promise of a boolean that resolves to true if the update completed
       *     without triggering another update.
       * @category updates
       */
      get updateComplete() {
          return this.getUpdateComplete();
      }
      /**
       * Override point for the `updateComplete` promise.
       *
       * It is not safe to override the `updateComplete` getter directly due to a
       * limitation in TypeScript which means it is not possible to call a
       * superclass getter (e.g. `super.updateComplete.then(...)`) when the target
       * language is ES5 (https://github.com/microsoft/TypeScript/issues/338).
       * This method should be overridden instead. For example:
       *
       * ```ts
       * class MyElement extends LitElement {
       *   override async getUpdateComplete() {
       *     const result = await super.getUpdateComplete();
       *     await this._myChild.updateComplete;
       *     return result;
       *   }
       * }
       * ```
       *
       * @return A promise of a boolean that resolves to true if the update completed
       *     without triggering another update.
       * @category updates
       */
      getUpdateComplete() {
          return this.__updatePromise;
      }
      /**
       * Controls whether or not `update()` should be called when the element requests
       * an update. By default, this method always returns `true`, but this can be
       * customized to control when to update.
       *
       * @param _changedProperties Map of changed properties with old values
       * @category updates
       */
      shouldUpdate(_changedProperties) {
          return true;
      }
      /**
       * Updates the element. This method reflects property values to attributes.
       * It can be overridden to render and keep updated element DOM.
       * Setting properties inside this method will *not* trigger
       * another update.
       *
       * @param _changedProperties Map of changed properties with old values
       * @category updates
       */
      update(_changedProperties) {
          // The forEach() expression will only run when when __reflectingProperties is
          // defined, and it returns undefined, setting __reflectingProperties to
          // undefined
          this.__reflectingProperties &&= this.__reflectingProperties.forEach((p) => this.__propertyToAttribute(p, this[p]));
          this.__markUpdated();
      }
      /**
       * Invoked whenever the element is updated. Implement to perform
       * post-updating tasks via DOM APIs, for example, focusing an element.
       *
       * Setting properties inside this method will trigger the element to update
       * again after this update cycle completes.
       *
       * @param _changedProperties Map of changed properties with old values
       * @category updates
       */
      updated(_changedProperties) { }
      /**
       * Invoked when the element is first updated. Implement to perform one time
       * work on the element after update.
       *
       * ```ts
       * firstUpdated() {
       *   this.renderRoot.getElementById('my-text-area').focus();
       * }
       * ```
       *
       * Setting properties inside this method will trigger the element to update
       * again after this update cycle completes.
       *
       * @param _changedProperties Map of changed properties with old values
       * @category updates
       */
      firstUpdated(_changedProperties) { }
  }
  /**
   * Memoized list of all element styles.
   * Created lazily on user subclasses when finalizing the class.
   * @nocollapse
   * @category styles
   */
  ReactiveElement$1.elementStyles = [];
  /**
   * Options used when calling `attachShadow`. Set this property to customize
   * the options for the shadowRoot; for example, to create a closed
   * shadowRoot: `{mode: 'closed'}`.
   *
   * Note, these options are used in `createRenderRoot`. If this method
   * is customized, options should be respected if possible.
   * @nocollapse
   * @category rendering
   */
  ReactiveElement$1.shadowRootOptions = { mode: 'open' };
  // Assigned here to work around a jscompiler bug with static fields
  // when compiling to ES5.
  // https://github.com/google/closure-compiler/issues/3177
  ReactiveElement$1[JSCompiler_renameProperty$2('elementProperties')] = new Map();
  ReactiveElement$1[JSCompiler_renameProperty$2('finalized')] = new Map();
  // Apply polyfills if available
  polyfillSupport$3?.({ ReactiveElement: ReactiveElement$1 });
  // Dev mode warnings...
  {
      // Default warning set.
      ReactiveElement$1.enabledWarnings = [
          'change-in-update',
          'async-perform-update',
      ];
      const ensureOwnWarnings = function (ctor) {
          if (!ctor.hasOwnProperty(JSCompiler_renameProperty$2('enabledWarnings'))) {
              ctor.enabledWarnings = ctor.enabledWarnings.slice();
          }
      };
      ReactiveElement$1.enableWarning = function (warning) {
          ensureOwnWarnings(this);
          if (!this.enabledWarnings.includes(warning)) {
              this.enabledWarnings.push(warning);
          }
      };
      ReactiveElement$1.disableWarning = function (warning) {
          ensureOwnWarnings(this);
          const i = this.enabledWarnings.indexOf(warning);
          if (i >= 0) {
              this.enabledWarnings.splice(i, 1);
          }
      };
  }
  // IMPORTANT: do not change the property name or the assignment expression.
  // This line will be used in regexes to search for ReactiveElement usage.
  (global$3.reactiveElementVersions ??= []).push('2.0.4');
  if (global$3.reactiveElementVersions.length > 1) {
      issueWarning$4('multiple-versions', `Multiple versions of Lit loaded. Loading multiple versions ` +
          `is not recommended.`);
  }

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  // Allows minifiers to rename references to globalThis
  const global$2 = globalThis;
  /**
   * Useful for visualizing and logging insights into what the Lit template system is doing.
   *
   * Compiled out of prod mode builds.
   */
  const debugLogEvent$1 = (event) => {
          const shouldEmit = global$2
              .emitLitDebugLogEvents;
          if (!shouldEmit) {
              return;
          }
          global$2.dispatchEvent(new CustomEvent('lit-debug', {
              detail: event,
          }));
      }
      ;
  // Used for connecting beginRender and endRender events when there are nested
  // renders when errors are thrown preventing an endRender event from being
  // called.
  let debugLogRenderId = 0;
  let issueWarning$3;
  {
      global$2.litIssuedWarnings ??= new Set();
      // Issue a warning, if we haven't already.
      issueWarning$3 = (code, warning) => {
          warning += code
              ? ` See https://lit.dev/msg/${code} for more information.`
              : '';
          if (!global$2.litIssuedWarnings.has(warning)) {
              console.warn(warning);
              global$2.litIssuedWarnings.add(warning);
          }
      };
      issueWarning$3('dev-mode', `Lit is in dev mode. Not recommended for production!`);
  }
  const wrap = global$2.ShadyDOM?.inUse &&
      global$2.ShadyDOM?.noPatch === true
      ? global$2.ShadyDOM.wrap
      : (node) => node;
  const trustedTypes$1 = global$2.trustedTypes;
  /**
   * Our TrustedTypePolicy for HTML which is declared using the html template
   * tag function.
   *
   * That HTML is a developer-authored constant, and is parsed with innerHTML
   * before any untrusted expressions have been mixed in. Therefor it is
   * considered safe by construction.
   */
  const policy = trustedTypes$1
      ? trustedTypes$1.createPolicy('lit-html', {
          createHTML: (s) => s,
      })
      : undefined;
  const identityFunction = (value) => value;
  const noopSanitizer = (_node, _name, _type) => identityFunction;
  /** Sets the global sanitizer factory. */
  const setSanitizer = (newSanitizer) => {
      if (sanitizerFactoryInternal !== noopSanitizer) {
          throw new Error(`Attempted to overwrite existing lit-html security policy.` +
              ` setSanitizeDOMValueFactory should be called at most once.`);
      }
      sanitizerFactoryInternal = newSanitizer;
  };
  /**
   * Only used in internal tests, not a part of the public API.
   */
  const _testOnlyClearSanitizerFactoryDoNotCallOrElse = () => {
      sanitizerFactoryInternal = noopSanitizer;
  };
  const createSanitizer = (node, name, type) => {
      return sanitizerFactoryInternal(node, name, type);
  };
  // Added to an attribute name to mark the attribute as bound so we can find
  // it easily.
  const boundAttributeSuffix = '$lit$';
  // This marker is used in many syntactic positions in HTML, so it must be
  // a valid element name and attribute name. We don't support dynamic names (yet)
  // but this at least ensures that the parse tree is closer to the template
  // intention.
  const marker = `lit$${Math.random().toFixed(9).slice(2)}$`;
  // String used to tell if a comment is a marker comment
  const markerMatch = '?' + marker;
  // Text used to insert a comment marker node. We use processing instruction
  // syntax because it's slightly smaller, but parses as a comment node.
  const nodeMarker = `<${markerMatch}>`;
  const d = document;
  // Creates a dynamic marker. We never have to search for these in the DOM.
  const createMarker = () => d.createComment('');
  const isPrimitive = (value) => value === null || (typeof value != 'object' && typeof value != 'function');
  const isArray = Array.isArray;
  const isIterable = (value) => isArray(value) ||
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      typeof value?.[Symbol.iterator] === 'function';
  const SPACE_CHAR = `[ \t\n\f\r]`;
  const ATTR_VALUE_CHAR = `[^ \t\n\f\r"'\`<>=]`;
  const NAME_CHAR = `[^\\s"'>=/]`;
  // These regexes represent the five parsing states that we care about in the
  // Template's HTML scanner. They match the *end* of the state they're named
  // after.
  // Depending on the match, we transition to a new state. If there's no match,
  // we stay in the same state.
  // Note that the regexes are stateful. We utilize lastIndex and sync it
  // across the multiple regexes used. In addition to the five regexes below
  // we also dynamically create a regex to find the matching end tags for raw
  // text elements.
  /**
   * End of text is: `<` followed by:
   *   (comment start) or (tag) or (dynamic tag binding)
   */
  const textEndRegex = /<(?:(!--|\/[^a-zA-Z])|(\/?[a-zA-Z][^>\s]*)|(\/?$))/g;
  const COMMENT_START = 1;
  const TAG_NAME = 2;
  const DYNAMIC_TAG_NAME = 3;
  const commentEndRegex = /-->/g;
  /**
   * Comments not started with <!--, like </{, can be ended by a single `>`
   */
  const comment2EndRegex = />/g;
  /**
   * The tagEnd regex matches the end of the "inside an opening" tag syntax
   * position. It either matches a `>`, an attribute-like sequence, or the end
   * of the string after a space (attribute-name position ending).
   *
   * See attributes in the HTML spec:
   * https://www.w3.org/TR/html5/syntax.html#elements-attributes
   *
   * " \t\n\f\r" are HTML space characters:
   * https://infra.spec.whatwg.org/#ascii-whitespace
   *
   * So an attribute is:
   *  * The name: any character except a whitespace character, ("), ('), ">",
   *    "=", or "/". Note: this is different from the HTML spec which also excludes control characters.
   *  * Followed by zero or more space characters
   *  * Followed by "="
   *  * Followed by zero or more space characters
   *  * Followed by:
   *    * Any character except space, ('), ("), "<", ">", "=", (`), or
   *    * (") then any non-("), or
   *    * (') then any non-(')
   */
  const tagEndRegex = new RegExp(`>|${SPACE_CHAR}(?:(${NAME_CHAR}+)(${SPACE_CHAR}*=${SPACE_CHAR}*(?:${ATTR_VALUE_CHAR}|("|')|))|$)`, 'g');
  const ENTIRE_MATCH = 0;
  const ATTRIBUTE_NAME = 1;
  const SPACES_AND_EQUALS = 2;
  const QUOTE_CHAR = 3;
  const singleQuoteAttrEndRegex = /'/g;
  const doubleQuoteAttrEndRegex = /"/g;
  /**
   * Matches the raw text elements.
   *
   * Comments are not parsed within raw text elements, so we need to search their
   * text content for marker strings.
   */
  const rawTextElement = /^(?:script|style|textarea|title)$/i;
  /** TemplateResult types */
  const HTML_RESULT = 1;
  const SVG_RESULT = 2;
  const MATHML_RESULT = 3;
  // TemplatePart types
  // IMPORTANT: these must match the values in PartType
  const ATTRIBUTE_PART = 1;
  const CHILD_PART = 2;
  const PROPERTY_PART = 3;
  const BOOLEAN_ATTRIBUTE_PART = 4;
  const EVENT_PART = 5;
  const ELEMENT_PART = 6;
  const COMMENT_PART = 7;
  /**
   * Generates a template literal tag function that returns a TemplateResult with
   * the given result type.
   */
  const tag = (type) => (strings, ...values) => {
      // Warn against templates octal escape sequences
      // We do this here rather than in render so that the warning is closer to the
      // template definition.
      if (strings.some((s) => s === undefined)) {
          console.warn('Some template strings are undefined.\n' +
              'This is probably caused by illegal octal escape sequences.');
      }
      {
          // Import static-html.js results in a circular dependency which g3 doesn't
          // handle. Instead we know that static values must have the field
          // `_$litStatic$`.
          if (values.some((val) => val?.['_$litStatic$'])) {
              issueWarning$3('', `Static values 'literal' or 'unsafeStatic' cannot be used as values to non-static templates.\n` +
                  `Please use the static 'html' tag function. See https://lit.dev/docs/templates/expressions/#static-expressions`);
          }
      }
      return {
          // This property needs to remain unminified.
          ['_$litType$']: type,
          strings,
          values,
      };
  };
  /**
   * Interprets a template literal as an HTML template that can efficiently
   * render to and update a container.
   *
   * ```ts
   * const header = (title: string) => html`<h1>${title}</h1>`;
   * ```
   *
   * The `html` tag returns a description of the DOM to render as a value. It is
   * lazy, meaning no work is done until the template is rendered. When rendering,
   * if a template comes from the same expression as a previously rendered result,
   * it's efficiently updated instead of replaced.
   */
  const html = tag(HTML_RESULT);
  /**
   * A sentinel value that signals that a value was handled by a directive and
   * should not be written to the DOM.
   */
  const noChange = Symbol.for('lit-noChange');
  /**
   * A sentinel value that signals a ChildPart to fully clear its content.
   *
   * ```ts
   * const button = html`${
   *  user.isAdmin
   *    ? html`<button>DELETE</button>`
   *    : nothing
   * }`;
   * ```
   *
   * Prefer using `nothing` over other falsy values as it provides a consistent
   * behavior between various expression binding contexts.
   *
   * In child expressions, `undefined`, `null`, `''`, and `nothing` all behave the
   * same and render no nodes. In attribute expressions, `nothing` _removes_ the
   * attribute, while `undefined` and `null` will render an empty string. In
   * property expressions `nothing` becomes `undefined`.
   */
  const nothing = Symbol.for('lit-nothing');
  /**
   * The cache of prepared templates, keyed by the tagged TemplateStringsArray
   * and _not_ accounting for the specific template tag used. This means that
   * template tags cannot be dynamic - they must statically be one of html, svg,
   * or attr. This restriction simplifies the cache lookup, which is on the hot
   * path for rendering.
   */
  const templateCache = new WeakMap();
  const walker = d.createTreeWalker(d, 129 /* NodeFilter.SHOW_{ELEMENT|COMMENT} */);
  let sanitizerFactoryInternal = noopSanitizer;
  function trustFromTemplateString(tsa, stringFromTSA) {
      // A security check to prevent spoofing of Lit template results.
      // In the future, we may be able to replace this with Array.isTemplateObject,
      // though we might need to make that check inside of the html and svg
      // functions, because precompiled templates don't come in as
      // TemplateStringArray objects.
      if (!isArray(tsa) || !tsa.hasOwnProperty('raw')) {
          let message = 'invalid template strings array';
          {
              message = `
          Internal Error: expected template strings to be an array
          with a 'raw' field. Faking a template strings array by
          calling html or svg like an ordinary function is effectively
          the same as calling unsafeHtml and can lead to major security
          issues, e.g. opening your code up to XSS attacks.
          If you're using the html or svg tagged template functions normally
          and still seeing this error, please file a bug at
          https://github.com/lit/lit/issues/new?template=bug_report.md
          and include information about your build tooling, if any.
        `
                  .trim()
                  .replace(/\n */g, '\n');
          }
          throw new Error(message);
      }
      return policy !== undefined
          ? policy.createHTML(stringFromTSA)
          : stringFromTSA;
  }
  /**
   * Returns an HTML string for the given TemplateStringsArray and result type
   * (HTML or SVG), along with the case-sensitive bound attribute names in
   * template order. The HTML contains comment markers denoting the `ChildPart`s
   * and suffixes on bound attributes denoting the `AttributeParts`.
   *
   * @param strings template strings array
   * @param type HTML or SVG
   * @return Array containing `[html, attrNames]` (array returned for terseness,
   *     to avoid object fields since this code is shared with non-minified SSR
   *     code)
   */
  const getTemplateHtml = (strings, type) => {
      // Insert makers into the template HTML to represent the position of
      // bindings. The following code scans the template strings to determine the
      // syntactic position of the bindings. They can be in text position, where
      // we insert an HTML comment, attribute value position, where we insert a
      // sentinel string and re-write the attribute name, or inside a tag where
      // we insert the sentinel string.
      const l = strings.length - 1;
      // Stores the case-sensitive bound attribute names in the order of their
      // parts. ElementParts are also reflected in this array as undefined
      // rather than a string, to disambiguate from attribute bindings.
      const attrNames = [];
      let html = type === SVG_RESULT ? '<svg>' : type === MATHML_RESULT ? '<math>' : '';
      // When we're inside a raw text tag (not it's text content), the regex
      // will still be tagRegex so we can find attributes, but will switch to
      // this regex when the tag ends.
      let rawTextEndRegex;
      // The current parsing state, represented as a reference to one of the
      // regexes
      let regex = textEndRegex;
      for (let i = 0; i < l; i++) {
          const s = strings[i];
          // The index of the end of the last attribute name. When this is
          // positive at end of a string, it means we're in an attribute value
          // position and need to rewrite the attribute name.
          // We also use a special value of -2 to indicate that we encountered
          // the end of a string in attribute name position.
          let attrNameEndIndex = -1;
          let attrName;
          let lastIndex = 0;
          let match;
          // The conditions in this loop handle the current parse state, and the
          // assignments to the `regex` variable are the state transitions.
          while (lastIndex < s.length) {
              // Make sure we start searching from where we previously left off
              regex.lastIndex = lastIndex;
              match = regex.exec(s);
              if (match === null) {
                  break;
              }
              lastIndex = regex.lastIndex;
              if (regex === textEndRegex) {
                  if (match[COMMENT_START] === '!--') {
                      regex = commentEndRegex;
                  }
                  else if (match[COMMENT_START] !== undefined) {
                      // We started a weird comment, like </{
                      regex = comment2EndRegex;
                  }
                  else if (match[TAG_NAME] !== undefined) {
                      if (rawTextElement.test(match[TAG_NAME])) {
                          // Record if we encounter a raw-text element. We'll switch to
                          // this regex at the end of the tag.
                          rawTextEndRegex = new RegExp(`</${match[TAG_NAME]}`, 'g');
                      }
                      regex = tagEndRegex;
                  }
                  else if (match[DYNAMIC_TAG_NAME] !== undefined) {
                      {
                          throw new Error('Bindings in tag names are not supported. Please use static templates instead. ' +
                              'See https://lit.dev/docs/templates/expressions/#static-expressions');
                      }
                  }
              }
              else if (regex === tagEndRegex) {
                  if (match[ENTIRE_MATCH] === '>') {
                      // End of a tag. If we had started a raw-text element, use that
                      // regex
                      regex = rawTextEndRegex ?? textEndRegex;
                      // We may be ending an unquoted attribute value, so make sure we
                      // clear any pending attrNameEndIndex
                      attrNameEndIndex = -1;
                  }
                  else if (match[ATTRIBUTE_NAME] === undefined) {
                      // Attribute name position
                      attrNameEndIndex = -2;
                  }
                  else {
                      attrNameEndIndex = regex.lastIndex - match[SPACES_AND_EQUALS].length;
                      attrName = match[ATTRIBUTE_NAME];
                      regex =
                          match[QUOTE_CHAR] === undefined
                              ? tagEndRegex
                              : match[QUOTE_CHAR] === '"'
                                  ? doubleQuoteAttrEndRegex
                                  : singleQuoteAttrEndRegex;
                  }
              }
              else if (regex === doubleQuoteAttrEndRegex ||
                  regex === singleQuoteAttrEndRegex) {
                  regex = tagEndRegex;
              }
              else if (regex === commentEndRegex || regex === comment2EndRegex) {
                  regex = textEndRegex;
              }
              else {
                  // Not one of the five state regexes, so it must be the dynamically
                  // created raw text regex and we're at the close of that element.
                  regex = tagEndRegex;
                  rawTextEndRegex = undefined;
              }
          }
          {
              // If we have a attrNameEndIndex, which indicates that we should
              // rewrite the attribute name, assert that we're in a valid attribute
              // position - either in a tag, or a quoted attribute value.
              console.assert(attrNameEndIndex === -1 ||
                  regex === tagEndRegex ||
                  regex === singleQuoteAttrEndRegex ||
                  regex === doubleQuoteAttrEndRegex, 'unexpected parse state B');
          }
          // We have four cases:
          //  1. We're in text position, and not in a raw text element
          //     (regex === textEndRegex): insert a comment marker.
          //  2. We have a non-negative attrNameEndIndex which means we need to
          //     rewrite the attribute name to add a bound attribute suffix.
          //  3. We're at the non-first binding in a multi-binding attribute, use a
          //     plain marker.
          //  4. We're somewhere else inside the tag. If we're in attribute name
          //     position (attrNameEndIndex === -2), add a sequential suffix to
          //     generate a unique attribute name.
          // Detect a binding next to self-closing tag end and insert a space to
          // separate the marker from the tag end:
          const end = regex === tagEndRegex && strings[i + 1].startsWith('/>') ? ' ' : '';
          html +=
              regex === textEndRegex
                  ? s + nodeMarker
                  : attrNameEndIndex >= 0
                      ? (attrNames.push(attrName),
                          s.slice(0, attrNameEndIndex) +
                              boundAttributeSuffix +
                              s.slice(attrNameEndIndex)) +
                          marker +
                          end
                      : s + marker + (attrNameEndIndex === -2 ? i : end);
      }
      const htmlResult = html +
          (strings[l] || '<?>') +
          (type === SVG_RESULT ? '</svg>' : type === MATHML_RESULT ? '</math>' : '');
      // Returned as an array for terseness
      return [trustFromTemplateString(strings, htmlResult), attrNames];
  };
  class Template {
      constructor(
      // This property needs to remain unminified.
      { strings, ['_$litType$']: type }, options) {
          this.parts = [];
          let node;
          let nodeIndex = 0;
          let attrNameIndex = 0;
          const partCount = strings.length - 1;
          const parts = this.parts;
          // Create template element
          const [html, attrNames] = getTemplateHtml(strings, type);
          this.el = Template.createElement(html, options);
          walker.currentNode = this.el.content;
          // Re-parent SVG or MathML nodes into template root
          if (type === SVG_RESULT || type === MATHML_RESULT) {
              const wrapper = this.el.content.firstChild;
              wrapper.replaceWith(...wrapper.childNodes);
          }
          // Walk the template to find binding markers and create TemplateParts
          while ((node = walker.nextNode()) !== null && parts.length < partCount) {
              if (node.nodeType === 1) {
                  {
                      const tag = node.localName;
                      // Warn if `textarea` includes an expression and throw if `template`
                      // does since these are not supported. We do this by checking
                      // innerHTML for anything that looks like a marker. This catches
                      // cases like bindings in textarea there markers turn into text nodes.
                      if (/^(?:textarea|template)$/i.test(tag) &&
                          node.innerHTML.includes(marker)) {
                          const m = `Expressions are not supported inside \`${tag}\` ` +
                              `elements. See https://lit.dev/msg/expression-in-${tag} for more ` +
                              `information.`;
                          if (tag === 'template') {
                              throw new Error(m);
                          }
                          else
                              issueWarning$3('', m);
                      }
                  }
                  // TODO (justinfagnani): for attempted dynamic tag names, we don't
                  // increment the bindingIndex, and it'll be off by 1 in the element
                  // and off by two after it.
                  if (node.hasAttributes()) {
                      for (const name of node.getAttributeNames()) {
                          if (name.endsWith(boundAttributeSuffix)) {
                              const realName = attrNames[attrNameIndex++];
                              const value = node.getAttribute(name);
                              const statics = value.split(marker);
                              const m = /([.?@])?(.*)/.exec(realName);
                              parts.push({
                                  type: ATTRIBUTE_PART,
                                  index: nodeIndex,
                                  name: m[2],
                                  strings: statics,
                                  ctor: m[1] === '.'
                                      ? PropertyPart
                                      : m[1] === '?'
                                          ? BooleanAttributePart
                                          : m[1] === '@'
                                              ? EventPart
                                              : AttributePart,
                              });
                              node.removeAttribute(name);
                          }
                          else if (name.startsWith(marker)) {
                              parts.push({
                                  type: ELEMENT_PART,
                                  index: nodeIndex,
                              });
                              node.removeAttribute(name);
                          }
                      }
                  }
                  // TODO (justinfagnani): benchmark the regex against testing for each
                  // of the 3 raw text element names.
                  if (rawTextElement.test(node.tagName)) {
                      // For raw text elements we need to split the text content on
                      // markers, create a Text node for each segment, and create
                      // a TemplatePart for each marker.
                      const strings = node.textContent.split(marker);
                      const lastIndex = strings.length - 1;
                      if (lastIndex > 0) {
                          node.textContent = trustedTypes$1
                              ? trustedTypes$1.emptyScript
                              : '';
                          // Generate a new text node for each literal section
                          // These nodes are also used as the markers for node parts
                          // We can't use empty text nodes as markers because they're
                          // normalized when cloning in IE (could simplify when
                          // IE is no longer supported)
                          for (let i = 0; i < lastIndex; i++) {
                              node.append(strings[i], createMarker());
                              // Walk past the marker node we just added
                              walker.nextNode();
                              parts.push({ type: CHILD_PART, index: ++nodeIndex });
                          }
                          // Note because this marker is added after the walker's current
                          // node, it will be walked to in the outer loop (and ignored), so
                          // we don't need to adjust nodeIndex here
                          node.append(strings[lastIndex], createMarker());
                      }
                  }
              }
              else if (node.nodeType === 8) {
                  const data = node.data;
                  if (data === markerMatch) {
                      parts.push({ type: CHILD_PART, index: nodeIndex });
                  }
                  else {
                      let i = -1;
                      while ((i = node.data.indexOf(marker, i + 1)) !== -1) {
                          // Comment node has a binding marker inside, make an inactive part
                          // The binding won't work, but subsequent bindings will
                          parts.push({ type: COMMENT_PART, index: nodeIndex });
                          // Move to the end of the match
                          i += marker.length - 1;
                      }
                  }
              }
              nodeIndex++;
          }
          {
              // If there was a duplicate attribute on a tag, then when the tag is
              // parsed into an element the attribute gets de-duplicated. We can detect
              // this mismatch if we haven't precisely consumed every attribute name
              // when preparing the template. This works because `attrNames` is built
              // from the template string and `attrNameIndex` comes from processing the
              // resulting DOM.
              if (attrNames.length !== attrNameIndex) {
                  throw new Error(`Detected duplicate attribute bindings. This occurs if your template ` +
                      `has duplicate attributes on an element tag. For example ` +
                      `"<input ?disabled=\${true} ?disabled=\${false}>" contains a ` +
                      `duplicate "disabled" attribute. The error was detected in ` +
                      `the following template: \n` +
                      '`' +
                      strings.join('${...}') +
                      '`');
              }
          }
          // We could set walker.currentNode to another node here to prevent a memory
          // leak, but every time we prepare a template, we immediately render it
          // and re-use the walker in new TemplateInstance._clone().
          debugLogEvent$1 &&
              debugLogEvent$1({
                  kind: 'template prep',
                  template: this,
                  clonableTemplate: this.el,
                  parts: this.parts,
                  strings,
              });
      }
      // Overridden via `litHtmlPolyfillSupport` to provide platform support.
      /** @nocollapse */
      static createElement(html, _options) {
          const el = d.createElement('template');
          el.innerHTML = html;
          return el;
      }
  }
  function resolveDirective(part, value, parent = part, attributeIndex) {
      // Bail early if the value is explicitly noChange. Note, this means any
      // nested directive is still attached and is not run.
      if (value === noChange) {
          return value;
      }
      let currentDirective = attributeIndex !== undefined
          ? parent.__directives?.[attributeIndex]
          : parent.__directive;
      const nextDirectiveConstructor = isPrimitive(value)
          ? undefined
          : // This property needs to remain unminified.
              value['_$litDirective$'];
      if (currentDirective?.constructor !== nextDirectiveConstructor) {
          // This property needs to remain unminified.
          currentDirective?.['_$notifyDirectiveConnectionChanged']?.(false);
          if (nextDirectiveConstructor === undefined) {
              currentDirective = undefined;
          }
          else {
              currentDirective = new nextDirectiveConstructor(part);
              currentDirective._$initialize(part, parent, attributeIndex);
          }
          if (attributeIndex !== undefined) {
              (parent.__directives ??= [])[attributeIndex] =
                  currentDirective;
          }
          else {
              parent.__directive = currentDirective;
          }
      }
      if (currentDirective !== undefined) {
          value = resolveDirective(part, currentDirective._$resolve(part, value.values), currentDirective, attributeIndex);
      }
      return value;
  }
  /**
   * An updateable instance of a Template. Holds references to the Parts used to
   * update the template instance.
   */
  class TemplateInstance {
      constructor(template, parent) {
          this._$parts = [];
          /** @internal */
          this._$disconnectableChildren = undefined;
          this._$template = template;
          this._$parent = parent;
      }
      // Called by ChildPart parentNode getter
      get parentNode() {
          return this._$parent.parentNode;
      }
      // See comment in Disconnectable interface for why this is a getter
      get _$isConnected() {
          return this._$parent._$isConnected;
      }
      // This method is separate from the constructor because we need to return a
      // DocumentFragment and we don't want to hold onto it with an instance field.
      _clone(options) {
          const { el: { content }, parts: parts, } = this._$template;
          const fragment = (options?.creationScope ?? d).importNode(content, true);
          walker.currentNode = fragment;
          let node = walker.nextNode();
          let nodeIndex = 0;
          let partIndex = 0;
          let templatePart = parts[0];
          while (templatePart !== undefined) {
              if (nodeIndex === templatePart.index) {
                  let part;
                  if (templatePart.type === CHILD_PART) {
                      part = new ChildPart(node, node.nextSibling, this, options);
                  }
                  else if (templatePart.type === ATTRIBUTE_PART) {
                      part = new templatePart.ctor(node, templatePart.name, templatePart.strings, this, options);
                  }
                  else if (templatePart.type === ELEMENT_PART) {
                      part = new ElementPart(node, this, options);
                  }
                  this._$parts.push(part);
                  templatePart = parts[++partIndex];
              }
              if (nodeIndex !== templatePart?.index) {
                  node = walker.nextNode();
                  nodeIndex++;
              }
          }
          // We need to set the currentNode away from the cloned tree so that we
          // don't hold onto the tree even if the tree is detached and should be
          // freed.
          walker.currentNode = d;
          return fragment;
      }
      _update(values) {
          let i = 0;
          for (const part of this._$parts) {
              if (part !== undefined) {
                  debugLogEvent$1 &&
                      debugLogEvent$1({
                          kind: 'set part',
                          part,
                          value: values[i],
                          valueIndex: i,
                          values,
                          templateInstance: this,
                      });
                  if (part.strings !== undefined) {
                      part._$setValue(values, part, i);
                      // The number of values the part consumes is part.strings.length - 1
                      // since values are in between template spans. We increment i by 1
                      // later in the loop, so increment it by part.strings.length - 2 here
                      i += part.strings.length - 2;
                  }
                  else {
                      part._$setValue(values[i]);
                  }
              }
              i++;
          }
      }
  }
  class ChildPart {
      // See comment in Disconnectable interface for why this is a getter
      get _$isConnected() {
          // ChildParts that are not at the root should always be created with a
          // parent; only RootChildNode's won't, so they return the local isConnected
          // state
          return this._$parent?._$isConnected ?? this.__isConnected;
      }
      constructor(startNode, endNode, parent, options) {
          this.type = CHILD_PART;
          this._$committedValue = nothing;
          // The following fields will be patched onto ChildParts when required by
          // AsyncDirective
          /** @internal */
          this._$disconnectableChildren = undefined;
          this._$startNode = startNode;
          this._$endNode = endNode;
          this._$parent = parent;
          this.options = options;
          // Note __isConnected is only ever accessed on RootParts (i.e. when there is
          // no _$parent); the value on a non-root-part is "don't care", but checking
          // for parent would be more code
          this.__isConnected = options?.isConnected ?? true;
          {
              // Explicitly initialize for consistent class shape.
              this._textSanitizer = undefined;
          }
      }
      /**
       * The parent node into which the part renders its content.
       *
       * A ChildPart's content consists of a range of adjacent child nodes of
       * `.parentNode`, possibly bordered by 'marker nodes' (`.startNode` and
       * `.endNode`).
       *
       * - If both `.startNode` and `.endNode` are non-null, then the part's content
       * consists of all siblings between `.startNode` and `.endNode`, exclusively.
       *
       * - If `.startNode` is non-null but `.endNode` is null, then the part's
       * content consists of all siblings following `.startNode`, up to and
       * including the last child of `.parentNode`. If `.endNode` is non-null, then
       * `.startNode` will always be non-null.
       *
       * - If both `.endNode` and `.startNode` are null, then the part's content
       * consists of all child nodes of `.parentNode`.
       */
      get parentNode() {
          let parentNode = wrap(this._$startNode).parentNode;
          const parent = this._$parent;
          if (parent !== undefined &&
              parentNode?.nodeType === 11 /* Node.DOCUMENT_FRAGMENT */) {
              // If the parentNode is a DocumentFragment, it may be because the DOM is
              // still in the cloned fragment during initial render; if so, get the real
              // parentNode the part will be committed into by asking the parent.
              parentNode = parent.parentNode;
          }
          return parentNode;
      }
      /**
       * The part's leading marker node, if any. See `.parentNode` for more
       * information.
       */
      get startNode() {
          return this._$startNode;
      }
      /**
       * The part's trailing marker node, if any. See `.parentNode` for more
       * information.
       */
      get endNode() {
          return this._$endNode;
      }
      _$setValue(value, directiveParent = this) {
          if (this.parentNode === null) {
              throw new Error(`This \`ChildPart\` has no \`parentNode\` and therefore cannot accept a value. This likely means the element containing the part was manipulated in an unsupported way outside of Lit's control such that the part's marker nodes were ejected from DOM. For example, setting the element's \`innerHTML\` or \`textContent\` can do this.`);
          }
          value = resolveDirective(this, value, directiveParent);
          if (isPrimitive(value)) {
              // Non-rendering child values. It's important that these do not render
              // empty text nodes to avoid issues with preventing default <slot>
              // fallback content.
              if (value === nothing || value == null || value === '') {
                  if (this._$committedValue !== nothing) {
                      debugLogEvent$1 &&
                          debugLogEvent$1({
                              kind: 'commit nothing to child',
                              start: this._$startNode,
                              end: this._$endNode,
                              parent: this._$parent,
                              options: this.options,
                          });
                      this._$clear();
                  }
                  this._$committedValue = nothing;
              }
              else if (value !== this._$committedValue && value !== noChange) {
                  this._commitText(value);
              }
              // This property needs to remain unminified.
          }
          else if (value['_$litType$'] !== undefined) {
              this._commitTemplateResult(value);
          }
          else if (value.nodeType !== undefined) {
              if (this.options?.host === value) {
                  this._commitText(`[probable mistake: rendered a template's host in itself ` +
                      `(commonly caused by writing \${this} in a template]`);
                  console.warn(`Attempted to render the template host`, value, `inside itself. This is almost always a mistake, and in dev mode `, `we render some warning text. In production however, we'll `, `render it, which will usually result in an error, and sometimes `, `in the element disappearing from the DOM.`);
                  return;
              }
              this._commitNode(value);
          }
          else if (isIterable(value)) {
              this._commitIterable(value);
          }
          else {
              // Fallback, will render the string representation
              this._commitText(value);
          }
      }
      _insert(node) {
          return wrap(wrap(this._$startNode).parentNode).insertBefore(node, this._$endNode);
      }
      _commitNode(value) {
          if (this._$committedValue !== value) {
              this._$clear();
              if (sanitizerFactoryInternal !== noopSanitizer) {
                  const parentNodeName = this._$startNode.parentNode?.nodeName;
                  if (parentNodeName === 'STYLE' || parentNodeName === 'SCRIPT') {
                      let message = 'Forbidden';
                      {
                          if (parentNodeName === 'STYLE') {
                              message =
                                  `Lit does not support binding inside style nodes. ` +
                                      `This is a security risk, as style injection attacks can ` +
                                      `exfiltrate data and spoof UIs. ` +
                                      `Consider instead using css\`...\` literals ` +
                                      `to compose styles, and do dynamic styling with ` +
                                      `css custom properties, ::parts, <slot>s, ` +
                                      `and by mutating the DOM rather than stylesheets.`;
                          }
                          else {
                              message =
                                  `Lit does not support binding inside script nodes. ` +
                                      `This is a security risk, as it could allow arbitrary ` +
                                      `code execution.`;
                          }
                      }
                      throw new Error(message);
                  }
              }
              debugLogEvent$1 &&
                  debugLogEvent$1({
                      kind: 'commit node',
                      start: this._$startNode,
                      parent: this._$parent,
                      value: value,
                      options: this.options,
                  });
              this._$committedValue = this._insert(value);
          }
      }
      _commitText(value) {
          // If the committed value is a primitive it means we called _commitText on
          // the previous render, and we know that this._$startNode.nextSibling is a
          // Text node. We can now just replace the text content (.data) of the node.
          if (this._$committedValue !== nothing &&
              isPrimitive(this._$committedValue)) {
              const node = wrap(this._$startNode).nextSibling;
              {
                  if (this._textSanitizer === undefined) {
                      this._textSanitizer = createSanitizer(node, 'data', 'property');
                  }
                  value = this._textSanitizer(value);
              }
              debugLogEvent$1 &&
                  debugLogEvent$1({
                      kind: 'commit text',
                      node,
                      value,
                      options: this.options,
                  });
              node.data = value;
          }
          else {
              {
                  const textNode = d.createTextNode('');
                  this._commitNode(textNode);
                  // When setting text content, for security purposes it matters a lot
                  // what the parent is. For example, <style> and <script> need to be
                  // handled with care, while <span> does not. So first we need to put a
                  // text node into the document, then we can sanitize its content.
                  if (this._textSanitizer === undefined) {
                      this._textSanitizer = createSanitizer(textNode, 'data', 'property');
                  }
                  value = this._textSanitizer(value);
                  debugLogEvent$1 &&
                      debugLogEvent$1({
                          kind: 'commit text',
                          node: textNode,
                          value,
                          options: this.options,
                      });
                  textNode.data = value;
              }
          }
          this._$committedValue = value;
      }
      _commitTemplateResult(result) {
          // This property needs to remain unminified.
          const { values, ['_$litType$']: type } = result;
          // If $litType$ is a number, result is a plain TemplateResult and we get
          // the template from the template cache. If not, result is a
          // CompiledTemplateResult and _$litType$ is a CompiledTemplate and we need
          // to create the <template> element the first time we see it.
          const template = typeof type === 'number'
              ? this._$getTemplate(result)
              : (type.el === undefined &&
                  (type.el = Template.createElement(trustFromTemplateString(type.h, type.h[0]), this.options)),
                  type);
          if (this._$committedValue?._$template === template) {
              debugLogEvent$1 &&
                  debugLogEvent$1({
                      kind: 'template updating',
                      template,
                      instance: this._$committedValue,
                      parts: this._$committedValue._$parts,
                      options: this.options,
                      values,
                  });
              this._$committedValue._update(values);
          }
          else {
              const instance = new TemplateInstance(template, this);
              const fragment = instance._clone(this.options);
              debugLogEvent$1 &&
                  debugLogEvent$1({
                      kind: 'template instantiated',
                      template,
                      instance,
                      parts: instance._$parts,
                      options: this.options,
                      fragment,
                      values,
                  });
              instance._update(values);
              debugLogEvent$1 &&
                  debugLogEvent$1({
                      kind: 'template instantiated and updated',
                      template,
                      instance,
                      parts: instance._$parts,
                      options: this.options,
                      fragment,
                      values,
                  });
              this._commitNode(fragment);
              this._$committedValue = instance;
          }
      }
      // Overridden via `litHtmlPolyfillSupport` to provide platform support.
      /** @internal */
      _$getTemplate(result) {
          let template = templateCache.get(result.strings);
          if (template === undefined) {
              templateCache.set(result.strings, (template = new Template(result)));
          }
          return template;
      }
      _commitIterable(value) {
          // For an Iterable, we create a new InstancePart per item, then set its
          // value to the item. This is a little bit of overhead for every item in
          // an Iterable, but it lets us recurse easily and efficiently update Arrays
          // of TemplateResults that will be commonly returned from expressions like:
          // array.map((i) => html`${i}`), by reusing existing TemplateInstances.
          // If value is an array, then the previous render was of an
          // iterable and value will contain the ChildParts from the previous
          // render. If value is not an array, clear this part and make a new
          // array for ChildParts.
          if (!isArray(this._$committedValue)) {
              this._$committedValue = [];
              this._$clear();
          }
          // Lets us keep track of how many items we stamped so we can clear leftover
          // items from a previous render
          const itemParts = this._$committedValue;
          let partIndex = 0;
          let itemPart;
          for (const item of value) {
              if (partIndex === itemParts.length) {
                  // If no existing part, create a new one
                  // TODO (justinfagnani): test perf impact of always creating two parts
                  // instead of sharing parts between nodes
                  // https://github.com/lit/lit/issues/1266
                  itemParts.push((itemPart = new ChildPart(this._insert(createMarker()), this._insert(createMarker()), this, this.options)));
              }
              else {
                  // Reuse an existing part
                  itemPart = itemParts[partIndex];
              }
              itemPart._$setValue(item);
              partIndex++;
          }
          if (partIndex < itemParts.length) {
              // itemParts always have end nodes
              this._$clear(itemPart && wrap(itemPart._$endNode).nextSibling, partIndex);
              // Truncate the parts array so _value reflects the current state
              itemParts.length = partIndex;
          }
      }
      /**
       * Removes the nodes contained within this Part from the DOM.
       *
       * @param start Start node to clear from, for clearing a subset of the part's
       *     DOM (used when truncating iterables)
       * @param from  When `start` is specified, the index within the iterable from
       *     which ChildParts are being removed, used for disconnecting directives in
       *     those Parts.
       *
       * @internal
       */
      _$clear(start = wrap(this._$startNode).nextSibling, from) {
          this._$notifyConnectionChanged?.(false, true, from);
          while (start && start !== this._$endNode) {
              const n = wrap(start).nextSibling;
              wrap(start).remove();
              start = n;
          }
      }
      /**
       * Implementation of RootPart's `isConnected`. Note that this method
       * should only be called on `RootPart`s (the `ChildPart` returned from a
       * top-level `render()` call). It has no effect on non-root ChildParts.
       * @param isConnected Whether to set
       * @internal
       */
      setConnected(isConnected) {
          if (this._$parent === undefined) {
              this.__isConnected = isConnected;
              this._$notifyConnectionChanged?.(isConnected);
          }
          else {
              throw new Error('part.setConnected() may only be called on a ' +
                  'RootPart returned from render().');
          }
      }
  }
  class AttributePart {
      get tagName() {
          return this.element.tagName;
      }
      // See comment in Disconnectable interface for why this is a getter
      get _$isConnected() {
          return this._$parent._$isConnected;
      }
      constructor(element, name, strings, parent, options) {
          this.type = ATTRIBUTE_PART;
          /** @internal */
          this._$committedValue = nothing;
          /** @internal */
          this._$disconnectableChildren = undefined;
          this.element = element;
          this.name = name;
          this._$parent = parent;
          this.options = options;
          if (strings.length > 2 || strings[0] !== '' || strings[1] !== '') {
              this._$committedValue = new Array(strings.length - 1).fill(new String());
              this.strings = strings;
          }
          else {
              this._$committedValue = nothing;
          }
          {
              this._sanitizer = undefined;
          }
      }
      /**
       * Sets the value of this part by resolving the value from possibly multiple
       * values and static strings and committing it to the DOM.
       * If this part is single-valued, `this._strings` will be undefined, and the
       * method will be called with a single value argument. If this part is
       * multi-value, `this._strings` will be defined, and the method is called
       * with the value array of the part's owning TemplateInstance, and an offset
       * into the value array from which the values should be read.
       * This method is overloaded this way to eliminate short-lived array slices
       * of the template instance values, and allow a fast-path for single-valued
       * parts.
       *
       * @param value The part value, or an array of values for multi-valued parts
       * @param valueIndex the index to start reading values from. `undefined` for
       *   single-valued parts
       * @param noCommit causes the part to not commit its value to the DOM. Used
       *   in hydration to prime attribute parts with their first-rendered value,
       *   but not set the attribute, and in SSR to no-op the DOM operation and
       *   capture the value for serialization.
       *
       * @internal
       */
      _$setValue(value, directiveParent = this, valueIndex, noCommit) {
          const strings = this.strings;
          // Whether any of the values has changed, for dirty-checking
          let change = false;
          if (strings === undefined) {
              // Single-value binding case
              value = resolveDirective(this, value, directiveParent, 0);
              change =
                  !isPrimitive(value) ||
                      (value !== this._$committedValue && value !== noChange);
              if (change) {
                  this._$committedValue = value;
              }
          }
          else {
              // Interpolation case
              const values = value;
              value = strings[0];
              let i, v;
              for (i = 0; i < strings.length - 1; i++) {
                  v = resolveDirective(this, values[valueIndex + i], directiveParent, i);
                  if (v === noChange) {
                      // If the user-provided value is `noChange`, use the previous value
                      v = this._$committedValue[i];
                  }
                  change ||=
                      !isPrimitive(v) || v !== this._$committedValue[i];
                  if (v === nothing) {
                      value = nothing;
                  }
                  else if (value !== nothing) {
                      value += (v ?? '') + strings[i + 1];
                  }
                  // We always record each value, even if one is `nothing`, for future
                  // change detection.
                  this._$committedValue[i] = v;
              }
          }
          if (change && !noCommit) {
              this._commitValue(value);
          }
      }
      /** @internal */
      _commitValue(value) {
          if (value === nothing) {
              wrap(this.element).removeAttribute(this.name);
          }
          else {
              {
                  if (this._sanitizer === undefined) {
                      this._sanitizer = sanitizerFactoryInternal(this.element, this.name, 'attribute');
                  }
                  value = this._sanitizer(value ?? '');
              }
              debugLogEvent$1 &&
                  debugLogEvent$1({
                      kind: 'commit attribute',
                      element: this.element,
                      name: this.name,
                      value,
                      options: this.options,
                  });
              wrap(this.element).setAttribute(this.name, (value ?? ''));
          }
      }
  }
  class PropertyPart extends AttributePart {
      constructor() {
          super(...arguments);
          this.type = PROPERTY_PART;
      }
      /** @internal */
      _commitValue(value) {
          {
              if (this._sanitizer === undefined) {
                  this._sanitizer = sanitizerFactoryInternal(this.element, this.name, 'property');
              }
              value = this._sanitizer(value);
          }
          debugLogEvent$1 &&
              debugLogEvent$1({
                  kind: 'commit property',
                  element: this.element,
                  name: this.name,
                  value,
                  options: this.options,
              });
          // eslint-disable-next-line @typescript-eslint/no-explicit-any
          this.element[this.name] = value === nothing ? undefined : value;
      }
  }
  class BooleanAttributePart extends AttributePart {
      constructor() {
          super(...arguments);
          this.type = BOOLEAN_ATTRIBUTE_PART;
      }
      /** @internal */
      _commitValue(value) {
          debugLogEvent$1 &&
              debugLogEvent$1({
                  kind: 'commit boolean attribute',
                  element: this.element,
                  name: this.name,
                  value: !!(value && value !== nothing),
                  options: this.options,
              });
          wrap(this.element).toggleAttribute(this.name, !!value && value !== nothing);
      }
  }
  class EventPart extends AttributePart {
      constructor(element, name, strings, parent, options) {
          super(element, name, strings, parent, options);
          this.type = EVENT_PART;
          if (this.strings !== undefined) {
              throw new Error(`A \`<${element.localName}>\` has a \`@${name}=...\` listener with ` +
                  'invalid content. Event listeners in templates must have exactly ' +
                  'one expression and no surrounding text.');
          }
      }
      // EventPart does not use the base _$setValue/_resolveValue implementation
      // since the dirty checking is more complex
      /** @internal */
      _$setValue(newListener, directiveParent = this) {
          newListener =
              resolveDirective(this, newListener, directiveParent, 0) ?? nothing;
          if (newListener === noChange) {
              return;
          }
          const oldListener = this._$committedValue;
          // If the new value is nothing or any options change we have to remove the
          // part as a listener.
          const shouldRemoveListener = (newListener === nothing && oldListener !== nothing) ||
              newListener.capture !==
                  oldListener.capture ||
              newListener.once !==
                  oldListener.once ||
              newListener.passive !==
                  oldListener.passive;
          // If the new value is not nothing and we removed the listener, we have
          // to add the part as a listener.
          const shouldAddListener = newListener !== nothing &&
              (oldListener === nothing || shouldRemoveListener);
          debugLogEvent$1 &&
              debugLogEvent$1({
                  kind: 'commit event listener',
                  element: this.element,
                  name: this.name,
                  value: newListener,
                  options: this.options,
                  removeListener: shouldRemoveListener,
                  addListener: shouldAddListener,
                  oldListener,
              });
          if (shouldRemoveListener) {
              this.element.removeEventListener(this.name, this, oldListener);
          }
          if (shouldAddListener) {
              // Beware: IE11 and Chrome 41 don't like using the listener as the
              // options object. Figure out how to deal w/ this in IE11 - maybe
              // patch addEventListener?
              this.element.addEventListener(this.name, this, newListener);
          }
          this._$committedValue = newListener;
      }
      handleEvent(event) {
          if (typeof this._$committedValue === 'function') {
              this._$committedValue.call(this.options?.host ?? this.element, event);
          }
          else {
              this._$committedValue.handleEvent(event);
          }
      }
  }
  class ElementPart {
      constructor(element, parent, options) {
          this.element = element;
          this.type = ELEMENT_PART;
          /** @internal */
          this._$disconnectableChildren = undefined;
          this._$parent = parent;
          this.options = options;
      }
      // See comment in Disconnectable interface for why this is a getter
      get _$isConnected() {
          return this._$parent._$isConnected;
      }
      _$setValue(value) {
          debugLogEvent$1 &&
              debugLogEvent$1({
                  kind: 'commit to element binding',
                  element: this.element,
                  value,
                  options: this.options,
              });
          resolveDirective(this, value);
      }
  }
  // Apply polyfills if available
  const polyfillSupport$2 = global$2.litHtmlPolyfillSupportDevMode
      ;
  polyfillSupport$2?.(Template, ChildPart);
  // IMPORTANT: do not change the property name or the assignment expression.
  // This line will be used in regexes to search for lit-html usage.
  (global$2.litHtmlVersions ??= []).push('3.2.0');
  if (global$2.litHtmlVersions.length > 1) {
      issueWarning$3('multiple-versions', `Multiple versions of Lit loaded. ` +
          `Loading multiple versions is not recommended.`);
  }
  /**
   * Renders a value, usually a lit-html TemplateResult, to the container.
   *
   * This example renders the text "Hello, Zoe!" inside a paragraph tag, appending
   * it to the container `document.body`.
   *
   * ```js
   * import {html, render} from 'lit';
   *
   * const name = "Zoe";
   * render(html`<p>Hello, ${name}!</p>`, document.body);
   * ```
   *
   * @param value Any [renderable
   *   value](https://lit.dev/docs/templates/expressions/#child-expressions),
   *   typically a {@linkcode TemplateResult} created by evaluating a template tag
   *   like {@linkcode html} or {@linkcode svg}.
   * @param container A DOM container to render to. The first render will append
   *   the rendered value to the container, and subsequent renders will
   *   efficiently update the rendered value if the same result type was
   *   previously rendered there.
   * @param options See {@linkcode RenderOptions} for options documentation.
   * @see
   * {@link https://lit.dev/docs/libraries/standalone-templates/#rendering-lit-html-templates| Rendering Lit HTML Templates}
   */
  const render = (value, container, options) => {
      if (container == null) {
          // Give a clearer error message than
          //     Uncaught TypeError: Cannot read properties of null (reading
          //     '_$litPart$')
          // which reads like an internal Lit error.
          throw new TypeError(`The container to render into may not be ${container}`);
      }
      const renderId = debugLogRenderId++ ;
      const partOwnerNode = options?.renderBefore ?? container;
      // This property needs to remain unminified.
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      let part = partOwnerNode['_$litPart$'];
      debugLogEvent$1 &&
          debugLogEvent$1({
              kind: 'begin render',
              id: renderId,
              value,
              container,
              options,
              part,
          });
      if (part === undefined) {
          const endNode = options?.renderBefore ?? null;
          // This property needs to remain unminified.
          // eslint-disable-next-line @typescript-eslint/no-explicit-any
          partOwnerNode['_$litPart$'] = part = new ChildPart(container.insertBefore(createMarker(), endNode), endNode, undefined, options ?? {});
      }
      part._$setValue(value);
      debugLogEvent$1 &&
          debugLogEvent$1({
              kind: 'end render',
              id: renderId,
              value,
              container,
              options,
              part,
          });
      return part;
  };
  {
      render.setSanitizer = setSanitizer;
      render.createSanitizer = createSanitizer;
      {
          render._testOnlyClearSanitizerFactoryDoNotCallOrElse =
              _testOnlyClearSanitizerFactoryDoNotCallOrElse;
      }
  }

  /**
   * @license
   * Copyright 2019 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  const NODE_MODE = false;
  // Allows minifiers to rename references to globalThis
  const global$1 = globalThis;
  /**
   * Whether the current browser supports `adoptedStyleSheets`.
   */
  const supportsAdoptingStyleSheets = global$1.ShadowRoot &&
      (global$1.ShadyCSS === undefined || global$1.ShadyCSS.nativeShadow) &&
      'adoptedStyleSheets' in Document.prototype &&
      'replace' in CSSStyleSheet.prototype;
  const constructionToken = Symbol();
  const cssTagCache = new WeakMap();
  /**
   * A container for a string of CSS text, that may be used to create a CSSStyleSheet.
   *
   * CSSResult is the return value of `css`-tagged template literals and
   * `unsafeCSS()`. In order to ensure that CSSResults are only created via the
   * `css` tag and `unsafeCSS()`, CSSResult cannot be constructed directly.
   */
  class CSSResult {
      constructor(cssText, strings, safeToken) {
          // This property needs to remain unminified.
          this['_$cssResult$'] = true;
          if (safeToken !== constructionToken) {
              throw new Error('CSSResult is not constructable. Use `unsafeCSS` or `css` instead.');
          }
          this.cssText = cssText;
          this._strings = strings;
      }
      // This is a getter so that it's lazy. In practice, this means stylesheets
      // are not created until the first element instance is made.
      get styleSheet() {
          // If `supportsAdoptingStyleSheets` is true then we assume CSSStyleSheet is
          // constructable.
          let styleSheet = this._styleSheet;
          const strings = this._strings;
          if (supportsAdoptingStyleSheets && styleSheet === undefined) {
              const cacheable = strings !== undefined && strings.length === 1;
              if (cacheable) {
                  styleSheet = cssTagCache.get(strings);
              }
              if (styleSheet === undefined) {
                  (this._styleSheet = styleSheet = new CSSStyleSheet()).replaceSync(this.cssText);
                  if (cacheable) {
                      cssTagCache.set(strings, styleSheet);
                  }
              }
          }
          return styleSheet;
      }
      toString() {
          return this.cssText;
      }
  }
  const textFromCSSResult = (value) => {
      // This property needs to remain unminified.
      if (value['_$cssResult$'] === true) {
          return value.cssText;
      }
      else if (typeof value === 'number') {
          return value;
      }
      else {
          throw new Error(`Value passed to 'css' function must be a 'css' function result: ` +
              `${value}. Use 'unsafeCSS' to pass non-literal values, but take care ` +
              `to ensure page security.`);
      }
  };
  /**
   * Wrap a value for interpolation in a {@linkcode css} tagged template literal.
   *
   * This is unsafe because untrusted CSS text can be used to phone home
   * or exfiltrate data to an attacker controlled site. Take care to only use
   * this with trusted input.
   */
  const unsafeCSS = (value) => new CSSResult(typeof value === 'string' ? value : String(value), undefined, constructionToken);
  /**
   * A template literal tag which can be used with LitElement's
   * {@linkcode LitElement.styles} property to set element styles.
   *
   * For security reasons, only literal string values and number may be used in
   * embedded expressions. To incorporate non-literal values {@linkcode unsafeCSS}
   * may be used inside an expression.
   */
  const css = (strings, ...values) => {
      const cssText = strings.length === 1
          ? strings[0]
          : values.reduce((acc, v, idx) => acc + textFromCSSResult(v) + strings[idx + 1], strings[0]);
      return new CSSResult(cssText, strings, constructionToken);
  };
  /**
   * Applies the given styles to a `shadowRoot`. When Shadow DOM is
   * available but `adoptedStyleSheets` is not, styles are appended to the
   * `shadowRoot` to [mimic spec behavior](https://wicg.github.io/construct-stylesheets/#using-constructed-stylesheets).
   * Note, when shimming is used, any styles that are subsequently placed into
   * the shadowRoot should be placed *before* any shimmed adopted styles. This
   * will match spec behavior that gives adopted sheets precedence over styles in
   * shadowRoot.
   */
  const adoptStyles = (renderRoot, styles) => {
      if (supportsAdoptingStyleSheets) {
          renderRoot.adoptedStyleSheets = styles.map((s) => s instanceof CSSStyleSheet ? s : s.styleSheet);
      }
      else {
          for (const s of styles) {
              const style = document.createElement('style');
              // eslint-disable-next-line @typescript-eslint/no-explicit-any
              const nonce = global$1['litNonce'];
              if (nonce !== undefined) {
                  style.setAttribute('nonce', nonce);
              }
              style.textContent = s.cssText;
              renderRoot.appendChild(style);
          }
      }
  };
  const cssResultFromStyleSheet = (sheet) => {
      let cssText = '';
      for (const rule of sheet.cssRules) {
          cssText += rule.cssText;
      }
      return unsafeCSS(cssText);
  };
  const getCompatibleStyle = supportsAdoptingStyleSheets ||
      (NODE_MODE )
      ? (s) => s
      : (s) => s instanceof CSSStyleSheet ? cssResultFromStyleSheet(s) : s;

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  // TODO (justinfagnani): Add `hasOwn` here when we ship ES2022
  const { is, defineProperty, getOwnPropertyDescriptor, getOwnPropertyNames, getOwnPropertySymbols, getPrototypeOf, } = Object;
  // Lets a minifier replace globalThis references with a minified name
  const global = globalThis;
  let issueWarning$2;
  const trustedTypes = global
      .trustedTypes;
  // Temporary workaround for https://crbug.com/993268
  // Currently, any attribute starting with "on" is considered to be a
  // TrustedScript source. Such boolean attributes must be set to the equivalent
  // trusted emptyScript value.
  const emptyStringForBooleanAttribute = trustedTypes
      ? trustedTypes.emptyScript
      : '';
  const polyfillSupport$1 = global.reactiveElementPolyfillSupportDevMode
      ;
  {
      // Ensure warnings are issued only 1x, even if multiple versions of Lit
      // are loaded.
      const issuedWarnings = (global.litIssuedWarnings ??=
          new Set());
      // Issue a warning, if we haven't already.
      issueWarning$2 = (code, warning) => {
          warning += ` See https://lit.dev/msg/${code} for more information.`;
          if (!issuedWarnings.has(warning)) {
              console.warn(warning);
              issuedWarnings.add(warning);
          }
      };
      issueWarning$2('dev-mode', `Lit is in dev mode. Not recommended for production!`);
      // Issue polyfill support warning.
      if (global.ShadyDOM?.inUse && polyfillSupport$1 === undefined) {
          issueWarning$2('polyfill-support-missing', `Shadow DOM is being polyfilled via \`ShadyDOM\` but ` +
              `the \`polyfill-support\` module has not been loaded.`);
      }
  }
  /**
   * Useful for visualizing and logging insights into what the Lit template system is doing.
   *
   * Compiled out of prod mode builds.
   */
  const debugLogEvent = (event) => {
          const shouldEmit = global
              .emitLitDebugLogEvents;
          if (!shouldEmit) {
              return;
          }
          global.dispatchEvent(new CustomEvent('lit-debug', {
              detail: event,
          }));
      }
      ;
  /*
   * When using Closure Compiler, JSCompiler_renameProperty(property, object) is
   * replaced at compile time by the munged name for object[property]. We cannot
   * alias this function, so we have to use a small shim that has the same
   * behavior when not compiling.
   */
  /*@__INLINE__*/
  const JSCompiler_renameProperty$1 = (prop, _obj) => prop;
  const defaultConverter = {
      toAttribute(value, type) {
          switch (type) {
              case Boolean:
                  value = value ? emptyStringForBooleanAttribute : null;
                  break;
              case Object:
              case Array:
                  // if the value is `null` or `undefined` pass this through
                  // to allow removing/no change behavior.
                  value = value == null ? value : JSON.stringify(value);
                  break;
          }
          return value;
      },
      fromAttribute(value, type) {
          let fromValue = value;
          switch (type) {
              case Boolean:
                  fromValue = value !== null;
                  break;
              case Number:
                  fromValue = value === null ? null : Number(value);
                  break;
              case Object:
              case Array:
                  // Do *not* generate exception when invalid JSON is set as elements
                  // don't normally complain on being mis-configured.
                  // TODO(sorvell): Do generate exception in *dev mode*.
                  try {
                      // Assert to adhere to Bazel's "must type assert JSON parse" rule.
                      fromValue = JSON.parse(value);
                  }
                  catch (e) {
                      fromValue = null;
                  }
                  break;
          }
          return fromValue;
      },
  };
  /**
   * Change function that returns true if `value` is different from `oldValue`.
   * This method is used as the default for a property's `hasChanged` function.
   */
  const notEqual = (value, old) => !is(value, old);
  const defaultPropertyDeclaration$1 = {
      attribute: true,
      type: String,
      converter: defaultConverter,
      reflect: false,
      hasChanged: notEqual,
  };
  // Ensure metadata is enabled. TypeScript does not polyfill
  // Symbol.metadata, so we must ensure that it exists.
  Symbol.metadata ??= Symbol('metadata');
  // Map from a class's metadata object to property options
  // Note that we must use nullish-coalescing assignment so that we only use one
  // map even if we load multiple version of this module.
  global.litPropertyMetadata ??= new WeakMap();
  /**
   * Base element class which manages element properties and attributes. When
   * properties change, the `update` method is asynchronously called. This method
   * should be supplied by subclasses to render updates as desired.
   * @noInheritDoc
   */
  class ReactiveElement
  // In the Node build, this `extends` clause will be substituted with
  // `(globalThis.HTMLElement ?? HTMLElement)`.
  //
  // This way, we will first prefer any global `HTMLElement` polyfill that the
  // user has assigned, and then fall back to the `HTMLElement` shim which has
  // been imported (see note at the top of this file about how this import is
  // generated by Rollup). Note that the `HTMLElement` variable has been
  // shadowed by this import, so it no longer refers to the global.
   extends HTMLElement {
      /**
       * Adds an initializer function to the class that is called during instance
       * construction.
       *
       * This is useful for code that runs against a `ReactiveElement`
       * subclass, such as a decorator, that needs to do work for each
       * instance, such as setting up a `ReactiveController`.
       *
       * ```ts
       * const myDecorator = (target: typeof ReactiveElement, key: string) => {
       *   target.addInitializer((instance: ReactiveElement) => {
       *     // This is run during construction of the element
       *     new MyController(instance);
       *   });
       * }
       * ```
       *
       * Decorating a field will then cause each instance to run an initializer
       * that adds a controller:
       *
       * ```ts
       * class MyElement extends LitElement {
       *   @myDecorator foo;
       * }
       * ```
       *
       * Initializers are stored per-constructor. Adding an initializer to a
       * subclass does not add it to a superclass. Since initializers are run in
       * constructors, initializers will run in order of the class hierarchy,
       * starting with superclasses and progressing to the instance's class.
       *
       * @nocollapse
       */
      static addInitializer(initializer) {
          this.__prepare();
          (this._initializers ??= []).push(initializer);
      }
      /**
       * Returns a list of attributes corresponding to the registered properties.
       * @nocollapse
       * @category attributes
       */
      static get observedAttributes() {
          // Ensure we've created all properties
          this.finalize();
          // this.__attributeToPropertyMap is only undefined after finalize() in
          // ReactiveElement itself. ReactiveElement.observedAttributes is only
          // accessed with ReactiveElement as the receiver when a subclass or mixin
          // calls super.observedAttributes
          return (this.__attributeToPropertyMap && [...this.__attributeToPropertyMap.keys()]);
      }
      /**
       * Creates a property accessor on the element prototype if one does not exist
       * and stores a {@linkcode PropertyDeclaration} for the property with the
       * given options. The property setter calls the property's `hasChanged`
       * property option or uses a strict identity check to determine whether or not
       * to request an update.
       *
       * This method may be overridden to customize properties; however,
       * when doing so, it's important to call `super.createProperty` to ensure
       * the property is setup correctly. This method calls
       * `getPropertyDescriptor` internally to get a descriptor to install.
       * To customize what properties do when they are get or set, override
       * `getPropertyDescriptor`. To customize the options for a property,
       * implement `createProperty` like this:
       *
       * ```ts
       * static createProperty(name, options) {
       *   options = Object.assign(options, {myOption: true});
       *   super.createProperty(name, options);
       * }
       * ```
       *
       * @nocollapse
       * @category properties
       */
      static createProperty(name, options = defaultPropertyDeclaration$1) {
          // If this is a state property, force the attribute to false.
          if (options.state) {
              options.attribute = false;
          }
          this.__prepare();
          this.elementProperties.set(name, options);
          if (!options.noAccessor) {
              const key = // Use Symbol.for in dev mode to make it easier to maintain state
                      // when doing HMR.
                      Symbol.for(`${String(name)} (@property() cache)`)
                  ;
              const descriptor = this.getPropertyDescriptor(name, key, options);
              if (descriptor !== undefined) {
                  defineProperty(this.prototype, name, descriptor);
              }
          }
      }
      /**
       * Returns a property descriptor to be defined on the given named property.
       * If no descriptor is returned, the property will not become an accessor.
       * For example,
       *
       * ```ts
       * class MyElement extends LitElement {
       *   static getPropertyDescriptor(name, key, options) {
       *     const defaultDescriptor =
       *         super.getPropertyDescriptor(name, key, options);
       *     const setter = defaultDescriptor.set;
       *     return {
       *       get: defaultDescriptor.get,
       *       set(value) {
       *         setter.call(this, value);
       *         // custom action.
       *       },
       *       configurable: true,
       *       enumerable: true
       *     }
       *   }
       * }
       * ```
       *
       * @nocollapse
       * @category properties
       */
      static getPropertyDescriptor(name, key, options) {
          const { get, set } = getOwnPropertyDescriptor(this.prototype, name) ?? {
              get() {
                  return this[key];
              },
              set(v) {
                  this[key] = v;
              },
          };
          if (get == null) {
              if ('value' in (getOwnPropertyDescriptor(this.prototype, name) ?? {})) {
                  throw new Error(`Field ${JSON.stringify(String(name))} on ` +
                      `${this.name} was declared as a reactive property ` +
                      `but it's actually declared as a value on the prototype. ` +
                      `Usually this is due to using @property or @state on a method.`);
              }
              issueWarning$2('reactive-property-without-getter', `Field ${JSON.stringify(String(name))} on ` +
                  `${this.name} was declared as a reactive property ` +
                  `but it does not have a getter. This will be an error in a ` +
                  `future version of Lit.`);
          }
          return {
              get() {
                  return get?.call(this);
              },
              set(value) {
                  const oldValue = get?.call(this);
                  set.call(this, value);
                  this.requestUpdate(name, oldValue, options);
              },
              configurable: true,
              enumerable: true,
          };
      }
      /**
       * Returns the property options associated with the given property.
       * These options are defined with a `PropertyDeclaration` via the `properties`
       * object or the `@property` decorator and are registered in
       * `createProperty(...)`.
       *
       * Note, this method should be considered "final" and not overridden. To
       * customize the options for a given property, override
       * {@linkcode createProperty}.
       *
       * @nocollapse
       * @final
       * @category properties
       */
      static getPropertyOptions(name) {
          return this.elementProperties.get(name) ?? defaultPropertyDeclaration$1;
      }
      /**
       * Initializes static own properties of the class used in bookkeeping
       * for element properties, initializers, etc.
       *
       * Can be called multiple times by code that needs to ensure these
       * properties exist before using them.
       *
       * This method ensures the superclass is finalized so that inherited
       * property metadata can be copied down.
       * @nocollapse
       */
      static __prepare() {
          if (this.hasOwnProperty(JSCompiler_renameProperty$1('elementProperties'))) {
              // Already prepared
              return;
          }
          // Finalize any superclasses
          const superCtor = getPrototypeOf(this);
          superCtor.finalize();
          // Create own set of initializers for this class if any exist on the
          // superclass and copy them down. Note, for a small perf boost, avoid
          // creating initializers unless needed.
          if (superCtor._initializers !== undefined) {
              this._initializers = [...superCtor._initializers];
          }
          // Initialize elementProperties from the superclass
          this.elementProperties = new Map(superCtor.elementProperties);
      }
      /**
       * Finishes setting up the class so that it's ready to be registered
       * as a custom element and instantiated.
       *
       * This method is called by the ReactiveElement.observedAttributes getter.
       * If you override the observedAttributes getter, you must either call
       * super.observedAttributes to trigger finalization, or call finalize()
       * yourself.
       *
       * @nocollapse
       */
      static finalize() {
          if (this.hasOwnProperty(JSCompiler_renameProperty$1('finalized'))) {
              return;
          }
          this.finalized = true;
          this.__prepare();
          // Create properties from the static properties block:
          if (this.hasOwnProperty(JSCompiler_renameProperty$1('properties'))) {
              const props = this.properties;
              const propKeys = [
                  ...getOwnPropertyNames(props),
                  ...getOwnPropertySymbols(props),
              ];
              for (const p of propKeys) {
                  this.createProperty(p, props[p]);
              }
          }
          // Create properties from standard decorator metadata:
          const metadata = this[Symbol.metadata];
          if (metadata !== null) {
              const properties = litPropertyMetadata.get(metadata);
              if (properties !== undefined) {
                  for (const [p, options] of properties) {
                      this.elementProperties.set(p, options);
                  }
              }
          }
          // Create the attribute-to-property map
          this.__attributeToPropertyMap = new Map();
          for (const [p, options] of this.elementProperties) {
              const attr = this.__attributeNameForProperty(p, options);
              if (attr !== undefined) {
                  this.__attributeToPropertyMap.set(attr, p);
              }
          }
          this.elementStyles = this.finalizeStyles(this.styles);
          {
              if (this.hasOwnProperty('createProperty')) {
                  issueWarning$2('no-override-create-property', 'Overriding ReactiveElement.createProperty() is deprecated. ' +
                      'The override will not be called with standard decorators');
              }
              if (this.hasOwnProperty('getPropertyDescriptor')) {
                  issueWarning$2('no-override-get-property-descriptor', 'Overriding ReactiveElement.getPropertyDescriptor() is deprecated. ' +
                      'The override will not be called with standard decorators');
              }
          }
      }
      /**
       * Takes the styles the user supplied via the `static styles` property and
       * returns the array of styles to apply to the element.
       * Override this method to integrate into a style management system.
       *
       * Styles are deduplicated preserving the _last_ instance in the list. This
       * is a performance optimization to avoid duplicated styles that can occur
       * especially when composing via subclassing. The last item is kept to try
       * to preserve the cascade order with the assumption that it's most important
       * that last added styles override previous styles.
       *
       * @nocollapse
       * @category styles
       */
      static finalizeStyles(styles) {
          const elementStyles = [];
          if (Array.isArray(styles)) {
              // Dedupe the flattened array in reverse order to preserve the last items.
              // Casting to Array<unknown> works around TS error that
              // appears to come from trying to flatten a type CSSResultArray.
              const set = new Set(styles.flat(Infinity).reverse());
              // Then preserve original order by adding the set items in reverse order.
              for (const s of set) {
                  elementStyles.unshift(getCompatibleStyle(s));
              }
          }
          else if (styles !== undefined) {
              elementStyles.push(getCompatibleStyle(styles));
          }
          return elementStyles;
      }
      /**
       * Returns the property name for the given attribute `name`.
       * @nocollapse
       */
      static __attributeNameForProperty(name, options) {
          const attribute = options.attribute;
          return attribute === false
              ? undefined
              : typeof attribute === 'string'
                  ? attribute
                  : typeof name === 'string'
                      ? name.toLowerCase()
                      : undefined;
      }
      constructor() {
          super();
          this.__instanceProperties = undefined;
          /**
           * True if there is a pending update as a result of calling `requestUpdate()`.
           * Should only be read.
           * @category updates
           */
          this.isUpdatePending = false;
          /**
           * Is set to `true` after the first update. The element code cannot assume
           * that `renderRoot` exists before the element `hasUpdated`.
           * @category updates
           */
          this.hasUpdated = false;
          /**
           * Name of currently reflecting property
           */
          this.__reflectingProperty = null;
          this.__initialize();
      }
      /**
       * Internal only override point for customizing work done when elements
       * are constructed.
       */
      __initialize() {
          this.__updatePromise = new Promise((res) => (this.enableUpdating = res));
          this._$changedProperties = new Map();
          // This enqueues a microtask that ust run before the first update, so it
          // must be called before requestUpdate()
          this.__saveInstanceProperties();
          // ensures first update will be caught by an early access of
          // `updateComplete`
          this.requestUpdate();
          this.constructor._initializers?.forEach((i) => i(this));
      }
      /**
       * Registers a `ReactiveController` to participate in the element's reactive
       * update cycle. The element automatically calls into any registered
       * controllers during its lifecycle callbacks.
       *
       * If the element is connected when `addController()` is called, the
       * controller's `hostConnected()` callback will be immediately called.
       * @category controllers
       */
      addController(controller) {
          (this.__controllers ??= new Set()).add(controller);
          // If a controller is added after the element has been connected,
          // call hostConnected. Note, re-using existence of `renderRoot` here
          // (which is set in connectedCallback) to avoid the need to track a
          // first connected state.
          if (this.renderRoot !== undefined && this.isConnected) {
              controller.hostConnected?.();
          }
      }
      /**
       * Removes a `ReactiveController` from the element.
       * @category controllers
       */
      removeController(controller) {
          this.__controllers?.delete(controller);
      }
      /**
       * Fixes any properties set on the instance before upgrade time.
       * Otherwise these would shadow the accessor and break these properties.
       * The properties are stored in a Map which is played back after the
       * constructor runs. Note, on very old versions of Safari (<=9) or Chrome
       * (<=41), properties created for native platform properties like (`id` or
       * `name`) may not have default values set in the element constructor. On
       * these browsers native properties appear on instances and therefore their
       * default value will overwrite any element default (e.g. if the element sets
       * this.id = 'id' in the constructor, the 'id' will become '' since this is
       * the native platform default).
       */
      __saveInstanceProperties() {
          const instanceProperties = new Map();
          const elementProperties = this.constructor
              .elementProperties;
          for (const p of elementProperties.keys()) {
              if (this.hasOwnProperty(p)) {
                  instanceProperties.set(p, this[p]);
                  delete this[p];
              }
          }
          if (instanceProperties.size > 0) {
              this.__instanceProperties = instanceProperties;
          }
      }
      /**
       * Returns the node into which the element should render and by default
       * creates and returns an open shadowRoot. Implement to customize where the
       * element's DOM is rendered. For example, to render into the element's
       * childNodes, return `this`.
       *
       * @return Returns a node into which to render.
       * @category rendering
       */
      createRenderRoot() {
          const renderRoot = this.shadowRoot ??
              this.attachShadow(this.constructor.shadowRootOptions);
          adoptStyles(renderRoot, this.constructor.elementStyles);
          return renderRoot;
      }
      /**
       * On first connection, creates the element's renderRoot, sets up
       * element styling, and enables updating.
       * @category lifecycle
       */
      connectedCallback() {
          // Create renderRoot before controllers `hostConnected`
          this.renderRoot ??=
              this.createRenderRoot();
          this.enableUpdating(true);
          this.__controllers?.forEach((c) => c.hostConnected?.());
      }
      /**
       * Note, this method should be considered final and not overridden. It is
       * overridden on the element instance with a function that triggers the first
       * update.
       * @category updates
       */
      enableUpdating(_requestedUpdate) { }
      /**
       * Allows for `super.disconnectedCallback()` in extensions while
       * reserving the possibility of making non-breaking feature additions
       * when disconnecting at some point in the future.
       * @category lifecycle
       */
      disconnectedCallback() {
          this.__controllers?.forEach((c) => c.hostDisconnected?.());
      }
      /**
       * Synchronizes property values when attributes change.
       *
       * Specifically, when an attribute is set, the corresponding property is set.
       * You should rarely need to implement this callback. If this method is
       * overridden, `super.attributeChangedCallback(name, _old, value)` must be
       * called.
       *
       * See [using the lifecycle callbacks](https://developer.mozilla.org/en-US/docs/Web/Web_Components/Using_custom_elements#using_the_lifecycle_callbacks)
       * on MDN for more information about the `attributeChangedCallback`.
       * @category attributes
       */
      attributeChangedCallback(name, _old, value) {
          this._$attributeToProperty(name, value);
      }
      __propertyToAttribute(name, value) {
          const elemProperties = this.constructor.elementProperties;
          const options = elemProperties.get(name);
          const attr = this.constructor.__attributeNameForProperty(name, options);
          if (attr !== undefined && options.reflect === true) {
              const converter = options.converter?.toAttribute !==
                  undefined
                  ? options.converter
                  : defaultConverter;
              const attrValue = converter.toAttribute(value, options.type);
              if (this.constructor.enabledWarnings.includes('migration') &&
                  attrValue === undefined) {
                  issueWarning$2('undefined-attribute-value', `The attribute value for the ${name} property is ` +
                      `undefined on element ${this.localName}. The attribute will be ` +
                      `removed, but in the previous version of \`ReactiveElement\`, ` +
                      `the attribute would not have changed.`);
              }
              // Track if the property is being reflected to avoid
              // setting the property again via `attributeChangedCallback`. Note:
              // 1. this takes advantage of the fact that the callback is synchronous.
              // 2. will behave incorrectly if multiple attributes are in the reaction
              // stack at time of calling. However, since we process attributes
              // in `update` this should not be possible (or an extreme corner case
              // that we'd like to discover).
              // mark state reflecting
              this.__reflectingProperty = name;
              if (attrValue == null) {
                  this.removeAttribute(attr);
              }
              else {
                  this.setAttribute(attr, attrValue);
              }
              // mark state not reflecting
              this.__reflectingProperty = null;
          }
      }
      /** @internal */
      _$attributeToProperty(name, value) {
          const ctor = this.constructor;
          // Note, hint this as an `AttributeMap` so closure clearly understands
          // the type; it has issues with tracking types through statics
          const propName = ctor.__attributeToPropertyMap.get(name);
          // Use tracking info to avoid reflecting a property value to an attribute
          // if it was just set because the attribute changed.
          if (propName !== undefined && this.__reflectingProperty !== propName) {
              const options = ctor.getPropertyOptions(propName);
              const converter = typeof options.converter === 'function'
                  ? { fromAttribute: options.converter }
                  : options.converter?.fromAttribute !== undefined
                      ? options.converter
                      : defaultConverter;
              // mark state reflecting
              this.__reflectingProperty = propName;
              this[propName] = converter.fromAttribute(value, options.type
              // eslint-disable-next-line @typescript-eslint/no-explicit-any
              );
              // mark state not reflecting
              this.__reflectingProperty = null;
          }
      }
      /**
       * Requests an update which is processed asynchronously. This should be called
       * when an element should update based on some state not triggered by setting
       * a reactive property. In this case, pass no arguments. It should also be
       * called when manually implementing a property setter. In this case, pass the
       * property `name` and `oldValue` to ensure that any configured property
       * options are honored.
       *
       * @param name name of requesting property
       * @param oldValue old value of requesting property
       * @param options property options to use instead of the previously
       *     configured options
       * @category updates
       */
      requestUpdate(name, oldValue, options) {
          // If we have a property key, perform property update steps.
          if (name !== undefined) {
              if (name instanceof Event) {
                  issueWarning$2(``, `The requestUpdate() method was called with an Event as the property name. This is probably a mistake caused by binding this.requestUpdate as an event listener. Instead bind a function that will call it with no arguments: () => this.requestUpdate()`);
              }
              options ??= this.constructor.getPropertyOptions(name);
              const hasChanged = options.hasChanged ?? notEqual;
              const newValue = this[name];
              if (hasChanged(newValue, oldValue)) {
                  this._$changeProperty(name, oldValue, options);
              }
              else {
                  // Abort the request if the property should not be considered changed.
                  return;
              }
          }
          if (this.isUpdatePending === false) {
              this.__updatePromise = this.__enqueueUpdate();
          }
      }
      /**
       * @internal
       */
      _$changeProperty(name, oldValue, options) {
          // TODO (justinfagnani): Create a benchmark of Map.has() + Map.set(
          // vs just Map.set()
          if (!this._$changedProperties.has(name)) {
              this._$changedProperties.set(name, oldValue);
          }
          // Add to reflecting properties set.
          // Note, it's important that every change has a chance to add the
          // property to `__reflectingProperties`. This ensures setting
          // attribute + property reflects correctly.
          if (options.reflect === true && this.__reflectingProperty !== name) {
              (this.__reflectingProperties ??= new Set()).add(name);
          }
      }
      /**
       * Sets up the element to asynchronously update.
       */
      async __enqueueUpdate() {
          this.isUpdatePending = true;
          try {
              // Ensure any previous update has resolved before updating.
              // This `await` also ensures that property changes are batched.
              await this.__updatePromise;
          }
          catch (e) {
              // Refire any previous errors async so they do not disrupt the update
              // cycle. Errors are refired so developers have a chance to observe
              // them, and this can be done by implementing
              // `window.onunhandledrejection`.
              Promise.reject(e);
          }
          const result = this.scheduleUpdate();
          // If `scheduleUpdate` returns a Promise, we await it. This is done to
          // enable coordinating updates with a scheduler. Note, the result is
          // checked to avoid delaying an additional microtask unless we need to.
          if (result != null) {
              await result;
          }
          return !this.isUpdatePending;
      }
      /**
       * Schedules an element update. You can override this method to change the
       * timing of updates by returning a Promise. The update will await the
       * returned Promise, and you should resolve the Promise to allow the update
       * to proceed. If this method is overridden, `super.scheduleUpdate()`
       * must be called.
       *
       * For instance, to schedule updates to occur just before the next frame:
       *
       * ```ts
       * override protected async scheduleUpdate(): Promise<unknown> {
       *   await new Promise((resolve) => requestAnimationFrame(() => resolve()));
       *   super.scheduleUpdate();
       * }
       * ```
       * @category updates
       */
      scheduleUpdate() {
          const result = this.performUpdate();
          if (this.constructor.enabledWarnings.includes('async-perform-update') &&
              typeof result?.then ===
                  'function') {
              issueWarning$2('async-perform-update', `Element ${this.localName} returned a Promise from performUpdate(). ` +
                  `This behavior is deprecated and will be removed in a future ` +
                  `version of ReactiveElement.`);
          }
          return result;
      }
      /**
       * Performs an element update. Note, if an exception is thrown during the
       * update, `firstUpdated` and `updated` will not be called.
       *
       * Call `performUpdate()` to immediately process a pending update. This should
       * generally not be needed, but it can be done in rare cases when you need to
       * update synchronously.
       *
       * @category updates
       */
      performUpdate() {
          // Abort any update if one is not pending when this is called.
          // This can happen if `performUpdate` is called early to "flush"
          // the update.
          if (!this.isUpdatePending) {
              return;
          }
          debugLogEvent?.({ kind: 'update' });
          if (!this.hasUpdated) {
              // Create renderRoot before first update. This occurs in `connectedCallback`
              // but is done here to support out of tree calls to `enableUpdating`/`performUpdate`.
              this.renderRoot ??=
                  this.createRenderRoot();
              {
                  // Produce warning if any reactive properties on the prototype are
                  // shadowed by class fields. Instance fields set before upgrade are
                  // deleted by this point, so any own property is caused by class field
                  // initialization in the constructor.
                  const ctor = this.constructor;
                  const shadowedProperties = [...ctor.elementProperties.keys()].filter((p) => this.hasOwnProperty(p) && p in getPrototypeOf(this));
                  if (shadowedProperties.length) {
                      throw new Error(`The following properties on element ${this.localName} will not ` +
                          `trigger updates as expected because they are set using class ` +
                          `fields: ${shadowedProperties.join(', ')}. ` +
                          `Native class fields and some compiled output will overwrite ` +
                          `accessors used for detecting changes. See ` +
                          `https://lit.dev/msg/class-field-shadowing ` +
                          `for more information.`);
                  }
              }
              // Mixin instance properties once, if they exist.
              if (this.__instanceProperties) {
                  // TODO (justinfagnani): should we use the stored value? Could a new value
                  // have been set since we stored the own property value?
                  for (const [p, value] of this.__instanceProperties) {
                      this[p] = value;
                  }
                  this.__instanceProperties = undefined;
              }
              // Trigger initial value reflection and populate the initial
              // changedProperties map, but only for the case of experimental
              // decorators on accessors, which will not have already populated the
              // changedProperties map. We can't know if these accessors had
              // initializers, so we just set them anyway - a difference from
              // experimental decorators on fields and standard decorators on
              // auto-accessors.
              // For context why experimentalDecorators with auto accessors are handled
              // specifically also see:
              // https://github.com/lit/lit/pull/4183#issuecomment-1711959635
              const elementProperties = this.constructor
                  .elementProperties;
              if (elementProperties.size > 0) {
                  for (const [p, options] of elementProperties) {
                      if (options.wrapped === true &&
                          !this._$changedProperties.has(p) &&
                          this[p] !== undefined) {
                          this._$changeProperty(p, this[p], options);
                      }
                  }
              }
          }
          let shouldUpdate = false;
          const changedProperties = this._$changedProperties;
          try {
              shouldUpdate = this.shouldUpdate(changedProperties);
              if (shouldUpdate) {
                  this.willUpdate(changedProperties);
                  this.__controllers?.forEach((c) => c.hostUpdate?.());
                  this.update(changedProperties);
              }
              else {
                  this.__markUpdated();
              }
          }
          catch (e) {
              // Prevent `firstUpdated` and `updated` from running when there's an
              // update exception.
              shouldUpdate = false;
              // Ensure element can accept additional updates after an exception.
              this.__markUpdated();
              throw e;
          }
          // The update is no longer considered pending and further updates are now allowed.
          if (shouldUpdate) {
              this._$didUpdate(changedProperties);
          }
      }
      /**
       * Invoked before `update()` to compute values needed during the update.
       *
       * Implement `willUpdate` to compute property values that depend on other
       * properties and are used in the rest of the update process.
       *
       * ```ts
       * willUpdate(changedProperties) {
       *   // only need to check changed properties for an expensive computation.
       *   if (changedProperties.has('firstName') || changedProperties.has('lastName')) {
       *     this.sha = computeSHA(`${this.firstName} ${this.lastName}`);
       *   }
       * }
       *
       * render() {
       *   return html`SHA: ${this.sha}`;
       * }
       * ```
       *
       * @category updates
       */
      willUpdate(_changedProperties) { }
      // Note, this is an override point for polyfill-support.
      // @internal
      _$didUpdate(changedProperties) {
          this.__controllers?.forEach((c) => c.hostUpdated?.());
          if (!this.hasUpdated) {
              this.hasUpdated = true;
              this.firstUpdated(changedProperties);
          }
          this.updated(changedProperties);
          if (this.isUpdatePending &&
              this.constructor.enabledWarnings.includes('change-in-update')) {
              issueWarning$2('change-in-update', `Element ${this.localName} scheduled an update ` +
                  `(generally because a property was set) ` +
                  `after an update completed, causing a new update to be scheduled. ` +
                  `This is inefficient and should be avoided unless the next update ` +
                  `can only be scheduled as a side effect of the previous update.`);
          }
      }
      __markUpdated() {
          this._$changedProperties = new Map();
          this.isUpdatePending = false;
      }
      /**
       * Returns a Promise that resolves when the element has completed updating.
       * The Promise value is a boolean that is `true` if the element completed the
       * update without triggering another update. The Promise result is `false` if
       * a property was set inside `updated()`. If the Promise is rejected, an
       * exception was thrown during the update.
       *
       * To await additional asynchronous work, override the `getUpdateComplete`
       * method. For example, it is sometimes useful to await a rendered element
       * before fulfilling this Promise. To do this, first await
       * `super.getUpdateComplete()`, then any subsequent state.
       *
       * @return A promise of a boolean that resolves to true if the update completed
       *     without triggering another update.
       * @category updates
       */
      get updateComplete() {
          return this.getUpdateComplete();
      }
      /**
       * Override point for the `updateComplete` promise.
       *
       * It is not safe to override the `updateComplete` getter directly due to a
       * limitation in TypeScript which means it is not possible to call a
       * superclass getter (e.g. `super.updateComplete.then(...)`) when the target
       * language is ES5 (https://github.com/microsoft/TypeScript/issues/338).
       * This method should be overridden instead. For example:
       *
       * ```ts
       * class MyElement extends LitElement {
       *   override async getUpdateComplete() {
       *     const result = await super.getUpdateComplete();
       *     await this._myChild.updateComplete;
       *     return result;
       *   }
       * }
       * ```
       *
       * @return A promise of a boolean that resolves to true if the update completed
       *     without triggering another update.
       * @category updates
       */
      getUpdateComplete() {
          return this.__updatePromise;
      }
      /**
       * Controls whether or not `update()` should be called when the element requests
       * an update. By default, this method always returns `true`, but this can be
       * customized to control when to update.
       *
       * @param _changedProperties Map of changed properties with old values
       * @category updates
       */
      shouldUpdate(_changedProperties) {
          return true;
      }
      /**
       * Updates the element. This method reflects property values to attributes.
       * It can be overridden to render and keep updated element DOM.
       * Setting properties inside this method will *not* trigger
       * another update.
       *
       * @param _changedProperties Map of changed properties with old values
       * @category updates
       */
      update(_changedProperties) {
          // The forEach() expression will only run when when __reflectingProperties is
          // defined, and it returns undefined, setting __reflectingProperties to
          // undefined
          this.__reflectingProperties &&= this.__reflectingProperties.forEach((p) => this.__propertyToAttribute(p, this[p]));
          this.__markUpdated();
      }
      /**
       * Invoked whenever the element is updated. Implement to perform
       * post-updating tasks via DOM APIs, for example, focusing an element.
       *
       * Setting properties inside this method will trigger the element to update
       * again after this update cycle completes.
       *
       * @param _changedProperties Map of changed properties with old values
       * @category updates
       */
      updated(_changedProperties) { }
      /**
       * Invoked when the element is first updated. Implement to perform one time
       * work on the element after update.
       *
       * ```ts
       * firstUpdated() {
       *   this.renderRoot.getElementById('my-text-area').focus();
       * }
       * ```
       *
       * Setting properties inside this method will trigger the element to update
       * again after this update cycle completes.
       *
       * @param _changedProperties Map of changed properties with old values
       * @category updates
       */
      firstUpdated(_changedProperties) { }
  }
  /**
   * Memoized list of all element styles.
   * Created lazily on user subclasses when finalizing the class.
   * @nocollapse
   * @category styles
   */
  ReactiveElement.elementStyles = [];
  /**
   * Options used when calling `attachShadow`. Set this property to customize
   * the options for the shadowRoot; for example, to create a closed
   * shadowRoot: `{mode: 'closed'}`.
   *
   * Note, these options are used in `createRenderRoot`. If this method
   * is customized, options should be respected if possible.
   * @nocollapse
   * @category rendering
   */
  ReactiveElement.shadowRootOptions = { mode: 'open' };
  // Assigned here to work around a jscompiler bug with static fields
  // when compiling to ES5.
  // https://github.com/google/closure-compiler/issues/3177
  ReactiveElement[JSCompiler_renameProperty$1('elementProperties')] = new Map();
  ReactiveElement[JSCompiler_renameProperty$1('finalized')] = new Map();
  // Apply polyfills if available
  polyfillSupport$1?.({ ReactiveElement });
  // Dev mode warnings...
  {
      // Default warning set.
      ReactiveElement.enabledWarnings = [
          'change-in-update',
          'async-perform-update',
      ];
      const ensureOwnWarnings = function (ctor) {
          if (!ctor.hasOwnProperty(JSCompiler_renameProperty$1('enabledWarnings'))) {
              ctor.enabledWarnings = ctor.enabledWarnings.slice();
          }
      };
      ReactiveElement.enableWarning = function (warning) {
          ensureOwnWarnings(this);
          if (!this.enabledWarnings.includes(warning)) {
              this.enabledWarnings.push(warning);
          }
      };
      ReactiveElement.disableWarning = function (warning) {
          ensureOwnWarnings(this);
          const i = this.enabledWarnings.indexOf(warning);
          if (i >= 0) {
              this.enabledWarnings.splice(i, 1);
          }
      };
  }
  // IMPORTANT: do not change the property name or the assignment expression.
  // This line will be used in regexes to search for ReactiveElement usage.
  (global.reactiveElementVersions ??= []).push('2.0.4');
  if (global.reactiveElementVersions.length > 1) {
      issueWarning$2('multiple-versions', `Multiple versions of Lit loaded. Loading multiple versions ` +
          `is not recommended.`);
  }

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  /*
   * When using Closure Compiler, JSCompiler_renameProperty(property, object) is
   * replaced at compile time by the munged name for object[property]. We cannot
   * alias this function, so we have to use a small shim that has the same
   * behavior when not compiling.
   */
  /*@__INLINE__*/
  const JSCompiler_renameProperty = (prop, _obj) => prop;
  let issueWarning$1;
  {
      // Ensure warnings are issued only 1x, even if multiple versions of Lit
      // are loaded.
      const issuedWarnings = (globalThis.litIssuedWarnings ??= new Set());
      // Issue a warning, if we haven't already.
      issueWarning$1 = (code, warning) => {
          warning += ` See https://lit.dev/msg/${code} for more information.`;
          if (!issuedWarnings.has(warning)) {
              console.warn(warning);
              issuedWarnings.add(warning);
          }
      };
  }
  /**
   * Base element class that manages element properties and attributes, and
   * renders a lit-html template.
   *
   * To define a component, subclass `LitElement` and implement a
   * `render` method to provide the component's template. Define properties
   * using the {@linkcode LitElement.properties properties} property or the
   * {@linkcode property} decorator.
   */
  class LitElement extends ReactiveElement {
      constructor() {
          super(...arguments);
          /**
           * @category rendering
           */
          this.renderOptions = { host: this };
          this.__childPart = undefined;
      }
      /**
       * @category rendering
       */
      createRenderRoot() {
          const renderRoot = super.createRenderRoot();
          // When adoptedStyleSheets are shimmed, they are inserted into the
          // shadowRoot by createRenderRoot. Adjust the renderBefore node so that
          // any styles in Lit content render before adoptedStyleSheets. This is
          // important so that adoptedStyleSheets have precedence over styles in
          // the shadowRoot.
          this.renderOptions.renderBefore ??= renderRoot.firstChild;
          return renderRoot;
      }
      /**
       * Updates the element. This method reflects property values to attributes
       * and calls `render` to render DOM via lit-html. Setting properties inside
       * this method will *not* trigger another update.
       * @param changedProperties Map of changed properties with old values
       * @category updates
       */
      update(changedProperties) {
          // Setting properties in `render` should not trigger an update. Since
          // updates are allowed after super.update, it's important to call `render`
          // before that.
          const value = this.render();
          if (!this.hasUpdated) {
              this.renderOptions.isConnected = this.isConnected;
          }
          super.update(changedProperties);
          this.__childPart = render(value, this.renderRoot, this.renderOptions);
      }
      /**
       * Invoked when the component is added to the document's DOM.
       *
       * In `connectedCallback()` you should setup tasks that should only occur when
       * the element is connected to the document. The most common of these is
       * adding event listeners to nodes external to the element, like a keydown
       * event handler added to the window.
       *
       * ```ts
       * connectedCallback() {
       *   super.connectedCallback();
       *   addEventListener('keydown', this._handleKeydown);
       * }
       * ```
       *
       * Typically, anything done in `connectedCallback()` should be undone when the
       * element is disconnected, in `disconnectedCallback()`.
       *
       * @category lifecycle
       */
      connectedCallback() {
          super.connectedCallback();
          this.__childPart?.setConnected(true);
      }
      /**
       * Invoked when the component is removed from the document's DOM.
       *
       * This callback is the main signal to the element that it may no longer be
       * used. `disconnectedCallback()` should ensure that nothing is holding a
       * reference to the element (such as event listeners added to nodes external
       * to the element), so that it is free to be garbage collected.
       *
       * ```ts
       * disconnectedCallback() {
       *   super.disconnectedCallback();
       *   window.removeEventListener('keydown', this._handleKeydown);
       * }
       * ```
       *
       * An element may be re-connected after being disconnected.
       *
       * @category lifecycle
       */
      disconnectedCallback() {
          super.disconnectedCallback();
          this.__childPart?.setConnected(false);
      }
      /**
       * Invoked on each update to perform rendering tasks. This method may return
       * any value renderable by lit-html's `ChildPart` - typically a
       * `TemplateResult`. Setting properties inside this method will *not* trigger
       * the element to update.
       * @category rendering
       */
      render() {
          return noChange;
      }
  }
  // This property needs to remain unminified.
  LitElement['_$litElement$'] = true;
  /**
   * Ensure this class is marked as `finalized` as an optimization ensuring
   * it will not needlessly try to `finalize`.
   *
   * Note this property name is a string to prevent breaking Closure JS Compiler
   * optimizations. See @lit/reactive-element for more information.
   */
  LitElement[JSCompiler_renameProperty('finalized')] = true;
  // Install hydration if available
  globalThis.litElementHydrateSupport?.({ LitElement });
  // Apply polyfills if available
  const polyfillSupport = globalThis.litElementPolyfillSupportDevMode
      ;
  polyfillSupport?.({ LitElement });
  // IMPORTANT: do not change the property name or the assignment expression.
  // This line will be used in regexes to search for LitElement usage.
  (globalThis.litElementVersions ??= []).push('4.1.0');
  if (globalThis.litElementVersions.length > 1) {
      issueWarning$1('multiple-versions', `Multiple versions of Lit loaded. Loading multiple versions ` +
          `is not recommended.`);
  }

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  let issueWarning;
  {
      // Ensure warnings are issued only 1x, even if multiple versions of Lit
      // are loaded.
      const issuedWarnings = (globalThis.litIssuedWarnings ??= new Set());
      // Issue a warning, if we haven't already.
      issueWarning = (code, warning) => {
          warning += ` See https://lit.dev/msg/${code} for more information.`;
          if (!issuedWarnings.has(warning)) {
              console.warn(warning);
              issuedWarnings.add(warning);
          }
      };
  }
  const legacyProperty = (options, proto, name) => {
      const hasOwnProperty = proto.hasOwnProperty(name);
      proto.constructor.createProperty(name, hasOwnProperty ? { ...options, wrapped: true } : options);
      // For accessors (which have a descriptor on the prototype) we need to
      // return a descriptor, otherwise TypeScript overwrites the descriptor we
      // define in createProperty() with the original descriptor. We don't do this
      // for fields, which don't have a descriptor, because this could overwrite
      // descriptor defined by other decorators.
      return hasOwnProperty
          ? Object.getOwnPropertyDescriptor(proto, name)
          : undefined;
  };
  // This is duplicated from a similar variable in reactive-element.ts, but
  // actually makes sense to have this default defined with the decorator, so
  // that different decorators could have different defaults.
  const defaultPropertyDeclaration = {
      attribute: true,
      type: String,
      converter: defaultConverter$1,
      reflect: false,
      hasChanged: notEqual$1,
  };
  /**
   * Wraps a class accessor or setter so that `requestUpdate()` is called with the
   * property name and old value when the accessor is set.
   */
  const standardProperty = (options = defaultPropertyDeclaration, target, context) => {
      const { kind, metadata } = context;
      if (metadata == null) {
          issueWarning('missing-class-metadata', `The class ${target} is missing decorator metadata. This ` +
              `could mean that you're using a compiler that supports decorators ` +
              `but doesn't support decorator metadata, such as TypeScript 5.1. ` +
              `Please update your compiler.`);
      }
      // Store the property options
      let properties = globalThis.litPropertyMetadata.get(metadata);
      if (properties === undefined) {
          globalThis.litPropertyMetadata.set(metadata, (properties = new Map()));
      }
      properties.set(context.name, options);
      if (kind === 'accessor') {
          // Standard decorators cannot dynamically modify the class, so we can't
          // replace a field with accessors. The user must use the new `accessor`
          // keyword instead.
          const { name } = context;
          return {
              set(v) {
                  const oldValue = target.get.call(this);
                  target.set.call(this, v);
                  this.requestUpdate(name, oldValue, options);
              },
              init(v) {
                  if (v !== undefined) {
                      this._$changeProperty(name, undefined, options);
                  }
                  return v;
              },
          };
      }
      else if (kind === 'setter') {
          const { name } = context;
          return function (value) {
              const oldValue = this[name];
              target.call(this, value);
              this.requestUpdate(name, oldValue, options);
          };
      }
      throw new Error(`Unsupported decorator location: ${kind}`);
  };
  /**
   * A class field or accessor decorator which creates a reactive property that
   * reflects a corresponding attribute value. When a decorated property is set
   * the element will update and render. A {@linkcode PropertyDeclaration} may
   * optionally be supplied to configure property features.
   *
   * This decorator should only be used for public fields. As public fields,
   * properties should be considered as primarily settable by element users,
   * either via attribute or the property itself.
   *
   * Generally, properties that are changed by the element should be private or
   * protected fields and should use the {@linkcode state} decorator.
   *
   * However, sometimes element code does need to set a public property. This
   * should typically only be done in response to user interaction, and an event
   * should be fired informing the user; for example, a checkbox sets its
   * `checked` property when clicked and fires a `changed` event. Mutating public
   * properties should typically not be done for non-primitive (object or array)
   * properties. In other cases when an element needs to manage state, a private
   * property decorated via the {@linkcode state} decorator should be used. When
   * needed, state properties can be initialized via public properties to
   * facilitate complex interactions.
   *
   * ```ts
   * class MyElement {
   *   @property({ type: Boolean })
   *   clicked = false;
   * }
   * ```
   * @category Decorator
   * @ExportDecoratedItems
   */
  function property(options) {
      return (protoOrTarget, nameOrContext
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      ) => {
          return (typeof nameOrContext === 'object'
              ? standardProperty(options, protoOrTarget, nameOrContext)
              : legacyProperty(options, protoOrTarget, nameOrContext));
      };
  }

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  /**
   * Declares a private or protected reactive property that still triggers
   * updates to the element when it changes. It does not reflect from the
   * corresponding attribute.
   *
   * Properties declared this way must not be used from HTML or HTML templating
   * systems, they're solely for properties internal to the element. These
   * properties may be renamed by optimization tools like closure compiler.
   * @category Decorator
   */
  function state(options) {
      return property({
          ...options,
          // Add both `state` and `attribute` because we found a third party
          // controller that is keying off of PropertyOptions.state to determine
          // whether a field is a private internal property or not.
          state: true,
          attribute: false,
      });
  }

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  /**
   * Wraps up a few best practices when returning a property descriptor from a
   * decorator.
   *
   * Marks the defined property as configurable, and enumerable, and handles
   * the case where we have a busted Reflect.decorate zombiefill (e.g. in Angular
   * apps).
   *
   * @internal
   */
  const desc = (obj, name, descriptor) => {
      // For backwards compatibility, we keep them configurable and enumerable.
      descriptor.configurable = true;
      descriptor.enumerable = true;
      if (
      // We check for Reflect.decorate each time, in case the zombiefill
      // is applied via lazy loading some Angular code.
      Reflect.decorate &&
          typeof name !== 'object') {
          // If we're called as a legacy decorator, and Reflect.decorate is present
          // then we have no guarantees that the returned descriptor will be
          // defined on the class, so we must apply it directly ourselves.
          Object.defineProperty(obj, name, descriptor);
      }
      return descriptor;
  };

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  {
      // Ensure warnings are issued only 1x, even if multiple versions of Lit
      // are loaded.
      (globalThis.litIssuedWarnings ??= new Set());
  }

  /**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  /**
   * A property decorator that converts a class property into a getter that
   * returns the `assignedElements` of the given `slot`. Provides a declarative
   * way to use
   * [`HTMLSlotElement.assignedElements`](https://developer.mozilla.org/en-US/docs/Web/API/HTMLSlotElement/assignedElements).
   *
   * Can be passed an optional {@linkcode QueryAssignedElementsOptions} object.
   *
   * Example usage:
   * ```ts
   * class MyElement {
   *   @queryAssignedElements({ slot: 'list' })
   *   listItems!: Array<HTMLElement>;
   *   @queryAssignedElements()
   *   unnamedSlotEls!: Array<HTMLElement>;
   *
   *   render() {
   *     return html`
   *       <slot name="list"></slot>
   *       <slot></slot>
   *     `;
   *   }
   * }
   * ```
   *
   * Note, the type of this property should be annotated as `Array<HTMLElement>`.
   *
   * @category Decorator
   */
  function queryAssignedElements(options) {
      return ((obj, name) => {
          const { slot, selector } = options ?? {};
          const slotSelector = `slot${slot ? `[name=${slot}]` : ':not([name])'}`;
          return desc(obj, name, {
              get() {
                  const slotEl = this.renderRoot?.querySelector(slotSelector);
                  const elements = slotEl?.assignedElements(options) ?? [];
                  return (selector === undefined
                      ? elements
                      : elements.filter((node) => node.matches(selector)));
              },
          });
      });
  }

  /**
   * @license
   * Copyright 2020 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  window.ShadyDOM?.inUse &&
      window.ShadyDOM?.noPatch === true
      ? window.ShadyDOM.wrap
      : (node) => node;
  /**
   * Tests whether a part has only a single-expression with no strings to
   * interpolate between.
   *
   * Only AttributePart and PropertyPart can have multiple expressions.
   * Multi-expression parts have a `strings` property and single-expression
   * parts do not.
   */
  const isSingleExpression = (part) => part.strings === undefined;

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  const PartType = {
      ATTRIBUTE: 1,
      CHILD: 2,
      PROPERTY: 3,
      BOOLEAN_ATTRIBUTE: 4,
      EVENT: 5,
      ELEMENT: 6,
  };
  /**
   * Creates a user-facing directive function from a Directive class. This
   * function has the same parameters as the directive's render() method.
   */
  const directive = (c) => (...values) => ({
      // This property needs to remain unminified.
      ['_$litDirective$']: c,
      values,
  });
  /**
   * Base class for creating custom directives. Users should extend this class,
   * implement `render` and/or `update`, and then pass their subclass to
   * `directive`.
   */
  class Directive {
      constructor(_partInfo) { }
      // See comment in Disconnectable interface for why this is a getter
      get _$isConnected() {
          return this._$parent._$isConnected;
      }
      /** @internal */
      _$initialize(part, parent, attributeIndex) {
          this.__part = part;
          this._$parent = parent;
          this.__attributeIndex = attributeIndex;
      }
      /** @internal */
      _$resolve(part, props) {
          return this.update(part, props);
      }
      update(_part, props) {
          return this.render(...props);
      }
  }

  /**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  /**
   * Recursively walks down the tree of Parts/TemplateInstances/Directives to set
   * the connected state of directives and run `disconnected`/ `reconnected`
   * callbacks.
   *
   * @return True if there were children to disconnect; false otherwise
   */
  const notifyChildrenConnectedChanged = (parent, isConnected) => {
      const children = parent._$disconnectableChildren;
      if (children === undefined) {
          return false;
      }
      for (const obj of children) {
          // The existence of `_$notifyDirectiveConnectionChanged` is used as a "brand" to
          // disambiguate AsyncDirectives from other DisconnectableChildren
          // (as opposed to using an instanceof check to know when to call it); the
          // redundancy of "Directive" in the API name is to avoid conflicting with
          // `_$notifyConnectionChanged`, which exists `ChildParts` which are also in
          // this list
          // Disconnect Directive (and any nested directives contained within)
          // This property needs to remain unminified.
          obj['_$notifyDirectiveConnectionChanged']?.(isConnected, false);
          // Disconnect Part/TemplateInstance
          notifyChildrenConnectedChanged(obj, isConnected);
      }
      return true;
  };
  /**
   * Removes the given child from its parent list of disconnectable children, and
   * if the parent list becomes empty as a result, removes the parent from its
   * parent, and so forth up the tree when that causes subsequent parent lists to
   * become empty.
   */
  const removeDisconnectableFromParent = (obj) => {
      let parent, children;
      do {
          if ((parent = obj._$parent) === undefined) {
              break;
          }
          children = parent._$disconnectableChildren;
          children.delete(obj);
          obj = parent;
      } while (children?.size === 0);
  };
  const addDisconnectableToParent = (obj) => {
      // Climb the parent tree, creating a sparse tree of children needing
      // disconnection
      for (let parent; (parent = obj._$parent); obj = parent) {
          let children = parent._$disconnectableChildren;
          if (children === undefined) {
              parent._$disconnectableChildren = children = new Set();
          }
          else if (children.has(obj)) {
              // Once we've reached a parent that already contains this child, we
              // can short-circuit
              break;
          }
          children.add(obj);
          installDisconnectAPI(parent);
      }
  };
  /**
   * Changes the parent reference of the ChildPart, and updates the sparse tree of
   * Disconnectable children accordingly.
   *
   * Note, this method will be patched onto ChildPart instances and called from
   * the core code when parts are moved between different parents.
   */
  function reparentDisconnectables(newParent) {
      if (this._$disconnectableChildren !== undefined) {
          removeDisconnectableFromParent(this);
          this._$parent = newParent;
          addDisconnectableToParent(this);
      }
      else {
          this._$parent = newParent;
      }
  }
  /**
   * Sets the connected state on any directives contained within the committed
   * value of this part (i.e. within a TemplateInstance or iterable of
   * ChildParts) and runs their `disconnected`/`reconnected`s, as well as within
   * any directives stored on the ChildPart (when `valueOnly` is false).
   *
   * `isClearingValue` should be passed as `true` on a top-level part that is
   * clearing itself, and not as a result of recursively disconnecting directives
   * as part of a `clear` operation higher up the tree. This both ensures that any
   * directive on this ChildPart that produced a value that caused the clear
   * operation is not disconnected, and also serves as a performance optimization
   * to avoid needless bookkeeping when a subtree is going away; when clearing a
   * subtree, only the top-most part need to remove itself from the parent.
   *
   * `fromPartIndex` is passed only in the case of a partial `_clear` running as a
   * result of truncating an iterable.
   *
   * Note, this method will be patched onto ChildPart instances and called from the
   * core code when parts are cleared or the connection state is changed by the
   * user.
   */
  function notifyChildPartConnectedChanged(isConnected, isClearingValue = false, fromPartIndex = 0) {
      const value = this._$committedValue;
      const children = this._$disconnectableChildren;
      if (children === undefined || children.size === 0) {
          return;
      }
      if (isClearingValue) {
          if (Array.isArray(value)) {
              // Iterable case: Any ChildParts created by the iterable should be
              // disconnected and removed from this ChildPart's disconnectable
              // children (starting at `fromPartIndex` in the case of truncation)
              for (let i = fromPartIndex; i < value.length; i++) {
                  notifyChildrenConnectedChanged(value[i], false);
                  removeDisconnectableFromParent(value[i]);
              }
          }
          else if (value != null) {
              // TemplateInstance case: If the value has disconnectable children (will
              // only be in the case that it is a TemplateInstance), we disconnect it
              // and remove it from this ChildPart's disconnectable children
              notifyChildrenConnectedChanged(value, false);
              removeDisconnectableFromParent(value);
          }
      }
      else {
          notifyChildrenConnectedChanged(this, isConnected);
      }
  }
  /**
   * Patches disconnection API onto ChildParts.
   */
  const installDisconnectAPI = (obj) => {
      if (obj.type == PartType.CHILD) {
          obj._$notifyConnectionChanged ??=
              notifyChildPartConnectedChanged;
          obj._$reparentDisconnectables ??= reparentDisconnectables;
      }
  };
  /**
   * An abstract `Directive` base class whose `disconnected` method will be
   * called when the part containing the directive is cleared as a result of
   * re-rendering, or when the user calls `part.setConnected(false)` on
   * a part that was previously rendered containing the directive (as happens
   * when e.g. a LitElement disconnects from the DOM).
   *
   * If `part.setConnected(true)` is subsequently called on a
   * containing part, the directive's `reconnected` method will be called prior
   * to its next `update`/`render` callbacks. When implementing `disconnected`,
   * `reconnected` should also be implemented to be compatible with reconnection.
   *
   * Note that updates may occur while the directive is disconnected. As such,
   * directives should generally check the `this.isConnected` flag during
   * render/update to determine whether it is safe to subscribe to resources
   * that may prevent garbage collection.
   */
  class AsyncDirective extends Directive {
      constructor() {
          super(...arguments);
          // @internal
          this._$disconnectableChildren = undefined;
      }
      /**
       * Initialize the part with internal fields
       * @param part
       * @param parent
       * @param attributeIndex
       */
      _$initialize(part, parent, attributeIndex) {
          super._$initialize(part, parent, attributeIndex);
          addDisconnectableToParent(this);
          this.isConnected = part._$isConnected;
      }
      // This property needs to remain unminified.
      /**
       * Called from the core code when a directive is going away from a part (in
       * which case `shouldRemoveFromParent` should be true), and from the
       * `setChildrenConnected` helper function when recursively changing the
       * connection state of a tree (in which case `shouldRemoveFromParent` should
       * be false).
       *
       * @param isConnected
       * @param isClearingDirective - True when the directive itself is being
       *     removed; false when the tree is being disconnected
       * @internal
       */
      ['_$notifyDirectiveConnectionChanged'](isConnected, isClearingDirective = true) {
          if (isConnected !== this.isConnected) {
              this.isConnected = isConnected;
              if (isConnected) {
                  this.reconnected?.();
              }
              else {
                  this.disconnected?.();
              }
          }
          if (isClearingDirective) {
              notifyChildrenConnectedChanged(this, isConnected);
              removeDisconnectableFromParent(this);
          }
      }
      /**
       * Sets the value of the directive's Part outside the normal `update`/`render`
       * lifecycle of a directive.
       *
       * This method should not be called synchronously from a directive's `update`
       * or `render`.
       *
       * @param directive The directive to update
       * @param value The value to set
       */
      setValue(value) {
          if (isSingleExpression(this.__part)) {
              this.__part._$setValue(value, this);
          }
          else {
              // this.__attributeIndex will be defined in this case, but
              // assert it in dev mode
              if (this.__attributeIndex === undefined) {
                  throw new Error(`Expected this.__attributeIndex to be a number`);
              }
              const newValues = [...this.__part._$committedValue];
              newValues[this.__attributeIndex] = value;
              this.__part._$setValue(newValues, this, 0);
          }
      }
      /**
       * User callbacks for implementing logic to release any resources/subscriptions
       * that may have been retained by this directive. Since directives may also be
       * re-connected, `reconnected` should also be implemented to restore the
       * working state of the directive prior to the next render.
       */
      disconnected() { }
      reconnected() { }
  }

  /**
   * @license
   * Copyright 2020 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   */
  /**
   * Creates a new Ref object, which is container for a reference to an element.
   */
  const createRef = () => new Ref();
  /**
   * An object that holds a ref value.
   */
  class Ref {
  }
  // When callbacks are used for refs, this map tracks the last value the callback
  // was called with, for ensuring a directive doesn't clear the ref if the ref
  // has already been rendered to a new spot. It is double-keyed on both the
  // context (`options.host`) and the callback, since we auto-bind class methods
  // to `options.host`.
  const lastElementForContextAndCallback = new WeakMap();
  class RefDirective extends AsyncDirective {
      render(_ref) {
          return nothing;
      }
      update(part, [ref]) {
          const refChanged = ref !== this._ref;
          if (refChanged && this._ref !== undefined) {
              // The ref passed to the directive has changed;
              // unset the previous ref's value
              this._updateRefValue(undefined);
          }
          if (refChanged || this._lastElementForRef !== this._element) {
              // We either got a new ref or this is the first render;
              // store the ref/element & update the ref value
              this._ref = ref;
              this._context = part.options?.host;
              this._updateRefValue((this._element = part.element));
          }
          return nothing;
      }
      _updateRefValue(element) {
          if (!this.isConnected) {
              element = undefined;
          }
          if (typeof this._ref === 'function') {
              // If the current ref was called with a previous value, call with
              // `undefined`; We do this to ensure callbacks are called in a consistent
              // way regardless of whether a ref might be moving up in the tree (in
              // which case it would otherwise be called with the new value before the
              // previous one unsets it) and down in the tree (where it would be unset
              // before being set). Note that element lookup is keyed by
              // both the context and the callback, since we allow passing unbound
              // functions that are called on options.host, and we want to treat
              // these as unique "instances" of a function.
              const context = this._context ?? globalThis;
              let lastElementForCallback = lastElementForContextAndCallback.get(context);
              if (lastElementForCallback === undefined) {
                  lastElementForCallback = new WeakMap();
                  lastElementForContextAndCallback.set(context, lastElementForCallback);
              }
              if (lastElementForCallback.get(this._ref) !== undefined) {
                  this._ref.call(this._context, undefined);
              }
              lastElementForCallback.set(this._ref, element);
              // Call the ref with the new element value
              if (element !== undefined) {
                  this._ref.call(this._context, element);
              }
          }
          else {
              this._ref.value = element;
          }
      }
      get _lastElementForRef() {
          return typeof this._ref === 'function'
              ? lastElementForContextAndCallback
                  .get(this._context ?? globalThis)
                  ?.get(this._ref)
              : this._ref?.value;
      }
      disconnected() {
          // Only clear the box if our element is still the one in it (i.e. another
          // directive instance hasn't rendered its element to it before us); that
          // only happens in the event of the directive being cleared (not via manual
          // disconnection)
          if (this._lastElementForRef === this._element) {
              this._updateRefValue(undefined);
          }
      }
      reconnected() {
          // If we were manually disconnected, we can safely put our element back in
          // the box, since no rendering could have occurred to change its state
          this._updateRefValue(this._element);
      }
  }
  /**
   * Sets the value of a Ref object or calls a ref callback with the element it's
   * bound to.
   *
   * A Ref object acts as a container for a reference to an element. A ref
   * callback is a function that takes an element as its only argument.
   *
   * The ref directive sets the value of the Ref object or calls the ref callback
   * during rendering, if the referenced element changed.
   *
   * Note: If a ref callback is rendered to a different element position or is
   * removed in a subsequent render, it will first be called with `undefined`,
   * followed by another call with the new element it was rendered to (if any).
   *
   * ```js
   * // Using Ref object
   * const inputRef = createRef();
   * render(html`<input ${ref(inputRef)}>`, container);
   * inputRef.value.focus();
   *
   * // Using callback
   * const callback = (inputElement) => inputElement.focus();
   * render(html`<input ${ref(callback)}>`, container);
   * ```
   */
  const ref = directive(RefDirective);

  var css_248z$1 = css`:host{-webkit-text-size-adjust:100%;-webkit-tap-highlight-color:rgba(0,0,0,0);color:var(--sgds-body-color-default);font-family:var(--sgds-font-family-brand);font-size:var(--sgds-font-size-2);font-weight:var(--sgds-font-weight-regular);line-height:var(--sgds-line-height-body);margin:0;*,:after,:before{box-sizing:border-box}:disabled{cursor:not-allowed}@media (prefers-reduced-motion:no-preference){:root{scroll-behavior:smooth}}a[target=_blank]{align-items:center;display:flex;gap:var(--sgds-gap-2-xs)}::slotted(a[target=_blank]):after,a[target=_blank]:after{background-color:currentColor;content:"/";display:inline-block;-webkit-mask-image:url("data:image/svg+xml;charset=utf-8,%3Csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' fill='none'%3E%3Cpath fill-rule='evenodd' clip-rule='evenodd' d='M9.274 3.9H9.3a.6.6 0 0 1 0 1.2c-.85 0-1.451 0-1.922.039-.463.038-.745.11-.968.223A2.4 2.4 0 0 0 5.361 6.41c-.113.223-.184.505-.222.968-.039.47-.04 1.072-.04 1.922v5.4c0 .85.001 1.451.04 1.922.038.463.11.745.222.968a2.4 2.4 0 0 0 1.05 1.048c.222.114.504.185.967.223.47.038 1.072.039 1.922.039h5.4c.85 0 1.451 0 1.921-.039.464-.038.746-.11.969-.223a2.4 2.4 0 0 0 1.048-1.048c.113-.223.185-.505.223-.968.038-.47.039-1.072.039-1.922a.6.6 0 1 1 1.2 0v.026c0 .818 0 1.469-.043 1.993-.044.538-.136.996-.35 1.415a3.6 3.6 0 0 1-1.573 1.574c-.42.213-.878.305-1.415.35-.525.042-1.175.042-1.993.042H9.274c-.818 0-1.469 0-1.993-.043-.538-.044-.996-.136-1.415-.35a3.6 3.6 0 0 1-1.574-1.573c-.213-.42-.305-.877-.35-1.415-.042-.524-.042-1.175-.042-1.993V9.274c0-.818 0-1.468.043-1.993.044-.538.136-.996.35-1.415a3.6 3.6 0 0 1 1.573-1.574c.42-.213.877-.305 1.415-.35C7.805 3.9 8.456 3.9 9.274 3.9Zm3.626.6a.6.6 0 0 1 .6-.6h6a.6.6 0 0 1 .6.6v6a.6.6 0 1 1-1.2 0V5.949l-5.976 5.975a.6.6 0 0 1-.848-.848L18.05 5.1H13.5a.6.6 0 0 1-.6-.6Z' fill='%230E0E0E'/%3E%3C/svg%3E");mask-image:url("data:image/svg+xml;charset=utf-8,%3Csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' fill='none'%3E%3Cpath fill-rule='evenodd' clip-rule='evenodd' d='M9.274 3.9H9.3a.6.6 0 0 1 0 1.2c-.85 0-1.451 0-1.922.039-.463.038-.745.11-.968.223A2.4 2.4 0 0 0 5.361 6.41c-.113.223-.184.505-.222.968-.039.47-.04 1.072-.04 1.922v5.4c0 .85.001 1.451.04 1.922.038.463.11.745.222.968a2.4 2.4 0 0 0 1.05 1.048c.222.114.504.185.967.223.47.038 1.072.039 1.922.039h5.4c.85 0 1.451 0 1.921-.039.464-.038.746-.11.969-.223a2.4 2.4 0 0 0 1.048-1.048c.113-.223.185-.505.223-.968.038-.47.039-1.072.039-1.922a.6.6 0 1 1 1.2 0v.026c0 .818 0 1.469-.043 1.993-.044.538-.136.996-.35 1.415a3.6 3.6 0 0 1-1.573 1.574c-.42.213-.878.305-1.415.35-.525.042-1.175.042-1.993.042H9.274c-.818 0-1.469 0-1.993-.043-.538-.044-.996-.136-1.415-.35a3.6 3.6 0 0 1-1.574-1.573c-.213-.42-.305-.877-.35-1.415-.042-.524-.042-1.175-.042-1.993V9.274c0-.818 0-1.468.043-1.993.044-.538.136-.996.35-1.415a3.6 3.6 0 0 1 1.573-1.574c.42-.213.877-.305 1.415-.35C7.805 3.9 8.456 3.9 9.274 3.9Zm3.626.6a.6.6 0 0 1 .6-.6h6a.6.6 0 0 1 .6.6v6a.6.6 0 1 1-1.2 0V5.949l-5.976 5.975a.6.6 0 0 1-.848-.848L18.05 5.1H13.5a.6.6 0 0 1-.6-.6Z' fill='%230E0E0E'/%3E%3C/svg%3E");-webkit-mask-position:center;mask-position:center;-webkit-mask-repeat:no-repeat;mask-repeat:no-repeat;padding:0 .45em}::slotted(svg){vertical-align:middle}}`;

  /**
   * @cssprop --sgds-{stateColor} - State colors in hexadecimal value
   * @cssprop --sgds-{stateColor}-rgb - State colors in rgb value
   * @cssprop --sgds-{stateColor}-{weights} - State colors with different weightage in hexadecimal value
   * @cssprop --sgds-gray-{weights} - State colors with different weightage in hexadecimal value
   * @cssprop --overlay-background-color - The drawer and modal component overlay background color
   * @cssprop --zindex-modal - The drawer and modal component z-index value
   */
  class SgdsElement extends LitElement {
      /** Emits a custom event with more convenient defaults. */
      emit(name, options) {
          const event = new CustomEvent(name, Object.assign({ bubbles: true, cancelable: false, composed: true, detail: {} }, options));
          this.dispatchEvent(event);
          return event;
      }
      static define(name, elementConstructor = this, options = {}) {
          const currentlyRegisteredConstructor = customElements.get(name);
          if (!currentlyRegisteredConstructor) {
              // We try to register as the actual class first. If for some reason that fails, we fall back to anonymous classes.
              // customElements can only have 1 class of the same "object id" per registry, so that is why the try {} catch {} exists.
              // Some tools like Jest Snapshots and if you import the constructor and call `new SgdsButton()` they will fail with
              //   the anonymous class version.
              try {
                  customElements.define(name, elementConstructor, options);
              }
              catch (_err) {
                  customElements.define(name, class extends elementConstructor {
                  }, options);
              }
              return;
          }
          // let newVersion = ' (unknown version)';
          // let existingVersion = newVersion;
          // if ('version' in elementConstructor && elementConstructor.version) {
          //   newVersion = ' v' + elementConstructor.version;
          // }
          // if ('version' in currentlyRegisteredConstructor && currentlyRegisteredConstructor.version) {
          //   existingVersion = ' v' + currentlyRegisteredConstructor.version;
          // }
          // // Need to make sure we're not working with null or empty strings before doing version comparisons.
          // if (newVersion && existingVersion && newVersion === existingVersion) {
          //   // If versions match, we don't need to warn anyone. Carry on.
          //   return;
          // }
          // console.warn(
          //   `Attempted to register <${name}>${newVersion}, but <${name}>${existingVersion} has already been registered.`
          // );
      }
      constructor() {
          super();
          Object.entries(this.constructor.dependencies).forEach(([name, component]) => {
              this.constructor.define(name, component);
          });
      }
  }
  SgdsElement.styles = [css_248z$1];
  /** @internal */
  SgdsElement.dependencies = {};

  var css_248z = css`:host{display:contents}.tooltip-placeholder{display:inline-block}.tooltip{word-wrap:break-word;display:block;line-break:auto;opacity:0;text-align:left;text-decoration:none;text-shadow:none;text-transform:none;white-space:normal;word-break:normal;word-spacing:normal;z-index:1080}.tooltip.show{opacity:1}.tooltip-inner{background-color:var(--sgds-surface-fixed-dark);border-radius:var(--sgds-border-radius-md);box-shadow:0 0 2px 0 rgba(0,0,0,.12),0 8px 16px 0 rgba(0,0,0,.14);color:var(--sgds-color-fixed-light);font-size:var(--sgds-font-size-1);max-width:var(--sgds-dimension-320);padding:var(--sgds-padding-xs) var(--sgds-padding-sm)}div{max-width:fit-content}`;

  /**
   * @summary Tooltips display more information when users hover over, focus on, or interact with an element.
   * @slot default - The element to target the tooltip to.
   *
   */
  class SgdsTooltip extends SgdsElement {
      constructor() {
          super(...arguments);
          this._myTooltip = createRef();
          this._bsTooltip = null;
          /** The tooltip's content. Content has to be textual */
          this.content = "";
          /** The placement of tooltip relative to its target */
          this.placement = "top";
          /** The method to invoke the tooltip. `hover focus` is the default value which allows tooltip to be triggered via mouse hover and keyboard focus. Add `tabindex=0 `for HTMLelements that are not tabbable. */
          this.trigger = "hover focus";
      }
      _handleSlotChange() {
          // For a11y purpose
          this._tooltipTargetElements.forEach(el => el.setAttribute("data-sgds-tooltip", this.content));
      }
      _handleClickOutOfElement(e, self) {
          if (!e.composedPath().includes(self)) {
              this.hide();
          }
      }
      connectedCallback() {
          super.connectedCallback();
          if (this.trigger === "click") {
              document.addEventListener("click", (event) => this._handleClickOutOfElement(event, this));
              document.addEventListener("touchstart", (event) => this._handleClickOutOfElement(event, this));
          }
      }
      disconnectedCallback() {
          super.disconnectedCallback();
          document.removeEventListener("click", (event) => this._handleClickOutOfElement(event, this));
          document.removeEventListener("touchstart", (event) => this._handleClickOutOfElement(event, this));
      }
      _initializeTooltip() {
          this.tooltipConfig = {
              popperConfig: (defaultConfig) => {
                  this.popperConfig = defaultConfig;
                  const defaultModifiers = defaultConfig.modifiers;
                  const newModifiers = defaultModifiers.map(mod => {
                      if (mod.name === "flip") {
                          mod.options.fallbackPlacements = [];
                      }
                      return mod;
                  });
                  this.popperConfig.modifiers = newModifiers;
                  return this.popperConfig;
              },
              placement: this.placement,
              trigger: this.trigger,
              title: this.content,
              html: true,
              container: this.shadowRoot.querySelector("div") // tooltip to appear inside the shadow root of sgds-tooltip instead of anywhere in the DOM, so that scoped styles can apply
          };
          this._bsTooltip = new Tooltip(this._myTooltip.value, this.tooltipConfig);
      }
      firstUpdated() {
          this._initializeTooltip();
          this._myTooltip.value.addEventListener("show.bs.tooltip", () => {
              this.emit("sgds-show");
          });
          this._myTooltip.value.addEventListener("shown.bs.tooltip", () => {
              this.emit("sgds-after-show");
          });
          this._myTooltip.value.addEventListener("hide.bs.tooltip", () => {
              this.emit("sgds-hide");
          });
          this._myTooltip.value.addEventListener("hidden.bs.tooltip", () => {
              this.emit("sgds-after-hide");
          });
      }
      /** Hides the Tooltip */
      hide() {
          this._bsTooltip.hide();
      }
      /** Shows the Tooltip */
      show() {
          this._bsTooltip.show();
      }
      render() {
          return html `
      <div ${ref(this._myTooltip)} class="tooltip-placeholder">
        <slot @slotchange=${this._handleSlotChange}></slot>
      </div>
    `;
      }
  }
  SgdsTooltip.styles = [...SgdsElement.styles, css_248z];
  __decorate([
      property({ type: String })
  ], SgdsTooltip.prototype, "content", void 0);
  __decorate([
      property({ type: String })
  ], SgdsTooltip.prototype, "placement", void 0);
  __decorate([
      property({ type: String })
  ], SgdsTooltip.prototype, "trigger", void 0);
  __decorate([
      state()
  ], SgdsTooltip.prototype, "popperConfig", void 0);
  __decorate([
      queryAssignedElements()
  ], SgdsTooltip.prototype, "_tooltipTargetElements", void 0);

  /**
   *
   * @param name tagname of custom element
   * @returns boolean
   */
  function register(name, constructor) {
      if (!customElements.get(name)) {
          customElements.define(name, constructor);
      }
  }

  register("sgds-tooltip", SgdsTooltip);

}));
//# sourceMappingURL=index.umd.js.map
